<?php
// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/*---------------------------------
	 Plugins Check
------------------------------------*/

add_action( 'admin_init', 'kite_check_plugins' );
function kite_check_plugins() {
	$plugins = array(
		'WOOCS' => array( 'woocommerce-currency-switcher/index.php', 'WooCommerce Currency Switcher' ),
	);
	foreach ( $plugins as $key => $value ) {
		if ( class_exists( $key ) && ! kite_woocommerce_installed() ) {
			deactivate_plugins( $value[0] );
			wp_die( 'To Active ' . $value[1] . ' plugin , Woocommerce plugin needed' );
		}
	}
}


/* -------------------------------------------------------------------------- */
/*                  Add  featured image column in admin panel                 */
/* -------------------------------------------------------------------------- */

if ( ! function_exists( 'kite_add_post_thumbnail_column' ) ) {
	function kite_add_post_thumbnail_column( $cols ) {
		$cols['kite_post_thumb'] = esc_html__( 'Featured', 'pinkmart' );
		return $cols;
	}
}
add_filter( 'manage_posts_columns', 'kite_add_post_thumbnail_column', 5 ); // Add the posts columns filter.
add_filter( 'manage_pages_columns', 'kite_add_post_thumbnail_column', 5 ); // Add the pages columns filter.

/* -------------------------------------------------------------------------- */
/*                Hook into the posts an pages column managing.               */
/* -------------------------------------------------------------------------- */

if ( ! function_exists( 'kite_display_post_thumbnail_column' ) ) {
	function kite_display_post_thumbnail_column( $col, $id ) {
		switch ( $col ) {
			case 'kite_post_thumb':
				if ( function_exists( 'the_post_thumbnail' ) ) {

					echo the_post_thumbnail( 'admin-list-thumb' );

				} else {
					echo esc_html__( 'Not supported in theme', 'pinkmart' );
				}
				break;
		}
	}
}
add_action( 'manage_posts_custom_column', 'kite_display_post_thumbnail_column', 5, 2 );
add_action( 'manage_pages_custom_column', 'kite_display_post_thumbnail_column', 5, 2 );

/* -------------------------------------------------------------------------- */
/*                  Custom Excerpt for posts + no format box                  */
/* -------------------------------------------------------------------------- */

if ( ! function_exists( 'kite_default_hidden_meta_boxes' ) ) {
	function kite_default_hidden_meta_boxes( $hidden, $screen ) {
		// Grab the current post type
		$post_type = $screen->post_type;
		// If we're on a 'post'...
		if ( $post_type == 'post' ) {
			// Define which meta boxes we wish to hide
			$hidden = array(
				'trackbacksdiv',
				'slugdiv',
				'revisionsdiv',
				'postcustom',
				'commentstatusdiv',
				'authordiv',
				'formatdiv',
			);
			// Pass our new defaults onto WordPress
			return $hidden;
		}
		// If we are not on a 'post', pass the
		// original defaults, as defined by WordPress
		return $hidden;
	}
}
add_action( 'default_hidden_meta_boxes', 'kite_default_hidden_meta_boxes', 10, 2 );

//
// ─── KITE FUNCTION TO Show Activate Core Plugins Notice ──────────────────────────────────────
//
add_action( 'admin_notices', 'kite_install_required_plugins');
function kite_install_required_plugins() {
	$tgmpa = call_user_func( array( get_class( $GLOBALS['tgmpa'] ), 'get_instance' ) );
	$check_plugins[] = 'kitestudio-core';
	$check_plugins[] = 'kt-pro-tools';
	foreach( $check_plugins as $key => $slug ) {
		if ( ! $tgmpa->is_plugin_installed( $slug ) ) {
			$plugins[ $slug ] = 'install';
		}
		if ( $tgmpa->can_plugin_activate( $slug ) ) {
			$plugins[ $slug ] = 'activate';
		}
	}
	if ( empty( $plugins ) ) {
		return;
	}
	?>
	<div class="notice notice-info kt-theme-notice">
		<p> <?php echo sprintf( __( 'Thanks for choosing %1$s%2$s%3$s', 'pinkmart' ), '<strong>', KITEST_THEME_MAIN_NAME, '</strong>' );?></p>
		<p><?php echo sprintf( __( 'To take full advantages of %1$s theme and enabling demo importer, %2$splease install core plugins.%3$s', 'pinkmart' ), KITEST_THEME_MAIN_NAME, '<strong>', '</strong>' );?></p>
		<ul class="kt-plugins-form" data-redirect="<?php echo admin_url('admin.php?page=pinkmart-dashboard');?>">
		<?php 
		foreach( $plugins as $slug => $action ) {
			?>
				<li data-slug="<?php echo esc_attr( $slug ); ?>" class="plugin-to-install">
					<?php
					if ( $action == 'install' ) {
						$actions = array(
							'install'   => 'install',
							'update'    => '',
							'activate'  => ''
						);
					} else {
						$actions = array(
							'install'   => '',
							'update'    => '',
							'activate'  => 'activate'
						);
					}
					?>
					<input 
						type="checkbox" 
						name="plugin-import[<?php echo esc_attr( $slug ); ?>]" 
						id="plugin-import[<?php echo esc_attr( $slug ); ?>]" 
						checked="checked" 
						disabled="disabled"
						data-actions="<?php echo esc_attr( json_encode( $actions ) );?>"
						data-slug="<?php echo esc_attr( $slug );?>"
						data-wpnonce="<?php echo wp_create_nonce( 'bulk-plugins' ); ?>"
					/>
				</li>
			<?php
		}
		?>
		</ul>
		<a href="#" class='button button-large kt-install-core-plugins'>Install Core Plugins</a>
	</div>
	<?php
}

?>