<?php

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/* -------------------------------------------------------------------------- */
/*                   Add NEXT/PREV item in portfolio detail                   */
/* -------------------------------------------------------------------------- */
if ( ! function_exists( 'kite_load_portfolio_detail_navigation' ) ) {
	function kite_load_portfolio_detail_navigation() {
		$skill_ids;
		$back_url;
		$id;

		// check to see if the submitted nonce matches with the generated nonce we created earlier
		check_ajax_referer( 'ajax-nonce', 'security' );

		if ( isset( $_REQUEST ) ) {

			$id        = wp_filter_nohtml_kses( $_REQUEST['pid'] );
			$skill_ids = explode( ' ', wp_filter_nohtml_kses( $_REQUEST['skill_ids'] ) );
			$back_url  = wp_filter_nohtml_kses( $_REQUEST['back_url'] );

			if ( $skill_ids[0] == 'all' ) {
				$tax_query = array();
			} else {
				$tax_query = array(
					array(
						'taxonomy' => 'skills',
						'field'    => 'id',
						'terms'    => $skill_ids,
					),
				);
			}
			$args = array(
				'fields'         => 'ids', // we don't really need all post data so just id wil do fine.
				'posts_per_page' => -1, // -1 to get all post
				'post_type'      => 'portfolio',
				'tax_query'      => $tax_query,
			);

			$post_ids = get_posts( $args );

			$thisindex = array_search( $id, $post_ids );

			if ( $thisindex == 0 ) {
				$previd = '';
			} else {
				$previd = $post_ids[ $thisindex - 1 ];
			}

			if ( $thisindex == count( $post_ids ) - 1 ) {
				$nextid = '';
			} else {
				$nextid = $post_ids[ $thisindex + 1 ];
			}

			?>
			<div class="container">
				<div class="row "> 
					<div class="span2"></div>
					<div class="span8 nav_box">

						<!-- Prev Arrows -->
						<?php
						if ( ! empty( $previd ) ) :
							$thumb      = wp_get_attachment_image_src( get_post_thumbnail_id( $previd ), medium_large );
							$checkTitle = get_post_meta( $previd, 'title-bar', true );
							$title      = get_post_meta( $previd, 'title-text', true );
							if ( ( $checkTitle == 0 ) || empty( $title ) ) {
								$title = get_the_title( $previd );
							}
							?>
							   
							<a href="<?php echo esc_url( get_permalink( $previd ) ); ?> " title="<?php esc_attr_e( 'PREV', 'pinkmart' ); ?>" class="prevPD portfolioDetailNavLink" data-pid="<?php echo esc_attr( $previd ); ?>" data-skills="<?php echo esc_attr( implode( ' ', $skill_ids ) ); ?>">
								<div class="prevnav">
									<div class="bg" style="background-image:url(<?php echo esc_url( $thumb[0] ); ?>);background-color:#ddd;"></div>
									<span class="posttitle"><?php echo esc_html( $title ); ?></span>
								</div>
							</a>

						<?php endif; ?>


						<!-- Back to portfolio -->
						<a id="pdbacktoportfolio" href="<?php echo esc_url( $back_url ); ?>" title="<?php esc_attr_e( 'Back to portfolio', 'pinkmart' ); ?>" class="
																   <?php
																	if ( empty( $previd ) ) {
																		echo 'noPrev'; }
																	?>
						 <?php
							if ( empty( $nextid ) ) {
														echo 'nonext'; }
							?>
">
								<span class="icon-icons2" data-name="grid2"></span>
						</a>

						<!-- Next Arrows -->
						<?php

						if ( ! empty( $nextid ) ) :
							$thumb      = wp_get_attachment_image_src( get_post_thumbnail_id( $nextid ), medium_large );
							$checkTitle = get_post_meta( $nextid, 'title-bar', true );
							$title      = get_post_meta( $nextid, 'title-text', true );
							if ( ( $checkTitle == 0 ) || empty( $title ) ) {
								$title = get_the_title( $nextid );
							}

							?>
							<a href="<?php echo esc_url( get_permalink( $nextid ) ); ?>" title="<?php esc_attr_e( 'NEXT', 'pinkmart' ); ?>"  class="nextpd portfolioDetailNavLink" data-pid="<?php echo esc_attr( $nextid ); ?>" data-skills="<?php echo esc_attr( implode( ' ', $skill_ids ) ); ?>">
								<div class="nextnav">
									<div class="bg" style="background-image:url(<?php echo esc_url( $thumb[0] ); ?>);background-color:#ddd;"></div>
									<span class="posttitle"><?php echo esc_html( $title ); ?></span>
								</div>
							</a>
						<?php endif; ?>
					</div>
				</div>
			</div>
			<?php
		}
		die();
	}
}
add_action( 'wp_ajax_load_pd_navigation', 'kite_load_portfolio_detail_navigation' );
add_action( 'wp_ajax_nopriv_load_pd_navigation', 'kite_load_portfolio_detail_navigation' );

/* -------------------------------------------------------------------------- */
/*                   Add NEXT/PREV item in portfolio detail                   */
/* -------------------------------------------------------------------------- */
if ( ! function_exists( 'kite_load_creative_portfolio_detail_navigation' ) ) {
	function kite_load_creative_portfolio_detail_navigation() {
		$skill_ids;
		$back_url;
		$id;

		// check to see if the submitted nonce matches with the generated nonce we created earlier
		check_ajax_referer( 'ajax-nonce', 'security' );

		if ( isset( $_REQUEST ) ) {
			$id        = wp_filter_nohtml_kses( $_REQUEST['pid'] );
			$skill_ids = explode( ' ', wp_filter_nohtml_kses( $_REQUEST['skill_ids'] ) );
			$back_url  = wp_filter_nohtml_kses( $_REQUEST['back_url'] );

			if ( $skill_ids[0] == 'all' ) {
				$tax_query = array();
			} else {
				$tax_query = array(
					array(
						'taxonomy' => 'skills',
						'field'    => 'id',
						'terms'    => $skill_ids,
					),
				);
			}

			$args = array(
				'fields'         => 'ids', // we don't really need all post data so just id wil do fine.
				'posts_per_page' => -1, // -1 to get all post
				'post_type'      => 'portfolio',
				'tax_query'      => $tax_query,
			);

			$post_ids = get_posts( $args );

			$thisindex = array_search( $id, $post_ids );

			if ( $thisindex == 0 ) {
				$previd = '';
			} else {
				$previd = $post_ids[ $thisindex - 1 ];
			}

			if ( $thisindex == count( $post_ids ) - 1 ) {
				$nextid = '';
			} else {
				$nextid = $post_ids[ $thisindex + 1 ];
			}
			?>

			<!-- Next Arrows -->
			<?php

			if ( ! empty( $nextid ) ) :
				?>
				<a href="<?php echo esc_url( get_permalink( $nextid ) ); ?>" title="<?php esc_attr_e( 'NEXT', 'pinkmart' ); ?>"  class="portfolioDetailNavLink" data-pid="<?php echo esc_attr( $nextid ); ?>" data-skills="<?php echo esc_attr( implode( ' ', $skill_ids ) ); ?>">
					<div class="arrows-button-next no-select">
						<span class="text">
							<?php esc_html_e( 'NEXT', 'pinkmart' ); ?>
						</span>
					</div>
				</a>
			<?php endif; ?>

			<!-- Back to portfolio -->
			<a id="pdbacktoportfolio" href="<?php echo esc_url( $back_url ); ?>" title="<?php esc_attr_e( 'Back to portfolio', 'pinkmart' ); ?>" class="
													   <?php
														if ( empty( $nextid ) ) {
															echo 'nonext'; }
														?>
			">
				<div>
					<span class="backToPortfolio" data-name="grid2"></span>
				</div>
			</a>

			<!-- Prev Arrows -->
			<?php
			if ( ! empty( $previd ) ) :
				?>

				<a href="<?php echo esc_url( get_permalink( $previd ) ); ?>" title="<?php esc_attr_e( 'PREV', 'pinkmart' ); ?>" class="portfolioDetailNavLink" data-pid="<?php echo esc_attr( $previd ); ?>" data-skills="<?php echo esc_attr( implode( ' ', $skill_ids ) ); ?>">
					<div class="arrows-button-prev no-select">
						<span class="text">
							<?php esc_html_e( 'PREV', 'pinkmart' ); ?>
						</span>
					</div>
				</a>

				<?php
			endif;
		}
		die();
	}
}
add_action( 'wp_ajax_load_cpd_navigation', 'kite_load_creative_portfolio_detail_navigation' );
add_action( 'wp_ajax_nopriv_load_cpd_navigation', 'kite_load_creative_portfolio_detail_navigation' );

//
// ─── INSTAGRAM AJAX FUNCTIONALITY ───────────────────────────────────────────────
//
function kite_instagram_generate_dom() {

	$insta_data = $_POST['insta_data'];
	$insta_html = $_POST['insta_html'];
	if ( empty( $insta_html ) ) {
		die();
	}
	$instagram = kite_instagram_decode( $insta_html, true, $insta_data['hashtag'] );
	if ( is_wp_error( $instagram ) ) {
		die();
	}
	$i                   = 1;
	$transient_name      = 'instagram-media-new-' . sanitize_title_with_dashes( $insta_data['username'] );
	$instagram_serialize = maybe_serialize( $instagram );
	set_transient( $transient_name, $instagram_serialize, apply_filters( 'null_instagram_cache_time', DAY_IN_SECONDS * 2 ) );
	foreach ( $instagram as $item ) {

		if ( $i > $insta_data['image_num'] ) {
			break;
		}
		$i++;

		if ( $insta_data['resolution'] == 'low_resolution' || $insta_data['resolution'] == 'low_resolution_crop' || $insta_data['resolution'] == 'standard_resolution' || $insta_data['image_resolution'] == 'standard_resolution_crop' ) {
			$image = $item['large'];
		} else {
			$image = $item[ $insta_data['resolution'] ];
		}

		$media_tag = "<img src=\"data:image/gif;base64,R0lGODlhAQABAAAAACH5BAEKAAEALAAAAAABAAEAAAICTAEAOw==\" class=\"media\" data-src=\"{$image}\" />";

		$content  = '<div class="instagram-img ' . esc_attr( $insta_data['carousel'] ) . ' " >';
		$content .= '<a  href="' . esc_url( $item['link'] ) . '" target="_blank">';

		$content .= '<img src="' . esc_url( $image ) . '" alt="instagram_feed"/>';

		$content .= '<div class="hover"></div>
                <div class="content">';

		if ( $insta_data['like'] == 'enable' ) {
			$content .= '<span class="like">' . kite_pretty_number( $item['likes'] ) . '</span>';
		}

		if ( $insta_data['comment'] == 'enable' ) {
			$content .= '<span class="comment">' . kite_pretty_number( $item['comments'] ) . '</span>';
		}

		$content .= '</div>';

		// output media
		echo '' . $content . '</a></div>';

	}
	die();
}
add_action( 'wp_ajax_kite-instagram-generate-dom', 'kite_instagram_generate_dom' );
add_action( 'wp_ajax_nopriv_kite-instagram-generate-dom', 'kite_instagram_generate_dom' );

/*-----------------------------------------------------------------*/
// Ajaxed Search
/*-----------------------------------------------------------------*/
if ( ! function_exists( 'kite_ajax_search' ) ) {
	function kite_ajax_search() {
		$search_post_type = kite_opt( 'search_post_type' );

		if ( ! $search_post_type && kite_woocommerce_installed() ) { // set on product when update theme
			$search_post_type = 'product';
		}
		$s   = strtolower( trim( sanitize_text_field( $_GET['s'] ) ) );
		$cat = trim( sanitize_text_field( $_GET['cat'] ) );
		$results = [];
		if ( kite_opt( 'show_tags_in_search_result', false ) ) {
			$terms = 'product' == $search_post_type ? get_terms( array( 'taxonomy' => 'product_tag' ) ) : get_terms( array( 'taxonomy' => 'post_tag' ) );
			$found_terms = [];

			if ( ! is_wp_error( $terms ) && !empty( $terms ) ) {
				foreach ( $terms as $term ) {
					if ( strpos( strtolower( $term->name ), $s ) || strpos( strtolower( $term->name ), $s ) === 0 ) {
						$found_terms[] = $term;
					}
				}
			}

			if ( ! empty( $found_terms ) ) {
				$results[] = "<h6>" . __( 'Keywords', 'pinkmart' ) . "</h6>";
				$results[] = "<div class='kt-tags'>";
				foreach( $found_terms as $term ) {
					$results[] = sprintf( '<div class="searchitem kt-tag"><a href="%s">%s</a></div>', get_tag_link( $term->term_id ), $term->name );
				}
				$results[] = '</div>';
			}
		}

		if ( kite_opt( 'show_cats_list_in_search_result', false ) ) {
			$terms = 'product' == $search_post_type ? get_terms( array( 'taxonomy' => 'product_cat' ) ) : get_terms( array( 'taxonomy' => 'category' ) );
			$found_terms = [];

			if ( ! is_wp_error( $terms ) && !empty( $terms ) ) {
				foreach ( $terms as $term ) {
					if ( strpos( strtolower( $term->name ), $s ) || strpos( strtolower( $term->name ), $s ) === 0 ) {
						$found_terms[] = $term;
					}
				}
			}

			if ( ! empty( $found_terms ) ) {
				$results[] = "<h6>" . __( 'Categories', 'pinkmart' ) . "</h6>";
				$results[] = '<div class="kt-cats">';
				foreach( $found_terms as $term ) {
					$parent = $term->parent ? get_term( $term->parent ) : '';
					if ( ! empty( $parent ) ) {
						$results[] = sprintf( '<div class="searchitem kt-cat"><a href="%s">%s</a>%s%s</div>', get_category_link( $term->term_id ), $term->name, __( ' in ', 'pinkmart' ), $parent->name );
					} else {
						$results[] = sprintf( '<div class="searchitem kt-cat"><a href="%s">%s</a></div>', get_category_link( $term->term_id ), $term->name );
					}
					$results[] = "<hr>";
				}
				$results[] = '</div>';
			}
		}
		if ( $cat == 'all' ) {
			$args = array(
				's'              => $s,
				'post_type'      => $search_post_type,
				'posts_per_page' => 20,
				'no_found_rows'  => 1,
			);
		} else {
			if ( $search_post_type == 'product' ) {
				$args = array(
					's'              => $s,
					'post_type'      => $search_post_type,
					'posts_per_page' => 20,
					'no_found_rows'  => 1,
					'product_cat'    => $cat,
				);
			} else {
				$args = array(
					's'              => $s,
					'post_type'      => $search_post_type,
					'posts_per_page' => 20,
					'no_found_rows'  => 1,
					'category_name'  => $cat,
				);
			}
		}
		global $post;
		$posts        = get_posts( $args );
		$products_Sku = array();
		if ( $search_post_type == 'product' ) {
			$args_sku            = array(
				'post_type'        => 'product',
				'posts_per_page'   => 20,
				'meta_query'       => array(
					array(
						'key'     => '_sku',
						'value'   => $s,
						'compare' => 'like',
					),
				),
				'suppress_filters' => 0,
			);
			$products_sku        = get_posts( $args_sku );
			$args_variations_sku = array(
				'post_type'        => 'product_variation',
				'posts_per_page'   => 20,
				'meta_query'       => array(
					array(
						'key'     => '_sku',
						'value'   => $s,
						'compare' => 'like',
					),
				),
				'suppress_filters' => 0,
			);
			$AllSearchResults    = array_merge( $posts, $products_sku );
			$products_id         = array();
			foreach ( $AllSearchResults as $key => $product ) {
				$id = $product->ID;
				if ( in_array( $id, $products_id ) ) {
					unset( $AllSearchResults[ $key ] );
				} else {
					$products_id[] = $id;
				}
			}
		}
		if ( $search_post_type != 'product' ) {
			$AllSearchResults = $posts;
		}
		if ( count( $AllSearchResults ) > 0 ) {
			$items = 'product' == $search_post_type ? __( 'Products', 'pinkmart' ) : __( 'Posts', 'pinkmart' );
			$results[] = "<h6>$items</h6>";
			$columns = kite_opt( 'search_result_columns', false ) ? '' : 'columns-2';
			$results[] = '<div class="kt-items ' . $columns . '">';
			if ( $search_post_type == 'product' ) {
				add_filter( 'woocommerce_format_price_range', 'kite_format_price_range', 1, 3 );
				foreach ( $AllSearchResults as $post ) :
					setup_postdata( $post );
					$product   = wc_get_product( get_the_ID() );
					$main_cat = kite_get_post_primary_category( get_the_ID(), 'product_cat' )['primary_category'];
					$results[] = sprintf( '<div class="searchitem"><a href="%s" class="Link">%s<span class="searchitemdesc"><span class="itemdesc">%s</span><span class="kt-cat">%s</span> %s</span></a></div>', get_permalink(), ( ( has_post_thumbnail() ) ? woocommerce_get_product_thumbnail( 'shop_thumbnail' ) : '' ), $product->get_title(), $main_cat->name, $product->get_price_html() );
				endforeach;
				remove_filter( 'woocommerce_format_price_range', 'kite_format_price_range', 1, 3 );
			} else {
				foreach ( $AllSearchResults as $post ) :
					setup_postdata( $post );
					$main_cat = kite_get_post_primary_category( get_the_ID(), 'product_cat' )['primary_category'];
					$results[] = sprintf( '<div class="searchitem"><a href="%s" class="Link">%s<span class="searchitemdesc">%s</span></a></div>', get_permalink(), ( ( '' == $featured_image = get_the_post_thumbnail() ) ? '' : '<div class="imageswrap">' . $featured_image . '</div>' ), get_the_title() );
				endforeach;
			}
			$results[] = '</div>';
			$result = implode( $results );
			echo '' . $result;
		} else {
			echo "<div class='emptyresult'>" . esc_html__( 'Nothing Found For : ', 'pinkmart' ) . '</div>';
		}
		wp_reset_postdata();
		die();
	}
}

add_action( 'wp_ajax_kite_ajax_search_action', 'kite_ajax_search' );
add_action( 'wp_ajax_nopriv_kite_ajax_search_action', 'kite_ajax_search' );

function kite_format_price_range( $price, $from, $to ) {
	$price = sprintf( _x( '%1$s %2$s', 'Price range: from-to', 'woocommerce' ), is_numeric( $from ) ? wc_price( $from ) : $from, is_numeric( $to ) ? wc_price( $to ) : $to );
	return $price;
}