<?php
/**
 * Elementor Banner Widget.
 *
 * @since 1.0.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

class Kite_Banner_Widget extends \Elementor\Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve Banner widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'kite-banner';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Banner widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Banner', 'pinkmart' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Banner widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-info-box kite-element-icon';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Animated Text widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array( 'by-kite' );
	}

	/**
	 * Register Animated Text widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function _register_controls() {

		$this->start_controls_section(
			'content_section',
			array(
				'label' => esc_html__( 'Banner', 'pinkmart' ),
				'tab'   => \Elementor\Controls_Manager::TAB_CONTENT,
			)
		);
		$this->add_control(
			'image_url',
			array(
				'label'   => esc_html__( 'Image URL', 'pinkmart' ),
				'type'    => \Elementor\Controls_Manager::MEDIA,
				'default' => array(
					'url' => \Elementor\Utils::get_placeholder_image_src(),
				),
			)
		);
		$this->add_control(
			'image_size',
			array(
				'label'   => esc_html__( 'Image Size', 'pinkmart' ),
				'type'    => \Elementor\Controls_Manager::SELECT,
				'options' => array(
					'full'      => esc_html__( 'Full', 'pinkmart' ),
					'medium'    => esc_html__( 'Medium', 'pinkmart' ),
					'thumbnail' => esc_html__( 'Thumbnail', 'pinkmart' ),
					'custom'    => esc_html__( 'Custom', 'pinkmart' ),
				),
				'default' => 'full',
			)
		);
		$this->add_control(
			'image_size_width',
			array(
				'label'       => esc_html__( 'Image Size Width', 'pinkmart' ),
				'label_block' => false,
				'type'        => \Elementor\Controls_Manager::TEXT,
				'condition'   => array(
					'image_size' => 'custom',
				),
			)
		);

		$this->add_control(
			'image_size_height',
			array(
				'label'       => esc_html__( 'Image Size Height', 'pinkmart' ),
				'label_block' => false,
				'type'        => \Elementor\Controls_Manager::TEXT,
				'condition'   => array(
					'image_size' => 'custom',
				),
			)
		);

		$this->add_control(
			'image_size_crop',
			array(
				'label'        => esc_html__( 'Crop Image', 'pinkmart' ),
				'type'         => \Elementor\Controls_Manager::SWITCHER,
				'label_on'     => esc_html__( 'Yes', 'pinkmart' ),
				'label_off'    => esc_html__( 'No', 'pinkmart' ),
				'return_value' => 'yes',
				'default'      => 'yes',
				'condition'    => array(
					'image_size' => 'custom',
				),
			)
		);
		$this->add_control(
			'heading',
			array(
				'label' => esc_html__( 'Heading', 'pinkmart' ),
				'type'  => \Elementor\Controls_Manager::TEXTAREA,
			)
		);
		$this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			array(
				'name'     => 'heading_typography',
				'label'    => esc_html__( 'Heading Typography', 'pinkmart' ),
				'scheme'   => \Elementor\Scheme_Typography::TYPOGRAPHY_1,
				'selector' => '{{WRAPPER}} .content .heading',
			)
		);
		$this->add_control(
			'heading_color',
			array(
				'label'     => esc_html__( 'Heading Color', 'pinkmart' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				'default'   => '',
				'selectors' => array(
					'{{WRAPPER}} .content .heading' => 'color:{{VALUE}}',
				),
			)
		);
		$this->add_control(
			'title',
			array(
				'label' => esc_html__( 'Title', 'pinkmart' ),
				'type'  => \Elementor\Controls_Manager::TEXTAREA,
			)
		);
		$this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			array(
				'name'     => 'title_typography',
				'label'    => esc_html__( 'Title Typography', 'pinkmart' ),
				'scheme'   => \Elementor\Scheme_Typography::TYPOGRAPHY_1,
				'selector' => '{{WRAPPER}} .content .title',
			)
		);
		$this->add_control(
			'title_color',
			array(
				'label'     => esc_html__( 'Title Color', 'pinkmart' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				'default'   => '',
				'selectors' => array(
					'{{WRAPPER}} .content .title' => 'color:{{VALUE}}',
				),
			)
		);
		$this->add_control(
			'subtitle',
			array(
				'label' => esc_html__( 'Subtitle', 'pinkmart' ),
				'type'  => \Elementor\Controls_Manager::TEXTAREA,
			)
		);
		$this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			array(
				'name'     => 'subtitle_typography',
				'label'    => esc_html__( 'Subtitle Typography', 'pinkmart' ),
				'scheme'   => \Elementor\Scheme_Typography::TYPOGRAPHY_1,
				'selector' => '{{WRAPPER}} .content .subtitle',
			)
		);
		$this->add_control(
			'subtitle_color',
			array(
				'label'     => esc_html__( 'Subtitle Color', 'pinkmart' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				'default'   => '',
				'selectors' => array(
					'{{WRAPPER}} .content .subtitle' => 'color:{{VALUE}}',
				),
			)
		);
		$this->add_control(
			'badge',
			array(
				'label'        => esc_html__( 'Badge', 'pinkmart' ),
				'type'         => \Elementor\Controls_Manager::SWITCHER,
				'label_on'     => esc_html__( 'Enable', 'pinkmart' ),
				'label_off'    => esc_html__( 'Disable', 'pinkmart' ),
				'return_value' => 'enable',
				'default'      => '',
			)
		);
		$this->add_control(
			'badge_position',
			array(
				'label'     => esc_html__( 'Badge Position', 'pinkmart' ),
				'type'      => \Elementor\Controls_Manager::SELECT,
				'options'   => array(
					'top left'     => esc_html__( 'Top Left', 'pinkmart' ),
					'top right'    => esc_html__( 'Top Right', 'pinkmart' ),
					'bottom left'  => esc_html__( 'Bottom Left', 'pinkmart' ),
					'bottom right' => esc_html__( 'Bottom Right', 'pinkmart' ),
				),
				'default'   => 'top left',
				'condition' => array(
					'badge' => 'enable',
				),
			)
		);
		$this->add_control(
			'badge_bg_color',
			array(
				'label'     => esc_html__( 'Badge Background Color', 'pinkmart' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				'default'   => '',
				'condition' => array(
					'badge' => 'enable',
				),
			)
		);
		$this->add_control(
			'badge_content',
			array(
				'label'     => esc_html__( 'Badge Content', 'pinkmart' ),
				'type'      => \Elementor\Controls_Manager::TEXTAREA,
				'condition' => array(
					'badge' => 'enable',
				),
			)
		);
		$this->add_control(
			'badge_content_color',
			array(
				'label'     => esc_html__( 'Badge Content Color', 'pinkmart' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				'default'   => '',
				'condition' => array(
					'badge' => 'enable',
				),
			)
		);
		$this->add_control(
			'alignment',
			array(
				'label'   => esc_html__( 'Content Position', 'pinkmart' ),
				'type'    => \Elementor\Controls_Manager::SELECT,
				'options' => array(
					'top_left'      => esc_html__( 'Top Left', 'pinkmart' ),
					'top_center'    => esc_html__( 'Top Center', 'pinkmart' ),
					'top_right'     => esc_html__( 'Top Right', 'pinkmart' ),
					'center_center' => esc_html__( 'Center Center', 'pinkmart' ),
					'center_left'   => esc_html__( 'Center Left', 'pinkmart' ),
					'center_right'  => esc_html__( 'Center Right', 'pinkmart' ),
					'bottom_left'   => esc_html__( 'Bottom Left', 'pinkmart' ),
					'bottom_center' => esc_html__( 'Bottom Center', 'pinkmart' ),
					'bottom_right'  => esc_html__( 'Bottom Right', 'pinkmart' ),
				),
				'default' => 'top_left',
			)
		);
		$this->add_responsive_control(
			'margin',
			array(
				'label'      => esc_html__( 'Content Margin', 'pinkmart' ),
				'type'       => \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => array( 'px', '%', 'em' ),
				'selectors'  => array(
					'{{WRAPPER}} .banner .content' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				),
			)
		);
		$this->add_control(
			'hover',
			array(
				'label'        => esc_html__( 'Hover', 'pinkmart' ),
				'type'         => \Elementor\Controls_Manager::SWITCHER,
				'label_on'     => esc_html__( 'Enable', 'pinkmart' ),
				'label_off'    => esc_html__( 'Disable', 'pinkmart' ),
				'return_value' => 'enable',
				'default'      => 'enable',
			)
		);
		$this->add_control(
			'hover_color',
			array(
				'label'     => esc_html__( 'Hover Color', 'pinkmart' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				'default'   => '',
				'selectors' => array(
					'{{WRAPPER}} .banner:hover .hover' => 'background-color: {{VALUE}}',
				),
				'condition' => array(
					'hover' => 'enable',
				),
			)
		);
		$this->add_control(
			'hover_zoom',
			array(
				'label'        => esc_html__( 'Hover Zoom Animation', 'pinkmart' ),
				'type'         => \Elementor\Controls_Manager::SWITCHER,
				'label_on'     => esc_html__( 'Enable', 'pinkmart' ),
				'label_off'    => esc_html__( 'Disable', 'pinkmart' ),
				'return_value' => 'enable',
				'default'      => 'disable',
				'condition'    => array(
					'hover' => 'enable',
				),
			)
		);
		$this->add_control(
			'url',
			array(
				'label'       => esc_html__( 'Link', 'pinkmart' ),
				'label_block' => true,
				'type'        => \Elementor\Controls_Manager::URL,
				'description' => esc_html__( 'Optional URL to another web page.', 'pinkmart' ),
			)
		);
		$this->add_control(
			'url_title',
			array(
				'label'       => esc_html__( 'Link Title', 'pinkmart' ),
				'label_block' => true,
				'type'        => \Elementor\Controls_Manager::TEXT,
				'description' => esc_html__( 'Optional URL to another web page.', 'pinkmart' ),
			)
		);
		$this->add_control(
			'link_color',
			array(
				'label'     => esc_html__( 'Link Color', 'pinkmart' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				'default'   => '',
				'selectors' => array(
					'{{WRAPPER}} .banner a span,{{WRAPPER}} .banner a.link span:after' => 'color:{{VALUE}}',
				),
			)
		);
		$this->add_control(
			'button_style',
			array(
				'label'   => esc_html__( 'Button Style', 'pinkmart' ),
				'type'    => \Elementor\Controls_Manager::SELECT,
				'options' => array(
					'link' => esc_html__( 'Link Style', 'pinkmart' ),
					'fill' => esc_html__( 'Button Fill Style', 'pinkmart' ),
				),
				'default' => 'link',
			)
		);
		$this->add_control(
			'link_bg_color',
			array(
				'label'     => esc_html__( 'Link Background Color', 'pinkmart' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				'default'   => '',
				'condition' => array(
					'button_style' => 'fill',
				),
				'selectors' => array(
					'{{WRAPPER}} .banner a.fill' => 'background-color:{{VALUE}}',
				),
			)
		);
		$this->add_control(
			'link_bg_hover_color',
			array(
				'label'     => esc_html__( 'Link Background Hover Color', 'pinkmart' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				'default'   => '',
				'condition' => array(
					'button_style' => 'fill',
				),
				'selectors' => array(
					'{{WRAPPER}} .banner a.fill:hover' => 'background-color:{{VALUE}} !important;border-color: {{VALUE}} !important',
				),
			)
		);
		$this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			array(
				'name'      => 'link_typography',
				'label'     => __( 'Link Typography', 'pinkmart' ),
				'scheme'    => \Elementor\Scheme_Typography::TYPOGRAPHY_1,
				'selector'  => '{{WRAPPER}} a',
				'condition' => array(
					'button_style' => 'link',
				),
			)
		);
		$this->add_control(
			'show_button',
			array(
				'label'        => esc_html__( 'Show Button on release style', 'pinkmart' ),
				'type'         => \Elementor\Controls_Manager::SWITCHER,
				'label_on'     => esc_html__( 'Enable', 'pinkmart' ),
				'label_off'    => esc_html__( 'Disable', 'pinkmart' ),
				'return_value' => 'enable',
				'default'      => '',
			)
		);
		$this->add_control(
			'size',
			array(
				'label'     => esc_html__( 'Button Size', 'pinkmart' ),
				'type'      => \Elementor\Controls_Manager::SELECT,
				'options'   => array(
					'default'  => esc_html__( 'Default', 'pinkmart' ),
					'small'    => esc_html__( 'Small', 'pinkmart' ),
					'standard' => esc_html__( 'Medium', 'pinkmart' ),
					'large'    => esc_html__( 'Large', 'pinkmart' ),
				),
				'default'   => 'default',
				'condition' => array(
					'button_style' => 'fill',
				),
			)
		);
		$this->end_controls_section();
	}

	/**
	 * Render Animated Text widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function render() {

		$settings = $this->get_settings_for_display();
		if ( $settings['image_size'] == 'custom' ) {
			$image_size = 'image_size="custom" image_size_width="' . $settings['image_size_width'] . '" image_size_height="' . $settings['image_size_height'] . '" image_size_crop="' . $settings['image_size_crop'] . '"';
		} else {
			$image_size = 'image_size="' . $settings['image_size'] . '"';
		}

		if ( $settings['hover'] == 'enable' ) {
			$hover = 'hover="enable" hover_color_preset="custom" hover_color="' . $settings['hover_color'] . '" hover_zoom="' . $settings['hover_zoom'] . '"';
		} else {
			$hover = 'hover="disable"';
		}
		if ( $settings['badge'] == 'enable' ) {
			$badge = 'badge="enable" badge_content="' . $settings['badge_content'] . '" badge_bg_color="' . $settings['badge_bg_color'] . '" badge_content_color="' . $settings['badge_content_color'] . '" badge_position="' . $settings['badge_position'] . '"';
		} else {
			$badge = 'badge="disable"';
		}
		$shortcode = '[banner image_url="' . $settings['image_url']['id'] . '" ' . $image_size . ' heading="' . $settings['heading'] . '" heading_color="' . $settings['heading_color'] . '" title="' . $settings['title'] . '" title_color="' . $settings['title_color'] . '" subtitle="' . $settings['subtitle'] . '" subtitle_color="' . $settings['subtitle_color'] . '" alignment="' . $settings['alignment'] . '" ' . $hover . ' url="' . $settings['url']['url'] . '" new_tab="' . $settings['url']['is_external'] . '" url_title="' . $settings['url_title'] . '" link_color="' . $settings['link_color'] . '" link_bg_color="' . $settings['link_bg_color'] . '" button_style="' . $settings['button_style'] . '" show_button="' . $settings['show_button'] . '" size="' . $settings['size'] . '" ' . $badge . ' heading_size="custom" title_size="custom" subtitle_size="custom" link_size="custom"]';
		echo do_shortcode( shortcode_unautop( $shortcode ) );
	}

	/**
	 * Whether the reload preview is required or not.
	 *
	 * Used to determine whether the reload preview is required.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return bool Whether the reload preview is required.
	 */
	public function is_reload_preview_required() {
		return false;
	}

	/**
	 * Render shortcode widget as plain content.
	 *
	 * Override the default behavior by printing the shortcode instead of rendering it.
	 *
	 * @since 1.0.0
	 * @access public
	 */
	public function render_plain_content() {
		// In plain mode, render without shortcode
		$settings = $this->get_settings_for_display();
		if ( $settings['image_size'] == 'custom' ) {
			$image_size = 'image_size="custom" image_size_width="' . $settings['image_size_width'] . '" image_size_height="' . $settings['image_size_height'] . '" image_size_crop="' . $settings['image_size_crop'] . '"';
		} else {
			$image_size = 'image_size="' . $settings['image_size'] . '"';
		}

		if ( $settings['hover'] == 'enable' ) {
			$hover = 'hover="enable" hover_color_preset="custom" hover_color="' . $settings['hover_color'] . '" hover_zoom="' . $settings['hover_zoom'] . '"';
		} else {
			$hover = 'hover="disable"';
		}

		if ( $settings['badge'] == 'enable' ) {
			$badge = 'badge="enable" badge_content="' . $settings['badge_content'] . '" badge_bg_color="' . $settings['badge_bg_color'] . '" badge_content_color="' . $settings['badge_content_color'] . '" badge_position="' . $settings['badge_position'] . '"';
		} else {
			$badge = 'badge="disable"';
		}
		$shortcode = '[banner image_url="' . $settings['image_url']['id'] . '" ' . $image_size . ' heading="' . $settings['heading'] . '" heading_color="' . $settings['heading_color'] . '" title="' . $settings['title'] . '" title_color="' . $settings['title_color'] . '" subtitle="' . $settings['subtitle'] . '" subtitle_color="' . $settings['subtitle_color'] . '" alignment="' . $settings['alignment'] . '" ' . $hover . ' url="' . $settings['url']['url'] . '" new_tab="' . $settings['url']['is_external'] . '" url_title="' . $settings['url_title'] . '" link_color="' . $settings['link_color'] . '" link_bg_color="' . $settings['link_bg_color'] . '" button_style="' . $settings['button_style'] . '" show_button="' . $settings['show_button'] . '" size="' . $settings['size'] . '" ' . $badge . ' heading_size="custom" title_size="custom" subtitle_size="custom" link_size="custom"]';
		echo "$shortcode";

	}

	protected function _content_template() {
		?>
		<#
		let container_class = 'banner ';
		container_class += (settings.image_url.url == '') ? ' no-image ' : '';
		container_class += settings.alignment;
		container_class += (settings.url_title != '' && settings.url.url != '') ? ' has_button ' : '';
		container_class += (settings.url_title != '' && settings.url.url != '' && settings.show_button == 'enable') ? ' show_button ' : '';
		container_class += (settings.hover_zoom != 'enable') ? '' : ' zoom ';
		
		view.addRenderAttribute('banner-container','class',[container_class]);
		#>
		<div {{{view.getRenderAttributeString('banner-container')}}}>
			<# if (settings.image_url.url != "") { #>
				<div class="image">
					<# if (settings.hover == 'enable') { #>
						<div class="hover"></div>
					<# } #>
					<img src="{{{settings.image_url.url}}}" alt="{{settings.title}}">
				</div>
			<# } #>	
			<div class="content-container">
				<# 
				if (settings.badge == 'enable') { 
					view.addRenderAttribute('badge','class','badge '+settings.badge_position);	
				#>
					<div {{{view.getRenderAttributeString('badge')}}}><span style="white-space:pre;">{{settings.badge_content}}</span></div>
				<# 
				} 
				#>
				<div class="content">
					<#
					if (settings.heading != "") {
						view.addRenderAttribute('heading','class','heading clearfix');
						view.addInlineEditingAttributes('heading','none');	
					#>
						<span {{{view.getRenderAttributeString('heading')}}}>{{settings.heading}}</span>
					<#
					}
					if (settings.title != "") {
						view.addRenderAttribute('title','class','title clearfix');
						view.addInlineEditingAttributes('title','none');	
					#>
						<span {{{view.getRenderAttributeString('title')}}}>{{settings.title}}</span>
					<#
					}
					if (settings.subtitle != "") {
						view.addRenderAttribute('subtitle','class','subtitle');
						view.addInlineEditingAttributes('subtitle','none');	
					#>
						<span {{{view.getRenderAttributeString('subtitle')}}}>{{settings.subtitle}}</span>
					<#
					}
					if (settings.url.url != "" ) {
						let button_class = '';
						let button_size = (settings.size == 'standard') ? 'button-medium' : ((settings.size != "") ? 'button-'+settings.size:'');
						button_class += (settings.button_style == 'fill') ? 'kt_button style2 text '+button_size : '';
						let target = (settings.url.is_external) ? "_blank" : "_self";
						let link_style = (settings.url_title != "") ? '':'display:none;';
						view.addRenderAttribute(
							'link',
							{
								class: [button_class] + ' ' + settings.button_style,
								href: settings.url.url,
								target: [target],
								style: [link_style]
							}
						);
						view.addRenderAttribute('link_text','class','txt');
						view.addInlineEditingAttributes('link_text','none');
					#>
						<a {{{view.getRenderAttributeString('link')}}}>
							<span {{{view.getRenderAttributeString('link_text')}}}>{{settings.url_title}}</span>
							<# if (settings.button_style == 'link') { #>
								<span class="icon icon-chevron-right"></span>
							<# } #>
						</a>
					<#
					}
					#>
				</div>
			</div>	
		</div>
		<?php
	}
}
\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \Kite_Banner_Widget() );
