<?php
/**
 * Elementor Blog Widget.
 *
 * @since 1.0.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

class Kite_Blog_Head_Line_Widget extends \Elementor\Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve Blog widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'kite-blog-headline';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Blog widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Blog - HeadLine Style', 'pinkmart' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Blog widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-columns kite-element-icon';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Blog widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array( 'by-kite' );
	}

	/**
	 * Register Blog widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function _register_controls() {
		$posts_cats = array();
		$cat_args   = array(
			'orderby'    => 'term_id',
			'order'      => 'ASC',
			'hide_empty' => false,
		);

		$terms = get_terms( 'category', $cat_args );

		foreach ( $terms as $taxonomy ) {
			 $posts_cats[ $taxonomy->slug ] = $taxonomy->name;
		}
		$this->start_controls_section(
			'content_section',
			array(
				'label' => esc_html__( 'Blog', 'pinkmart' ),
				'tab'   => \Elementor\Controls_Manager::TAB_CONTENT,
			)
		);
		$this->add_control(
			'blog_filter',
			array(
				'label'       => esc_html__( 'Blog Categories', 'pinkmart' ),
				'label_block' => true,
				'type'        => \Elementor\Controls_Manager::SELECT,
				'options'     => array(
					'all'    => esc_html__( 'All', 'pinkmart' ),
					'custom' => esc_html__( 'Custom', 'pinkmart' ),
				),
				'default'     => 'all',
			)
		);
		$this->add_control(
			'blog_category',
			array(
				'label'       => esc_html__( 'Category', 'pinkmart' ),
				'label_block' => true,
				'multiple'    => true,
				'type'        => \Elementor\Controls_Manager::SELECT2,
				'options'     => $posts_cats,
				'default'     => '',
				'condition'   => array(
					'blog_filter' => 'custom',
				),
			)
		);
		$this->add_control(
			'image_size',
			array(
				'label'       => __( 'Image Size', 'pinkmart' ),
				'type'        => \Elementor\Controls_Manager::SELECT,
				'options'     => array(
					'full'         => 'Full',
					'medium'       => 'Medium',
					'thumbnail'    => 'Thumbnail',
					'shop_catalog' => esc_html__( 'Shop Catalog', 'pinkmart' ),
				),
				'description' => esc_html__( 'This item is for quality of loaded image.', 'pinkmart' ),
				'default'     => 'shop_catalog',
			)
		);
		$this->add_control(
			'custom_image_size',
			array(
				'label'        => __( 'Custom Hover Image Size', 'pinkmart' ),
				'type'         => \Elementor\Controls_Manager::SWITCHER,
				'label_on'     => __( 'Enable', 'pinkmart' ),
				'label_off'    => __( 'Disable', 'pinkmart' ),
				'return_value' => 'enable',
				'default'      => 'disable',
			)
		);
		$this->add_control(
			'custom_image_width',
			array(
				'label'     => __( 'Custom Hover Image Width', 'pinkmart' ),
				'type'      => \Elementor\Controls_Manager::TEXT,
				'condition' => array(
					'custom_image_size' => 'enable',
				),
			)
		);
		$this->add_control(
			'custom_image_height',
			array(
				'label'     => __( 'Custom Hover Image Height', 'pinkmart' ),
				'type'      => \Elementor\Controls_Manager::TEXT,
				'condition' => array(
					'custom_image_size' => 'enable',
				),
			)
		);
		$this->add_control(
			'image_animation',
			array(
				'label'   => __( 'Image reveal animation', 'pinkmart' ),
				'type'    => \Elementor\Controls_Manager::SELECT,
				'options' => array(
					2  => __( 'Default style', 'pinkmart' ),
					4  => __( 'Style 1', 'pinkmart' ),
					5  => __( 'Style 2', 'pinkmart' ),
					9  => __( 'Style 3', 'pinkmart' ),
					10 => __( 'Style 4', 'pinkmart' ),
				),
				'default' => 2,
			)
		);
		$this->add_control(
			'blog_post_number',
			array(
				'label'      => esc_html__( 'Number of posts', 'pinkmart' ),
				'type'       => \Elementor\Controls_Manager::SLIDER,
				'size_units' => array( 'num' ),
				'range'      => array(
					'num' => array(
						'min'  => 1,
						'max'  => 30,
						'step' => 1,
					),
				),
				'default'    => array(
					'unit' => 'num',
					'size' => 8,
				),
			)
		);
		$this->add_control(
			'blog_description',
			array(
				'label'        => __( 'Discription Visibility', 'pinkmart' ),
				'type'         => \Elementor\Controls_Manager::SWITCHER,
				'label_on'     => __( 'Yes', 'pinkmart' ),
				'label_off'    => __( 'No', 'pinkmart' ),
				'return_value' => 'enable',
				'default'      => '',
			)
		);
		$this->add_control(
			'blog_category_visibility',
			array(
				'label'        => __( 'Category Visibility', 'pinkmart' ),
				'type'         => \Elementor\Controls_Manager::SWITCHER,
				'label_on'     => __( 'Yes', 'pinkmart' ),
				'label_off'    => __( 'No', 'pinkmart' ),
				'return_value' => 'enable',
				'default'      => '',
			)
		);
		$this->add_control(
			'blog_more_button',
			array(
				'label'        => esc_html__( 'Disable Load More Button', 'pinkmart' ),
				'type'         => \Elementor\Controls_Manager::SWITCHER,
				'label_on'     => esc_html__( 'Yes', 'pinkmart' ),
				'label_off'    => esc_html__( 'No', 'pinkmart' ),
				'return_value' => 'disable',
				'default'      => 'disable',
			)
		);
		$this->add_control(
			'load_more_style',
			array(
				'label'     => esc_html__( 'Load more style', 'pinkmart' ),
				'type'      => \Elementor\Controls_Manager::SELECT,
				'options'   => array(
					'dark'       => esc_html__( 'Dark', 'pinkmart' ),
					'lightstyle' => esc_html__( 'Light', 'pinkmart' ),
				),
				'default'   => 'dark',
				'condition' => array(
					'blog_more_button' => '',
				),
			)
		);
		$this->end_controls_section();

	}

	/**
	 * Render Blog widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function render() {

		$settings = $this->get_settings_for_display();
		if ( is_array( $settings['blog_category'] ) ) {
			$blog_category = implode( ',', $settings['blog_category'] );
		} else {
			$blog_category = $settings['blog_category'];
		}

		$settings['blog_description']         = ( $settings['blog_description'] == 'enable' ) ? 'enable' : 'disable';
		$settings['blog_category_visibility'] = ( $settings['blog_category_visibility'] == 'enable' ) ? 'enable' : 'disable';
		$shortcode                            = '[head-line-blog blog_category="' . $blog_category . '" image_size="' . $settings['image_size'] . '" custom_image_size="' . $settings['custom_image_size'] . '" custom_image_width="' . $settings['custom_image_width'] . '" custom_image_height="' . $settings['custom_image_height'] . '" blog_category_visibility="' . $settings['blog_category_visibility'] . '" blog_description="' . $settings['blog_description'] . '" blog_more_button="' . $settings['blog_more_button'] . '" load_more_style="' . $settings['load_more_style'] . '" image_animation="' . $settings['image_animation'] . '" blog_post_number="' . $settings['blog_post_number']['size'] . '"]';
		echo do_shortcode( shortcode_unautop( $shortcode ) );
	}

	/**
	 * Whether the reload preview is required or not.
	 *
	 * Used to determine whether the reload preview is required.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return bool Whether the reload preview is required.
	 */
	public function is_reload_preview_required() {
		return false;
	}

	/**
	 * Render shortcode widget as plain content.
	 *
	 * Override the default behavior by printing the shortcode instead of rendering it.
	 *
	 * @since 1.0.0
	 * @access public
	 */
	public function render_plain_content() {
		// In plain mode, render without shortcode
		$settings = $this->get_settings_for_display();
		if ( is_array( $settings['blog_category'] ) ) {
			$blog_category = implode( ',', $settings['blog_category'] );
		} else {
			$blog_category = $settings['blog_category'];
		}

		$settings['blog_description']         = ( $settings['blog_description'] == 'enable' ) ? 'enable' : 'disable';
		$settings['blog_category_visibility'] = ( $settings['blog_category_visibility'] == 'enable' ) ? 'enable' : 'disable';
		$shortcode                            = '[head-line-blog blog_category="' . $blog_category . '" image_size="' . $settings['image_size'] . '" custom_image_size="' . $settings['custom_image_size'] . '" custom_image_width="' . $settings['custom_image_width'] . '" custom_image_height="' . $settings['custom_image_height'] . '" blog_category_visibility="' . $settings['blog_category_visibility'] . '" blog_description="' . $settings['blog_description'] . '" blog_more_button="' . $settings['blog_more_button'] . '" load_more_style="' . $settings['load_more_style'] . '" image_animation="' . $settings['image_animation'] . '" blog_post_number="' . $settings['blog_post_number']['size'] . '"]';
		echo "$shortcode";

	}

	protected function _content_template() {

	}
}
\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \Kite_Blog_Head_Line_Widget() );
