<?php
/**
 * Elementor Count Down Widget.
 *
 * @since 1.0.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

class Kite_Count_Down_Widget extends \Elementor\Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve Count Down widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'kite-count-down';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Count Down widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Count Down', 'pinkmart' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Count Down widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-countdown kite-element-icon';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Count Down widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array( 'by-kite' );
	}

	/**
	 * Register Count Down widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function _register_controls() {

		$this->start_controls_section(
			'content_section',
			array(
				'label' => esc_html__( 'Count Down', 'pinkmart' ),
				'tab'   => \Elementor\Controls_Manager::TAB_CONTENT,
			)
		);
		$this->add_control(
			'end_date',
			array(
				'label' => esc_html__( 'count to', 'pinkmart' ),
				'type'  => \Elementor\Controls_Manager::DATE_TIME,

			)
		);
		$this->add_control(
			'style',
			array(
				'label'   => esc_html__( 'countdown style', 'pinkmart' ),
				'type'    => \Elementor\Controls_Manager::SELECT,
				'options' => array(
					'default'    => esc_html__( 'Style 1', 'pinkmart' ),
					'deal_style' => esc_html__( 'Style 2', 'pinkmart' ),
				),
				'default' => 'default',
			)
		);
		$this->add_control(
			'bg_color',
			array(
				'label'     => esc_html__( 'Background Color', 'pinkmart' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				'default'   => '',
				'selectors' => array(
					'{{WRAPPER}} .countdown-timer' => 'background-color: {{VALUE}}',
				),
				'condition' => array(
					'style' => 'deal_style',
				),
			)
		);
		$this->add_control(
			'color',
			array(
				'label'     => esc_html__( 'Color', 'pinkmart' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				'default'   => '',
				'selectors' => array(
					'{{WRAPPER}} .countdown-timer .number, {{WRAPPER}} .countdown-timer.secondstyle .time-block span:not(.seconds).number' => 'color: {{VALUE}}',
				),
			)
		);
		$this->add_control(
			'label_color',
			array(
				'label'     => esc_html__( 'Label Color', 'pinkmart' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				'default'   => '',
				'selectors' => array(
					'{{WRAPPER}} .countdown-timer .label' => 'color: {{VALUE}}',
				),
			)
		);
		$this->add_control(
			'fontsize',
			array(
				'label'   => esc_html__( 'Countdown font size', 'pinkmart' ),
				'type'    => \Elementor\Controls_Manager::SELECT,
				'options' => array(
					'16' => '16',
					'20' => '20',
					'28' => '28',
					'35' => '35',
					'44' => '44',
				),
				'default' => '16',
			)
		);
		$this->add_control(
			'alignment',
			array(
				'label'   => esc_html__( 'Alignment', 'pinkmart' ),
				'type'    => \Elementor\Controls_Manager::SELECT,
				'options' => array(
					'center' => esc_html__( 'Center', 'pinkmart' ),
					'left'   => esc_html__( 'Left', 'pinkmart' ),
					'right'  => esc_html__( 'Right', 'pinkmart' ),
				),
				'default' => 'center',
			)
		);
		$this->end_controls_section();

	}

	/**
	 * Render Count Down widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function render() {

		$settings  = $this->get_settings_for_display();
		$end_date  = date( 'Y-m-d\TH:i:s', strtotime( $settings['end_date'] ) );
		$shortcode = '[countdown end_date="' . $end_date . '" style="' . $settings['style'] . '" alignment="' . $settings['alignment'] . '" fontsize="' . $settings['fontsize'] . '"]';
		echo do_shortcode( shortcode_unautop( $shortcode ) );
	}

	/**
	 * Whether the reload preview is required or not.
	 *
	 * Used to determine whether the reload preview is required.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return bool Whether the reload preview is required.
	 */
	public function is_reload_preview_required() {
		return false;
	}

	/**
	 * Render shortcode widget as plain content.
	 *
	 * Override the default behavior by printing the shortcode instead of rendering it.
	 *
	 * @since 1.0.0
	 * @access public
	 */
	public function render_plain_content() {
		// In plain mode, render without shortcode
		$settings  = $this->get_settings_for_display();
		$end_date  = date( 'Y-m-d\TH:i:s', strtotime( $settings['end_date'] ) );
		$shortcode = '[countdown end_date="' . $end_date . '" style="' . $settings['style'] . '" alignment="' . $settings['alignment'] . '" fontsize="' . $settings['fontsize'] . '"]';
		echo "$shortcode";

	}

	protected function _content_template() {
		?>
		<# 
		let classes = ['countdown-timer',settings.alignment,'fontsize'+settings.fontsize];
		classes = (settings.style == 'deal_style') ? [...classes, 'secondstyle'] : classes;
		classes = classes.join(' ');
		#>
		<div class="{{classes}}" data-end="{{settings.end_date}}">
			<div class="time-block">
				<span class="days number">0</span>
				<span class="label">Days</span>
			</div>
			<div class="time-block">
				<span class="hours number">0</span>
				<span class="label">Hours</span>
			</div>
			<div class="time-block">
				<span class="minutes number">0</span>
				<span class="label">Mins</span>
			</div>
			<div class="time-block">
				<span class="seconds number">0</span>
				<span class="label">Secs</span>
			</div>
		</div>
		<?php
	}
}
\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \Kite_Count_Down_Widget() );
