<?php
/**
 * Elementor Gallery Widget.
 *
 * @since 1.0.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

class Kite_Gallery_Widget extends \Elementor\Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve Gallery widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'kite-gallery';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Gallery widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Gallery', 'pinkmart' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Gallery widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-inner-section kite-element-icon';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Gallery widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array( 'by-kite' );
	}

	/**
	 * Register Gallery widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function _register_controls() {
		$gallery_cats = array();
		$cat_args     = array(
			'orderby'    => 'term_id',
			'order'      => 'ASC',
			'hide_empty' => false,
		);

		$terms = get_terms( 'gallery_cat', $cat_args );
		if ( ! empty( $terms ) && ! is_wp_error( $terms ) ) { // check is gallery plugin is active or not
			foreach ( $terms as $taxonomy ) {
					$gallery_cats[ $taxonomy->slug ] = $taxonomy->name;
			}
		}
		$this->start_controls_section(
			'content_section',
			array(
				'label' => esc_html__( 'Gallery', 'pinkmart' ),
				'tab'   => \Elementor\Controls_Manager::TAB_CONTENT,
			)
		);
		$this->add_control(
			'portfolio_masonry',
			array(
				'label'   => esc_html__( 'Grid Layout', 'pinkmart' ),
				'type'    => \Elementor\Controls_Manager::SELECT,
				'options' => array(
					'perfectMasonry' => esc_html__( 'Fixed Layout', 'pinkmart' ),
					'masonry'        => esc_html__( 'Masonary Layout', 'pinkmart' ),
				),
				'default' => 'perfectMasonry',
			)
		);
		$this->add_control(
			'type',
			array(
				'label'   => esc_html__( 'Gallery Type', 'pinkmart' ),
				'type'    => \Elementor\Controls_Manager::SELECT,
				'options' => array(
					'portfolio_space'    => esc_html__( 'Protfolio with Gutter', 'pinkmart' ),
					'portfolio_no_space' => esc_html__( 'Portfolio with No Gutter', 'pinkmart' ),
					'portfolio_text'     => esc_html__( 'Portfolio with Text', 'pinkmart' ),
				),
				'default' => 'portfolio_space',
			)
		);
		$this->add_control(
			'title_bar',
			array(
				'label'       => esc_html__( 'Show title', 'pinkmart' ),
				'label_block' => true,
				'type'        => \Elementor\Controls_Manager::SELECT,
				'options'     => array(
					'hide' => esc_html__( 'Do not show title', 'pinkmart' ),
					'show' => esc_html__( 'Show custom title', 'pinkmart' ),
				),
				'default'     => 'hide',
			)
		);
		$this->add_control(
			'title_text',
			array(
				'label'   => esc_html__( 'Title', 'pinkmart' ),
				'type'    => \Elementor\Controls_Manager::TEXT,
				'default' => '',
			)
		);
		$this->add_control(
			'filter_display',
			array(
				'label'       => esc_html__( 'Filter Display', 'pinkmart' ),
				'label_block' => true,
				'type'        => \Elementor\Controls_Manager::SELECT,
				'options'     => array(
					'hide' => esc_html__( 'Do not show title', 'pinkmart' ),
					'show' => esc_html__( 'Show custom title', 'pinkmart' ),
				),
				'default'     => 'show',
			)
		);
		$this->add_control(
			'filter_style',
			array(
				'label'       => esc_html__( 'Filter Style', 'pinkmart' ),
				'label_block' => true,
				'type'        => \Elementor\Controls_Manager::SELECT,
				'options'     => array(
					'standard' => esc_html__( 'Standard', 'pinkmart' ),
					'toggle'   => esc_html__( 'Toggle', 'pinkmart' ),
				),
				'default'     => 'standard',
			)
		);
		$this->add_control(
			'filter_toggle_state',
			array(
				'label'       => esc_html__( 'Filter toggle beginning state', 'pinkmart' ),
				'label_block' => true,
				'type'        => \Elementor\Controls_Manager::SELECT,
				'options'     => array(
					'close' => esc_html__( 'Close', 'pinkmart' ),
					'open'  => esc_html__( 'Open', 'pinkmart' ),
				),
				'default'     => 'close',
				'condition'   => array(
					'filter_style' => 'toggle',
				),
			)
		);
		$this->add_control(
			'portfolio_filter',
			array(
				'label'       => esc_html__( 'Gallery Categories', 'pinkmart' ),
				'label_block' => true,
				'type'        => \Elementor\Controls_Manager::SELECT,
				'options'     => array(
					'all'    => esc_html__( 'All', 'pinkmart' ),
					'custom' => esc_html__( 'Custom', 'pinkmart' ),
				),
				'default'     => 'all',
			)
		);
		$this->add_control(
			'filters',
			array(
				'label'       => esc_html__( 'Gallery custom Categories', 'pinkmart' ),
				'label_block' => true,
				'type'        => \Elementor\Controls_Manager::SELECT2,
				'multiple'    => true,
				'options'     => $gallery_cats,
				'condition'   => array(
					'portfolio_filter' => 'custom',
				),
			)
		);
		$this->add_control(
			'gallery_posts_page',
			array(
				'label'      => esc_html__( 'Items', 'pinkmart' ),
				'type'       => \Elementor\Controls_Manager::SLIDER,
				'size_units' => array( 'num' ),
				'range'      => array(
					'num' => array(
						'min'  => 1,
						'max'  => 30,
						'step' => 1,
					),
				),
				'default'    => array(
					'unit' => 'num',
					'size' => 12,
				),
			)
		);
		$this->add_control(
			'filter_loadmore_style',
			array(
				'label'       => esc_html__( 'Style', 'pinkmart' ),
				'label_block' => true,
				'type'        => \Elementor\Controls_Manager::SELECT,
				'options'     => array(
					'darkstyle'  => esc_html__( 'Dark', 'pinkmart' ),
					'lightstyle' => esc_html__( 'Light', 'pinkmart' ),
				),
				'default'     => 'darkstyle',
				'description' => 'dark and light styles set for filter bar , load more button , title and subtitle',
			)
		);
		$this->add_control(
			'gallery_thumbnail_display',
			array(
				'label'       => esc_html__( 'Gallery Thumbnail Display', 'pinkmart' ),
				'label_block' => true,
				'type'        => \Elementor\Controls_Manager::SELECT,
				'options'     => array(
					true  => esc_html__( 'Show', 'pinkmart' ),
					false => esc_html__( 'Hide', 'pinkmart' ),
				),
				'default'     => true,
				'description' => esc_html__( 'Do you prefer to have the galery thumbnails?', 'pinkmart' ),
			)
		);
		$this->add_control(
			'portfolio_hover',
			array(
				'label'       => esc_html__( 'Hover type', 'pinkmart' ),
				'label_block' => true,
				'type'        => \Elementor\Controls_Manager::SELECT,
				'options'     => array(
					'simplegallery' => esc_html__( 'Simple Gallery', 'pinkmart' ),
					'bordertype'    => esc_html__( 'Border Style', 'pinkmart' ),
					'simpletype'    => esc_html__( 'Simple', 'pinkmart' ),
				),
				'default'     => 'simplegallery',
			)
		);
		$this->add_control(
			'portfolio_hover_style',
			array(
				'label'       => esc_html__( 'Hover Style', 'pinkmart' ),
				'label_block' => true,
				'type'        => \Elementor\Controls_Manager::SELECT,
				'options'     => array(
					'lightstyle' => esc_html__( 'Light', 'pinkmart' ),
					'darkstyle'  => esc_html__( 'Dark', 'pinkmart' ),
				),
				'default'     => 'lightstyle',
			)
		);
		$this->add_control(
			'portfolio_hover_like_button',
			array(
				'label'       => esc_html__( 'Display like Button On hover', 'pinkmart' ),
				'label_block' => true,
				'type'        => \Elementor\Controls_Manager::SELECT,
				'options'     => array(
					'show' => esc_html__( 'Show', 'pinkmart' ),
					'hide' => esc_html__( 'Hide', 'pinkmart' ),
				),
				'default'     => 'show',
			)
		);
		$this->add_control(
			'gallery_pop_up',
			array(
				'label'       => esc_html__( 'Pop-up style', 'pinkmart' ),
				'label_block' => true,
				'type'        => \Elementor\Controls_Manager::SELECT,
				'options'     => array(
					'darkPopUp'  => esc_html__( 'Dark', 'pinkmart' ),
					'lightPopUp' => esc_html__( 'Light', 'pinkmart' ),
				),
				'default'     => 'darkPopUp',
			)
		);
		$this->add_control(
			'show_more_button',
			array(
				'label'        => esc_html__( 'Show Load More Button', 'pinkmart' ),
				'type'         => \Elementor\Controls_Manager::SWITCHER,
				'label_on'     => esc_html__( 'Enable', 'pinkmart' ),
				'label_off'    => esc_html__( 'Disable', 'pinkmart' ),
				'return_value' => 'enable',
				'default'      => 'disable',
			)
		);
		$this->end_controls_section();
		$this->start_controls_section(
			'animation_section',
			array(
				'label' => esc_html__( 'Animation', 'pinkmart' ),
				'tab'   => \Elementor\Controls_Manager::TAB_CONTENT,
			)
		);
		$this->add_control(
			'animation_style',
			array(
				'label'       => esc_html__( 'Gallery Slide Animation', 'pinkmart' ),
				'label_block' => true,
				'type'        => \Elementor\Controls_Manager::SELECT,
				'options'     => array(
					'lg-fade'                     => esc_html__( 'Fade', 'pinkmart' ),
					'lg-slide'                    => esc_html__( 'Slide', 'pinkmart' ),
					'lg-zoom-in'                  => esc_html__( 'Zoom-In', 'pinkmart' ),
					'lg-zoom-in-big'              => esc_html__( 'Zoom-In Big', 'pinkmart' ),
					'lg-zoom-out'                 => esc_html__( 'Zoom-Out', 'pinkmart' ),
					'lightPopUp'                  => esc_html__( 'Zoom-Out Big', 'pinkmart' ),
					'lg-zoom-out-in'              => esc_html__( 'Zoom-Out In', 'pinkmart' ),
					'lg-zoom-in-out'              => esc_html__( 'Zoom-In Out', 'pinkmart' ),
					'lg-soft-zoom'                => esc_html__( 'Soft Zoom', 'pinkmart' ),
					'lg-scale-up'                 => esc_html__( 'Scale-Up', 'pinkmart' ),
					'lg-slide-circular'           => esc_html__( 'Circular Slide', 'pinkmart' ),
					'lg-slide-circular-vertical'  => esc_html__( 'Circular Vertical Slide', 'pinkmart' ),
					'lg-slide-vertical'           => esc_html__( 'Vertical Slide', 'pinkmart' ),
					'lg-slide-vertical-growth'    => esc_html__( 'Vertical Slide with growth', 'pinkmart' ),
					'lg-slide-skew-only'          => esc_html__( 'Skew', 'pinkmart' ),
					'lg-slide-skew-only-rev'      => esc_html__( 'reverse Skew', 'pinkmart' ),
					'lg-slide-skew-only'          => esc_html__( 'Skew', 'pinkmart' ),
					'lg-slide-skew-only-y'        => esc_html__( 'Horizontal Skew', 'pinkmart' ),
					'lg-slide-skew-only-y-rev'    => 'Reverse Horizontal Skew',
					'lg-slide-skew'               => esc_html__( 'Slide Skew', 'pinkmart' ),
					'lg-slide-skew-rev'           => esc_html__( 'Slide reverse Skew', 'pinkmart' ),
					'lg-slide-skew-cross'         => esc_html__( 'Slide Skew Cross', 'pinkmart' ),
					'lg-slide-skew-cross-rev'     => esc_html__( 'Reverse Slide Skew Cross', 'pinkmart' ),
					'lg-slide-skew-ver'           => esc_html__( 'Vertical Slide Skew', 'pinkmart' ),
					'lg-slide-skew-ver-rev'       => esc_html__( 'Reverse Vertical Slide Skew', 'pinkmart' ),
					'lg-slide-skew-ver-cross'     => esc_html__( 'Vertical Slide Skew Cross', 'pinkmart' ),
					'lg-slide-skew-ver-cross-rev' => esc_html__( 'Reverse Vertical Slide Skew Cross', 'pinkmart' ),
					'lg-lollipop'                 => esc_html__( 'Lollipop', 'pinkmart' ),
					'lg-lollipop-rev'             => esc_html__( 'Reverse Lollipop', 'pinkmart' ),
					'lg-rotate'                   => esc_html__( 'Rotate', 'pinkmart' ),
					'lg-rotate-rev'               => esc_html__( 'Asynchronous Rotate', 'pinkmart' ),
					'lg-tube'                     => esc_html__( 'Tube', 'pinkmart' ),
				),
				'default'     => 'lg-fade',
			)
		);
		$this->add_control(
			'enterance_animation',
			array(
				'label'       => esc_html__( 'Entrance animation', 'pinkmart' ),
				'label_block' => true,
				'type'        => \Elementor\Controls_Manager::SELECT,
				'options'     => array(
					'fadeinfrombottom' => esc_html__( 'FadeIn From Bottom', 'pinkmart' ),
					'fadeinfromtop'    => esc_html__( 'FadeIn From Top', 'pinkmart' ),
					'fadeinfromright'  => esc_html__( 'FadeIn From Right', 'pinkmart' ),
					'fadeinfromleft'   => esc_html__( 'FadeIn From Left', 'pinkmart' ),
					'zoomin'           => esc_html__( 'Zoom-in', 'pinkmart' ),
					'default'          => esc_html__( 'No Animation', 'pinkmart' ),
				),
				'default'     => 'fadeinfrombottom',
			)
		);
		$this->add_control(
			'responsive_animation',
			array(
				'label'        => esc_html__( 'Animation in Responsive', 'pinkmart' ),
				'type'         => \Elementor\Controls_Manager::SWITCHER,
				'label_on'     => esc_html__( 'Enable', 'pinkmart' ),
				'label_off'    => esc_html__( 'Disable', 'pinkmart' ),
				'return_value' => 'enable',
				'default'      => 'disable',
			)
		);
		$this->end_controls_section();

	}

	/**
	 * Render Gallery widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function render() {

		$settings = $this->get_settings_for_display();
		if ( is_array( $settings['filters'] ) ) {
			$filters = implode( ',', $settings['filters'] );
		} else {
			$filters = $settings['filters'];
		}
		$shortcode = '[kt_gallery type="' . $settings['type'] . '" title_bar="' . $settings['title_bar'] . '" title_text="' . $settings['title_text'] . '" portfolio_filter="' . $settings['portfolio_filter'] . '" filters="' . $filters . '" filter_display="' . $settings['filter_display'] . '" filter_style="' . $settings['filter_style'] . '" filter_loadmore_style="' . $settings['filter_loadmore_style'] . '" filter_toggle_state="' . $settings['filter_toggle_state'] . '" gallery_posts_page="' . $settings['gallery_posts_page']['size'] . '" portfolio_hover_like_button="' . $settings['portfolio_hover_like_button'] . '" portfolio_hover="' . $settings['portfolio_hover'] . '" portfolio_hover_style="' . $settings['portfolio_hover_style'] . '" gallery_pop_up="' . $settings['gallery_pop_up'] . '" enterance_animation="' . $settings['enterance_animation'] . '" responsive_animation="' . $settings['responsive_animation'] . '" animation_style="' . $settings['animation_style'] . '" portfolio_masonry="' . $settings['portfolio_masonry'] . '" gallery_thumbnail_display="' . $settings['gallery_thumbnail_display'] . '" show_more_button="' . $settings['show_more_button'] . '"]';
		echo do_shortcode( shortcode_unautop( $shortcode ) );
	}

	/**
	 * Whether the reload preview is required or not.
	 *
	 * Used to determine whether the reload preview is required.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return bool Whether the reload preview is required.
	 */
	public function is_reload_preview_required() {
		return false;
	}

	/**
	 * Render shortcode widget as plain content.
	 *
	 * Override the default behavior by printing the shortcode instead of rendering it.
	 *
	 * @since 1.0.0
	 * @access public
	 */
	public function render_plain_content() {
		// In plain mode, render without shortcode
		$settings = $this->get_settings_for_display();
		if ( is_array( $settings['filters'] ) ) {
			$filters = implode( ',', $settings['filters'] );
		} else {
			$filters = $settings['filters'];
		}
		$shortcode = '[kt_gallery type="' . $settings['type'] . '" title_bar="' . $settings['title_bar'] . '" title_text="' . $settings['title_text'] . '" portfolio_filter="' . $settings['portfolio_filter'] . '"filters="' . $filters . '" filter_display="' . $settings['filter_display'] . '" filter_style="' . $settings['filter_style'] . '" filter_loadmore_style="' . $settings['filter_loadmore_style'] . '" filter_toggle_state="' . $settings['filter_toggle_state'] . '" gallery_posts_page="' . $settings['gallery_posts_page']['size'] . '" portfolio_hover_like_button="' . $settings['portfolio_hover_like_button'] . '" portfolio_hover="' . $settings['portfolio_hover'] . '" portfolio_hover_style="' . $settings['portfolio_hover_style'] . '" gallery_pop_up="' . $settings['gallery_pop_up'] . '" enterance_animation="' . $settings['enterance_animation'] . '" responsive_animation="' . $settings['responsive_animation'] . '" animation_style="' . $settings['animation_style'] . '" portfolio_masonry="' . $settings['portfolio_masonry'] . '" gallery_thumbnail_display="' . $settings['gallery_thumbnail_display'] . '" show_more_button="' . $settings['show_more_button'] . '"]';

		echo "$shortcode";

	}

	protected function _content_template() {

	}
}
\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \Kite_Gallery_Widget() );
