<?php
/**
 * Elementor Icon Box Top Widget.
 *
 * @since 1.0.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

class Kite_Icon_Box_Top_Widget extends \Elementor\Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve Icon Box Top widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'kite-icon-box-top';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Icon Box Top widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Icon Box Top', 'pinkmart' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Icon Box Top widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-text-align-center kite-element-icon';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Icon Box Top widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array( 'by-kite' );
	}

	/**
	 * Register Icon Box Top widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function _register_controls() {
		$this->start_controls_section(
			'content_section',
			array(
				'label' => esc_html__( 'Icon Box Top', 'pinkmart' ),
				'tab'   => \Elementor\Controls_Manager::TAB_CONTENT,
			)
		);
		$this->add_control(
			'title',
			array(
				'label' => esc_html__( 'Title', 'pinkmart' ),
				'type'  => \Elementor\Controls_Manager::TEXTAREA,
			)
		);
		$this->add_control(
			'title_color',
			array(
				'label'   => esc_html__( 'Title color ', 'pinkmart' ),
				'type'    => \Elementor\Controls_Manager::COLOR,
				'default' => '',
			)
		);
		$this->add_control(
			'content_text',
			array(
				'label' => esc_html__( 'Content', 'pinkmart' ),
				'type'  => \Elementor\Controls_Manager::TEXTAREA,
			)
		);
		$this->add_control(
			'content_color',
			array(
				'label'   => esc_html__( 'Content color ', 'pinkmart' ),
				'type'    => \Elementor\Controls_Manager::COLOR,
				'default' => '',
			)
		);
		$this->add_control(
			'icon',
			array(
				'label'   => esc_html__( 'Icon', 'pinkmart' ),
				'type'    => \Elementor\Controls_Manager::ICON,
				'default' => '',
			)
		);

		$this->add_control(
			'alignment',
			array(
				'label'   => esc_html__( 'Icon Alignment', 'pinkmart' ),
				'type'    => \Elementor\Controls_Manager::SELECT,
				'options' => array(
					'right_alignment'  => esc_html__( 'Right', 'pinkmart' ),
					'center_alignment' => esc_html__( 'Center', 'pinkmart' ),
					'left_alignment'   => esc_html__( 'Left', 'pinkmart' ),
				),
				'default' => 'right_alignment',
			)
		);
		$this->add_control(
			'alignment_resp',
			array(
				'label'   => esc_html__( 'Icon Alignment in Mobile', 'pinkmart' ),
				'type'    => \Elementor\Controls_Manager::SELECT,
				'options' => array(
					'center_mob' => esc_html__( 'Center', 'pinkmart' ),
					'right_mob'  => esc_html__( 'Right', 'pinkmart' ),
					'left_mob'   => esc_html__( 'Left', 'pinkmart' ),
				),
				'default' => 'center_mob',
			)
		);
		$this->add_control(
			'icon_color',
			array(
				'label'   => esc_html__( 'Icon color ', 'pinkmart' ),
				'type'    => \Elementor\Controls_Manager::COLOR,
				'default' => '',
			)
		);
		$this->add_control(
			'url',
			array(
				'label'   => esc_html__( 'Link', 'pinkmart' ),
				'type'    => \Elementor\Controls_Manager::TEXT,
				'default' => '',
			)
		);
		$this->add_control(
			'elementor_link_title',
			array(
				'label'   => esc_html__( 'Link Title', 'pinkmart' ),
				'type'    => \Elementor\Controls_Manager::TEXT,
				'default' => '',
			)
		);
		$this->add_control(
			'whole_box_link',
			array(
				'label'        => esc_html__( 'Whole Icon box Link', 'pinkmart' ),
				'type'         => \Elementor\Controls_Manager::SWITCHER,
				'label_on'     => esc_html__( 'Enable', 'pinkmart' ),
				'label_off'    => esc_html__( 'Disable', 'pinkmart' ),
				'return_value' => 'enable',
				'default'      => 'disable',
			)
		);
		$this->end_controls_section();

	}

	/**
	 * Render Icon Box Top widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function render() {

		$settings  = $this->get_settings_for_display();
		$icon      = str_replace( 'icon icon-', '', $settings['icon'] );
		$shortcode = '[iconbox_top_noborder title="' . $settings['title'] . '" title_color="' . $settings['title_color'] . '" icon="' . $icon . '" icon_color="' . $settings['icon_color'] . '" alignment="' . $settings['alignment'] . '" alignment_resp="' . $settings['alignment_resp'] . '" url="' . $settings['url'] . '" elementor_link_title="' . $settings['elementor_link_title'] . '" whole_box_link="' . $settings['whole_box_link'] . '" content_text="' . $settings['content_text'] . '" content_color="' . $settings['content_color'] . '"]';
		echo do_shortcode( shortcode_unautop( $shortcode ) );
	}

	/**
	 * Whether the reload preview is required or not.
	 *
	 * Used to determine whether the reload preview is required.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return bool Whether the reload preview is required.
	 */
	public function is_reload_preview_required() {
		return false;
	}

	/**
	 * Render shortcode widget as plain content.
	 *
	 * Override the default behavior by printing the shortcode instead of rendering it.
	 *
	 * @since 1.0.0
	 * @access public
	 */
	public function render_plain_content() {
		// In plain mode, render without shortcode
		$settings  = $this->get_settings_for_display();
		$icon      = str_replace( 'icon icon-', '', $settings['icon'] );
		$shortcode = '[iconbox_top_noborder title="' . $settings['title'] . '" title_color="' . $settings['title_color'] . '" icon="' . $icon . '" icon_color="' . $settings['icon_color'] . '" alignment="' . $settings['alignment'] . '" url="' . $settings['url'] . '" elementor_link_title="' . $settings['elementor_link_title'] . '" whole_box_link="' . $settings['whole_box_link'] . '" content_text="' . $settings['content_text'] . '" content_color="' . $settings['content_color'] . '"]';
		echo "$shortcode";

	}

	protected function _content_template() {

	}
}
\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \Kite_Icon_Box_Top_Widget() );
