<?php
/**
 * Elementor Instagram Feed Widget.
 *
 * @since 1.0.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

class Kite_Instagram_Feed_Widget extends \Elementor\Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve Instagram Feed widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'kite-instagram-feed';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Instagram Feed widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Instagram Feed', 'pinkmart' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Instagram Feed widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-gallery-grid kite-element-icon';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Instagram Feed widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array( 'by-kite' );
	}

	/**
	 * Register Instagram Feed widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function _register_controls() {

		$this->start_controls_section(
			'content_section',
			array(
				'label' => esc_html__( 'Instagram Feed', 'pinkmart' ),
				'tab'   => \Elementor\Controls_Manager::TAB_CONTENT,
			)
		);
		$this->add_control(
			'user',
			array(
				'label' => esc_html__( 'Username', 'pinkmart' ),
				'type'  => \Elementor\Controls_Manager::TEXT,
			)
		);
		$this->add_control(
			'posts_count',
			array(
				'label'      => esc_html__( 'Post count', 'pinkmart' ),
				'type'       => \Elementor\Controls_Manager::SLIDER,
				'size_units' => array( 'num' ),
				'range'      => array(
					'num' => array(
						'min'  => 1,
						'max'  => 20,
						'step' => 1,
					),
				),
				'default'    => array(
					'unit' => 'num',
					'size' => 10,
				),
			)
		);
		$this->add_control(
			'column',
			array(
				'label'   => esc_html__( 'Columns', 'pinkmart' ),
				'type'    => \Elementor\Controls_Manager::SELECT,
				'options' => array(
					'1' => '1',
					'2' => '2',
					'3' => '3',
					'4' => '4',
					'5' => '5',
					'6' => '6',
				),
				'default' => '1',
			)
		);
		$this->add_control(
			'image_resolution',
			array(
				'label'       => esc_html__( 'Image Resolution', 'pinkmart' ),
				'label_block' => true,
				'type'        => \Elementor\Controls_Manager::SELECT,
				'options'     => array(
					'thumbnail' => esc_html__( 'Thumbnail (150x150)', 'pinkmart' ),
					'medium'    => esc_html__( 'Medium', 'pinkmart' ),
					'large'     => esc_html__( 'Full size', 'pinkmart' ),
				),
				'default'     => 'thumbnail',
			)
		);
		$this->add_control(
			'gutter',
			array(
				'label'        => esc_html__( 'Remove Gutter', 'pinkmart' ),
				'type'         => \Elementor\Controls_Manager::SWITCHER,
				'label_on'     => esc_html__( 'Yes', 'pinkmart' ),
				'label_off'    => esc_html__( 'No', 'pinkmart' ),
				'return_value' => 'no',
				'default'      => 'no',
				'description'  => esc_html__( 'Remove gutter between items', 'pinkmart' ),
			)
		);
		$this->add_control(
			'carousel',
			array(
				'label'       => esc_html__( 'Carousel/Grid', 'pinkmart' ),
				'label_block' => true,
				'type'        => \Elementor\Controls_Manager::SELECT,
				'options'     => array(
					'disable' => esc_html__( 'Grid', 'pinkmart' ),
					'enable'  => esc_html__( 'Carousel', 'pinkmart' ),
				),
				'default'     => 'disable',
			)
		);
		$this->add_control(
			'naxt_prev_btn',
			array(
				'label'       => esc_html__( 'Navigation Buttons Visibility', 'pinkmart' ),
				'label_block' => true,
				'type'        => \Elementor\Controls_Manager::SELECT,
				'options'     => array(
					'show' => esc_html__( 'Enable', 'pinkmart' ),
					'hide' => esc_html__( 'Disable', 'pinkmart' ),
				),
				'default'     => 'show',
				'condition'   => array(
					'carousel' => 'enable',
				),
			)
		);
		$this->add_control(
			'nav_style',
			array(
				'label'       => esc_html__( 'Navigations Style', 'pinkmart' ),
				'label_block' => true,
				'type'        => \Elementor\Controls_Manager::SELECT,
				'options'     => array(
					'light' => esc_html__( 'Light', 'pinkmart' ),
					'dark'  => esc_html__( 'Dark', 'pinkmart' ),
				),
				'default'     => 'light',
				'condition'   => array(
					'naxt_prev_btn' => 'show',
				),
			)
		);
		$this->add_control(
			'custom_hover_color',
			array(
				'label'   => esc_html__( 'Custom hover Color', 'pinkmart' ),
				'type'    => \Elementor\Controls_Manager::COLOR,
				'default' => '',
			)
		);
		$this->add_control(
			'like',
			array(
				'label'        => esc_html__( 'Like', 'pinkmart' ),
				'type'         => \Elementor\Controls_Manager::SWITCHER,
				'label_on'     => esc_html__( 'Enable', 'pinkmart' ),
				'label_off'    => esc_html__( 'Disable', 'pinkmart' ),
				'return_value' => 'enable',
				'default'      => 'disable',
				'description'  => esc_html__( 'Show likes count', 'pinkmart' ),
			)
		);
		$this->add_control(
			'comment',
			array(
				'label'        => esc_html__( 'Comment', 'pinkmart' ),
				'type'         => \Elementor\Controls_Manager::SWITCHER,
				'label_on'     => esc_html__( 'Enable', 'pinkmart' ),
				'label_off'    => esc_html__( 'Disable', 'pinkmart' ),
				'return_value' => 'enable',
				'default'      => 'disable',
				'description'  => esc_html__( 'Show comment count', 'pinkmart' ),
			)
		);
		$this->add_control(
			'eqaul_height_width',
			array(
				'label'        => esc_html__( 'Equal width and height image', 'pinkmart' ),
				'type'         => \Elementor\Controls_Manager::SWITCHER,
				'label_on'     => esc_html__( 'Enable', 'pinkmart' ),
				'label_off'    => esc_html__( 'Disable', 'pinkmart' ),
				'return_value' => 'enable',
				'default'      => 'enable',
				'description'  => esc_html__( 'Show likes count', 'pinkmart' ),
			)
		);
		$this->end_controls_section();
		$this->start_controls_section(
			'animation_section',
			array(
				'label' => esc_html__( 'Animation', 'pinkmart' ),
				'tab'   => \Elementor\Controls_Manager::TAB_CONTENT,
			)
		);

		$this->add_control(
			'enterance_animation',
			array(
				'label'       => esc_html__( 'Entrance animation', 'pinkmart' ),
				'label_block' => true,
				'type'        => \Elementor\Controls_Manager::SELECT,
				'options'     => array(
					'fadein'           => esc_html__( 'FadeIn', 'pinkmart' ),
					'fadeinfrombottom' => esc_html__( 'FadeIn From Bottom', 'pinkmart' ),
					'fadeinfromtop'    => esc_html__( 'FadeIn From Top', 'pinkmart' ),
					'fadeinfromright'  => esc_html__( 'FadeIn From Right', 'pinkmart' ),
					'fadeinfromleft'   => esc_html__( 'FadeIn From Left', 'pinkmart' ),
					'zoomin'           => esc_html__( 'Zoom-in', 'pinkmart' ),
					'default'          => esc_html__( 'No Animation', 'pinkmart' ),
				),
				'default'     => 'fadein',
			)
		);
		$this->add_control(
			'responsive_animation',
			array(
				'label'        => esc_html__( 'Animation in Responsive', 'pinkmart' ),
				'type'         => \Elementor\Controls_Manager::SWITCHER,
				'label_on'     => esc_html__( 'Enable', 'pinkmart' ),
				'label_off'    => esc_html__( 'Disable', 'pinkmart' ),
				'return_value' => 'enable',
				'default'      => 'disable',
			)
		);
		$this->end_controls_section();

	}

	/**
	 * Render Instagram Feed widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function render() {

		$settings = $this->get_settings_for_display();

		$shortcode = '[kt_instagram user="' . $settings['user'] . '" posts_count="' . $settings['posts_count']['size'] . '" column="' . $settings['column'] . '" image_resolution="' . $settings['image_resolution'] . '" gutter="' . $settings['gutter'] . '" carousel="' . $settings['carousel'] . '" naxt_prev_btn="' . $settings['naxt_prev_btn'] . '" nav_style="' . $settings['nav_style'] . '" custom_hover_color="' . $settings['custom_hover_color'] . '" hover_color="custom" like="' . $settings['like'] . '" comment="' . $settings['comment'] . '" eqaul_height_width="' . $settings['eqaul_height_width'] . '" enterance_animation="' . $settings['enterance_animation'] . '" responsive_animation="' . $settings['responsive_animation'] . '"]';
		echo do_shortcode( shortcode_unautop( $shortcode ) );
	}

	/**
	 * Whether the reload preview is required or not.
	 *
	 * Used to determine whether the reload preview is required.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return bool Whether the reload preview is required.
	 */
	public function is_reload_preview_required() {
		return true;
	}

	/**
	 * Render shortcode widget as plain content.
	 *
	 * Override the default behavior by printing the shortcode instead of rendering it.
	 *
	 * @since 1.0.0
	 * @access public
	 */
	public function render_plain_content() {
		// In plain mode, render without shortcode
		$settings  = $this->get_settings_for_display();
		$shortcode = '[kt_instagram user="' . $settings['user'] . '" posts_count="' . $settings['posts_count']['size'] . '" column="' . $settings['column'] . '" image_resolution="' . $settings['image_resolution'] . '" gutter="' . $settings['gutter'] . '" carousel="' . $settings['carousel'] . '" naxt_prev_btn="' . $settings['naxt_prev_btn'] . '" nav_style="' . $settings['nav_style'] . '" custom_hover_color="' . $settings['custom_hover_color'] . '" hover_color="custom" like="' . $settings['like'] . '" comment="' . $settings['comment'] . '" eqaul_height_width="' . $settings['eqaul_height_width'] . '" enterance_animation="' . $settings['enterance_animation'] . '" responsive_animation="' . $settings['responsive_animation'] . '"]';
		echo "$shortcode";

	}

	protected function _content_template() {

	}
}
\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \Kite_Instagram_Feed_Widget() );
