<?php
/**
 * Elementor LookBook Image Popup Reveal  Widget.
 *
 * @since 1.0.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

class kite_LookBook_Image_Popup_Reveal_Widget extends \Elementor\Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve LookBook Image Popup Reveal widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'kite-loobook-image-fullscreen-reveal';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve LookBook Image Popup Reveal widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'LookBook - Hover Fullscreen Reveal', 'pinkmart' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve LookBook Image Popup Reveal widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'icon icon-news kite-element-icon';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the LookBook Image Popup Reveal  widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array( 'by-kite' );
	}

	/**
	 * Register LookBook Image Popup Reveal  widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function _register_controls() {
		$this->start_controls_section(
			'content_section',
			array(
				'label' => __( 'LookBook Image Fullscreen Reveal ', 'pinkmart' ),
				'tab'   => \Elementor\Controls_Manager::TAB_CONTENT,
			)
		);
		$this->add_control(
			'imgs_id',
			array(
				'label'   => __( 'Images URL', 'pinkmart' ),
				'type'    => \Elementor\Controls_Manager::GALLERY,
				'default' => array(),
			)
		);
		$this->add_control(
			'title',
			array(
				'label' => __( 'Title', 'pinkmart' ),
				'type'  => \Elementor\Controls_Manager::TEXTAREA,
			)
		);
		$this->add_control(
			'alignment',
			array(
				'label'   => __( 'Title alignment', 'pinkmart' ),
				'type'    => \Elementor\Controls_Manager::SELECT,
				'options' => array(
					'center' => __( 'Center', 'pinkmart' ),
					'left'   => __( 'Left', 'pinkmart' ),
					'right'  => __( 'Right', 'pinkmart' ),
				),
				'default' => 'center',
			)
		);
		$this->add_control(
			'title_color',
			array(
				'label'   => __( 'Title color ', 'pinkmart' ),
				'type'    => \Elementor\Controls_Manager::COLOR,
				'default' => '',
			)
		);
		$this->add_control(
			'title_hover_color',
			array(
				'label'   => __( 'Title Hover color ', 'pinkmart' ),
				'type'    => \Elementor\Controls_Manager::COLOR,
				'default' => '',
			)
		);
		$this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			array(
				'name'     => 'title_typography',
				'label'    => __( 'Title Typography', 'pinkmart' ),
				'scheme'   => \Elementor\Scheme_Typography::TYPOGRAPHY_1,
				'selector' => '{{WRAPPER}} a',
			)
		);
		$this->add_control(
			'link_url',
			array(
				'label' => __( 'Link URL', 'pinkmart' ),
				'type'  => \Elementor\Controls_Manager::TEXTAREA,
			)
		);
		$this->add_control(
			'new_tab',
			array(
				'label'        => __( 'Open link in new tab', 'pinkmart' ),
				'type'         => \Elementor\Controls_Manager::SWITCHER,
				'label_on'     => __( 'Enable', 'pinkmart' ),
				'label_off'    => __( 'Disable', 'pinkmart' ),
				'return_value' => 'enable',
				'default'      => 'disable',
			)
		);
		$this->end_controls_section();

	}

	/**
	 * Render LookBook Image Popup Reveal  widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function render() {

		$settings = $this->get_settings_for_display();
		$imagesID = array();
		foreach ( $settings['imgs_id'] as $image ) {
			array_push( $imagesID, $image['id'] );
		}
		$imagesID  = implode( ',', $imagesID );
		$shortcode = '[imageFullScreenReveal imgs_id="' . $imagesID . '" title="' . $settings['title'] . '" alignment="' . $settings['alignment'] . '" title_color="' . $settings['title_color'] . '" title_hover_color="' . $settings['title_hover_color'] . '" link_url="' . $settings['link_url'] . '" new_tab="' . $settings['new_tab'] . '" title_font_size="custom"]';
		echo do_shortcode( shortcode_unautop( $shortcode ) );
	}

	/**
	 * Whether the reload preview is required or not.
	 *
	 * Used to determine whether the reload preview is required.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return bool Whether the reload preview is required.
	 */
	public function is_reload_preview_required() {
		return false;
	}

	/**
	 * Render shortcode widget as plain content.
	 *
	 * Override the default behavior by printing the shortcode instead of rendering it.
	 *
	 * @since 1.0.0
	 * @access public
	 */
	public function render_plain_content() {
		// In plain mode, render without shortcode
		$settings = $this->get_settings_for_display();
		$imagesID = array();
		foreach ( $settings['imgs_id'] as $image ) {
			array_push( $imagesID, $image['id'] );
		}
		$imagesID  = implode( ',', $imagesID );
		$shortcode = '[imageFullScreenReveal imgs_id="' . $imagesID . '" title="' . $settings['title'] . '" alignment="' . $settings['alignment'] . '" title_color="' . $settings['title_color'] . '" title_hover_color="' . $settings['title_hover_color'] . '" link_url="' . $settings['link_url'] . '" new_tab="' . $settings['new_tab'] . '" title_font_size="custom"]';
		echo "$shortcode";

	}

	protected function _content_template() {

	}
}
\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \kite_LookBook_Image_Popup_Reveal_Widget() );
