<?php
/**
 * Elementor Image Popup Reveal  Widget.
 *
 * @since 1.0.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

class kite_Image_Popup_Reveal_Widget extends \Elementor\Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve Image Popup Reveal widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'kite-lookbook-image-popup-reveal';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Image Popup Reveal widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'LookBook - Hover Popup Reveal', 'pinkmart' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Image Popup Reveal widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-image-rollover kite-element-icon';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Image Popup Reveal  widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array( 'by-kite' );
	}

	/**
	 * Register Image Popup Reveal  widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function _register_controls() {
		$this->start_controls_section(
			'content_section',
			array(
				'label' => __( 'Image Popup Reveal ', 'pinkmart' ),
				'tab'   => \Elementor\Controls_Manager::TAB_CONTENT,
			)
		);
		$this->add_control(
			'img_id',
			array(
				'label'   => __( 'Image URL', 'pinkmart' ),
				'type'    => \Elementor\Controls_Manager::MEDIA,
				'default' => array(
					'url' => \Elementor\Utils::get_placeholder_image_src(),
				),
			)
		);
		$this->add_control(
			'image_animation',
			array(
				'label'   => __( 'Image reveal animation', 'pinkmart' ),
				'type'    => \Elementor\Controls_Manager::SELECT,
				'options' => array(
					2  => __( 'Default style', 'pinkmart' ),
					4  => __( 'Style 1', 'pinkmart' ),
					5  => __( 'Style 2', 'pinkmart' ),
					9  => __( 'Style 3', 'pinkmart' ),
					10 => __( 'Style 4', 'pinkmart' ),
				),
				'default' => 2,
			)
		);
		$this->add_control(
			'image_size',
			array(
				'label'       => __( 'Image Size', 'pinkmart' ),
				'type'        => \Elementor\Controls_Manager::SELECT,
				'options'     => array(
					'full'         => 'Full',
					'medium'       => 'Medium',
					'thumbnail'    => 'Thumbnail',
					'shop_catalog' => esc_html__( 'Shop Catalog', 'pinkmart' ),
				),
				'description' => esc_html__( 'This item is for quality of loaded image.', 'pinkmart' ),
				'default'     => 'shop_catalog',
			)
		);
		$this->add_control(
			'custom_image_size',
			array(
				'label'        => __( 'Custom Hover Image Size', 'pinkmart' ),
				'type'         => \Elementor\Controls_Manager::SWITCHER,
				'label_on'     => __( 'Enable', 'pinkmart' ),
				'label_off'    => __( 'Disable', 'pinkmart' ),
				'return_value' => 'enable',
				'default'      => 'disable',
			)
		);
		$this->add_control(
			'custom_image_width',
			array(
				'label'     => __( 'Custom Hover Image Width', 'pinkmart' ),
				'type'      => \Elementor\Controls_Manager::TEXT,
				'condition' => array(
					'custom_image_size' => 'enable',
				),
			)
		);
		$this->add_control(
			'custom_image_height',
			array(
				'label'     => __( 'Custom Hover Image Height', 'pinkmart' ),
				'type'      => \Elementor\Controls_Manager::TEXT,
				'condition' => array(
					'custom_image_size' => 'enable',
				),
			)
		);
		$this->add_control(
			'title',
			array(
				'label' => __( 'Title', 'pinkmart' ),
				'type'  => \Elementor\Controls_Manager::TEXTAREA,
			)
		);
		$this->add_control(
			'alignment',
			array(
				'label'   => __( 'Title alignment', 'pinkmart' ),
				'type'    => \Elementor\Controls_Manager::SELECT,
				'options' => array(
					'center' => __( 'Center', 'pinkmart' ),
					'left'   => __( 'Left', 'pinkmart' ),
					'right'  => __( 'Right', 'pinkmart' ),
				),
				'default' => 'center',
			)
		);
		$this->add_control(
			'title_color',
			array(
				'label'     => __( 'Title color ', 'pinkmart' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				'default'   => '',
				'selectors' => array(
					'{{WRAPPER}} .imagepopupreveal > a' => 'color:{{VALUE}}',
					'{{WRAPPER}} .imagepopupreveal > a:after' => 'background-color:{{VALUE}}',
				),
			)
		);
		$this->add_control(
			'title_hover_color',
			array(
				'label'     => __( 'Title Hover Color ', 'pinkmart' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				'default'   => '',
				'selectors' => array(
					'{{WRAPPER}} .imagepopupreveal > a:hover' => 'color:{{VALUE}}',
					'{{WRAPPER}} .imagepopupreveal > a:hover:after' => 'background-color:{{VALUE}}',
				),
			)
		);
		$this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			array(
				'name'     => 'title_typography',
				'label'    => __( 'Title Typography', 'pinkmart' ),
				'scheme'   => \Elementor\Scheme_Typography::TYPOGRAPHY_1,
				'selector' => '{{WRAPPER}} a',
			)
		);
		$this->add_control(
			'link_url',
			array(
				'label' => __( 'Link URL', 'pinkmart' ),
				'type'  => \Elementor\Controls_Manager::URL,
			)
		);
		$this->end_controls_section();

	}

	/**
	 * Render Image Popup Reveal  widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function render() {

		$settings  = $this->get_settings_for_display();
		$shortcode = '[imagePopupReveal img_id="' . $settings['img_id']['id'] . '" image_size="' . $settings['image_size'] . '" title="' . $settings['title'] . '" alignment="' . $settings['alignment'] . '" title_color="' . $settings['title_color'] . '" title_hover_color="' . $settings['title_hover_color'] . '" link_url="' . $settings['link_url']['url'] . '" new_tab="' . $settings['link_url']['is_external'] . '" title_font_size="custom" custom_image_size="' . $settings['custom_image_size'] . '" custom_image_width="' . $settings['custom_image_width'] . '" custom_image_height="' . $settings['custom_image_height'] . '" image_animation="' . $settings['image_animation'] . '"]';
		echo do_shortcode( shortcode_unautop( $shortcode ) );
	}

	/**
	 * Whether the reload preview is required or not.
	 *
	 * Used to determine whether the reload preview is required.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return bool Whether the reload preview is required.
	 */
	public function is_reload_preview_required() {
		return false;
	}

	/**
	 * Render shortcode widget as plain content.
	 *
	 * Override the default behavior by printing the shortcode instead of rendering it.
	 *
	 * @since 1.0.0
	 * @access public
	 */
	public function render_plain_content() {
		// In plain mode, render without shortcode
		$settings  = $this->get_settings_for_display();
		$shortcode = '[imagePopupReveal img_id="' . $settings['img_id']['id'] . '" image_size="' . $settings['image_size'] . '" title="' . $settings['title'] . '" alignment="' . $settings['alignment'] . '" title_color="' . $settings['title_color'] . '" title_hover_color="' . $settings['title_hover_color'] . '" link_url="' . $settings['link_url']['url'] . '" new_tab="' . $settings['link_url']['is_external'] . '" title_font_size="custom" custom_image_size="' . $settings['custom_image_size'] . '" custom_image_width="' . $settings['custom_image_width'] . '" custom_image_height="' . $settings['custom_image_height'] . '" image_animation="' . $settings['image_animation'] . '"]';
		echo "$shortcode";

	}

	protected function _content_template() {

	}
}
\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \kite_Image_Popup_Reveal_Widget() );
