<?php
/**
 * Elementor Newsletter Widget.
 *
 * @since 1.0.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

class Kite_Newsletter_Widget extends \Elementor\Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve Newsletter widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'kite-newsletter';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Newsletter widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Newsletter', 'pinkmart' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Newsletter widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-mail kite-element-icon';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Newsletter widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array( 'by-kite' );
	}

	/**
	 * Register Newsletter widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function _register_controls() {
		$this->start_controls_section(
			'content_section',
			array(
				'label' => esc_html__( 'Newsletter', 'pinkmart' ),
				'tab'   => \Elementor\Controls_Manager::TAB_CONTENT,
			)
		);
		$this->add_control(
			'mailpoet_form',
			array(
				'label'   => esc_html__( 'MailPoet Form', 'pinkmart' ),
				'type'    => \Elementor\Controls_Manager::SELECT,
				'options' => array_merge( array( 1 => 'Select a form ...' ), array_flip( kite_get_mailpoet_forms() ) ),
				'default' => '1',
			)
		);
		$this->add_control(
			'mail_poet_form_style',
			array(
				'label'   => esc_html__( 'Form Style', 'pinkmart' ),
				'type'    => \Elementor\Controls_Manager::SELECT,
				'options' => array(
					'light' => esc_html__( 'Light', 'pinkmart' ),
					'dark'  => esc_html__( 'Dark', 'pinkmart' ),
				),
				'default' => 'light',
			)
		);
		$this->add_control(
			'mail_poet_form_width_style',
			array(
				'label'   => esc_html__( 'Form Width Style', 'pinkmart' ),
				'type'    => \Elementor\Controls_Manager::SELECT,
				'options' => array(
					'boxed'     => esc_html__( 'Boxed', 'pinkmart' ),
					'fullwidth' => esc_html__( 'fullwidth', 'pinkmart' ),
				),
				'default' => 'boxed',
			)
		);
		$this->add_control(
			'mail_poet_button_style',
			array(
				'label'   => esc_html__( 'Button Style', 'pinkmart' ),
				'type'    => \Elementor\Controls_Manager::SELECT,
				'options' => array(
					'style1' => esc_html__( 'Style 1', 'pinkmart' ),
					'style2' => esc_html__( 'Style 2', 'pinkmart' ),
					'style3' => esc_html__( 'Style 3', 'pinkmart' ),
				),
				'default' => 'style1',
			)
		);

		$this->end_controls_section();

	}

	/**
	 * Render Newsletter widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function render() {

		$settings = $this->get_settings_for_display();

		$shortcode = '[kt_newsletter_3 mailpoet_form="' . $settings['mailpoet_form'] . '" mail_poet_form_style="' . $settings['mail_poet_form_style'] . '" mail_poet_form_width_style="' . $settings['mail_poet_form_width_style'] . '" mail_poet_button_style="' . $settings['mail_poet_button_style'] . '"]';
		echo do_shortcode( shortcode_unautop( $shortcode ) );
	}

	/**
	 * Whether the reload preview is required or not.
	 *
	 * Used to determine whether the reload preview is required.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return bool Whether the reload preview is required.
	 */
	public function is_reload_preview_required() {
		return false;
	}

	/**
	 * Render shortcode widget as plain content.
	 *
	 * Override the default behavior by printing the shortcode instead of rendering it.
	 *
	 * @since 1.0.0
	 * @access public
	 */
	public function render_plain_content() {
		// In plain mode, render without shortcode
		$settings  = $this->get_settings_for_display();
		$shortcode = '[kt_newsletter_3 mailpoet_form="' . $settings['mailpoet_form'] . '" mail_poet_form_style="' . $settings['mail_poet_form_style'] . '" mail_poet_form_width_style="' . $settings['mail_poet_form_width_style'] . '" mail_poet_button_style="' . $settings['mail_poet_button_style'] . '"]';
		echo "$shortcode";

	}

	protected function _content_template() {

	}
}
\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \Kite_Newsletter_Widget() );
