<?php
/**
 * Elementor Modern Banner Widget.
 *
 * @since 1.0.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

class Kite_Modern_Banner_Widget extends \Elementor\Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve Modern Banner widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'kite-modern-banner';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Modern Banner widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Modern Banner', 'pinkmart' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Modern Banner widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-image-before-after kite-element-icon';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Animated Text widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array( 'by-kite' );
	}

	/**
	 * Register Animated Text widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function _register_controls() {

		$this->start_controls_section(
			'content_section',
			array(
				'label' => __( 'Modern Banner', 'pinkmart' ),
				'tab'   => \Elementor\Controls_Manager::TAB_CONTENT,
			)
		);
		$this->add_control(
			'image_url',
			array(
				'label'   => __( 'Image URL', 'pinkmart' ),
				'type'    => \Elementor\Controls_Manager::MEDIA,
				'default' => array(
					'url' => \Elementor\Utils::get_placeholder_image_src(),
				),
			)
		);
		$this->add_control(
			'second_image_url',
			array(
				'label'   => __( 'Second Image URL', 'pinkmart' ),
				'type'    => \Elementor\Controls_Manager::MEDIA,
				'default' => array(
					'url' => \Elementor\Utils::get_placeholder_image_src(),
				),
			)
		);
		$this->add_control(
			'hover_effect',
			array(
				'label'   => __( 'Image Style', 'pinkmart' ),
				'type'    => \Elementor\Controls_Manager::SELECT,
				'options' => array(
					'1'  => __( 'Style 1', 'pinkmart' ),
					'2'  => __( 'Style 2', 'pinkmart' ),
					'3'  => __( 'Style 3', 'pinkmart' ),
					'4'  => __( 'Style 4', 'pinkmart' ),
					'5'  => __( 'Style 5', 'pinkmart' ),
					'6'  => __( 'Style 6', 'pinkmart' ),
					'7'  => __( 'Style 7', 'pinkmart' ),
					'8'  => __( 'Style 8', 'pinkmart' ),
					'9'  => __( 'Style 9', 'pinkmart' ),
					'10' => __( 'Style 10', 'pinkmart' ),
					'11' => __( 'Style 11', 'pinkmart' ),
					'12' => __( 'Style 12', 'pinkmart' ),
					'13' => __( 'Style 13', 'pinkmart' ),
					'14' => __( 'Style 14', 'pinkmart' ),
					'15' => __( 'Style 15', 'pinkmart' ),
					'16' => __( 'Style 16', 'pinkmart' ),
				),
				'default' => '1',
			)
		);
		$this->add_control(
			'image_size',
			array(
				'label'   => __( 'Image Size', 'pinkmart' ),
				'type'    => \Elementor\Controls_Manager::SELECT,
				'options' => array(
					'full'      => 'Full',
					'medium'    => 'Medium',
					'thumbnail' => 'Thumbnail',
					'custom'    => 'Custom',
				),
				'default' => 'full',
			)
		);
		$this->add_control(
			'image_size_width',
			array(
				'label'       => __( 'Image Size Width', 'pinkmart' ),
				'label_block' => false,
				'type'        => \Elementor\Controls_Manager::TEXT,
				'condition'   => array(
					'image_size' => 'custom',
				),
			)
		);

		$this->add_control(
			'image_size_height',
			array(
				'label'       => __( 'Image Size Height', 'pinkmart' ),
				'label_block' => false,
				'type'        => \Elementor\Controls_Manager::TEXT,
				'condition'   => array(
					'image_size' => 'custom',
				),
			)
		);

		$this->add_control(
			'image_size_crop',
			array(
				'label'        => __( 'Crop Image', 'pinkmart' ),
				'type'         => \Elementor\Controls_Manager::SWITCHER,
				'label_on'     => __( 'Yes', 'pinkmart' ),
				'label_off'    => __( 'No', 'pinkmart' ),
				'return_value' => 'yes',
				'default'      => 'yes',
				'condition'    => array(
					'image_size' => 'custom',
				),
			)
		);
		$this->add_control(
			'heading',
			array(
				'label' => __( 'Heading', 'pinkmart' ),
				'type'  => \Elementor\Controls_Manager::TEXTAREA,
			)
		);
		$this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			array(
				'name'     => 'heading_typography',
				'label'    => __( 'Heading Typography', 'pinkmart' ),
				'scheme'   => \Elementor\Scheme_Typography::TYPOGRAPHY_1,
				'selector' => '{{WRAPPER}} .content .heading',
			)
		);
		$this->add_control(
			'heading_color',
			array(
				'label'   => __( 'Heading Color', 'pinkmart' ),
				'type'    => \Elementor\Controls_Manager::COLOR,
				'default' => '',
			)
		);
		$this->add_control(
			'title',
			array(
				'label' => __( 'Title', 'pinkmart' ),
				'type'  => \Elementor\Controls_Manager::TEXTAREA,
			)
		);
		$this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			array(
				'name'     => 'title_typography',
				'label'    => __( 'Title Typography', 'pinkmart' ),
				'scheme'   => \Elementor\Scheme_Typography::TYPOGRAPHY_1,
				'selector' => '{{WRAPPER}} .content .title',
			)
		);
		$this->add_control(
			'title_color',
			array(
				'label'   => __( 'Title Color', 'pinkmart' ),
				'type'    => \Elementor\Controls_Manager::COLOR,
				'default' => '',
			)
		);
		$this->add_control(
			'subtitle',
			array(
				'label' => __( 'Subtitle', 'pinkmart' ),
				'type'  => \Elementor\Controls_Manager::TEXTAREA,
			)
		);
		$this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			array(
				'name'     => 'subtitle_typography',
				'label'    => __( 'Subtitle Typography', 'pinkmart' ),
				'scheme'   => \Elementor\Scheme_Typography::TYPOGRAPHY_1,
				'selector' => '{{WRAPPER}} .content .subtitle',
			)
		);
		$this->add_control(
			'subtitle_color',
			array(
				'label'   => __( 'Subtitle Color', 'pinkmart' ),
				'type'    => \Elementor\Controls_Manager::COLOR,
				'default' => '',
			)
		);
		$this->add_control(
			'badge',
			array(
				'label'        => __( 'Badge', 'pinkmart' ),
				'type'         => \Elementor\Controls_Manager::SWITCHER,
				'label_on'     => __( 'Enable', 'pinkmart' ),
				'label_off'    => __( 'Disable', 'pinkmart' ),
				'return_value' => 'enable',
				'default'      => '',
			)
		);
		$this->add_control(
			'badge_position',
			array(
				'label'     => __( 'Badge Position', 'pinkmart' ),
				'type'      => \Elementor\Controls_Manager::SELECT,
				'options'   => array(
					'top left'     => 'Top Left',
					'top right'    => 'Top Right',
					'bottom left'  => 'Bottom Left',
					'bottom right' => 'Bottom Right',
				),
				'default'   => 'top left',
				'condition' => array(
					'badge' => 'enable',
				),
			)
		);
		$this->add_control(
			'badge_bg_color',
			array(
				'label'     => __( 'Badge Background Color', 'pinkmart' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				'default'   => '',
				'condition' => array(
					'badge' => 'enable',
				),
			)
		);
		$this->add_control(
			'badge_content',
			array(
				'label'     => __( 'Badge Content', 'pinkmart' ),
				'type'      => \Elementor\Controls_Manager::TEXTAREA,
				'condition' => array(
					'badge' => 'enable',
				),
			)
		);
		$this->add_control(
			'badge_content_color',
			array(
				'label'     => __( 'Badge Content Color', 'pinkmart' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				'default'   => '',
				'condition' => array(
					'badge' => 'enable',
				),
			)
		);
		$this->add_control(
			'alignment',
			array(
				'label'   => __( 'Content Position', 'pinkmart' ),
				'type'    => \Elementor\Controls_Manager::SELECT,
				'options' => array(
					'top_left'      => 'Top Left',
					'top_center'    => 'Top Center',
					'top_right'     => 'Top Right',
					'center_center' => 'Center Center',
					'center_left'   => 'Center Left',
					'center_right'  => 'Center Right',
					'bottom_left'   => 'Bottom Left',
					'bottom_center' => 'Bottom Center',
					'bottom_right'  => 'Bottom Right',
				),
				'default' => 'top_left',
			)
		);
		$this->add_responsive_control(
			'margin',
			array(
				'label'      => __( 'Margin', 'pinkmart' ),
				'type'       => \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => array( 'px', '%', 'em' ),
				'selectors'  => array(
					'{{WRAPPER}} .modernbanner .content' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				),
			)
		);
		$this->add_control(
			'hover',
			array(
				'label'        => __( 'Hover', 'pinkmart' ),
				'type'         => \Elementor\Controls_Manager::SWITCHER,
				'label_on'     => __( 'Enable', 'pinkmart' ),
				'label_off'    => __( 'Disable', 'pinkmart' ),
				'return_value' => 'enable',
				'default'      => 'enable',
			)
		);
		$this->add_control(
			'hover_color',
			array(
				'label'     => __( 'Hover Color', 'pinkmart' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				'default'   => '',
				'selectors' => array(
					'{{WRAPPER}} .modernbanner:hover .hover' => 'background-color: {{VALUE}}',
				),
				'condition' => array(
					'hover' => 'enable',
				),
			)
		);
		$this->add_control(
			'hover_zoom',
			array(
				'label'        => __( 'Hover Zoom Animation', 'pinkmart' ),
				'type'         => \Elementor\Controls_Manager::SWITCHER,
				'label_on'     => __( 'Enable', 'pinkmart' ),
				'label_off'    => __( 'Disable', 'pinkmart' ),
				'return_value' => 'enable',
				'default'      => 'disable',
				'condition'    => array(
					'hover' => 'enable',
				),
			)
		);
		$this->add_control(
			'url',
			array(
				'label'       => __( 'Link', 'pinkmart' ),
				'label_block' => true,
				'type'        => \Elementor\Controls_Manager::URL,
				'description' => esc_html__( 'Optional URL to another web page.', 'pinkmart' ),
			)
		);
		$this->add_control(
			'url_title',
			array(
				'label'       => __( 'Link Title', 'pinkmart' ),
				'label_block' => true,
				'type'        => \Elementor\Controls_Manager::TEXT,
				'description' => esc_html__( 'Optional URL to another web page.', 'pinkmart' ),
			)
		);
		$this->add_control(
			'link_color',
			array(
				'label'     => __( 'Link Color', 'pinkmart' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				'default'   => '',
				'selectors' => array(
					'{{WRAPPER}} .banner a span,{{WRAPPER}} .banner a.link span:after' => 'color:{{VALUE}}',
				),
			)
		);
		$this->add_control(
			'button_style',
			array(
				'label'   => __( 'Button Style', 'pinkmart' ),
				'type'    => \Elementor\Controls_Manager::SELECT,
				'options' => array(
					'link' => 'Link Style',
					'fill' => 'Button Fill Style',
				),
				'default' => 'link',
			)
		);
		$this->add_control(
			'link_bg_color',
			array(
				'label'     => __( 'Link Background Color', 'pinkmart' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				'default'   => '',
				'condition' => array(
					'button_style' => 'fill',
				),
				'selectors' => array(
					'{{WRAPPER}} .banner a.fill' => 'background-color:{{VALUE}}',
				),
			)
		);
		$this->add_control(
			'link_bg_hover_color',
			array(
				'label'     => esc_html__( 'Link Background Hover Color', 'pinkmart' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				'default'   => '',
				'condition' => array(
					'button_style' => 'fill',
				),
				'selectors' => array(
					'{{WRAPPER}} .banner a.fill:hover' => 'background-color:{{VALUE}} !important;border-color: {{VALUE}} !important',
				),
			)
		);
		$this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			array(
				'name'      => 'link_typography',
				'label'     => __( 'Link Typography', 'pinkmart' ),
				'scheme'    => \Elementor\Scheme_Typography::TYPOGRAPHY_1,
				'selector'  => '{{WRAPPER}} a',
				'condition' => array(
					'button_style' => 'link',
				),
			)
		);
		$this->add_control(
			'show_button',
			array(
				'label'        => __( 'Show Button on release style', 'pinkmart' ),
				'type'         => \Elementor\Controls_Manager::SWITCHER,
				'label_on'     => __( 'Enable', 'pinkmart' ),
				'label_off'    => __( 'Disable', 'pinkmart' ),
				'return_value' => 'enable',
				'default'      => '',
			)
		);
		$this->add_control(
			'size',
			array(
				'label'     => __( 'Button Size', 'pinkmart' ),
				'type'      => \Elementor\Controls_Manager::SELECT,
				'options'   => array(
					'default'  => 'Default',
					'small'    => 'Small',
					'standard' => 'Medium',
					'large'    => 'Large',
				),
				'default'   => 'default',
				'condition' => array(
					'button_style' => 'fill',
				),
			)
		);
		$this->end_controls_section();
	}

	/**
	 * Render Animated Text widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function render() {

		$settings = $this->get_settings_for_display();
		if ( $settings['image_size'] == 'custom' ) {
			$image_size = 'image_size="custom" image_size_width="' . $settings['image_size_width'] . '" image_size_height="' . $settings['image_size_height'] . '" image_size_crop="' . $settings['image_size_crop'] . '"';
		} else {
			$image_size = 'image_size="' . $settings['image_size'] . '"';
		}

		if ( $settings['hover'] == 'enable' ) {
			$hover = 'hover="enable" hover_color_preset="custom" hover_color="' . $settings['hover_color'] . '" hover_zoom="' . $settings['hover_zoom'] . '"';
		} else {
			$hover = 'hover="disable"';
		}
		if ( $settings['badge'] == 'enable' ) {
			$badge = 'badge="enable" badge_content="' . $settings['badge_content'] . '" badge_bg_color="' . $settings['badge_bg_color'] . '" badge_content_color="' . $settings['badge_content_color'] . '" badge_position="' . $settings['badge_position'] . '"';
		} else {
			$badge = 'badge="disable"';
		}
		$shortcode = '[modernBanner image_url="' . $settings['image_url']['id'] . '" ' . $image_size . ' second_image_url="' . $settings['second_image_url']['id'] . '" hover_effect="' . $settings['hover_effect'] . '" heading="' . $settings['heading'] . '" heading_color="' . $settings['heading_color'] . '" title="' . $settings['title'] . '" title_color="' . $settings['title_color'] . '" subtitle="' . $settings['subtitle'] . '" subtitle_color="' . $settings['subtitle_color'] . '" alignment="' . $settings['alignment'] . '" ' . $hover . ' url="' . $settings['url']['url'] . '" new_tab="' . $settings['url']['is_external'] . '" url_title="' . $settings['url_title'] . '" link_color="' . $settings['link_color'] . '" link_bg_color="' . $settings['link_bg_color'] . '" button_style="' . $settings['button_style'] . '" show_button="' . $settings['show_button'] . '" size="' . $settings['size'] . '" ' . $badge . ' heading_size="custom" title_size="custom" subtitle_size="custom" link_size="custom"]';
		echo do_shortcode( shortcode_unautop( $shortcode ) );
	}

	/**
	 * Whether the reload preview is required or not.
	 *
	 * Used to determine whether the reload preview is required.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return bool Whether the reload preview is required.
	 */
	public function is_reload_preview_required() {
		return true;
	}

	/**
	 * Render shortcode widget as plain content.
	 *
	 * Override the default behavior by printing the shortcode instead of rendering it.
	 *
	 * @since 1.0.0
	 * @access public
	 */
	public function render_plain_content() {
		// In plain mode, render without shortcode
		$settings = $this->get_settings_for_display();
		if ( $settings['image_size'] == 'custom' ) {
			$image_size = 'image_size="custom" image_size_width="' . $settings['image_size_width'] . '" image_size_height="' . $settings['image_size_height'] . '" image_size_crop="' . $settings['image_size_crop'] . '"';
		} else {
			$image_size = 'image_size="' . $settings['image_size'] . '"';
		}

		if ( $settings['hover'] == 'enable' ) {
			$hover = 'hover="enable" hover_color_preset="custom" hover_color="' . $settings['hover_color'] . '" hover_zoom="' . $settings['hover_zoom'] . '"';
		} else {
			$hover = 'hover="disable"';
		}

		if ( $settings['badge'] == 'enable' ) {
			$badge = 'badge="enable" badge_content="' . $settings['badge_content'] . '" badge_bg_color="' . $settings['badge_bg_color'] . '" badge_content_color="' . $settings['badge_content_color'] . '" badge_position="' . $settings['badge_position'] . '"';
		} else {
			$badge = 'badge="disable"';
		}
		$shortcode = '[modernBanner image_url="' . $settings['image_url']['id'] . '" ' . $image_size . ' second_image_url="' . $settings['second_image_url']['id'] . '" hover_effect="' . $settings['hover_effect'] . '" heading="' . $settings['heading'] . '" heading_color="' . $settings['heading_color'] . '" title="' . $settings['title'] . '" title_color="' . $settings['title_color'] . '" subtitle="' . $settings['subtitle'] . '" subtitle_color="' . $settings['subtitle_color'] . '" alignment="' . $settings['alignment'] . '" ' . $hover . ' url="' . $settings['url']['url'] . '" new_tab="' . $settings['url']['is_external'] . '" url_title="' . $settings['url_title'] . '" link_color="' . $settings['link_color'] . '" link_bg_color="' . $settings['link_bg_color'] . '" button_style="' . $settings['button_style'] . '" show_button="' . $settings['show_button'] . '" size="' . $settings['size'] . '" ' . $badge . ' heading_size="custom" title_size="custom" subtitle_size="custom" link_size="custom"]';
		echo "$shortcode";

	}

	protected function _content_template() {

	}
}
\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \kite_Modern_Banner_Widget() );
