<?php
/**
 * Elementor Showcase Widget.
 *
 * Elementor widget that inserts an embbedable content into the page, from any given URL.
 *
 * @since 1.0.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

class Kite_ShowCase_Widget extends \Elementor\Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve Showcase widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'kite-showcase';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Showcase widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'ShowCase', 'pinkmart' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Showcase widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-gallery-group kite-element-icon';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Showcase widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array( 'by-kite' );
	}

	/**
	 * Register Showcase widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function _register_controls() {
		$this->start_controls_section(
			'testimonial_settings',
			array(
				'label' => esc_html__( 'ShowCase Settings', 'pinkmart' ),
				'tab'   => \Elementor\Controls_Manager::TAB_CONTENT,
			)
		);
		$this->add_control(
			'title',
			array(
				'label' => esc_html__( 'Title', 'pinkmart' ),
				'type'  => \Elementor\Controls_Manager::TEXT,
			)
		);
		$this->add_control(
			'subtitle',
			array(
				'label' => esc_html__( 'Subtitle', 'pinkmart' ),
				'type'  => \Elementor\Controls_Manager::TEXTAREA,
			)
		);
		$this->add_control(
			'nextsection',
			array(
				'label'   => esc_html__( 'Next Section Button Visibility', 'pinkmart' ),
				'type'    => \Elementor\Controls_Manager::SELECT,
				'options' => array(
					'show' => esc_html__( 'Show', 'pinkmart' ),
					'hide' => esc_html__( 'Hide', 'pinkmart' ),
				),
				'default' => 'show',
			)
		);
		$this->add_control(
			'overlay',
			array(
				'label'   => esc_html__( 'Overlay', 'pinkmart' ),
				'type'    => \Elementor\Controls_Manager::SELECT,
				'options' => array(
					'show' => esc_html__( 'Show', 'pinkmart' ),
					'hide' => esc_html__( 'Hide', 'pinkmart' ),
				),
				'default' => 'show',
			)
		);
		$this->add_control(
			'style',
			array(
				'label'   => esc_html__( 'Next Section Button Visibility', 'pinkmart' ),
				'type'    => \Elementor\Controls_Manager::SELECT,
				'options' => array(
					'dark'  => esc_html__( 'Dark', 'pinkmart' ),
					'light' => esc_html__( 'Light', 'pinkmart' ),
				),
				'default' => 'dark',
			)
		);
		$this->add_control(
			'hover_color',
			array(
				'label'   => esc_html__( 'Enter optional color for On-Hover state', 'pinkmart' ),
				'type'    => \Elementor\Controls_Manager::COLOR,
				'default' => '#cccccc',
			)
		);
		$this->add_control(
			'direction',
			array(
				'label'   => esc_html__( 'Showcase Location ', 'pinkmart' ),
				'type'    => \Elementor\Controls_Manager::SELECT,
				'options' => array(
					'left-align'  => esc_html__( 'Left', 'pinkmart' ),
					'right-align' => esc_html__( 'Right', 'pinkmart' ),
				),
				'default' => 'left-align',
			)
		);
		$this->end_controls_section();

		$this->start_controls_section(
			'repeater_section',
			array(
				'label' => esc_html__( 'Showcase Items', 'pinkmart' ),
				'tab'   => \Elementor\Controls_Manager::TAB_CONTENT,
			)
		);
		$repeater = new \Elementor\Repeater();
		$repeater->add_control(
			'title',
			array(
				'label' => esc_html__( 'Title', 'pinkmart' ),
				'type'  => \Elementor\Controls_Manager::TEXT,
			)
		);
		$repeater->add_control(
			'subtitle',
			array(
				'label' => esc_html__( 'Subtitle', 'pinkmart' ),
				'type'  => \Elementor\Controls_Manager::TEXT,
			)
		);
		$repeater->add_control(
			'text',
			array(
				'label' => esc_html__( 'Content', 'pinkmart' ),
				'type'  => \Elementor\Controls_Manager::TEXTAREA,
			)
		);
		$repeater->add_control(
			'text_bg',
			array(
				'label'   => esc_html__( 'Text Background', 'pinkmart' ),
				'type'    => \Elementor\Controls_Manager::SELECT,
				'options' => array(
					'show' => esc_html__( 'Show', 'pinkmart' ),
					'hide' => esc_html__( 'Hide', 'pinkmart' ),
				),
				'default' => 'hide',
			)
		);

		$repeater->add_control(
			'bg',
			array(
				'label'   => esc_html__( 'Background Image', 'pinkmart' ),
				'type'    => \Elementor\Controls_Manager::MEDIA,
				'default' => array(
					'url' => \Elementor\Utils::get_placeholder_image_src(),
				),
			)
		);
		$repeater->add_control(
			'images',
			array(
				'label'   => esc_html__( 'Select images from media library.', 'pinkmart' ),
				'type'    => \Elementor\Controls_Manager::GALLERY,
				'default' => array(),
			)
		);
		$repeater->add_control(
			'outer_link',
			array(
				'label'         => esc_html__( 'Optional URL to another web page.', 'pinkmart' ),
				'type'          => \Elementor\Controls_Manager::URL,
				'placeholder'   => esc_html__( 'https://your-link.com', 'pinkmart' ),
				'show_external' => true,
				'default'       => array(
					'url' => '#',
				),
			)
		);
		$repeater->add_control(
			'link_title',
			array(
				'label'       => esc_html__( 'Link Title', 'pinkmart' ),
				'type'        => \Elementor\Controls_Manager::TEXT,
				'placeholder' => esc_html__( 'Link title', 'pinkmart' ),
			)
		);
		$this->add_control(
			'showcase_items',
			array(
				'label'       => esc_html__( 'ShowCase Items', 'pinkmart' ),
				'type'        => \Elementor\Controls_Manager::REPEATER,
				'fields'      => $repeater->get_controls(),
				'default'     => array(
					array(
						'title' => esc_html__( 'First Showcase Item', 'pinkmart' ),
					),
					array(
						'title' => esc_html__( 'Second Showcase Item', 'pinkmart' ),
					),
				),
				'title_field' => '{{{ title }}}',
			)
		);
		$this->end_controls_section();

	}

	/**
	 * Render Showcase widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function render() {
		$settings       = $this->get_settings_for_display();
		$showcase_items = '';
		foreach ( $settings['showcase_items'] as $item ) {
			$imagesId = array();
			foreach ( $item['images'] as $img ) {
				array_push( $imagesId, $img['id'] );
			}
			$imagesId        = implode( ',', $imagesId );
			$showcase_items .= '[showcase_item title="' . $item['title'] . '" subtitle="' . $item['subtitle'] . '" text="' . $item['text'] . '" text_bg="' . $item['text_bg'] . '" bg="' . $item['bg']['id'] . '" images="' . $imagesId . '" outer_link="' . $item['outer_link']['url'] . '" link_title="' . $item['link_title'] . '" new_tab="' . $item['outer_link']['is_external'] . '" elementor="true"]';
		}
		$shortcode = '[showcase title="' . $settings['title'] . '" subtitle="' . $settings['subtitle'] . '" nextsection="' . $settings['nextsection'] . '" direction="' . $settings['direction'] . '" style="' . $settings['style'] . '" hover_color="' . $settings['hover_color'] . '" overlay="' . $settings['overlay'] . '"]' . $showcase_items . '[/showcase]';
		echo do_shortcode( shortcode_unautop( $shortcode ) );

	}

	/**
	 * Whether the reload preview is required or not.
	 *
	 * Used to determine whether the reload preview is required.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return bool Whether the reload preview is required.
	 */
	public function is_reload_preview_required() {
		return false;
	}

	/**
	 * Render shortcode widget as plain content.
	 *
	 * Override the default behavior by printing the shortcode instead of rendering it.
	 *
	 * @since 1.0.0
	 * @access public
	 */
	public function render_plain_content() {
		// In plain mode, render without shortcode
		$settings       = $this->get_settings_for_display();
		$showcase_items = '';
		foreach ( $settings['showcase_items'] as $item ) {
			$imagesId = array();
			foreach ( $item['images'] as $img ) {
				array_push( $imagesId, $img['id'] );
			}
			$imagesId        = implode( ',', $imagesId );
			$showcase_items .= '[showcase_item title="' . $item['title'] . '" subtitle="' . $item['subtitle'] . '" text="' . $item['text'] . '" text_bg="' . $item['text_bg'] . '" bg="' . $item['bg']['id'] . '" images="' . $imagesId . '" outer_link="' . $item['outer_link']['url'] . '" link_title="' . $item['link_title'] . '" new_tab="' . $item['outer_link']['is_external'] . '" elementor="true"]';
		}
		$shortcode = '[showcase title="' . $settings['title'] . '" subtitle="' . $settings['subtitle'] . '" nextsection="' . $settings['nextsection'] . '" direction="' . $settings['direction'] . '" style="' . $settings['style'] . '" hover_color="' . $settings['hover_color'] . '" overlay="' . $settings['overlay'] . '"]' . $showcase_items . '[/showcase]';

		echo "$shortcode";
	}

	protected function _content_template() {

	}
}
\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \Kite_ShowCase_Widget() );
