<?php
/**
 * Elementor Social Link Widget.
 *
 * @since 1.0.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

class Kite_Social_Link_Widget extends \Elementor\Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve Social Link widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'kite-social-link';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Social Link widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Social Link', 'pinkmart' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Social Link widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-twitter-embed kite-element-icon';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Social Link widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array( 'by-kite' );
	}

	/**
	 * Register Social Link widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function _register_controls() {

		$this->start_controls_section(
			'content_section',
			array(
				'label' => esc_html__( 'Social Link', 'pinkmart' ),
				'tab'   => \Elementor\Controls_Manager::TAB_CONTENT,
			)
		);
		$this->add_control(
			'sociallink_type',
			array(
				'label'   => esc_html__( 'Social Network Type', 'pinkmart' ),
				'type'    => \Elementor\Controls_Manager::SELECT,
				'options' => array(
					'facebook'     => esc_html__( 'Facebook', 'pinkmart' ),
					'twitter'      => esc_html__( 'Twitter', 'pinkmart' ),
					'vimeo'        => esc_html__( 'Vimeo', 'pinkmart' ),
					'youtube-play' => esc_html__( 'YouTube', 'pinkmart' ),
					'google-plus'  => esc_html__( 'Google+', 'pinkmart' ),
					'dribbble'     => esc_html__( 'Dribbble', 'pinkmart' ),
					'tumblr'       => esc_html__( 'Tumblr', 'pinkmart' ),
					'linkedin'     => esc_html__( 'Linkedin', 'pinkmart' ),
					'flickr'       => esc_html__( 'Flickr', 'pinkmart' ),
					'github'       => esc_html__( 'Github', 'pinkmart' ),
					'lastfm'       => esc_html__( 'Last.fm', 'pinkmart' ),
					'paypal'       => esc_html__( 'Paypal', 'pinkmart' ),
					'feed'         => esc_html__( 'RSS', 'pinkmart' ),
					'skype'        => esc_html__( 'Skype', 'pinkmart' ),
					'wordpress'    => esc_html__( 'WordPress', 'pinkmart' ),
					'yahoo'        => esc_html__( 'Yahoo', 'pinkmart' ),
					'steam'        => esc_html__( 'Steam', 'pinkmart' ),
					'reddit-alien' => esc_html__( 'Reddit', 'pinkmart' ),
					'stumbleupon'  => esc_html__( 'StumbleUpon', 'pinkmart' ),
					'pinterest'    => esc_html__( 'Pinterest', 'pinkmart' ),
					'deviantart'   => esc_html__( 'DeviantArt', 'pinkmart' ),
					'xing'         => esc_html__( 'Xing', 'pinkmart' ),
					'blogger'      => esc_html__( 'Blogger', 'pinkmart' ),
					'soundcloud'   => esc_html__( 'SoundCloud', 'pinkmart' ),
					'delicious'    => esc_html__( 'Delicious', 'pinkmart' ),
					'foursquare'   => esc_html__( 'Foursquare', 'pinkmart' ),
					'instagram'    => esc_html__( 'Instagram', 'pinkmart' ),
					'behance'      => esc_html__( 'Behance', 'pinkmart' ),
					'custom'       => esc_html__( 'Custom Social Network', 'pinkmart' ),
				),
				'default' => 'custom',
			)
		);
		$this->add_control(
			'sociallink_url',
			array(
				'label' => esc_html__( 'Social Network URL', 'pinkmart' ),
				'type'  => \Elementor\Controls_Manager::TEXT,
			)
		);
		$this->add_control(
			'sociallink_style',
			array(
				'label'   => esc_html__( 'Social Network Type', 'pinkmart' ),
				'type'    => \Elementor\Controls_Manager::SELECT,
				'options' => array(
					'dark'  => esc_html__( 'Dark', 'pinkmart' ),
					'light' => esc_html__( 'Light', 'pinkmart' ),
				),
				'default' => 'dark',
			)
		);
		$this->add_control(
			'sociallink_text',
			array(
				'label'     => esc_html__( 'Social network name', 'pinkmart' ),
				'type'      => \Elementor\Controls_Manager::TEXT,
				'default'   => '',
				'condition' => array(
					'sociallink_type' => 'custom',
				),
			)
		);
		$this->end_controls_section();

	}

	/**
	 * Render Social Link widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function render() {

		$settings  = $this->get_settings_for_display();
		$shortcode = '[socialLink sociallink_type="' . $settings['sociallink_type'] . '" sociallink_url="' . $settings['sociallink_url'] . '" sociallink_style="' . $settings['sociallink_style'] . '" sociallink_text="' . $settings['sociallink_text'] . '"]';
		echo do_shortcode( shortcode_unautop( $shortcode ) );
	}

	/**
	 * Whether the reload preview is required or not.
	 *
	 * Used to determine whether the reload preview is required.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return bool Whether the reload preview is required.
	 */
	public function is_reload_preview_required() {
		return false;
	}

	/**
	 * Render shortcode widget as plain content.
	 *
	 * Override the default behavior by printing the shortcode instead of rendering it.
	 *
	 * @since 1.0.0
	 * @access public
	 */
	public function render_plain_content() {
		// In plain mode, render without shortcode
		$settings  = $this->get_settings_for_display();
		$icon      = str_replace( 'icon icon-', '', $settings['icon'] );
		$shortcode = '[socialLink sociallink_type="' . $settings['sociallink_type'] . '" sociallink_url="' . $settings['sociallink_url'] . '" sociallink_style="' . $settings['sociallink_style'] . '" sociallink_text="' . $settings['sociallink_text'] . '"]';
		echo "$shortcode";

	}

	protected function _content_template() {

	}
}
\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \Kite_Social_Link_Widget() );
