<?php
/**
 * Elementor Teta TextBox Widget.
 *
 * @since 1.0.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

class Kite_Text_Slider_Widget extends \Elementor\Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve Teta TextBox widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'kite-text-slider';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Teta TextBox widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Text Slider', 'pinkmart' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Teta TextBox widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-animation-text kite-element-icon';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Teta TextBox widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array( 'by-kite' );
	}

	/**
	 * Register Teta TextBox widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function _register_controls() {
		$this->start_controls_section(
			'content_section',
			array(
				'label' => esc_html__( 'Text Slider', 'pinkmart' ),
				'tab'   => \Elementor\Controls_Manager::TAB_CONTENT,
			)
        );
        $repeater = new \Elementor\Repeater();
		$repeater->add_control(
			'text',
			array(
				'label' => esc_html__( 'Content', 'pinkmart' ),
				'type'  => \Elementor\Controls_Manager::WYSIWYG,
			)
		);
		$repeater->add_control(
			'icon',
			array(
				'label'     => esc_html__( 'Icon', 'pinkmart' ),
				'type'      => \Elementor\Controls_Manager::ICON,
			)
		);
		$this->add_control(
			'text_slides',
			array(
				'label'       => esc_html__( 'Text Slides', 'pinkmart' ),
				'type'        => \Elementor\Controls_Manager::REPEATER,
				'fields'      => $repeater->get_controls(),
				'default'     => array(
					array(
						'icon'  => 'home',
						'text'  => esc_html__( 'Home', 'pinkmart' ),
					),
					array(
						'icon'  => 'home',
						'text'  => esc_html__( 'Home 2', 'pinkmart' ),
					)
				),
				'title_field' => '{{{ text }}}',
			)
		);
		
		$this->add_responsive_control(
			'content_align',
			array(
				'label'        => esc_html__( 'Alignment', 'pinkmart' ),
				'type'         => \Elementor\Controls_Manager::CHOOSE,
				'options'      => array(
					'left'    => array(
						'title' => __( 'Left', 'pinkmart' ),
						'icon'  => 'eicon-text-align-left',
					),
					'center'  => array(
						'title' => __( 'Center', 'pinkmart' ),
						'icon'  => 'eicon-text-align-center',
					),
					'right'   => array(
						'title' => __( 'Right', 'pinkmart' ),
						'icon'  => 'eicon-text-align-right',
					),
				),
				'default'      => '',
				'prefix_class' => 'textbox-align-',
				'selectors'    => array(
					'{{WRAPPER}} .swiper-slide' => 'text-align:{{VALUE}} !important'
				),
			)
		);
		$this->add_responsive_control(
			'content_size',
			array(
				'label'      => esc_html__( 'Content Size', 'pinkmart' ),
				'type'       => \Elementor\Controls_Manager::SLIDER,
				'size_units' => array( '%', 'px' ),
				'range'      => array(
					'%'  => array(
						'min' => 0,
						'max' => 100,
					),
					'px' => array(
						'min' => 0,
						'max' => 1000,
					),
				),
				'selectors'  => array(
					'{{WRAPPER}}' => 'width: {{SIZE}}{{UNIT}};',
				),
			)
		);

		$this->end_controls_section();
        
        $this->start_controls_section(
			'general_style',
			array(
				'label' => esc_html__( 'General Style', 'pinkmart' ),
				'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
			)
        );

        $this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			array(
				'name'     => 'text_typography',
				'label'    => esc_html__( 'Content Typography', 'pinkmart' ),
				'scheme'   => \Elementor\Scheme_Typography::TYPOGRAPHY_1,
				'selector' => '{{WRAPPER}} .kt-slider-text',
			)
        );

        $this->add_responsive_control(
			'container_padding',
			array(
				'label'      => esc_html__( 'Container Padding', 'pinkmart' ),
				'type'       => \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => array( 'px', '%', 'em' ),
				'selectors'  => array(
					'{{WRAPPER}} .kt-text-slider-container' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				),
			)
        );
        
        $this->add_responsive_control(
			'icon_margin',
			array(
				'label'      => esc_html__( 'Icon Margin', 'pinkmart' ),
				'type'       => \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => array( 'px', '%', 'em' ),
				'selectors'  => array(
					'{{WRAPPER}} .swiper-slide .icon' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				),
			)
        );
        
        $this->add_control(
			'bg_color',
			array(
				'label'     => esc_html__( 'Background Color', 'pinkmart' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				'default'   => '',
				'selectors' => array(
					'{{WRAPPER}} .kt-text-slider-container' => 'background-color: {{VALUE}}',
				),
			)
        );

        $this->add_group_control(
			\Elementor\Group_Control_Border::get_type(),
			[
				'name' => 'border',
				'label' => __( 'Border', 'pinkmart' ),
				'selector' => '{{WRAPPER}} .kt-text-slider-container',
			]
		);
    
        $this->add_responsive_control(
			'border_radius',
			array(
				'label'      => esc_html__( 'Border Radius', 'pinkmart' ),
				'type'       => \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => array( 'px', '%', 'em' ),
				'selectors'  => array(
					'{{WRAPPER}} .kt-text-slider-container' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				),
			)
        );

        $this->add_control(
			'text_color',
			array(
				'label'     => esc_html__( 'Text Color', 'pinkmart' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				'default'   => '',
				'selectors' => array(
					'{{WRAPPER}} span' => 'color: {{VALUE}}',
				),
			)
        );

		$this->end_controls_section();
		
		$this->start_controls_section(
			'navigation_style',
			array(
				'label' => esc_html__( 'Navigation Style', 'pinkmart' ),
				'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
			)
		);
		
		$this->add_control(
			'next-icon',
			array(
				'label'     => esc_html__( 'Next Icon', 'pinkmart' ),
				'type'      => \Elementor\Controls_Manager::ICON,
			)
		);

		$this->add_control(
			'prev-icon',
			array(
				'label'     => esc_html__( 'Previous Icon', 'pinkmart' ),
				'type'      => \Elementor\Controls_Manager::ICON,
			)
		);

		$this->end_controls_section();
	}

	/**
	 * Render Teta TextBox widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function render() {

		$settings = $this->get_settings_for_display();

        foreach( $settings['text_slides'] as $slide ) {
            $text_slides[] = [
                'icon'  => $slide['icon'],
                'text'  => $slide['text']
            ];
        }

        $args = [
            'text_slides'   => $text_slides,
            'wrap_style'   	=> [],
			'classes'       => [],
			'prev_icon'		=> $settings['prev-icon'],
			'next_icon'		=> $settings['next-icon'],
        ];
        echo kite_sc_text_slider( $args );
	}

	/**
	 * Whether the reload preview is required or not.
	 *
	 * Used to determine whether the reload preview is required.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return bool Whether the reload preview is required.
	 */
	public function is_reload_preview_required() {
		return false;
	}

}
\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \Kite_Text_Slider_Widget() );
