<?php

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class Kite_Portfolio extends Kite_Post_Type {

	/**
     * Instance of this class.
     *
     * @var      object
     */
	protected static $instance = null;

	/**
     * Return an instance of this class.
     *
     * @return    object    A single instance of this class.
     */
    public static function get_instance() {

        // If the single instance hasn't been set, set it now.
        if ( null == self::$instance ) {
            self::$instance = new self;
        }

        return self::$instance;
	}
	
	function __construct() {
		parent::__construct( 'portfolio' );
	}

	function kite_enqueue_scripts() {
		wp_enqueue_script( 'hoverIntent' );
		wp_enqueue_script( 'jquery-easing' );

		wp_enqueue_script( 'nouislider' );
		wp_enqueue_style( 'nouislider' );

		// Include wpcolorpicker + its patch to support alpha chanel
		wp_enqueue_style( 'wp-color-picker' );
		wp_enqueue_script( 'wp-color-picker' );
		wp_enqueue_script( 'wp-color-picker-alpha' );

		wp_enqueue_style( 'kite-admin-css' );
		wp_enqueue_script( 'kite-admin-js' );

		wp_enqueue_script( 'kite-portfolio', KITEST_THEME_LIB_URI . '/post-types/js/portfolio.js', array( 'jquery' ), KITEST_THEME_VERSION );
	}

	function kite_on_process_field_for_store( $post_id, $key, $settings ) {

		$selectedOpt = $_POST[ $key ];

		// Save Portfolio Attributes Titles
		$attributesTitles = $_POST['attribute-title'];
		$attributes       = array_filter( array_map( 'trim', $attributesTitles ), 'strlen' );
		$attributes       = array_values( $attributesTitles );
		update_post_meta( $post_id, 'attribute-title', $attributes );
		// Save Portfolio Attributes Values
		$attributesValue = $_POST['attribute-value'];
		$attributes      = array_filter( array_map( 'trim', $attributesValue ), 'strlen' );
		$attributes      = array_values( $attributesValue );
		update_post_meta( $post_id, 'attribute-value', $attributes );

		return false;
	}

	protected function kite_get_options() {
		$fields = array(
			'title-bar-switch'        => array(
				'type'    => 'select',
				'label'   => esc_html__( 'Section Title', 'pinkmart' ),
				'options' => array(
					'2' => esc_html__( 'Show post title', 'pinkmart' ),
					'1' => esc_html__( 'Show custom title', 'pinkmart' ),
					'0' => esc_html__( 'No title', 'pinkmart' ),
				),
			),
			'title-text'              => array(
				'type'        => 'text',
				'label'       => esc_html__( 'Title Text', 'pinkmart' ),
				'placeholder' => esc_html__( 'Override title text', 'pinkmart' ),

			),
			'subtitle-text'           => array(
				'type'        => 'text',
				'label'       => esc_html__( 'Subtitle Text', 'pinkmart' ),
				'placeholder' => esc_html__( 'Subtitle text', 'pinkmart' ),
			),
			'image'                   => array(
				'type'    => 'upload',
				'title'   => esc_html__( 'Portfolio Image', 'pinkmart' ),
				'referer' => 'kt-portfolio-image',
				'meta'    => array( 'array' => true ),
			),
			'video-type'              => array(
				'type'    => 'select',
				'options' => array(
					'vimeo'   => esc_html__( 'Vimeo', 'pinkmart' ),
					'youtube' => esc_html__( 'YouTube', 'pinkmart' ),
				),
			),
			'video-id'                => array(
				'type'        => 'text',
				'placeholder' => esc_html__( 'Video URL', 'pinkmart' ),
			), // video id
			'audio-url'               => array(
				'type'        => 'text',
				'placeholder' => esc_html__( 'Audio URL', 'pinkmart' ),
			), // Audio url
			'link-url'                => array(
				'type'        => 'text',
				'placeholder' => esc_html__( 'URL', 'pinkmart' ),
			), // link
			'portfolio-featured-size' => array(
				'type'    => 'visual-select',
				'title'   => esc_html__( 'choose your portfolio post size', 'pinkmart' ),
				'options' => array(
					'square' => 'square',
					'big'    => 'big',
					'slim'   => 'slim',
					'hslim'  => 'hslim',
					'wide'   => 'wide',
				),
			),
			'portfolio-detail-style'  => array(
				'type'    => 'visual-select',
				'title'   => esc_html__( 'choose portfolio detail style', 'pinkmart' ),
				'options' => array(
					'portfolio_detail_full_width' => 'portfolio_detail_full_width',
					'portfolio_detail_boxed'      => 'portfolio_detail_boxed',
					'portfolio_detail_creative'   => 'portfolio_detail_creative',
				),
			),
			'social_share_inherit'    => array(
				'type'    => 'switch',
				'state0'  => esc_html__( 'Inherit from theme setting', 'pinkmart' ),
				'state1'  => esc_html__( 'Custom', 'pinkmart' ),
				'default' => 0,
				'value'   => 0,
			),
			'portfolio-social-share'  => array(
				'type'    => 'switch',
				'state0'  => esc_html__( 'Disable', 'pinkmart' ),
				'state1'  => esc_html__( 'Enable', 'pinkmart' ),
				'default' => 0,
			),
			'attribute-title'         => array(
				'type'        => 'text',
				'class'       => 'attribute-title',
				'placeholder' => esc_html__( 'Attribute Title', 'pinkmart' ),
				'meta'        => array(
					'array'    => true,
					'dontsave' => true,
				), // This will indirectly get saved
			), // Attribute Title
			'attribute-value'         => array(
				'type'        => 'text',
				'class'       => 'attribute-value',
				'placeholder' => esc_html__( 'Attribute Value', 'pinkmart' ),
				'meta'        => array(
					'array'    => true,
					'dontsave' => true,
				), // This will indirectly get saved
			), // Attribute Value
			'extra_class'             => array(
				'type'        => 'text',
				'label'       => esc_html__( 'Extra Class Name', 'pinkmart' ),
				'placeholder' => esc_html__( 'class name ex: class1 class2', 'pinkmart' ),
			), // Extra class name
		);
		// Option sections
		$options = array(
			'title-bar'              => array(
				'title'   => esc_html__( 'Portfolio Detail Title', 'pinkmart' ),
				'tooltip' => esc_html__( 'Choose a portfolio detail title and a subtitle.', 'pinkmart' ),
				'fields'  => array(
					'title-bar'     => $fields['title-bar-switch'],
					'title-text'    => $fields['title-text'],
					'subtitle-text' => $fields['subtitle-text'],
				),
			), // Title bar sec
			'featured-size'          => array(
				'title'   => esc_html__( 'Portfolio Thumbnail Size', 'pinkmart' ),
				'tooltip' => esc_html__( 'Choose a size for the post in the grid.', 'pinkmart' ),
				'fields'  => array(
					'portfolio-featured-size' => $fields['portfolio-featured-size'],
				),
			), // Portfolio Thumbnail Size
			'portfolio-detail-style' => array(
				'title'   => esc_html__( 'Portfolio Detail Style', 'pinkmart' ),
				'tooltip' => esc_html__( 'Choose a Style for portfolio detail.', 'pinkmart' ),
				'fields'  => array(
					'portfolio-detail-style' => $fields['portfolio-detail-style'],
				),
			), // Portfolio Thumbnail Size
			'gallery'                => array(
				'title'   => esc_html__( 'Portfolio Detail Header Images', 'pinkmart' ),
				'tooltip' => esc_html__( 'Choose one image to be shown at portfolio detail page. If you choose more than one image, it will be shown as a slider.', 'pinkmart' ),
				'fields'  => array(
					'image' => $fields['image'],
				),
			), // images sec
			'video'                  => array(
				'title'   => esc_html__( 'Portfolio Video', 'pinkmart' ),
				'tooltip' => esc_html__( 'Copy and paste your browser URL in this section to automatically load a video into your portfolio. Additional information can be uploaded in the content area.', 'pinkmart' ),
				'fields'  => array(
					'video-type' => $fields['video-type'],
					'video-id'   => $fields['video-id'],
				),
			), // Video sec
			'audio'                  => array(
				'title'   => esc_html__( 'Post Audio', 'pinkmart' ),
				'tooltip' => esc_html__( 'You can enter audio URL hosted in SoundCloud', 'pinkmart' ),
				'fields'  => array(
					'audio-url' => $fields['audio-url'],
				),
			), // Audio sec
			'link'                   => array(
				'title'   => esc_html__( 'Post Link', 'pinkmart' ),
				'tooltip' => esc_html__( 'You can enter the URL of another website.', 'pinkmart' ),
				'fields'  => array(
					'link-url' => $fields['link-url'],
				),
			), // Audio sec
			'portfolio-social-share' => array(
				'title'   => esc_html__( 'Portfolio Social Share', 'pinkmart' ),
				'tooltip' => esc_html__( 'Enable or Disable Social sharing for portfolio items.', 'pinkmart' ),
				'fields'  => array(
					'social_share_inherit'   => $fields['social_share_inherit'],
					'portfolio-social-share' => $fields['portfolio-social-share'],
				),
			), // portfolio social share icon sec
			'attribute'              => array(
				'title'   => esc_html__( 'Portfolio Detail Attributes', 'pinkmart' ),
				'tooltip' => esc_html__( 'You can add many attributes to your portfolio item here, for example you can add the project client, date of that project and etc.', 'pinkmart' ),
				'fields'  => array(
					'attribute-title' => $fields['attribute-title'],
					'attribute-value' => $fields['attribute-value'],
				),
			), // attribute sec
			'extra_class'            => array(
				'title'   => esc_html__( 'Extra Class name', 'pinkmart' ),
				'tooltip' => esc_html__( 'Style particular content element differently - add a class name and refer to it in custom CSS. use space between diffrent class name', 'pinkmart' ),
				'fields'  => array(
					'extra_class' => $fields['extra_class'],
				),
			), // Extra Class name
		);

		return array(
			array(
				'id'       => 'portfolio_meta_box',
				'title'    => esc_html__( 'Portfolio Options', 'pinkmart' ),
				'context'  => 'normal',
				'priority' => 'default',
				'options'  => $options,
			), // Meta box
		);
	}
}

function kite_register_portfolio_post_type() {
	Kite_Portfolio::get_instance();
}
add_action( 'after_setup_theme', 'kite_register_portfolio_post_type' );
