<?php
// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}
class Kite_Product extends Kite_Post_Type {

	/**
     * Instance of this class.
     *
     * @var      object
     */
	protected static $instance = null;

	/**
     * Return an instance of this class.
     *
     * @return    object    A single instance of this class.
     */
    public static function get_instance() {

        // If the single instance hasn't been set, set it now.
        if ( null == self::$instance ) {
            self::$instance = new self;
        }

        return self::$instance;
	}
	
	function __construct() {
		parent::__construct( 'product' );
	}

	function kite_enqueue_scripts() {

		wp_enqueue_script( 'jquery-easing' );

		wp_enqueue_script( 'nouislider' );
		wp_enqueue_style( 'nouislider' );

		// Include wpcolorpicker + its patch to support alpha chanel
		wp_enqueue_style( 'wp-color-picker' );
		wp_enqueue_script( 'wp-color-picker' );
		wp_enqueue_script( 'kite-product', KITEST_THEME_LIB_URI . '/post-types/js/product.js', array( 'jquery' ), KITEST_THEME_VERSION );
	}

	protected function kite_get_options() {

		$fields = array(
			'video_type'                      => array(
				'type'    => 'select',
				'label'   => esc_html__( 'Video type', 'pinkmart' ),
				'options' => array(
					'none'                        => esc_html__( 'No video', 'pinkmart' ),
					'local_video_popup'           => esc_html__( 'local video popup', 'pinkmart' ),
					'embeded_video_vimeo_popup'   => esc_html__( 'Vimeo video popup', 'pinkmart' ),
					'embeded_video_youtube_popup' => esc_html__( 'Youtube video popup', 'pinkmart' ),
				),
			),
			'video_webm'                      => array(
				'type'        => 'text',
				'label'       => esc_html__( '.webm extension', 'pinkmart' ),
				'placeholder' => esc_html__( '.webm video', 'pinkmart' ),
			),
			'video_mp4'                       => array(
				'type'        => 'text',
				'label'       => esc_html__( '.mp4 extension', 'pinkmart' ),
				'placeholder' => esc_html__( '.mp4 video', 'pinkmart' ),
			),
			'video_ogv'                       => array(
				'type'        => 'text',
				'label'       => esc_html__( '.ogv extension', 'pinkmart' ),
				'placeholder' => esc_html__( '.ogv video', 'pinkmart' ),
			),
			'video_vimeo_id'                  => array(
				'type'  => 'text',
				'label' => esc_html__( 'Vimeo Video link', 'pinkmart' ),
			),
			'video_youtube_id'                => array(
				'type'  => 'text',
				'label' => esc_html__( 'Youtube Video link', 'pinkmart' ),
			),
			'video_play_button_color'         => array(
				'type'    => 'select',
				'label'   => esc_html__( 'Select play button style.', 'pinkmart' ),
				'options' => array(
					'light' => esc_html__( 'Light', 'pinkmart' ),
					'dark'  => esc_html__( 'Dark', 'pinkmart' ),
				),
			),
			'video_button_label'              => array(
				'type'        => 'text',
				'label'       => esc_html__( 'Play button label', 'pinkmart' ),
				'placeholder' => esc_html__( 'Watch Video', 'pinkmart' ),
			),
			'shop_enable_zoom'                => array(
				'type'    => 'switch',
				'state0'  => esc_html__( 'Disabled', 'pinkmart' ),
				'state1'  => esc_html__( 'Enabled', 'pinkmart' ),
				'value'   => 1,
				'default' => 1,
			),
			'product_detail_style_inherit'    => array(
				'type'    => 'switch',
				'state0'  => esc_html__( 'Inherit from theme setting', 'pinkmart' ),
				'state1'  => esc_html__( 'Custom', 'pinkmart' ),
				'default' => 0,
				'value'   => 0,
			),
			'product_detail_style'            => array(
				'type'    => 'visual-select',
				'options' => array(
					'pd_classic'         => 'pd_classic',
					'pd_kt_classic'      => 'pd_kt_classic',
					'pd_background'      => 'pd_background',
					'pd_top'             => 'pd_top',
					'pd_classic_sidebar' => 'pd_classic_sidebar',
					'pd_fixed_summary'   => 'pd_fixed_summary',
				),
				'class'   => 'product-detail',
				'value'   => 'pd_classic',
			),
			'product-detail-sidebar-position' => array(
				'type'    => 'visual-select',
				'options' => array(
					'left'  => 'left',
					'right' => 'right',
				),
				'class'   => 'product-detail-sidebar',
				'value'   => 'right',
			),
			'product_detail_bg'               => array(
				'type'  => 'color',
				'label' => esc_html__( 'Background Color', 'pinkmart' ),
				'value' => '#fff',
			),
			'product_detail_txt_color'        => array(
				'type'   => 'switch',
				'label'  => esc_html__( 'Text Color', 'pinkmart' ),
				'state0' => esc_html__( 'Light', 'pinkmart' ),
				'state1' => esc_html__( 'Dark', 'pinkmart' ),
				'class'  => 'txt-color',
			),
			'custom_product_label'            => array(
				'label'       => esc_html__( 'Custom Product Label', 'pinkmart' ),
				'id'          => 'custom_product_label',
				'type'        => 'text',
				'placeholder' => esc_html__( 'For example: New', 'pinkmart' ),

			),
			'product_lable_bg'                => array(
				'type'  => 'color',
				'label' => esc_html__( 'Lable Background Color', 'pinkmart' ),
				'value' => '#eee',
			),

			'extra_class'                     => array(
				'type'        => 'text',
				'label'       => esc_html__( 'Extra Class Name', 'pinkmart' ),
				'placeholder' => esc_html__( 'class name ex: class1 class2', 'pinkmart' ),
			), // Extra class name
			'social_share_inherit'            => array(
				'type'    => 'switch',
				'state0'  => esc_html__( 'Inherit from theme setting', 'pinkmart' ),
				'state1'  => esc_html__( 'Custom', 'pinkmart' ),
				'default' => 0,
				'value'   => 0,
			),
			'product-social-share'            => array(
				'type'    => 'switch',
				'state0'  => esc_html__( 'Disable', 'pinkmart' ),
				'state1'  => esc_html__( 'Enable', 'pinkmart' ),
				'default' => 1,
			),
			'product_hashtag'                 => array(
				'label'       => esc_html__( 'Instagram product hashtag', 'pinkmart' ),
				'id'          => 'product_hashtag',
				'type'        => 'text',
				'placeholder' => esc_html__( 'For example: #nike_rush_run', 'pinkmart' ),

			),
		);

		// Option sections
		$options = array(
			'product_detail_style'            => array(
				'title'   => esc_html__( 'Product detail style', 'pinkmart' ),
				'tooltip' => esc_html__( 'Choose product detail style for this product', 'pinkmart' ),
				'fields'  => array(
					'product_detail_style_inherit' => $fields['product_detail_style_inherit'],
					'product_detail_style'         => $fields['product_detail_style'],
					'product_detail_bg'            => $fields['product_detail_bg'],
					'product_detail_txt_color'     => $fields['product_detail_txt_color'],
				),
			),
			'product_detail_sidebar_position' => array(
				'title'   => esc_html__( 'Product detail sidebar position', 'pinkmart' ),
				'tooltip' => esc_html__( 'Choose product detail sidebar position', 'pinkmart' ),
				'fields'  => array(
					'product-detail-sidebar-position' => $fields['product-detail-sidebar-position'],
				),
			), // Product detail bg color
			'shop_enable_zoom'                => array(
				'title'   => esc_html__( 'Zooming of Products Images', 'pinkmart' ),
				'tooltip' => esc_html__( 'Enable or disable zooming of products images', 'pinkmart' ),
				'fields'  => array(
					'shop_enable_zoom' => $fields['shop_enable_zoom'],
				),
			),
			'extra_class'                     => array(
				'title'   => esc_html__( 'Extra Class name', 'pinkmart' ),
				'tooltip' => esc_html__( 'Style particular content element differently - add a class name and refer to it in custom CSS. use space between diffrent class name', 'pinkmart' ),
				'fields'  => array(
					'extra_class' => $fields['extra_class'],
				),
			), // Extra Class name
			'custom_product_label'            => array(
				'title'   => esc_html__( 'custom product lable', 'pinkmart' ),
				'tooltip' => esc_html__( 'Insert custom Label to products', 'pinkmart' ),
				'fields'  => array(
					'custom_product_label' => $fields['custom_product_label'],
					'product_lable_bg'     => $fields['product_lable_bg'],
				),
			), // custom label product
			'product_hashtag'                 => array(
				'title'   => esc_html__( 'product hashtag', 'pinkmart' ),
				'tooltip' => esc_html__( 'Insert tag that will be used to display images from instagram from your customers.', 'pinkmart' ),
				'fields'  => array(
					'product_hashtag' => $fields['product_hashtag'],
				),
			), // instagram hashtag
			'product-social-share'            => array(
				'title'   => esc_html__( 'Social Share display', 'pinkmart' ),
				'tooltip' => esc_html__( 'Disable/enable social share', 'pinkmart' ),
				'fields'  => array(
					'social_share_inherit' => $fields['social_share_inherit'],
					'product-social-share' => $fields['product-social-share'],
				),
			), // Product detail social share button
			'video_type'                      => array(
				'title'   => esc_html__( 'Video type', 'pinkmart' ),
				'tooltip' => esc_html__( 'Select video display type.', 'pinkmart' ),
				'fields'  => array(
					'video_type' => $fields['video_type'],
				),
			), // Video Type
			'video_extensions'                => array(
				'title'   => esc_html__( 'Video extension', 'pinkmart' ),
				'tooltip' => esc_html__( 'Enter self Hosted Videos', 'pinkmart' ),
				'fields'  => array(
					'video_webm' => $fields['video_webm'],
					'video_mp4'  => $fields['video_mp4'],
					'video_ogv'  => $fields['video_ogv'],
				),
			),
			'video_vimeo_id'                  => array(
				'title'   => esc_html__( 'Vimeo Video Link', 'pinkmart' ),
				'tooltip' => esc_html__( 'Enter a Video link', 'pinkmart' ),
				'fields'  => array(
					'video_vimeo_id' => $fields['video_vimeo_id'],
				),
			),
			'video_youtube_id'                => array(
				'title'   => esc_html__( 'Youtube Video link', 'pinkmart' ),
				'tooltip' => esc_html__( 'Enter a Video link', 'pinkmart' ),
				'fields'  => array(
					'video_youtube_id' => $fields['video_youtube_id'],
				),
			), // Youtube ID
			'video_play_button_color'         => array(
				'title'   => esc_html__( 'Play button style', 'pinkmart' ),
				'tooltip' => esc_html__( 'Select play button style', 'pinkmart' ),
				'fields'  => array(
					'video_play_button_color' => $fields['video_play_button_color'],
					'video_button_label'      => $fields['video_button_label'],
				),
			), // Video Button Color
		);
		return array(
			array(
				'id'       => 'product_meta_box',
				'title'    => esc_html__( 'Settings', 'pinkmart' ),
				'context'  => 'normal',
				'priority' => 'default',
				'options'  => $options,
			), // Meta box 1
		);
	}
}

Kite_Product::get_instance();
