<?php

/* -------------------------------------------------------------------------- */
/*                        Check woocommerce activation                        */
/* -------------------------------------------------------------------------- */
if ( ! function_exists( 'kite_woocommerce_installed' ) ) {
	function kite_woocommerce_installed() {
		return class_exists( 'WooCommerce' );
	}
}

/* -------------------------------------------------------------------------- */
/*       Check if current request is an AJAX request for main-loop shop       */
/* -------------------------------------------------------------------------- */
if ( ! function_exists( 'kite_is_shop_ajax_request' ) ) {
	function kite_is_shop_ajax_request() {
		if ( isset( $_POST['ajax_shop_req'] ) && $_POST['ajax_shop_req'] == true ) {
			return true;
		}

		return false;
	}
}
/*--------------------------------------------------------------------------------
Add a pingback url auto-discovery header for single posts, pages, or attachments.
---------------------------------------------------------------------------------*/
function kite_pingback_header() {
	if ( is_singular() && pings_open() ) {
		echo '<link rel="pingback" href="', esc_url( get_bloginfo( 'pingback_url' ) ), '">';
	}
}
add_action( 'wp_head', 'kite_pingback_header' );

/*--------------------------------------------------------------------------------
Kite Preloader
---------------------------------------------------------------------------------*/
if ( ! function_exists( 'kite_preloader_display' ) ) {
	function kite_preloader_display() {
		if ( kite_opt( 'loader_display' , '3' ) == 1 ) { ?>
			<!-- Preloader -->
			<div id="preloader" class="firstload <?php echo kite_opt( 'preloader-type' ); ?>">
				<div id="preloader_box">
						<div id="preloader_items">
							<div class="preloader-items-container">
								<div class="preloader-image" style="background-image:url(<?php kite_preloader(); ?>);"></div>
							</div>
						</div>

						<div class="preloader-text-container">
							<div class="preloader-text">
							<?php
							if ( kite_opt( 'preloader-text' ) ) {
								kite_eopt( 'preloader-text' ); }
							?>
							</div>
						</div>

						<svg width="334" height="334" viewbox="0 0 40 40" class="preloader">
							<polygon points="0 0 0 40 40 40 40 0" class="rect" />
						</svg>
				</div>
				<?php if ( kite_opt( 'preloader-type' ) == 'simple' || kite_opt( 'preloader-type' ) == 'creative' ) { ?>
					<!-- preloader simple  -->
					<svg id="preloader-simple" width="50" height="50" viewbox="0 0 40 40" class="preloader">
						<polygon points="0 0 0 40 40 40 40 0" class="rect" />
					</svg>
					
					
				<?php } elseif ( kite_opt( 'preloader-type' ) == 'circular' ) { ?>
					<!-- preloader circular  -->
					<svg id="preloader-circular" height="50" width="50" class="preloader_circular">
						<circle cx="25" cy="25" r="20" fill="none" stroke-width="2" stroke-miterlimit="10" class="path"></circle>
					</svg>
				<?php } elseif ( kite_opt( 'preloader-type' ) == 'sniper' ) { ?>
					<!-- preloader sniper  -->
					<div  id="preloader-sniper"  class="sniperloader">
						<?php esc_html_e( 'Loading...', 'pinkmart' ); ?>
						<div class="ball"></div>
						<div class="ball"></div>
						<div class="ball"></div>
					</div>
				<?php } ?>            
			</div>
			<?php
		}
	}
	add_action( 'kite_preloader_section', 'kite_preloader_display', 10 );
}
/*--------------------------------------------------------------------------------
Kite Topbar
---------------------------------------------------------------------------------*/
if ( ! function_exists( 'kite_topbar' ) ) {
	function kite_topbar() {
		if ( ! kite_opt( 'topbar_display', false ) ) {
			return;
		}
		$headerType  = kite_opt( 'header-type', '1' );
		$headerStyle = kite_opt( 'header-style', 'normal-menu' );
		$topBarStyle = kite_opt( 'topbar_style', false ) ? 'light' : 'dark';
		
		include locate_template( 'templates/nav/topbar.php', false, false );
	}

	add_action( 'kite_topbar_section', 'kite_topbar', 10 );
}
/*--------------------------------------------------------------------------------
Kite Mobile Nav
---------------------------------------------------------------------------------*/
if ( ! function_exists( 'kite_mobile_nav' ) ) {
	function kite_mobile_nav() {
		include locate_template( 'templates/nav/mobile-nav-menu.php', false, false );
	}

	add_action( 'kite_mobile_nav_section', 'kite_mobile_nav', 10 );
}
/*
---------------------------------
	add SVG file type to uploads
------------------------------------*/
if ( ! function_exists( 'kite_mime_types' ) ) {
	function kite_mime_types( $mimes ) {
		$mimes['svg'] = 'image/svg+xml';
		return $mimes;
	}
}
add_action( 'upload_mimes', 'kite_mime_types' );

if ( ! function_exists( 'kite_svg_media_thumbnails' ) ) {
	function kite_svg_media_thumbnails( $response, $attachment, $meta ) {
		if ( $response['type'] === 'image' && $response['subtype'] === 'svg+xml' && class_exists( 'SimpleXMLElement' ) ) {
			WP_Filesystem();
			global $wp_filesystem;
			try {
				$path = get_attached_file( $attachment->ID );
				if ( WP_Filesystem( $path ) ) {
					$svg    = new SimpleXMLElement( $wp_filesystem->get_contents( $path ) );
					$src    = $response['url'];
					$width  = (int) $svg['width'];
					$height = (int) $svg['height'];

					// media gallery
					$response['image'] = compact( 'src', get_intermediate_image_sizes() );
					$response['thumb'] = compact( 'src', 'width', 'height' );

					// media single
					$response['sizes']['thumbnail'] = array(
						'height'      => $height,
						'width'       => $width,
						'url'         => $src,
						'orientation' => $height > $width ? 'portrait' : 'landscape',
					);
				}
			} catch ( Exception $e ) {
			}
		}

		return $response;
	}
}
add_filter( 'wp_prepare_attachment_for_js', 'kite_svg_media_thumbnails', 10, 3 );

/*
---------------------------------
	Lato font family
------------------------------------*/
if ( ! function_exists( 'kite_custom_google_fonts' ) ) {
	function kite_custom_google_fonts() {
		wp_enqueue_style( 'kite-custom-google-fonts', 'https://fonts.googleapis.com/css?family=Lato:300,400', false );
	}
}
add_action( 'wp_enqueue_scripts', 'kite_custom_google_fonts' );

/*
---------------------------------
	Gathering In-line styles of pages of main-page + adding them to main-page
------------------------------------*/
if ( ! function_exists( 'kite_add_vc_custom_css' ) ) {
	function kite_add_vc_custom_css() {
		if ( ! class_exists( 'Vc_Manager' ) ) {
			return;
		}

		$shortcodes_custom_css = '';

		if ( is_page_template( 'main-page.php' ) ) {
			$page_ids        = get_all_page_ids();
			$current_page_id = get_the_ID();

			if ( count( $page_ids ) > 0 ) {
				foreach ( $page_ids as $page_id ) {
					$separate_page = get_post_meta( $page_id, 'page-position-switch', true );

					if ( $separate_page !== '0' && $page_id != $current_page_id ) {
						$shortcodes_custom_css .= get_post_meta( $page_id, '_wpb_shortcodes_custom_css', true );
					}
				}

				if ( $shortcodes_custom_css != '' ) {
					echo '<s' . 'tyle data-type="vc_shortcodes-custom-css">';
					echo '' . $shortcodes_custom_css;
					echo '</s' . 'tyle>';
				}
			}
		} else {
			if ( function_exists( 'is_shop' ) ) {
				$shortcodes_custom_css = get_post_meta( wc_get_page_id( 'shop' ), '_wpb_shortcodes_custom_css', true );
				if ( is_shop() && $shortcodes_custom_css != '' ) {
					echo '<s' . 'tyle data-type="vc_shortcodes-custom-css">';
					echo '' . $shortcodes_custom_css;
					echo '</s' . 'tyle>';
				}
			}
		}
	}
}
add_action( 'wp_head', 'kite_add_vc_custom_css', 1000 );


/*---------------------------------
	Social Link
------------------------------------*/
if ( ! function_exists( 'kite_social_link' ) ) {
	function kite_social_link( $optKey, $text, $class, $socialname ) {
		$SocialText = $text;
		if ( kite_opt( $optKey ) != '' ) {
			if ( esc_attr( $optKey ) != 'social_custom1_url' && esc_attr( $optKey ) != 'social_custom2_url' ) {
				?>
		
			<li class="sociallink-shortcode textstyle <?php echo esc_attr( $socialname ); ?>">
				<a  href="<?php esc_url( kite_eopt( $optKey ) ); ?>" target="_blank">
					<span><?php echo esc_html( $SocialText ); ?></span>
				</a>
			</li>
			
				<?php
			} elseif ( esc_attr( $optKey ) == 'social_custom1_url' || esc_attr( $optKey ) == 'social_custom2_url' ) {
				?>
			<li class="sociallink-shortcode textstyle <?php echo esc_attr( $socialname ); ?>">
				<a  href="<?php esc_url( kite_eopt( $optKey ) ); ?>" target="_blank">
					<span><?php echo kite_eopt( $SocialText ); ?></span>
				</a>
			</li>
				<?php
			}
		}
	}
}

/*---------------------------------
	Social Icon
------------------------------------*/
if ( ! function_exists( 'kite_social_icon' ) ) {
	function kite_social_icon( $optKey, $class, $socialname, $footerStyle = false ) {
		if ( kite_opt( $optKey ) != '' ) {
			if ( esc_attr( $optKey ) != 'social_custom1_url' && esc_attr( $optKey ) != 'social_custom2_url' ) {
				?>
			
			<li class="<?php echo ( ! $footerStyle ? 'sociallink-shortcode' : 'footersocialicon' ); ?> iconstyle <?php echo esc_attr( $socialname ); ?>">
				<a  href="<?php esc_url( kite_eopt( $optKey ) ); ?>" target="_blank" >
					<span class="firsticon icon <?php echo esc_attr( $class ); ?>"></span>
					<?php if ( ! $footerStyle ) : ?>
					<span class="second-icon icon <?php echo esc_attr( $class ); ?>"></span>
					<?php endif; ?>
				</a>
			</li>
			
				<?php
			} elseif ( esc_attr( $optKey ) == 'social_custom1_url' || esc_attr( $optKey ) == 'social_custom2_url' ) {
				?>
			<li class="sociallink-shortcode iconstyle <?php echo esc_attr( $socialname ); ?>">
				<a  href="<?php esc_url( kite_eopt( $optKey ) ); ?>" >
					<span class="icon <?php echo esc_attr( $class ); ?>"></span>
				</a>
			</li>
				<?php
			}
		}
	}
}


/*---------------------------------
	 Font size in text editor
------------------------------------*/
if ( ! function_exists( 'kite_mce_buttons' ) ) {
	function kite_mce_buttons( $buttons ) {
		array_unshift( $buttons, 'fontsizeselect' );
		return $buttons;
	}
}
add_filter( 'mce_buttons_2', 'kite_mce_buttons' );


// Customize mce editor font sizes
if ( ! function_exists( 'kite_mce_text_sizes' ) ) {
	function kite_mce_text_sizes( $initArray ) {
		$initArray['fontsize_formats'] = '12px 13px 14px 15px 16px 17px 18px 19px 20px 21px 22px 24px 26px 28px 36px 40px 48px 60px 72px 80px';
		return $initArray;
	}
}
add_filter( 'tiny_mce_before_init', 'kite_mce_text_sizes' );

/*---------------------------------
	 Preloader
------------------------------------*/

if ( ! function_exists( 'kite_preloader' ) ) {

	function kite_preloader() {

		global $post;

		if ( isset( $post ) ) {

			if ( ! ( is_page() || is_archive() || is_search() ) && has_post_thumbnail( $post->ID ) ) {
				$thumb = get_post_thumbnail_id( $post->ID );
				if ( function_exists( 'aq_resize' ) ) {
					$img_url = wp_get_attachment_url( $thumb, 'full' );
					echo aq_resize( $img_url, 200, 200, true );
				} else {
					$img_url = wp_get_attachment_url( $thumb, 'thumbnail' );
					echo esc_url( $image_url );
				}
			} elseif ( kite_opt( 'preloader-logo' ) != '' ) {
				kite_eopt( 'preloader-logo' );
			} else {
				echo esc_url( get_template_directory_uri() . '/assets/img/preloader.png' );
			}
		} else {

			if ( get_option( 'preloader-logo' ) != '' ) {
				kite_eopt( 'preloader-logor' );
			} else {
				echo esc_url( get_template_directory_uri() . '/assets/img/preloader.png' );
			}
		}

	}
}

/*---------------------------------
	Customizing wp_title
------------------------------------*/

if ( ! function_exists( 'kite_filter_wp_title' ) ) {

	function kite_filter_wp_title( $title, $separator ) {

		if ( is_feed() ) {
			return $title;
		}
		global $paged, $page;

		if ( is_search() ) {

			$title = sprintf( esc_html__( 'Search results for %s', 'pinkmart' ), '"' . get_search_query() . '"' );

			if ( $paged >= 2 ) {
				$title .= " $separator " . sprintf( esc_html__( 'Page %s', 'pinkmart' ), $paged );
			}

			$title .= " $separator " . get_bloginfo( 'name', 'display' );

			return $title;

		}

		return $title;

	}
}
add_filter( 'wp_title', 'kite_filter_wp_title', 10, 2 );

/* -------------------------------------------------------------------------- */
/*                   Vertical menu - left And Right position                  */
/* -------------------------------------------------------------------------- */

if ( ! function_exists( 'kite_body_class_utility' ) ) {

	function kite_body_class_utility( $classes ) {

		if ( kite_woocommerce_installed() && kite_is_shop_ajax_request() ) {
			return;
		}

		if ( function_exists( 'is_woocommerce' ) && is_shop() ) {
			$classes[] = 'is-woocommerce-shop';
		}

		// prelaoder
		if ( kite_opt( 'loader_display' ) == 0 ) {
			$classes[] = 'no-preloader';
			/* notloaded class prevent from running animation of page transition at first time */
			$classes[]       = 'no-page-transition';
			$transition_type = kite_opt( 'page-transition-type' );
			if ( $transition_type == '' ) {
				$transition_type = 'fade';
			}

			if ( $transition_type != 'none' ) {
				$classes[] = $transition_type;
			}
		} else {
			// use fade effect even in preloader mode
			$classes[] = 'fade';
		}

		if ( kite_opt( 'woocommerce-notices' ) == '0' ) {
			$classes[] = 'no_wc_notices';
		}

		// Menu
		$headerPosition       = kite_opt( 'header-type' );
		$headerStyle          = kite_opt( 'header-style' );
		$ajax_page_transition = kite_opt( 'ajax_page_transition' );

		if ( $ajax_page_transition == 1 ) {
			$classes[] = 'ajax_page_transition';
		}

		// is left menu area turned on
		if ( isset( $headerPosition ) && $headerPosition == 7 ) { // left menu
			$classes[] = 'vertical_menu_enabled left_menu_enabled';
		} elseif ( isset( $headerPosition ) && $headerPosition == 8 ) { // right menu
			$classes[] = 'vertical_menu_enabled right_menu_enabled';
		} elseif ( isset( $headerPosition ) && $headerPosition == 10 ) { // humburger menu
			$classes[] = 'humburger_menu_enabled';
		}

		// Check wishlist
		if ( class_exists( 'YITH_WCWL' ) ) {
			$classes[] = 'wishlist-enable';
		}

		// Check compare
		if ( class_exists( 'YITH_Woocompare' ) ) {
			$classes[] = 'compare-enable';
		}

		// Product gallery
		if ( function_exists( 'is_woocommerce' ) ) {
			global $product;
			if ( is_product() ) {
				$attachment_ids = $product->get_gallery_image_ids();
				if ( count( $attachment_ids ) > 0 ) {
					$classes[] = 'have_gallery';
				}
			}
		}
		// Fixed add to cart
		$catalog_mode      = kite_opt( 'catalog_mode' );
		if ( kite_opt( 'shop-enable-fixed-addtocart' ) == '1' && $catalog_mode == 0 && kite_woocommerce_installed() && is_product() ) {
			$classes[] = 'fixed-add-to-cart-enable';
		}

		if ( kite_opt( 'show_history_in_search', false ) ) {
			$classes[] = 'kt-search-history';
		}
		// check if snap to scroll
		$snap_to_scroll           = kite_get_meta( 'snap-to-scroll' );
		$snap_to_scroll_nav_style = kite_get_meta( 'snap-to-scroll-nav-style' );
		if ( $snap_to_scroll_nav_style != 0 ) {
			$snap_to_scroll_nav_style = ' snap-to-scroll-dark-nav';
		} else {
			$snap_to_scroll_nav_style = '';
		}
		if ( $snap_to_scroll == '1' && ! is_page_template( 'main-page.php' ) ) {
			$classes[] = 'snap-to-scroll snap-to-scroll-init' . esc_attr( $snap_to_scroll_nav_style );
		}

		// product styles in shop(main page)
		if ( kite_woocommerce_installed() ) {
			if ( isset( $_GET['shopGutter'] ) && ( sanitize_text_field( $_GET['shopGutter'] ) == 'with-gutter' || sanitize_text_field( $_GET['shopGutter'] ) == 'no-gutter' ) ) {
				if ( sanitize_text_field( $_GET['shopGutter'] ) == 'no-gutter' ) {
					$product_gutter = 0;
				} else {
					$product_gutter = 1;
				}
			} else {
				$product_gutter = kite_opt( 'shop-product-gutter' );
			}

			if ( is_shop() || is_product_category() || is_product_tag() ) {

				if ( $product_gutter == 0 ) {
					$classes[] = 'no-gutter';
				}
			}

			$catalog_mode = kite_opt( 'catalog_mode', false );
			if ( $catalog_mode ) {
				$classes[] = 'catalog-mode';
			}

			if ( ! kite_opt( 'responsive-sticky-bottom-navbar', true ) ) {
				$classes[] = 'kt-disable-sticky-bottom-navbar';
			}
		}

		// check topbar is Enable Or not
		$topbar = kite_opt( 'topbar_display' );
		if ( $topbar == '1' ) {
			  $classes[] = 'has-topbar';
		}

		// check menu is has-scrollsticky styles or not
		$menuStyle = kite_opt( 'header-style' );
		if ( $menuStyle == 'scroll-sticky' ) {
			  $classes[] = 'has-scrollstickymenu';
		}

		// check if is portfolio detail creative or not
		$pPostDetailType = kite_get_meta( 'portfolio-detail-style' );

		if ( $pPostDetailType == 'portfolio_detail_creative' ) {
			  $classes[] = 'is_portfolio_detail_creative';
		}

		// check if page has extra class name or not
		$extra_class = kite_get_meta( 'extra_class' );
		if ( $extra_class ) {
			$classes[] = $extra_class;
		}

		// Check if show more button For Category Widget is Enable add Class categoryShowMorebutton

        if(  kite_opt( 'show_more_button_in_woocommerce_categories_widget', true ) ) {
            $classes[] =  'show-more-categories';
        }

        if ( kite_opt( 'categories_widget_scroll_animation', false ) ) {
            $classes[] =  'categories-scroll-animation';
        }
		
		return $classes;
	}
}
add_filter( 'body_class', 'kite_body_class_utility' );

if ( ! function_exists( 'kite_body_attr' ) ) {
	function kite_body_attr() {
		global $post;
		if ( function_exists( 'is_shop' ) && is_shop() ) {
			$page_id = wc_get_page_id( 'shop' );
		} else {
			if ( $post ) {
				$page_id = $post->ID;
			} else {
				$page_id = get_the_ID();
			}
		}
		echo 'data-pageid="' . esc_attr( $page_id ) . '"';
	}
}

/* -------------------------------------------------------------------------- */
/*                          Remove the excerpt "more"                         */
/* -------------------------------------------------------------------------- */

if ( ! function_exists( 'kite_new_excerpt_more' ) ) {
	function kite_new_excerpt_more( $more ) {
		return '';
	}
}
add_filter( 'excerpt_more', 'kite_new_excerpt_more' );


/* -------------------------------------------------------------------------- */
/*                retrieves the attachment ID from the file URL               */
/* -------------------------------------------------------------------------- */
if ( ! function_exists( 'kite_get_image_id' ) ) {
	function kite_get_image_id( $image_url ) {
		global $wpdb;
		$prefix = $wpdb->prefix;

		// generate Full size Image URL by removing image size info
		$original_image_url = preg_replace( '/-\d+x\d+(?=\.(jpg|jpeg|png|gif)$)/i', '', $image_url );

		if ( $original_image_url == '' ) {
			$original_image_url = $image_url;
		}

		$attachment = $wpdb->get_col( $wpdb->prepare( 'SELECT ID FROM ' . $prefix . 'posts' . " WHERE guid='%s';", $original_image_url ) );

		if ( count( $attachment ) ) {
			return $attachment[0];
		} else {
			return -1;
		}
	}
}

/* -------------------------------------------------------------------------- */
/*                             Return theme option                            */
/* -------------------------------------------------------------------------- */

if ( ! function_exists( 'kite_opt' ) ) {
	function kite_opt( $option, $def = '' ) {

		global ${KITEST_OPTIONS_KEY};
		$opt = ${KITEST_OPTIONS_KEY};
		if ( empty( $opt ) ) {
			$opt = maybe_unserialize( get_option( 'theme_pinkmart_default_options', false ) );
		}
		if ( ! isset( $opt[ $option ] ) ) {
			return apply_filters( 'kite_option_value', $def, $option );
		}

		$mutli_input_item = 'custom_sidebars';
		$iconItem         = 'topbar_icon';
		if ( is_array( $opt[ $option ] ) && isset( $opt[ $option ]['rgba'] ) ) {
			$value = $opt[ $option ]['rgba'];
		} elseif ( is_array( $opt[ $option ] ) && isset( $opt[ $option ]['font-family'] ) ) {
			$value = $opt[ $option ]['font-family'];
		} elseif ( is_array( $opt[ $option ] ) && isset( $opt[ $option ]['url'] ) ) {
			$value = $opt[ $option ]['url'];
		} elseif ( is_array( $opt[ $option ] ) && $option == $mutli_input_item ) {
			$value = implode( ',', $opt[ $option ] );
		} elseif ( $option == $iconItem ) {
			$icon = substr( $opt[ $option ], 5 );
			$value = $icon;
		} elseif ( is_array( $opt[ $option ] ) && isset( $opt[ $option ]['color'] ) ) {
			$value = $opt[ $option ]['color'];
		} else {
			$value = stripslashes( $opt[ $option ] );
		}

		return apply_filters( 'kite_option_value', $value, $option );
	}
}

if ( ! function_exists( 'kite_eopt' ) ) {
	function kite_eopt( $option ) {
		echo kite_opt( $option );
	}
}


/* -------------------------------------------------------------------------- */
/*                     Gets array value with specified key                    */
/* -------------------------------------------------------------------------- */

if ( ! function_exists( 'kite_array_value' ) ) {
	// if the key doesn't exist  default value is returned
	function kite_array_value( $key, $arr, $default = '' ) {
		return array_key_exists( $key, $arr ) ? $arr[ $key ] : $default;
	}
}

/* -------------------------------------------------------------------------- */
/*                       Deletes attachment by given url                      */
/* -------------------------------------------------------------------------- */

if ( ! function_exists( 'kite_delete_attachment' ) ) {
	function kite_delete_attachment( $url ) {
		global $wpdb;
		$prefix = $wpdb->prefix;

		// We need to get the image's meta ID.
		$results = $wpdb->get_results( $wpdb->prepare( 'SELECT ID FROM ' . $prefix . 'posts' . " where guid = %s AND post_type = 'attachment", $url ) );

		// And delete it
		foreach ( $results as $row ) {
			wp_delete_attachment( $row->ID );
		}
	}
}

/* -------------------------------------------------------------------------- */
/*                                get page meta                               */
/* -------------------------------------------------------------------------- */

if ( ! function_exists( 'kite_get_meta' ) ) {

	function kite_get_meta( $key = '', $single = true ) {
		$pid = null;

		if ( in_the_loop() || is_single() || ( is_page() && ! is_home() ) ) {
			$pid = get_the_ID();
		}

		// Special case for blog page
		if ( is_home() && ! is_front_page() ) {
			$pid = get_option( 'page_for_posts' );
		}

		if ( function_exists( 'is_shop' ) ) {
			if ( is_shop() ) {

				$pid = get_option( 'woocommerce_shop_page_id' );// use woocommerce function : wc_get_page_id('shop') instead of get_option('woocommerce_shop_page_id')
			}
		}

		if ( null == $pid ) {
			return '';
		}
		if ( $key == '' ) {
			return get_post_meta( $pid, $key, false );// return all post metas
		} else {
			return get_post_meta( $pid, $key, $single );
		}
	}
}

/* -------------------------------------------------------------------------- */
/*                      Get title of page inside its loop                     */
/* -------------------------------------------------------------------------- */

if ( ! function_exists( 'kite_get_the_title' ) ) {

	function kite_get_the_title() {
		$pid = null;

		if ( in_the_loop() || is_single() || ( is_page() && ! is_home() ) ) {

			$pid = get_the_ID();

		}

		// Special case for blog page
		if ( is_home() && ! is_front_page() ) {
			$pid = get_option( 'page_for_posts' );
		}

		if ( function_exists( 'is_shop' ) ) {
			if ( is_shop() ) {

				$pid = get_option( 'woocommerce_shop_page_id' );
			}
		}

		if ( null == $pid ) {
			return '';
		}
		return get_the_title( $pid );// return all post metas

	}
}

/* -------------------------------------------------------------------------- */
/*         Get video URL from known sources such as YouTube and vimeo         */
/* -------------------------------------------------------------------------- */

if ( ! function_exists( 'kite_extract_video_info' ) ) {
	function kite_extract_video_info( $string ) {
		// check for YouTube video URL
		if ( preg_match( '/https?:\/\/(?:www\.)?youtube\.com\/watch\?v=[^&\n\s"<>]+/i', $string, $matches ) ) {
			$url = parse_url( $matches[0] );
			parse_str( $url['query'], $queryParams );

			return array(
				'type' => 'youtube',
				'url'  => $matches[0],
				'id'   => $queryParams['v'],
			);
		}
		// Vimeo
		elseif ( preg_match( '/https?:\/\/(?:www\.)?vimeo\.com\/\d+/i', $string, $matches ) ) {
			$url = parse_url( $matches[0] );

			return array(
				'type' => 'vimeo',
				'url'  => $matches[0],
				'id'   => ltrim( $url['path'], '/' ),
			);
		}

		return null;
	}
}

/* -------------------------------------------------------------------------- */
/*                        Get Audio URL from SoundCloud                       */
/* -------------------------------------------------------------------------- */

if ( ! function_exists( 'kite_extract_audio_info' ) ) {
	function kite_extract_audio_info( $string ) {
		// check for soundcloud url
		if ( preg_match( '/https?:\/\/(?:www\.)?soundcloud\.com\/[^&\n\s"<>]+\/[^&\n\s"<>]+\/?/i', $string, $matches ) ) {
			return array(
				'type' => 'soundcloud',
				'url'  => $matches[0],
			);
		}

		return null;
	}
}

if ( ! function_exists( 'kite_soundcloud_get_embed' ) ) {
	function kite_soundcloud_get_embed( $url ) {
		$json = kite_get_url_content( "http://soundcloud.com/oembed?format=json&url=$url"/*, '127.0.0.1:86'*/ );

		if ( is_array( $json ) ) {
			return 'Server Error: ' . $json['error'] . " \nError No: " . $json['errorno'];
		}
		if ( trim( $json ) == '' ) {
			return 'Error: got empty response from soundcloud';
		}
		// Convert the response string to PHP object
		$data = json_decode( $json );

		if ( null == $data ) {
			return "Cant decode the soundcloud response \nData: $json";
		}
		return $data->html;
	}
}


/* -------------------------------------------------------------------------- */
/*                        Downloads data from given URL                       */
/* -------------------------------------------------------------------------- */

if ( ! function_exists( 'kite_get_url_content' ) ) {
	function kite_get_url_content( $url, $proxy = '' ) {
		$args = array(
			'headers'   => array(),
			'body'      => null,
			'sslverify' => true,
		);

		$response = wp_remote_get(
			$url,
			array(
				'timeout' => 45,
			)
		);

		if ( is_wp_error( $response ) ) {
			$error_message = $response->get_error_message();
			$ret           = array(
				'error'   => $error_message,
				'errorno' => '',
			);
		} else {
			$ret = $response['body'];
		}

		return $ret;
	}
}


/* -------------------------------------------------------------------------- */
/*                              Revolution slider                             */
/* -------------------------------------------------------------------------- */

if ( ! function_exists( 'kite_get_revolutionSlider_slides' ) ) {
	function kite_get_revolutionSlider_slides() {

		if ( class_exists( 'RevSlider' ) ) {

			// Get WPDB Object
			global $wpdb;

			// Table name
			$prefix = $wpdb->prefix;

			// Get sliders
			$sliders = $wpdb->get_results(
				'SELECT * FROM ' . $prefix . 'revslider_sliders' . '
												ORDER BY id ASC LIMIT 100'
			);
			$items   = array( 'no-slider' => esc_html__( 'No slider', 'pinkmart' ) );

			// Iterate over the sliders
			foreach ( $sliders as $key => $item ) {
				$items[ $item->alias ] = $item->alias;
			}
			return $items;
		}

	}
}

/* -------------------------------------------------------------------------- */
/*                       Generate Portfolio Skill array                       */
/* -------------------------------------------------------------------------- */

if ( ! function_exists( 'kite_generate_portfolio_skill' ) ) {
	function kite_generate_portfolio_skill() {
		$portfolioTerms = get_terms( 'skills' );
		$skillsArray    = array();

		if ( ! empty( $portfolioTerms ) && ! is_wp_error( $portfolioTerms ) ) { // check is portfolio plugin is active or not
			foreach ( $portfolioTerms as $term ) {
				$skillArray = array(
					'type'    => 'checkbox',
					'checked' => true,
					'value'   => 'visible',
					'label'   => $term->name,
				);

				$skillsArray[ 'term-' . $term->term_id ] = $skillArray;
			}
		}
		return $skillsArray;
	}
}

/* -------------------------------------------------------------------------- */
/*                                     CF7                                    */
/* -------------------------------------------------------------------------- */

if ( ! function_exists( 'kite_get_contact_form7_forms' ) ) {
	function kite_get_contact_form7_forms() {
		// Get WPDB Object
		global $wpdb;

		// Table name
		$table_name = $wpdb->prefix . 'posts';

		// Get forms
		$forms = $wpdb->get_results(
			"SELECT * FROM $table_name
                                      WHERE post_type='wpcf7_contact_form'
                                      LIMIT 100"
		);

		$items = array( 'no-form' => '' );

		// Iterate over the sliders
		foreach ( $forms as $key => $item ) {
			$items[ $item->ID ] = $item->post_title;
		}

		return $items;
	}
}

/* -------------------------------------------------------------------------- */
/*                  post pagination Search And Archive page!                  */
/* -------------------------------------------------------------------------- */

if ( ! function_exists( 'kite_get_pagination' ) ) {
	function kite_get_pagination( $query = null, $range = 3 ) {
		global $paged, $wp_query;

		$q      = $query == null ? $wp_query : $query;
		$output = '';

		// pages that exist
		if ( ! isset( $max_page ) ) {
			$max_page = $q->max_num_pages;
		}

		// We need the pagination only if there is more than 1 page
		if ( $max_page < 2 ) {
			return $output;
		}

		$output .= '<div class="post-pagination">';

		if ( ! $paged ) {
			$paged = 1;
		}

		// To the previous page
		if ( $paged > 1 ) {
			$output .= '<a class="prev-page-link" href="' . esc_url( get_pagenum_link( $paged - 1 ) ) . '">' . esc_html__( 'Prev', 'pinkmart' ) . '</a>';
		}

		if ( $max_page > $range + 1 ) {
			if ( $paged >= $range ) {
				$output .= '<a href="' . esc_url( get_pagenum_link( 1 ) ) . '">1</a>';
			}
			if ( $paged >= ( $range + 1 ) ) {
				$output .= '<span class="page-numbers">&hellip;</span>';
			}
		}

		// We need the sliding effect only if there are more pages than is the sliding range
		if ( $max_page > $range ) {
			// When closer to the beginning
			if ( $paged < $range ) {
				for ( $i = 1; $i <= ( $range + 1 ); $i++ ) {
					$output .= ( $i != $paged ) ? '<a href="' . esc_url( get_pagenum_link( $i ) ) . '">' . $i . '</a>' : '<span class="this-page">' . $i . '</span>';
				}
				// When closer to the end
			} elseif ( $paged >= ( $max_page - ceil( ( $range / 2 ) ) ) ) {
				for ( $i = $max_page - $range; $i <= $max_page; $i++ ) {
					$output .= ( $i != $paged ) ? '<a href="' . esc_url( get_pagenum_link( $i ) ) . '">' . $i . '</a>' : '<span class="this-page">' . $i . '</span>';
				}
				// Somewhere in the middle
			} elseif ( $paged >= $range && $paged < ( $max_page - ceil( ( $range / 2 ) ) ) ) {
				for ( $i = ( $paged - ceil( $range / 2 ) ); $i <= ( $paged + ceil( ( $range / 2 ) ) ); $i++ ) {
					$output .= ( $i != $paged ) ? '<a href="' . esc_url( get_pagenum_link( $i ) ) . '">' . $i . '</a>' : '<span class="this-page">' . $i . '</span>';
				}
			}
			// Less pages than the range, no sliding effect needed
		} else {
			for ( $i = 1; $i <= $max_page; $i++ ) {
				$output .= ( $i != $paged ) ? '<a href="' . esc_url( get_pagenum_link( $i ) ) . '">' . $i . '</a>' : '<span class="this-page">' . $i . '</span>';
			}
		}

		if ( $max_page > $range + 1 ) {
			// On the last page, don't put the Last page link
			if ( $paged <= $max_page - ( $range - 1 ) ) {
				$output .= '<span class="page-numbers">&hellip;</span><a href="' . esc_url( get_pagenum_link( $max_page ) ) . '">' . $max_page . '</a>';
			}
		}

		// Next page
		if ( $paged < $max_page ) {
			$output .= '<a class="next-page-link" href="' . esc_url( get_pagenum_link( $paged + 1 ) ) . '">' . esc_html__( 'Next', 'pinkmart' ) . '</a>';
		}

		$output .= '</div><!-- post-pagination -->';

		echo wp_kses( $output, $GLOBALS['kite-allowed-tags'] );
	}
}

/* -------------------------------------------------------------------------- */
/*                  Add support for Vertical Featured Images.                 */
/* -------------------------------------------------------------------------- */

if ( ! function_exists( 'kite_thumbnail_vertical_check' ) ) {
	function kite_thumbnail_vertical_check( $html, $post_id, $post_thumbnail_id, $size, $attr ) {
		$image_data = wp_get_attachment_image_src( $post_thumbnail_id, 'large' );
		// Get the image width and height from the data provided by wp_get_attachment_image_src()
		if ( $image_data ) {
			$width  = $image_data[1];
			$height = $image_data[2];
			if ( $height > $width ) {
				$html = str_replace( 'attachment-', 'vertical-image attachment-', $html );
			}
		}
		return $html;
	}
}

add_filter( 'post_thumbnail_html', 'kite_thumbnail_vertical_check', 10, 5 );

/* -------------------------------------------------------------------------- */
/*                           Search Pages by content                          */
/* -------------------------------------------------------------------------- */

if ( ! function_exists( 'kite_search_pages_by_content' ) ) {
	function kite_search_pages_by_content( $cnt ) {
		// Get WPDB Object
		global $wpdb;

		$sql = $wpdb->prepare(
			"SELECT * FROM $wpdb->posts WHERE post_type='page' AND post_status='publish' AND post_content LIKE %s",
			'%' . $wpdb->esc_like( $cnt ) . '%'
		);

		// Get forms
		$pages = $wpdb->get_results( $sql );

		return $pages;
	}
}

/* -------------------------------------------------------------------------- */
/*                              Custom Login Logo                             */
/* -------------------------------------------------------------------------- */

if ( ! function_exists( 'kite_login_logo' ) ) {
	function kite_login_logo() {
		wp_register_style( 'kite-login-head-inline-style', false );
		$login_logo      = ( kite_opt( 'login-logo' ) ? kite_opt( 'login-logo' ) : KITEST_THEME_LIB_URI . '/admin/img/wp_login_logo.png' );
		$kiteInlineStyle = 'h1 a { background: url(' . esc_url( $login_logo ) . ') center no-repeat !important; width:302px !important; height:67px !important; }';
		wp_add_inline_style( 'kite-login-head-inline-style', $kiteInlineStyle );
		wp_enqueue_style( 'kite-login-head-inline-style' );
	}
}
add_action( 'login_head', 'kite_login_logo' );

/* -------------------------------------------------------------------------- */
/*                            Sidebar widget count                            */
/* -------------------------------------------------------------------------- */

if ( ! function_exists( 'kite_count_sidebar_widgets' ) ) {
	function kite_count_sidebar_widgets( $sidebar_id, $echo = false ) {
		$sidebars = wp_get_sidebars_widgets();

		if ( ! isset( $sidebars[ $sidebar_id ] ) ) {
			return -1;
		}
		$cnt = count( $sidebars[ $sidebar_id ] );

		if ( $echo ) {
			echo esc_html( $cnt );
		} else {
			return $cnt;
		}
	}
}

/* -------------------------------------------------------------------------- */
/*                                 Get Sidebar                                */
/* -------------------------------------------------------------------------- */

if ( ! function_exists( 'kite_get_sidebar' ) ) {
	function kite_get_sidebar( $id = 1, $class = '' ) {
		if ( kite_count_sidebar_widgets( $id ) < 1 ) {
			$class .= ' no-widgets';
		}
		?>
		<div class="<?php echo esc_attr( $class ); ?>"><?php dynamic_sidebar( $id ); ?></div>
		<?php
	}
}

/* -------------------------------------------------------------------------- */
/*                       Get all exception pages of ajax                      */
/* -------------------------------------------------------------------------- */

if ( ! function_exists( 'kite_no_ajax_pages' ) ) {
	function kite_no_ajax_pages() {

		$no_ajax_pages = array();

		// Get translation pages for current page and merge with main array

		$no_ajax_pages = array_merge( $no_ajax_pages, kite_get_wpml_pages_of_current_page() );

		// Add logout URL to main array
		$no_ajax_pages[] = wp_specialchars_decode( wp_logout_url() );

		return $no_ajax_pages;
	}
}

if ( ! function_exists( 'kite_get_wpml_pages_of_current_page' ) ) {
	function kite_get_wpml_pages_of_current_page() {
		$wpml_pages_of_current_page = array();

		if ( defined( 'ICL_SITEPRESS_VERSION' ) ) {
			$language_pages = icl_get_languages( 'skip_missing=0' );

			foreach ( $language_pages as $key => $language_page ) {
				$wpml_pages_of_current_page[] = $language_page['url'];
			}
		}

		return $wpml_pages_of_current_page;
	}
}

// add 'row' that wrap feilds
if ( ! function_exists( 'kite_comment_before_fields' ) ) {
	function kite_comment_before_fields() {
		echo '<div class="row">';
	}
}

if ( ! function_exists( 'kite_comment_after_fields' ) ) {
	function kite_comment_after_fields() {
		echo '</div>';
	}
}

/* -------------------------------------------------------------------------- */
/*                     Add FeatureImage Boxes In Portfolio                    */
/* -------------------------------------------------------------------------- */

if ( ! function_exists( 'kite_multi_post_thumbnails' ) ) {
	function kite_multi_post_thumbnails() {
		if ( class_exists( 'MultiPostThumbnails' ) ) {

			$featureImageNum = 4;
			$counter         = 2;

			while ( $counter < ( $featureImageNum ) ) {

				// Add Slides in Portfolio Items
				new MultiPostThumbnails(
					array(
						'label'     => 'Featured Image ' . $counter,
						'id'        => $counter . '-slide',
						'post_type' => 'portfolio',
					)
				);

				$counter++;
			}
		}
	}
}
kite_multi_post_thumbnails();

/* -------------------------------------------------------------------------- */
/*                            Get Portfolio Slides                            */
/* -------------------------------------------------------------------------- */

if ( ! function_exists( 'kite_thumbnail_post_slideshow' ) ) {

	function kite_thumbnail_post_slideshow( $image_size, $id, $post_name, $pDTargetCheck, $terms, $isLink, $pLink, $layout, $portolio_type ) {

		// Add slideshow JavaScript
		global $add_slider;
		$add_slider = true;

		$maxthumbnum = 3;

		// Set the slideshow variable
		$slideshow = '';

		// Get The Post Type
		$posttype = get_post_type( $id );

		// Check whether the slide should be link
		$permalink = get_permalink( $id );
		$title     = get_the_title( $id ); // get the item title

		// For custom taxonomy use the fallowing line
		$terms      = wp_get_object_terms( $id, 'skills' );
		$term_names = array();
		foreach ( $terms as $term ) {
			$term_names[] = $term->name;
		}
			global $wp;

		if ( $isLink == true ) {

			  $permalink = '<a href="' . esc_url( $pLink ) . '"  title="' . esc_attr( $title ) . '" class="portfolioLink overlay thumbnail-' . esc_attr( $image_size ) . '">';

		} else {

			if ( $pDTargetCheck == 'portfolio_detail_inner' ) { // portfolio Ajax enable

				if ( is_home() ) { // If Your Portfolio item in Home Page - Portfolio link for fetch Ajax is below form

					$permalink = '<a href="' . esc_url( home_url( '/' ) ) . '#!portfolio-detail/' . esc_attr( $post_name ) . '"  title="' . esc_attr( $title ) . '" class="no_djax portfolioLink overlay thumbnail-' . esc_attr( $image_size ) . '">';

				} else {
					  $permalink = '<a href="' . esc_url( home_url( $wp->request ) ) . '#!portfolio-detail/' . esc_attr( $post_name ) . '"  title="' . esc_attr( $title ) . '" class="no_djax portfolioLink overlay thumbnail-' . esc_attr( $image_size ) . '">';

				}
			} else { // portfolio Ajax Disable
				$permalink = '<a href="' . esc_url( home_url( '/' ) ) . '?portfolio=' . esc_attr( $post_name ) . '"  title="' . esc_attr( $title ) . '" class="portfolioLink overlay thumbnail-' . esc_attr( $image_size ) . '" data-pid="' . esc_attr( $id ) . '">';
			}
		}

		$permalinkend = '</a>';

		$counter = 2; // start counter at 2

		$full = get_post_meta( $id, '_thumbnail_id', false ); // Get Image ID

		$image_size = 'Kite_thumbnail-' . $image_size;

		// Set appropriate size for masonry style
		if ( $layout == 'masonry' ) {
			 $image_size = 'Kite_thumbnail-auto-height';
		}

		// Get all slides
		while ( $counter <= ( $maxthumbnum ) ) {

			${'full' . $counter} = MultiPostThumbnails::get_post_thumbnail_id( $posttype, $counter . '-slide', $id ); // Get Image ID
			${'full' . $counter} = wp_get_attachment_image_src( ${'full' . $counter}, false ); // URL of Second Slide Full Image

			${'thumb' . $counter} = MultiPostThumbnails::get_post_thumbnail_id( $posttype, $counter . '-slide', $id );
			${'thumb' . $counter} = wp_get_attachment_image_src( ${'thumb' . $counter}, $image_size, false ); // URL of next Slide

			$counter++;

		}

		// number of entered thumbnails
		$maxthumbnumset = 0;
		if ( $full ) {
			$maxthumbnumset = 1;
		}

		if ( isset( $thumb2[0] ) && $thumb2[0] != '' ) {
			$maxthumbnumset++;
		}

		if ( isset( $thumb3[0] ) && $thumb3[0] != '' ) {
			$maxthumbnumset++;
		}

		// If there's a featured image
		if ( $maxthumbnumset > 0 ) {
			$thumb = '';
			if ( $full ) {
				$thumb = get_post_meta( $id, '_thumbnail_id', false );

				$temporarythumb = wp_get_attachment_image_src( $thumb[0], $image_size );  // URL of Featured first slide
				if ( $temporarythumb[3] == 'true' ) {
					$thumb = wp_get_attachment_image_src( $thumb[0], 'full' ); // load fullsize image insted when 'wp_get_attachment_image_src' function couldnt crop Images
				} else {
					$thumb = $temporarythumb;
				}
			}

			$slideshow .= $permalink . '<div class="hovercontent">';
			$slideshow .= '<div class="frame top">';
			$slideshow .= '<div></div>';
			$slideshow .= '</div>';
			$slideshow .= '<div class="frame right">';
			$slideshow .= '<div></div>';
			$slideshow .= '</div>';
			$slideshow .= '<div class="frame bottom">';
			$slideshow .= '<div></div>';
			$slideshow .= '</div>';
			$slideshow .= '<div class="frame left">';
			$slideshow .= '<div></div>';
			$slideshow .= '</div>';
			$slideshow .= '<div class="icon-wrap"><div class="icon-type"></div></div><div class="center-line"></div><div class="title-wrap"><div class="titlecontainer"><div class="hover-title">' . get_the_title( $id ) . '</div><div class="hover-subtitle">' . implode( ', ', $term_names ) . '</div></div></div>';
			$slideshow .= '</div>';
			$slideshow .= $permalinkend;
			if ( function_exists( 'getPostLikeLink' ) ) {
				$slideshow .= '<div class="like">' . getPostLikeLink( $id ) . '</div>';
			}
			// If there's more than one slide and the device is not iPad

			if ( $maxthumbnumset > 1 ) {

				$slideshow .= '<div class="portfolioswiper swiper-container"><div class="swiper-wrapper">';
			}

			$thumb1 = $thumb;

			// Loop through thumbnails and set them
			$tcounter = 1;
			while ( $tcounter <= $maxthumbnum ) {
				if ( ${'thumb' . $tcounter} ) {

					// Set appropriate size for masonry style
					if ( $layout == 'masonry' ) {
						$img = '<img src="' . esc_url( ${'thumb' . $tcounter}[0] ) . '" alt="' . esc_attr( $title ) . '">';
						$img = str_replace( 'src=', 'src="data:image/gif;base64,R0lGODlhAQABAAAAACH5BAEKAAEALAAAAAABAAEAAAICTAEAOw==" data-src=', $img );

						$slideshow .= '<div class="pslide lazy-load lazy-load-on-load" style="padding-top:' . esc_attr( kite_get_height_percentage( '', ${'thumb' . $tcounter}[1], ${'thumb' . $tcounter}[2] ) ) . '%;">' . $img . '</div>';
						break;

					} else {

						$height_percentage = '100%';
						if ( $image_size == 'Kite_thumbnail-slim' ) {
							$height_percentage = '200%';
							if ( $portolio_type == 'portfolio_text' ) {
								$height_percentage = 'calc(200% + 92px)'; // 77px meta height + 15 gutter
							} elseif ( $portolio_type == 'portfolio_space' ) {
								$height_percentage = 'calc(200% + 15px)'; // 77px meta height + 15 gutter
							}
						} elseif ( $image_size == 'Kite_thumbnail-hslim' ) {
							$height_percentage = '50%';
						} elseif ( $image_size == 'Kite_thumbnail-big' ) {
							$height_percentage = '100%';
							if ( $portolio_type == 'portfolio_text' ) {
								$height_percentage = 'calc(100% + 77px)';
							}
						} elseif ( $image_size == 'Kite_thumbnail-wide' ) {
							$height_percentage = '25%';
							if ( $portolio_type == 'portfolio_space' ) {
								$height_percentage = 'calc(25% + 15px)'; // 77px meta height + 15 gutter
							}
						}

						// If there is just 1 thumb or it is ipad
						if ( $maxthumbnumset == 1 ) {

							$slideshow .= '<div class="pslide"><div class="lazy-load lazy-load-on-load bg-lazy-load" data-src="' . esc_url( ${'thumb' . $tcounter}[0] ) . '" style="padding-top:' . esc_attr( $height_percentage ) . ';"></div></div>';
							break;
						} else {
							$slideshow .= '<div class="pslide swiper-slide"><div class="lazy-load lazy-load-on-load bg-lazy-load" data-src="' . esc_url( ${'thumb' . $tcounter}[0] ) . '" style="padding-top:' . esc_attr( $height_percentage ) . ';"></div></div>';
						}
					}
				}
				$tcounter++;
			}

			if ( $maxthumbnumset > 1 ) {

				$slideshow .= '</div></div>';
			}
		} else { // when we have no featured image
			$thumb1     = array( get_template_directory_uri() . '/assets/img/placeholders/noImage.jpg', 300, 300 );// sets a default image with a default size
			$slideshow .= '<div class="pslide swiper-slide lazy-load lazy-load-on-load bg-lazy-load" style="padding-top:' . esc_attr( kite_get_height_percentage( '', $thumb1[1], $thumb1[2] ) ) . '%;"></div>';
			$slideshow .= $permalink . '<div class="hovercontent">';
			$slideshow .= '<div class="frame top">';
			$slideshow .= '<div></div>';
			$slideshow .= '</div>';
			$slideshow .= '<div class="frame right">';
			$slideshow .= '<div></div>';
			$slideshow .= '</div>';
			$slideshow .= '<div class="frame bottom">';
			$slideshow .= '<div></div>';
			$slideshow .= '</div>';
			$slideshow .= '<div class="frame left">';
			$slideshow .= '<div></div>';
			$slideshow .= '</div>';
			$slideshow .= '<div class="icon-wrap"><div class="icon-type"></div></div><div class="center-line"></div><div class="title-wrap"><div class="titlecontainer"><div class="hover-title">' . get_the_title( $id ) . '</div><div class="hover-subtitle">' . implode( ', ', $term_names ) . '</div></div></div></div>';
			$slideshow .= $permalinkend;
			if ( function_exists( 'getPostLikeLink' ) ) {
				$slideshow .= '<div class="like">' . getPostLikeLink( $id ) . '</div>';
			}
		} // End if $full

		return $slideshow;

	}
}

/* -------------------------------------------------------------------------- */
/*                             Get Gallery Slides                             */
/* -------------------------------------------------------------------------- */

if ( ! function_exists( 'kite_thumbnail_gallery_slideshow' ) ) {

	function kite_thumbnail_gallery_slideshow( $image_size, $id, $post_name, $terms, $isLink, $pLink, $isVideo, $isAudio, $portfolioLoop, $count, $layout, $portolio_type ) {

		// Add slideshow javascript
		global $add_slider;
		$add_slider = true;

		// Set the slideshow variable
		$slideshow = '';

		// Get The Post Type
		$posttype = get_post_type( $id );

		// Check whether the slide should link
		$permalink = get_permalink( $id );
		$title     = get_the_title( $id ); // get the item title

		// For custom taxonomy use this line below
		$terms      = wp_get_object_terms( $id, 'gallery_cat' );
		$term_names = array();
		foreach ( $terms as $term ) {
			$term_names[] = $term->name;
		}
		$galleryId               = get_the_title( $id );
		$galleryTitleSwitch      = get_post_meta( $id, 'title-bar', true );
		$galleryTitle            = get_post_meta( $id, 'title-text', true );
		$galleryExternalLink     = get_post_meta( $id, 'gallery-external-link', true );
		$galleryExternalLinkText = get_post_meta( $id, 'gallery-external-link-text', true );
		$gallerySubTitle         = get_post_meta( $id, 'subtitle-text', true );

		if ( $galleryTitleSwitch == '1' ) { // Show custom title

			if ( $galleryExternalLink && $galleryExternalLinkText ) {
				$tilteDOM = "<h4> $galleryTitle </h4><p> $gallerySubTitle </p><p class='galleryexternalwrap'><a href='$galleryExternalLink' target='_blank' class='galleryexternallink'> $galleryExternalLinkText  </a></p>";
			} else {
				$tilteDOM = "<h4> $galleryTitle </h4><p> $gallerySubTitle </p>";
			}
		} else {  // Show gallery item title

			if ( $galleryExternalLink && $galleryExternalLinkText ) {
				$tilteDOM = "<h4> $galleryId </h4><p class='galleryexternalwrap'><a  href='$galleryExternalLink' target='_blank' class='galleryexternallink'> $galleryExternalLinkText </a></p>";
			} else {
				$tilteDOM = "<h4> $galleryId </h4>";
			}
		}

		// Creating gallery thumbnail image
		$gallery_url[] = '';
		$gallery_url   = get_post_meta( $id, '_thumbnail_id', false );
		if ( ! empty( $gallery_url ) ) {
			 $gallery_url = wp_get_attachment_image_src( $gallery_url[0], $image_size, false );
		} else { // If we had no gallery image
			 $gallery_url[0] = get_template_directory_uri() . '/assets/img/placeholders/noImage.jpg';
		}

		ob_start();

		// Social Share
		$SocialShareHtml = ob_get_clean();

		if ( $isLink == true ) {

			  $permalink = '<div class="galleryitem" data-sub-html="' . esc_attr( $tilteDOM ) . '" data-src="' . esc_url( $pLink ) . '"><a href="' . esc_url( $pLink ) . '"  title="' . esc_attr( $title ) . '" class="portfolioLink overlay thumbnail-' . esc_attr( $image_size ) . '">';

		} elseif ( $isVideo == true ) {
						  // generate URL of video
						  $videoSRC  = kite_get_meta( 'video-id' );
						  $permalink = '<div class="galleryitem" data-sub-html="' . esc_attr( $tilteDOM ) . '" data-src="' . esc_url( $videoSRC ) . '"><a href="' . esc_url( $gallery_url[0] ) . '"  title="' . esc_attr( $title ) . '" class=" portfolioLink overlay thumbnail-' . esc_attr( $image_size ) . '">';
		} elseif ( $isAudio == true ) {
						  $soundCloudURL = kite_get_meta( 'audio-url' );
						  $permalink     = '<div class="galleryitem" data-sub-html="' . esc_attr( $tilteDOM ) . '" data-iframe="true" data-src="https://w.soundcloud.com/player/?visual=true&url=' . esc_url( $soundCloudURL ) . '"><a href="' . esc_url( $gallery_url[0] ) . '"  title="' . esc_attr( $title ) . '" class=" portfolioLink overlay thumbnail-' . esc_attr( $image_size ) . '"><img alt="' . esc_attr( $title ) . '" src="' . esc_url( $gallery_url[0] ) . '"/>';
		} else {
			if ( $gallery_url[0] == '' ) {
				$gallery_url[0] = get_template_directory_uri() . '/assets/img/placeholders/noImage.jpg';
			}
						  $permalink = '<div class="galleryitem" data-sub-html="' . esc_attr( $tilteDOM ) . '" data-src="' . esc_url( $gallery_url[0] ) . '"><a href="' . esc_url( $gallery_url[0] ) . '"  title="' . esc_attr( $title ) . '" class="portfolioLink overlay thumbnail-' . esc_attr( $image_size ) . '"><img alt="' . esc_attr( $title ) . '" src="' . esc_url( $gallery_url[0] ) . '"/>';
		}

		$permalinkend = '</a></div>';

		$image_size = 'Kite_thumbnail-' . $image_size;

		// Set appropriate size for masonry style
		if ( $layout == 'masonry' ) {
			 $image_size = 'Kite_thumbnail-auto-height';
		}

		// Show featured image
			$thumb[]   = '';
				$thumb = get_post_meta( $id, '_thumbnail_id', false );// Get Image ID + has featured image
		if ( ! empty( $thumb ) ) {

			$temporarythumb = wp_get_attachment_image_src( $thumb[0], $image_size );

			if ( $temporarythumb[3] == 'true' ) {
					$thumb = wp_get_attachment_image_src( $thumb[0], 'full' ); // load fullsize image insted when 'wp_get_attachment_image_src' function couldnt crop Images
			} else {
				$thumb = $temporarythumb;
			}
		} else { // If we had no gallery image
			$thumb = wp_get_attachment_image_src( get_template_directory_uri() . '/assets/img/placeholders/noImage.jpg', $image_size, false );
		}

		if ( ! isset( $thum[0] ) ) {
			$thumb[0] = get_the_post_thumbnail_url($id);
		}

			$slideshow .= $permalink . '<div class="hovercontent">';
			$slideshow .= '<div class="frame top">';
			$slideshow .= '<div></div>';
			$slideshow .= '</div>';
			$slideshow .= '<div class="frame right">';
			$slideshow .= '<div></div>';
			$slideshow .= '</div>';
			$slideshow .= '<div class="frame bottom">';
			$slideshow .= '<div></div>';
			$slideshow .= '</div>';
			$slideshow .= '<div class="frame left">';
			$slideshow .= '<div></div>';
			$slideshow .= '</div>';
			$slideshow .= '<div class="title-wrap"><div class="titlecontainer"><div class="hover-title" >' . esc_html( get_the_title( $id ) ) . '</div><div class="hover-subtitle">' . implode( ', ', $term_names ) . '</div></div></div>';
			$slideshow .= '</div>';
			$slideshow .= $permalinkend;
		if ( function_exists( 'getPostLikeLink' ) ) {
			$slideshow .= '<div class="like">' . getPostLikeLink( $id ) . '</div>';
		}

			// Set the thumbnails

		if ( $layout == 'masonry' ) {
			$img = '<img src="' . esc_url( ${'thumb'}[0] ) . '" alt="' . esc_attr( $title ) . '">';
			$img = str_replace( 'src=', 'src="data:image/gif;base64,R0lGODlhAQABAAAAACH5BAEKAAEALAAAAAABAAEAAAICTAEAOw==" data-src=', $img );

			if ( $thumb == '' ) {// If we had no image, 300x300 is predefined size for thumbnails
				$thumb = array( get_template_directory_uri() . '/assets/img/placeholders/noImage.jpg', 300, 300 );
			}
			$slideshow .= '<div class="pslide lazy-load lazy-load-on-load" data-src="' . esc_url( ${'thumb'}[0] ) . '" style="padding-top:' . esc_attr( kite_get_height_percentage( '', ${'thumb'}[1], ${'thumb'}[2] ) ) . '%;">' . $img . '<a href="' . esc_url( ${'thumb'}[0] ) . '" ></a></div>';
		} else {
			$height_percentage = '100%';

			if ( $image_size == 'Kite_thumbnail-slim' ) {
				$height_percentage = '200%';
				if ( $portolio_type == 'portfolio_text' ) {
					$height_percentage = 'calc(200% + 92px)'; // 77px meta height + 15 gutter
				} elseif ( $portolio_type == 'portfolio_space' ) {
					$height_percentage = 'calc(200% + 15px)'; // 77px meta height + 15 gutter
				}
			} elseif ( $image_size == 'Kite_thumbnail-hslim' ) {
				$height_percentage = '50%';
			} elseif ( $image_size == 'Kite_thumbnail-big' ) {
				$height_percentage = '100%';
				if ( $portolio_type == 'portfolio_text' ) {
					$height_percentage = 'calc(100% + 77px)';
				}
			} elseif ( $image_size == 'Kite_thumbnail-wide' ) {
				$height_percentage = '25%';
				if ( $portolio_type == 'portfolio_space' ) {
					$height_percentage = 'calc(25% + 15px)'; // 77px meta height + 15 gutter
				}
			}

			$slideshow .= '<div class="pslide lazy-load lazy-load-on-load bg-lazy-load" data-src="' . esc_url( ${'thumb'}[0] ) . '" style="padding-top:' . esc_attr( $height_percentage ) . ';"><a href="' . esc_url( ${'thumb'}[0] ) . '"></a></div>';
		}

		return $slideshow;
	}
}

/*-----------------------------------------------------------------*/
// allowed skype protocol
/*-----------------------------------------------------------------*/
if ( ! function_exists( 'kite_ss_allow_skype_protocol' ) ) {
	function kite_ss_allow_skype_protocol( $protocols ) {
		$protocols[] = 'skype';
		return $protocols;
	}
}
add_filter( 'kses_allowed_protocols', 'kite_ss_allow_skype_protocol' );

/*-----------------------------------------------------------------*/
// Newsletter embedding (MailPoet)
/*-----------------------------------------------------------------*/
if ( ! function_exists( 'kite_get_mail_poet_forms' ) ) {
	function kite_get_mail_poet_forms() {

		// Get WPDB Object
		   global $wpdb;

		if ( class_exists( 'WYSIJA_NL_Widget' ) ) {// If the plugin is installed and activated create the shortcode

			// Get Form Values and IDs
			$table_name = $wpdb->prefix . 'wysija_form';
			if ( $wpdb->get_var( "SHOW TABLES LIKE '$table_name'" ) == $table_name ) {// If we had the DB
				$mailPoetForm = $wpdb->get_results( "SELECT * FROM {$wpdb->prefix}wysija_form" );
				$items        = array();

				// Iterate over the Forms
				foreach ( $mailPoetForm  as $value ) {
					 $items[ $value->name ] = $value->form_id;
				}
				if ( ! is_array( $items ) ) {
					return array();
				}
				return $items;
			}

			return array();

		}

		return array();
	}
}	

/* -------------------------------------------------------------------------- */
/*              increase quality of WordPress thumbnails images.              */
/* -------------------------------------------------------------------------- */

if ( ! function_exists( 'kite_thumbnail_quality' ) ) {
	function kite_thumbnail_quality( $quality ) {
		return 100;
	}
}
add_filter( 'jpeg_quality', 'kite_thumbnail_quality' );
add_filter( 'wp_editor_set_quality', 'kite_thumbnail_quality' );

/*---------------------------------
	kite_get_template_part
------------------------------------*/
/**
 * Like get_template_part() lets you pass args to the template file
 * Args are available in the tempalte as $template_args array
 *
 * @param string filepart
 * @param mixed wp_args style argument list
 */

if ( ! function_exists( 'kite_get_template_part' ) ) {

	function kite_get_template_part( $file, $template_args = array(), $cache_args = array() ) {
		$template_args = wp_parse_args( $template_args );
		$cache_args    = wp_parse_args( $cache_args );
		if ( $cache_args ) {
			foreach ( $template_args as $key => $value ) {
				if ( is_scalar( $value ) || is_array( $value ) ) {
					$cache_args[ $key ] = $value;
				} elseif ( is_object( $value ) && method_exists( $value, 'get_id' ) ) {
					$cache_args[ $key ] = call_user_func( 'get_id', $value );
				}
			}
			if ( ( $cache = wp_cache_get( $file, serialize( $cache_args ) ) ) !== false ) {
				if ( ! empty( $template_args['return'] ) ) {
					return $cache;
				}
				echo '' . $cache;
				return;
			}
		}
		$file_handle = $file;
		do_action( 'start_operation', 'kite_template_part::' . $file_handle );
		if ( file_exists( get_stylesheet_directory() . '/' . $file . '.php' ) ) {
			$file = get_stylesheet_directory() . '/' . $file . '.php';
		} elseif ( file_exists( get_template_directory() . '/' . $file . '.php' ) ) {
			$file = get_template_directory() . '/' . $file . '.php';
		}
		ob_start();
		$return = require $file;
		$data   = ob_get_clean();
		do_action( 'end_operation', 'kite_template_part::' . $file_handle );
		if ( $cache_args ) {
			wp_cache_set( $file, $data, serialize( $cache_args ), 3600 );
		}
		if ( ! empty( $template_args['return'] ) ) {
			if ( $return === false ) {
				return false;
			} else {
				return $data;
			}
		}
		echo '' . $data;
	}
}

/*-----------------------------------------------------------------*/
// Size Guide plugin
/*-----------------------------------------------------------------*/

if ( ! function_exists( 'kite_size_guide_plugin_styles' ) ) {

	function kite_size_guide_plugin_styles() {
		wp_dequeue_style( 'ct.sizeguide.style.css' );
		wp_dequeue_style( 'magnific.popup.css' );
		wp_dequeue_script( 'magnific.popup.js' );
		wp_dequeue_script( 'ct.sg.front.js' );
	}
}
add_action( 'wp_print_styles', 'kite_size_guide_plugin_styles' );


/*-----------------------------------------------------------------*/
// Custom Product Tabs for WooCommerce - Remove title
/*-----------------------------------------------------------------*/
if ( ! function_exists( 'kite_remove_yikes_custom_tab_heading' ) ) {

	function kite_remove_yikes_custom_tab_heading( $heading ) {
		return '';
	}
}
add_filter( 'yikes_woocommerce_custom_repeatable_product_tabs_heading', 'kite_remove_yikes_custom_tab_heading' );

/*-----------------------------------------------------------------*/
// wrap all sidebars
/*-----------------------------------------------------------------*/

if ( ! function_exists( 'kite_widget_sidebar' ) ) {
	function kite_widget_sidebar( $index ) {
		$footer_areas = array( 'footer-widget-1', 'footer-widget-2', 'footer-widget-3', 'footer-widget-4', 'footer-widget-5', 'footer-widget-6', 'footer-widget-7' );
		if ( in_array( $index, $footer_areas ) ) {
			return;
		}

		if ( ! is_admin() ) {
			echo '<div class="sidebar widget-area">';
		}
	}
}


if ( ! function_exists( 'kite_widget_sidebar_end' ) ) {
	function kite_widget_sidebar_end( $index ) {
		$footer_areas = array( 'footer-widget-1', 'footer-widget-2', 'footer-widget-3', 'footer-widget-4', 'footer-widget-5', 'footer-widget-6', 'footer-widget-7' );
		if ( in_array( $index, $footer_areas ) ) {
			return;
		}
		if ( ! is_admin() && $index != 'sidebar-store' ) { // sidebar-store is sidebar of dokan plugin (Due to adding widgets witout dynamic_sidebar when sidebar is empty in dokan! the closing tag in "sidebar-store" addded by "dokan_sidebar_store_after" action  )
			echo '</div>';
		}
	}
}

if ( ! function_exists( 'kite_dokan_widget_sidebar_end' ) ) {
	function kite_dokan_widget_sidebar_end() {
		if ( ! is_admin() ) {
			echo '</div>';
		}
	}
}
add_action( 'dynamic_sidebar_before', 'kite_widget_sidebar', 10 );
add_action( 'dynamic_sidebar_after', 'kite_widget_sidebar_end', 10 );
add_action( 'dokan_sidebar_store_after', 'kite_dokan_widget_sidebar_end', 10 );

/*-----------------------------------------------------------------*/
// Cookie Law info  - cookie bar
/*-----------------------------------------------------------------*/

if ( ! function_exists( 'kite_cookies_popup' ) ) {

	add_action( 'wp_footer', 'kite_cookies_popup', 300 );

	function kite_cookies_popup() {

		if ( ! kite_opt( 'cookies_info' ) || kite_opt( 'cookies_info' ) == '0' ) {
			return;
		}
		$page_id = kite_opt( 'cookies_policy_page' );

		?>
			<div class="kt-cookies-bar">
				<div class="kt-cookies-inner">
					<div class="cookies-info-text">
						<?php echo do_shortcode( kite_opt( 'cookies_text_message' ) ); ?>
					</div>
					<div class="cookies-buttons">
						<?php if ( $page_id ) : ?>
							 <a href="<?php echo get_page_link( $page_id ); ?>" class="cookies-more-btn" target="_blank"><?php esc_html_e( 'More info', 'pinkmart' ); ?></a>
						<?php endif; ?>
						<a href="<?php echo esc_url( '#' ); ?>" class="cookies-accept-btn"><?php esc_html_e( 'Accept', 'pinkmart' ); ?></a>
					</div>
				</div>
			</div>
		<?php

	}
}
 // set cookie when woocommerce is not installed
if ( ! kite_woocommerce_installed() ) {
	add_action( 'wp_enqueue_scripts', 'kite_custom_frontend_scripts' );
}

if ( ! function_exists( 'kite_custom_frontend_scripts' ) ) {
	function kite_custom_frontend_scripts() {
		wp_register_script( 'js-cookie', KITEST_THEME_ASSETS_URI . '/js/js.cookie.js', array( 'jquery' ), '2.1.4', true );
		wp_enqueue_script( 'js-cookie' );
	}
}

/*-----------------------------------------------------------------*/
// Maintenance mode
/*-----------------------------------------------------------------*/

if ( ! function_exists( 'kite_maintenance_page' ) ) {
	function kite_maintenance_page() {
		global $pagenow;
		if ( ! kite_opt( 'maintenance_mode' ) || kite_opt( 'maintenance_mode' ) == '0' ) {
			return;
		}
		$page_id = kite_opt( 'maintenance_page' );

		if ( ! $page_id ) {
			return;
		}
		if ( $pagenow !== 'wp-login.php' && ! current_user_can( 'manage_options' ) && ! is_admin() ) {
			wp_redirect( get_permalink( $page_id ) );
			exit();
		}
	}
}
add_action( 'get_header', 'kite_maintenance_page' );


/*-----------------------------------------------------------------*/
// Instagram
/*-----------------------------------------------------------------*/
function kite_get_svg( $variable ) {
	// return file_get_contents($variable);
	WP_Filesystem();
	global $wp_filesystem;
	$variable_data = $wp_filesystem->get_contents( $variable );
	return $variable_data;
}


if ( ! function_exists( 'kite_pretty_number' ) ) {
	function kite_pretty_number( $x = 0 ) {
		$x = (int) $x;

		if ( $x > 1000000 ) {
			return floor( $x / 1000000 ) . 'M';
		}

		if ( $x > 10000 ) {
			return floor( $x / 1000 ) . 'k';
		}
		return $x;
	}
}

if ( ! function_exists( 'kite_scrape_instagram' ) ) {
	function kite_scrape_instagram( $username, $slice = 9 ) {
		$username       = strtolower( $username );
		$by_hashtag     = ( substr( $username, 0, 1 ) == '#' );
		$transient_name = 'instagram-media-new-' . sanitize_title_with_dashes( $username );
		$instagram      = get_transient( $transient_name );

		if ( false === $instagram ) {

			$request_param = ( $by_hashtag ) ? 'explore/tags/' . substr( $username, 1 ) : trim( $username );
			$remote        = wp_remote_get( 'https://instagram.com/' . $request_param );
			if ( is_wp_error( $remote ) ) {
				return new WP_Error( 'site_down', esc_html__( 'Unable to communicate with Instagram.', 'pinkmart' ) );
			}

			if ( 200 != wp_remote_retrieve_response_code( $remote ) ) {
				return new WP_Error( 'invalid_response', esc_html__( 'Instagram did not return a 200.', 'pinkmart' ) );
			}
			$instagram = kite_instagram_decode( $remote['body'], false, $by_hashtag );
			// do not set an empty transient - should help catch private or empty accounts
			if ( ! empty( $instagram ) && ! is_wp_error( $instagram ) ) {
				$instagram = maybe_serialize( $instagram );
				set_transient( $transient_name, $instagram, apply_filters( 'null_instagram_cache_time', DAY_IN_SECONDS * 2 ) );
			}
		}
		if ( ! empty( $instagram ) && ! is_wp_error( $instagram ) ) {
			$instagram = maybe_unserialize( $instagram );
			return array_slice( $instagram, 0, $slice );
		} else {
			return new WP_Error( 'no_images', esc_html__( 'Instagram did not return any images.', 'pinkmart' ) );
		}
	}
}
function kite_instagram_decode( $insta_html_response, $ajax_request = false, $by_hashtag ) {
	if ( empty( $insta_html_response ) ) {
		return;
	}
	$shards     = explode( 'window._sharedData = ', $insta_html_response );
	$insta_json = explode( ';</script>', $shards[1] );
	if ( $ajax_request ) {
		$insta_array = json_decode( stripslashes( $insta_json[0] ), true );
	} else {
		$insta_array = json_decode( $insta_json[0], true );
	}
	if ( ! $insta_array ) {
		return new WP_Error( 'bad_json', esc_html__( 'Instagram has returned invalid data.', 'pinkmart' ) );
	}

	if ( isset( $insta_array['entry_data']['ProfilePage'][0]['graphql']['user']['edge_owner_to_timeline_media']['edges'] ) ) {
		$images = $insta_array['entry_data']['ProfilePage'][0]['graphql']['user']['edge_owner_to_timeline_media']['edges'];
	} elseif ( $by_hashtag && isset( $insta_array['entry_data']['TagPage'][0]['graphql']['hashtag']['edge_hashtag_to_media']['edges'] ) ) {
		$images = $insta_array['entry_data']['TagPage'][0]['graphql']['hashtag']['edge_hashtag_to_media']['edges'];
	} else {
		return new WP_Error( 'bad_json_2', esc_html__( 'Instagram has returned invalid data.', 'pinkmart' ) );
	}

	if ( ! is_array( $images ) ) {
		return new WP_Error( 'bad_array', esc_html__( 'Instagram has returned invalid data.', 'pinkmart' ) );
	}

	$instagram = array();

	foreach ( $images as $image ) {
		$image = $image['node'];

		$caption = esc_html__( 'Instagram Image', 'pinkmart' );
		if ( ! empty( $image['edge_media_to_caption']['edges'][0]['node']['text'] ) ) {
			$caption = $image['edge_media_to_caption']['edges'][0]['node']['text'];
		}

		$image['thumbnail_src'] = preg_replace( '/^https:/i', '', $image['thumbnail_src'] );
		$image['thumbnail']     = preg_replace( '/^https:/i', '', $image['thumbnail_resources'][0]['src'] );
		$image['medium']        = preg_replace( '/^https:/i', '', $image['thumbnail_resources'][2]['src'] );
		$image['large']         = $image['thumbnail_src'];

		$type = ( $image['is_video'] ) ? 'video' : 'image';

		$instagram[] = array(
			'description' => $caption,
			'link'        => '//instagram.com/p/' . $image['shortcode'],
			'comments'    => $image['edge_media_to_comment']['count'],
			'likes'       => $image['edge_liked_by']['count'],
			'thumbnail'   => $image['thumbnail'],
			'medium'      => $image['medium'],
			'large'       => $image['large'],
			'type'        => $type,
		);
	}
	return $instagram;
}

/*-----------------------------------------------------------------*/
// Social Share buttons
/*-----------------------------------------------------------------*/

if ( ! function_exists( 'kite_social_share' ) ) {
	function kite_social_share() {
		$socialshare = kite_opt( 'social_share_display' ); // theme settings;
		if ( $socialshare != 0 ) {
			?>
			<div class="socialshare-container">
				<div class="label hidden-phone hidden-v-tablet"> <?php esc_html_e( 'Share ', 'pinkmart' ); ?> </div>
			   <?php get_template_part( 'templates/social-share' ); ?>
			</div>
			<?php
		}
	}
}

/*-----------------------------------------------------------------*/
// add animation option to VC row
/*-----------------------------------------------------------------*/

if ( ! function_exists( 'kite_get_row_animation_attr' ) ) {
	function kite_get_row_animation_attr( $output, $obj, $attr ) {
		if ( ! class_exists( 'Vc_Manager') ) {
			return;
		}
		if ( ! empty( $attr['row_animation'] ) ) {

			$row_animation = $attr['row_animation'];
			if ( isset( $attr['row_animation_delay'] ) ) {
				$data_delay = $attr['row_animation_delay'];
			} else {
				$data_delay = 0;
			}

			$output = preg_replace_callback(
				'/row-animation-enable.*?"/',
				function ( $matches ) use ( $row_animation, $data_delay ) {
					return strtolower( $matches[0] . '  data-animation="' . $row_animation . '" data-delay="' . $data_delay . '"' );
				},
				$output
			);
		}
		return $output;
	}
}
add_filter( 'vc_shortcode_output', 'kite_get_row_animation_attr', 10, 3 );

/*-----------------------------------------------------------------*/
// Instagram Hashtag
/*-----------------------------------------------------------------*/
add_action( 'woocommerce_after_single_product_summary', 'kite_instagram_hashtag', 30 );
if ( ! function_exists( 'kite_instagram_hashtag' ) ) {
	function kite_instagram_hashtag() {
		
		if ( ! kite_opt( 'instagram_in_product_detail', true ) || empty( $hashtag = get_post_meta( get_the_ID(), 'product_hashtag', true ) ) ) {
			return;
		}
		$instagramimg = kite_sc_instgram_feed(
			array(
				'user'                => esc_html( $hashtag ),
				'column'              => '6',
				'image_resolution'    => 'medium',
				'carousel'            => 'enable',
				'enterance_animation' => 'disable',
				'like'                => 'enable',
				'gutter'              => 'no',
				'comment'             => 'enable',

			)
		);
		if ( ! empty( $instagramimg ) ) {
			?>
		
			<div class="kite_instagram_product">
				
					<div class="product-instagram">
						<h3> <?php echo esc_attr( $hashtag ); ?></h3>
						<?php esc_html_e( 'Tag your photos with this on Instagram.', 'pinkmart' ); ?>
					</div>
					<?php echo '' . $instagramimg; ?>
			</div>
			<?php
		}
	}
}

/*-----------------------------------------------------------------*/
// Popup Newsletter
/*-----------------------------------------------------------------*/
if ( ! function_exists( 'kite_popup_newsletter_content' ) ) {
	function kite_popup_newsletter_content() {

		if ( ! kite_opt( 'popupNewsletterDisplay' ) || kite_opt( 'popupNewsletterDisplay' ) == '0' ) {
			return;
		} else {

			if ( kite_opt( 'popupNewsLetterDisplayMobile' ) == '0' ) {
				echo '<div id="kt-popup-newsletter" class="hidden-phone">';
			} else {
				echo '<div id="kt-popup-newsletter">';
			}
			kite_popup_newsletter();
			echo '</div>';

		}
	}
}
add_action( 'wp_footer', 'kite_popup_newsletter_content', 50 );


if ( ! function_exists( 'kite_popup_newsletter' ) ) {
	function kite_popup_newsletter() {
		$delay = ( kite_opt( 'popupNewsLetterDelay' ) == '' ? '500' : kite_opt( 'popupNewsLetterDelay' ) );
		?>
		<div class="kt-popup-newsletter-inner <?php echo ( ! kite_opt( 'popupNewsLetterBackgroundImage' ) ) ? ' no_bg_image' : ''; ?>" data-delay="<?php echo esc_attr( $delay ); ?>">
		<?php
				echo '<div class="kt-popup-newsletter-close"></div>';
		?>
		<?php if ( kite_opt( 'popupNewsLetterBackgroundImage' ) ) { ?>
					<div class="kt-popup-newsletter-image" style="background: url(<?php echo kite_opt( 'popupNewsLetterBackgroundImage' ); ?>) center no-repeat"></div>
				<?php } ?>

				<div class="kt-popup-newsletter-content">
					<h4 class="kt-popup-newsletter-title">
						<?php echo kite_opt( 'popupNewsLetterTitle' ); ?>
					</h4>

					<h6 class="kt-popup-newsletter-subtitle">
						<?php echo kite_opt( 'popupNewsLetterSubtitle' ); ?>
					</h6>

					<div class="kt-popup-newsletter-shortcode kt-newsletter">
						<?php echo do_shortcode( kite_opt( 'popupNewsLetterShortcode' ) ); ?>                        
					</div>

					<p class="kt-popup-newsletter-text">
						<?php echo ( kite_opt( 'popupNewsLetterText' ) ); ?>
					</p>

				</div>
			</div>
		<?php
	}
}
/*-----------------------------------------------------------------*/
// Header banner
/*-----------------------------------------------------------------*/
if ( ! function_exists( 'kite_header_banner' ) ) {
	function kite_header_banner() {
		$color_scheme            = 'light';
		$background_banner_imge  = kite_opt( 'Header_PromoBar_BgImage' );
		$background_banner_color = kite_opt( 'Header_PromoBar_BgColor' );
		$Header_banner_style     = kite_opt( 'header-style' );

		if ( kite_opt( 'Header_PromoBar_textcolor' ) == 1 ) {
			$color_scheme = 'dark';
		}

		if ( ! kite_opt( 'Header_PromoBar_Display' ) ) {
			return;
		}
		?>
	<div class="header-banner color-scheme-<?php echo esc_attr( $color_scheme ); ?> <?php echo esc_attr( $Header_banner_style ); ?>" style="display:none;
													  <?php
														if ( $background_banner_imge ) {
															?>
		 background: url(<?php echo esc_url( $background_banner_imge ); ?>) center; background-size: cover;  <?php } ?> height: <?php echo kite_opt( 'Header_PromoBar_height' ) . 'px'; ?> ;  
									<?php
									if ( $background_banner_color ) {
										?>
		background-color:  <?php echo esc_attr( $background_banner_color ); ?>; <?php } ?> " data-responsive-height ="<?php echo kite_opt( 'Header_PromoBar_mobileheight' ) . 'px'; ?>" data-banner-height ="<?php echo kite_opt( 'Header_PromoBar_height' ) . 'px'; ?>">
			
			<?php if ( $background_banner_imge && $background_banner_color ) { ?>
				<div class="layer" style="background-color:<?php echo esc_attr( $background_banner_color ); ?>; opacity: 0.9">	
				<?php kite_header_PromoBar(); ?>
				</div>	
				
				<?php
			} else {
				kite_header_PromoBar();
			}
			?>
	
		</div>

		<?php

	}
}
add_action( 'wp_body_open', 'kite_header_banner', 50 );

if ( ! function_exists( 'kite_header_PromoBar' ) ) {
	function kite_header_PromoBar() {
		$banner_link    = kite_opt( 'Header_PromoBar_Link' );
		$banner_btn_txt = kite_opt( 'Header_PromoBar_btntext' );

		if ( kite_opt( 'Header_PromoBar_closebtn' ) ) :
			?>
			<div class="close-header-banner"></div>
			<?php endif; ?>
				
			<?php if ( $banner_link && ! $banner_btn_txt ) : ?>
				<a href="<?php echo esc_url( $banner_link ); ?>" class="header-banner-link"></a>
			<?php endif; ?>
			
			<div class="container header-banner-container">
				<div class="Header_content">
					<div class="header_banner_text"><?php echo kite_opt( 'Header_PromoBar_text' ); ?></div>
					<?php if ( $banner_btn_txt ) : ?>
					<a class="Hedear_button kt_button" href="<?php echo esc_url( $banner_link ); ?>">
						<span class="txt" data-hover="<?php echo esc_attr( $banner_btn_txt ); ?>"><?php echo esc_html( $banner_btn_txt ); ?></span>
					</a>
					<?php endif; ?>
				</div>
			</div>
		<?php
	}
}

//
// ─── NEWSLETTER - EMBEDDING MAILPOET - V3 ───────────────────────────────────────────
//
	
if ( ! function_exists( 'kite_get_mailpoet_forms' ) ) {
	function kite_get_mailpoet_forms() {

		// Get WPDB Object
		   global $wpdb;
		if ( function_exists( 'mailpoet_deactivate_plugin' ) ) {// If the plugin is installed and activated create the shortcode

			// Get Form Values and IDs
			$table_name = $wpdb->prefix . 'mailpoet_forms';
			if ( $wpdb->get_var( "SHOW TABLES LIKE '$table_name'" ) == $table_name ) {// If we had the DB
				$mailPoetForm = $wpdb->get_results( "SELECT * FROM {$wpdb->prefix}mailpoet_forms" );
				$items        = array();
				// Iterate over the Forms
				foreach ( $mailPoetForm  as $value ) {
					 $items[ $value->name ] = $value->id;
				}
				if ( ! is_array( $items ) ) {
					return array();
				}
				return $items;
			}

			return array();

		}

		return array();
	}
}

//
// ─── GET MAILCHIMP FORMS ID ─────────────────────────────────────────────────────
//

function kite_get_mailchimp_forms() {
	$options = array( '' => __('Select the form to show', 'pinkmart' ) ) ;
	if( ! function_exists('mc4wp_get_forms') ) {
		return $options;
	}

	$forms  = mc4wp_get_forms();
	foreach( $forms as $form ) {
		$options[ $form->ID ] = $form->name;
	}

    return $options;
}
/*
-----------------------------------------------------------------*/
// comment submit button
/*-----------------------------------------------------------------*/
if ( ! function_exists( 'kite_wc_comment_submit' ) ) {
	function kite_wc_comment_submit( $submit_button ) {
		$submit_button = '<div class="kt_button button-medium style2 fill text"><span class="txt" data-hover="' . esc_attr__( 'Submit', 'pinkmart' ) . ' "></span><span>' . $submit_button . '</span></div>';
		return $submit_button;
	}
}
add_filter( 'comment_form_submit_button', 'kite_wc_comment_submit' );
/*
-----------------------------------------------------------------*/
// visual composer FrontEnd editor
/*-----------------------------------------------------------------*/
function kite_get_vc_front_end_editor_link() {
	if ( ! class_exists( 'Vc_Manager' ) ) {
		return;
	}
	global $post;
	if ( ! is_object( $post ) ) {
		return;
	}
	$GLOBALS['pageID'] = $post->ID;
	add_filter(
		'vc_get_inline_url',
		function() {
			$the_ID = $GLOBALS['pageID'];
			return admin_url() . 'post.php?vc_action=vc_inline&post_id=' . $the_ID . '&post_type=' . get_post_type( $the_ID );
		}
	);
}
add_action( 'wp_head', 'kite_get_vc_front_end_editor_link' );


/*-----------------------------------------------------------------*/
// resonsive font size
/*-----------------------------------------------------------------*/

function kite_responsive_font_size( $selector = '', $fontsizes = '', $lineHeight = '' ) {

	$fontsizes       = explode( ',', $fontsizes );
	$lineHeight      = explode( ',', $lineHeight );
	$kiteInlineStyle = '';
	if ( empty( $selector ) || count( $fontsizes ) < 3 ) {
		return $kiteInlineStyle;
	}
	if ( ! empty( $fontsizes[0] ) ) {
		$kiteInlineStyle .= '@media(min-width:1140px){' . $selector . ' {font-size:' . $fontsizes[0] . 'px;line-height:' . ( ( ! empty( $lineHeight[0] ) ) ? $lineHeight[0] : $fontsizes[0] ) . 'px;}}';
	}

	if ( ! empty( $fontsizes[1] ) ) {
		$kiteInlineStyle .= '@media(max-width:1140px){' . $selector . ' {font-size:' . $fontsizes[1] . 'px;line-height:' . ( ( ! empty( $lineHeight[1] ) ) ? $lineHeight[1] : $fontsizes[1] ) . 'px;}}';
	} elseif ( ! empty( $fontsizes[0] ) ) {
		$kiteInlineStyle .= '@media(max-width:1140px){' . $selector . ' {font-size:' . $fontsizes[0] . 'px;line-height:' . ( ( ! empty( $lineHeight[0] ) ) ? $lineHeight[0] : $fontsizes[0] ) . 'px;}}';
	}

	if ( ! empty( $fontsizes[2] ) ) {
		$kiteInlineStyle .= '@media(max-width:767px){' . $selector . ' {font-size:' . $fontsizes[2] . 'px;line-height:' . ( ( ! empty( $lineHeight[2] ) ) ? $lineHeight[2] : $fontsizes[2] ) . 'px;}}';
	} elseif ( ! empty( $fontsizes[1] ) ) {
		$kiteInlineStyle .= '@media(max-width:767px){' . $selector . ' {font-size:' . $fontsizes[1] . 'px;line-height:' . ( ( ! empty( $lineHeight[1] ) ) ? $lineHeight[1] : $fontsizes[1] ) . 'px;}}';
	} elseif ( ! empty( $fontsizes[0] ) ) {
		$kiteInlineStyle .= '@media(max-width:767px){' . $selector . ' {font-size:' . $fontsizes[0] . 'px;line-height:' . ( ( ! empty( $lineHeight[0] ) ) ? $lineHeight[0] : $fontsizes[0] ) . 'px;}}';
	}
	return $kiteInlineStyle;
}

/* -------------------------------------------------------------------------- */
/*                          Elementor Container size                          */
/* -------------------------------------------------------------------------- */

add_action( 'redux/loaded', 'kite_set_elementor_container_size' );

function kite_set_elementor_container_size() {
	// Check if elementor is active or not
	if ( ! class_exists( '\Elementor\Plugin' ) ) {
		return;
	}
	if ( kite_opt( 'container_size' ) ) {
		update_option( 'elementor_container_width', '1220' );
	} else {
		update_option( 'elementor_container_width', kite_opt( 'dynamic_container_size' ) );
	}
}

function kite_prefix_kses_allowed_html( $tags, $context ) {
	switch ( $context ) {
		case 'socialtags':
			$tags = array(
				'a'      => array(
					'href'  => array(),
					'title' => array(),
				),
				'h1'     => array(),
				'h2'     => array(),
				'h3'     => array(),
				'h4'     => array(),
				'h5'     => array(),
				'h6'     => array(),
				'p'      => array(),
				'ul'     => array(),
				'li'     => array(),
				'br'     => array(),
				'em'     => array(),
				'strong' => array(),
			);
			return $tags;
		break;
		case 'socialentities':
			$tags = array(
				'em'     => array(),
				'i'      => array(),
				'strong' => array(),
				'span'   => array(
					'class' => array(),
					'style' => array(),
				),
			);
			return $tags;
		break;
		return $tags;
		default:
			return $tags;
	}
}
add_filter( 'wp_kses_allowed_html', 'kite_prefix_kses_allowed_html', 20, 2 );
/*--------------------------------------------------------------------------------
Kite Related Posts
---------------------------------------------------------------------------------*/
function kite_related_posts( $post, $related_count = 3 ) {
	global $post;
	$post_id = $post->ID;
	$terms   = get_the_terms( $post_id, 'category' );

	if ( empty( $terms ) ) {
		$terms = array();
	}

	$term_list = wp_list_pluck( $terms, 'slug' );

	$related_args = array(
		'post_type'      => 'post',
		'posts_per_page' => $related_count,
		'post_status'    => 'publish',
		'post__not_in'   => array( $post_id ),
		'orderby'        => 'rand',
		'tax_query'      => array(
			array(
				'taxonomy' => 'category',
				'field'    => 'slug',
				'terms'    => $term_list,
			),
		),
	);

	$query = new WP_Query( $related_args );
	ob_start();
	if ( $query->have_posts() ) {
		echo "<div class='related-posts-title'><span>" . __( 'Related Posts', 'pinkmart' ) . '</span></div>';
		?>
		<div class="related-posts-container">
		<?php
		while ( $query->have_posts() ) {
			$query->the_post();
			?>
			<div class="related-post">
				<span class="post-title"><a href="<?php the_permalink(); ?>"><?php the_title(); ?></a></span>
				<span class="post-info">
					<span class="post-date"><?php echo get_the_date(); ?></span>
					<span class="post-author kt-icon icon-user" data-name="user"><?php the_author_posts_link(); ?></span>
					<?php if ( comments_open() ) { ?>
					<span class="post-comments kt-icon icon-bubble" data-name="bubble">
						<?php
						if ( comments_open() ) {
							comments_popup_link( '0', '1', '%', 'comments-link', '' );}
						?>
					</span>
					<?php } ?>
				</span>
			</div>
			<?php
		}
		?>
		</div>
		<?php
	}
	wp_reset_query();
	return ob_get_clean();

}
if ( ! function_exists( 'kite_custom_comment_author_link' ) ) {
	function kite_custom_comment_author_link( $return, $author, $comment_id ) {
		$comment = get_comment( $comment_id );
		$avatar  = get_avatar( $comment, $size = '30' );
		return $avatar . '<span>' . $author . '</span>';
	}
}
add_filter( 'get_comment_author_link', 'kite_custom_comment_author_link', 10, 3 );


add_filter( 'jet-elements/allowed-vendor-addons', 'kite_disable_jet_woo_widgets', 1 );
function kite_disable_jet_woo_widgets( $widgets ) {
	if ( isset( $widgets['woo_recent_products'] ) ) {
		unset( $widgets['woo_recent_products'] );
	}

	if ( isset( $widgets['woo_featured_products'] ) ) {
		unset( $widgets['woo_featured_products'] );
	}

	if ( isset( $widgets['woo_sale_products'] ) ) {
		unset( $widgets['woo_sale_products'] );
	}

	if ( isset( $widgets['woo_best_selling_products'] ) ) {
		unset( $widgets['woo_best_selling_products'] );
	}

	if ( isset( $widgets['woo_top_rated_products'] ) ) {
		unset( $widgets['woo_top_rated_products'] );
	}

	if ( isset( $widgets['woo_product'] ) ) {
		unset( $widgets['woo_product'] );
	}

	if ( isset( $widgets['contact_form7'] ) ) {
		unset( $widgets['contact_form7'] );
	}

	return $widgets;
}

/* -------------------------------------------------------------------------- */
/*                              Add Social Login                              */
/* -------------------------------------------------------------------------- */

add_action( 'woocommerce_login_form_end', 'kite_add_social_login' );
add_action( 'login_form', 'kite_add_social_login' );
function kite_add_social_login() {
	$google_app_id       = kite_opt( 'google_app_id' );
	$google_app_secret   = kite_opt( 'google_app_secret' );
	$facebook_app_id     = kite_opt( 'facebook_app_id' );
	$facebook_app_secret = kite_opt( 'facebook_app_secret' );
	if ( class_exists( 'Social_Network_Authentication' ) && ( ( ! empty( $facebook_app_id ) && ! empty( $facebook_app_secret ) ) || ( ! empty( $google_app_id ) && ! empty( $google_app_secret ) ) ) ) :
		?>
		<div style="width: 100%;text-align: center;"><span class="social-login-title"><strong><?php esc_html_e( 'OR LOGIN WITH', 'pinkmart' ); ?></strong></span></div>
		<div class="kite-social-login">
			<?php if ( ! empty( $facebook_app_id ) && ! empty( $facebook_app_secret ) ) : ?>
				<div class="social-login-btn">
					<a class="kt_button button-large center style1 transparent hasicon" style="color: #2c4de0;" href="<?php echo add_query_arg( 'social_auth', 'facebook', wc_get_page_permalink( 'myaccount' ) ); ?>" title="facebook login">

						<span class="txt" data-hover="Facebook"><?php esc_html_e( 'Facebook', 'pinkmart' ); ?></span>
						<span class="icon" data-hover="icon-facebook-square">
							<span class="firsticon glyph icon-facebook-square"></span>
							<span class="hovericon glyph icon-facebook-square"></span>
						</span>
					</a>
				</div>
			<?php endif; ?>
			<?php
			if ( ! empty( $google_app_id ) && ! empty( $google_app_secret ) ) :
				?>
				<div class="social-login-btn">
					<a class="kt_button button-large center style1 transparent hasicon" style="color: #ff1616;" href="<?php echo add_query_arg( 'social_auth', 'google', wc_get_page_permalink( 'myaccount' ) ); ?>" title="google login">
	
						<span class="txt" data-hover="Google"><?php esc_html_e( 'Google', 'pinkmart' ); ?></span>
						<span class="icon" data-hover="icon-google-plus-square">
							<span class="firsticon glyph icon-google-plus-square"></span>
							<span class="hovericon glyph icon-google-plus-square"></span>
						</span>
					</a>
				</div>
				<?php
			endif;
			?>
		</div>
		<?php
	endif;
}

//
// ─── LOAD WIDGETIZED FOOTER ─────────────────────────────────────────────────────
//
add_action( 'kite_footer_action', 'kite_widgetized_footer', 5 );
function kite_widgetized_footer() {    
    $woocommerce_check = class_exists('WooCommerce') ? true : false;
    
    if ( is_page() ) {        
        $widgetized_footer = kite_get_meta("footer-widget-area");

        if ($widgetized_footer == "inherit") {

            if( kite_opt('footer-widget-area') ) {
                //Footer Widgetized Area
                get_template_part('templates/section', 'widgetized_footer');
            }
            
        } elseif( $widgetized_footer == "enable" ) {
            //Footer Widgetized Area
            get_template_part('templates/section', 'widgetized_footer');
        }
    } elseif ( $woocommerce_check && ( is_product_category() || is_product_tag() ) ) {
        if ( kite_opt('category_widget_area') ) {
            //Footer Widgetized Area
            get_template_part('templates/section', 'widgetized_footer');
        }
    } elseif ( $woocommerce_check && is_product() ) {
        if ( kite_opt('product_widget_area') ) {
            //Footer Widgetized Area
            get_template_part('templates/section', 'widgetized_footer');
        }
        
    } else {
        if ( kite_opt('footer-widget-area') ) {
            //Footer Widgetized Area
            get_template_part('templates/section', 'widgetized_footer');
        }
    }
    
    
}

//
// ─── Compatibility custom Product tab with elementor  ────────────────────────────────────
//

add_filter( 'yikes_woo_use_the_content_filter', '__return_false' );

add_filter( 'yikes_woo_filter_main_tab_content', 'yikes_woo_custom_tab_content_filter', 10, 1 );

function yikes_woo_custom_tab_content_filter( $content ) {

	$content = function_exists( 'capital_P_dangit' ) ? capital_P_dangit( $content ) : $content;
	$content = function_exists( 'wptexturize' ) ? wptexturize( $content ) : $content;
	$content = function_exists( 'convert_smilies' ) ? convert_smilies( $content ) : $content;
	$content = function_exists( 'wpautop' ) ? wpautop( $content ) : $content;
	$content = function_exists( 'shortcode_unautop' ) ? shortcode_unautop( $content ) : $content;
	$content = function_exists( 'prepend_attachment' ) ? prepend_attachment( $content ) : $content;
	$content = function_exists( 'wp_make_content_images_responsive' ) ? wp_make_content_images_responsive( $content ) : $content;

	if ( class_exists( 'WP_Embed' ) ) {

		// Deal with URLs
		$embed = new WP_Embed;
		$content = method_exists( $embed, 'autoembed' ) ? $embed->autoembed( $content ) : $content;
	}	

	return $content;
}

//
// ─── KITE FUNCTION TO GENERATE SEARCH FORM ──────────────────────────────────────
//
if ( ! function_exists( 'kite_generate_search_form' ) ) {
	function kite_generate_search_form( $args = array() ) {
		$defaults = array(
			'wrap_id'				=> '',
			'wrap_classes'			=> 'kt-search-form-wrap',
			'form_classes' 			=> 'kt-search-form',
			'style'					=> 'light',
			'terms'	  				=> array(),
			'search_place_holder' 	=> esc_attr__( 'Search Posts', 'pinkmart' ),
			'search_post_type'		=> 'post'
		);
	
		extract( wp_parse_args( $args, $defaults ) ); 
	
		include locate_template( 'templates/search-form.php', false, false );
	}
}

//
// ─── KITE FUNCTION TO RENDER ELEMENTOR TEMPLATE ─────────────────────────────────
//
function kite_render_elementor_template( $template_ID ) {
	if ( class_exists( '\Elementor\Plugin' ) ) {
		echo Elementor\Plugin::instance()->frontend->get_builder_content_for_display( $template_ID );
	}
}

//
// ─── KITE FUNCTION TO RETURN ELEMENTOR LIBRARIES BY TYPE ────────────────────────
//
if( ! function_exists('kite_get_elementor_templates_list') ) {
    function kite_get_elementor_templates_list( $template_type = 'all' ){
        $args = array(
            'posts_per_page'   => -1,
            'post_type'        => 'elementor_library',
            'post_status'      => 'publish'
        );

        if( $template_type !== 'all' ){
            $args['meta_key']   = '_elementor_template_type';
            $args['meta_value'] = $template_type;
        }

        $posts  = get_posts( $args );
        $output = array( '' => __( 'Select a template', 'pinkmart' ) );

        
        foreach ( $posts as $key => $value ) {
            $output[ $value->ID ] =  $value->post_title;
        }

        return $output;
    }
}

function kite_allowed_html() {

	$GLOBALS['kite-allowed-tags'] = array(
		'a' => array(
			'class' => array(),
			'href'  => array(),
			'rel'   => array(),
			'title' => array(),
		),
		'abbr' => array(
			'title' => array(),
		),
		'b' => array(),
		'blockquote' => array(
			'cite'  => array(),
		),
		'cite' => array(
			'title' => array(),
		),
		'code' => array(),
		'del' => array(
			'datetime' => array(),
			'title' => array(),
		),
		'dd' => array(),
		'div' => array(
			'class' => array(),
			'title' => array(),
			'style' => array(),
			'data-layoutmode' 	=> array(),
			'data-layoutMode' 	=> array(),
			'data-delay' 		=> array(),
			'data-animation' 	=> array(),
			'data-autoplay' 	=> array(),
			'data-visibileitems' 	=> array(),
			'data-product-page-preselected-id' 	=> array(),
		),
		'dl' => array(),
		'dt' => array(),
		'em' => array(),
		'h1' => array(),
		'h2' => array(),
		'h3' => array(),
		'h4' => array(),
		'h5' => array(),
		'h6' => array(),
		'i' => array(),
		'img' => array(
			'alt'    	=> array(),
			'class'  	=> array(),
			'height' 	=> array(),
			'src'    	=> array(),
			'srcset'    => array(),
			'data-src'  => array(),
			'data-srcset' => array(),
			'width'  	=> array(),

		),
		'li' => array(
			'class' => array(),
		),
		'ol' => array(
			'class' => array(),
		),
		'p' => array(
			'class' => array(),
		),
		'q' => array(
			'cite' => array(),
			'title' => array(),
		),
		'span' => array(
			'class' => array(),
			'title' => array(),
			'style' => array(),
		),
		'strike' => array(),
		'strong' => array(),
		'ul' => array(
			'class' => array(),
		),
	);
}
kite_allowed_html();

//
// ─── GET PRIMARY CATEGORY OF POST ───────────────────────────────────────────────
//
function kite_get_post_primary_category( $post_id, $term = 'category', $return_all_categories = false ) {
    $return = [];

    if ( class_exists( 'WPSEO_Primary_Term' ) ){
        // Show Primary category by Yoast if it is enabled & set
        $wpseo_primary_term = new WPSEO_Primary_Term( $term, $post_id );
        $primary_term = get_term( $wpseo_primary_term->get_primary_term() );

        if ( ! is_wp_error( $primary_term ) ) {
            $return['primary_category'] = $primary_term;
        }
    }

    if ( empty( $return['primary_category'] ) || $return_all_categories ) {
        $categories_list = get_the_terms( $post_id, $term );

        if ( empty( $return['primary_category'] ) && ! empty( $categories_list ) ) {
            $return['primary_category'] = $categories_list[0];  //get the first category
        }
        if ( $return_all_categories ) {
            $return['all_categories'] = [];

            if ( ! empty( $categories_list ) ) {
                foreach( $categories_list as &$category ) {
                    $return['all_categories'][] = $category->term_id;
                }
            }
        }
    }

    return $return;
}