<?php

require_once KITEST_THEME_LIB . '/forms/fieldtemplate.php';


/********************************
 * output function is taken from class-wc-meta-box-product-data.php of woocommerce plugin (woocommerce/includes/admin/meta-boxes/class-wc-meta-box-product-data.php)
 * add_attribute function is originally taken from class-wc-ajax.php  of woocommerce plugin ( woocommerce/includes/class-wc-ajax.php)
 * those function changed a bit to handle new attributes
 ********************************/

class Kite_Attribute_Settings {


	function __construct() {
		$this->kite_custom_fields_hooks();

		// WordPress Media Uploader
		add_action(
			'admin_enqueue_scripts',
			function() {
				global $post;

				wp_enqueue_script( 'media-upload' );
				wp_enqueue_script( 'thickbox' );
				wp_enqueue_style( 'thickbox' );

				wp_enqueue_media();
				wp_enqueue_script( 'media' );
			}
		);
	}

	function kite_custom_fields_hooks() {
		$attribute_taxonamies = wc_get_attribute_taxonomies();
		foreach ( $attribute_taxonamies as $tax ) {

			// Adding Color and Image option to all attributes
			add_action( 'pa_' . $tax->attribute_name . '_add_form_fields', array( $this, 'kite_add_custom_field' ) );
			add_action( 'pa_' . $tax->attribute_name . '_edit_form_fields', array( $this, 'kite_edit_custom_field' ) );
			add_action( 'edited_pa_' . $tax->attribute_name, array( $this, 'save_custom_meta' ), 10, 3 );
			add_action( 'create_pa_' . $tax->attribute_name, array( $this, 'save_custom_meta' ), 10, 3 );
		}
	}

	function kite_add_custom_field() {
		?>
		<tr class="form-field">
		   <td>
				<div class="form-field color-field clear-after all_taxonamies_color">
					<label for="tag-color"><?php esc_html_e( 'Color Swatch', 'pinkmart' ); ?></label>
					<div class="color-field-wrap clear-after">
						<input name="term-color" data-alpha="true" type="text" value="" class="colorinput"/>
						<div class="color-view"></div>
					</div>
					<p><?php esc_html_e( 'Select a color as a swatch of this term.', 'pinkmart' ); ?></p>
				</div>
			</td>
		</tr>
		
		<tr class="form-field">
			<td>
				<div class="form-field term-header-image-wrap">
					<label for="tag-image"><?php esc_html_e( 'Image Swatch', 'pinkmart' ); ?></label>
					<div id="product_cat_background_image" data-default-img="<?php echo wc_placeholder_img_src(); ?>" style="float: left; margin-right: 10px;"><img src="<?php echo esc_url( wc_placeholder_img_src() ); ?>" width="60px"/></div>
					<div style="line-height: 60px;">
						<input type="hidden" id="header-background-image" name="term-image-id" value= />
						<button type= type="button" class="upload_wc_cat_header_image_button button"><?php esc_html_e( 'Upload/Add image', 'pinkmart' ); ?></button>
						<button type="button" class="remove_wc_cat_header_image_button button"><?php esc_html_e( 'Remove image', 'pinkmart' ); ?></button>
					</div>
					<p style="clear: left;" ><?php esc_html_e( 'Select an image as a swatch of this term.', 'pinkmart' ); ?></p>
				</div>
			</td>       
		</tr>
		<?php
	}

	function kite_edit_custom_field( $term ) {
		$term_color    = get_term_meta( $term->term_id, 'term-color', true );
		$term_image_id = absint( get_term_meta( $term->term_id, 'term-image-id', true ) );
		if ( $term_image_id ) :
			$image = wp_get_attachment_url( $term_image_id );
		else :
			$image = wc_placeholder_img_src();
		endif;
		?>
		 <tr class="form-field term-color-wrap">
			 <th scope="row"><label for="color"><?php esc_html_e( 'Color Swatch', 'pinkmart' ); ?></label></th>
			<td>
				<div class="field color-field clear-after all_taxonamies_color">
					<div class="color-field-wrap clear-after">
						<input name="term-color" data-alpha="true" type="text" value="<?php echo esc_attr( $term_color ); ?>" class="colorinput"/>
						<div class="color-view"></div>
					</div>
				</div>
				<p class="color"><?php esc_html_e( 'Select a color as a swatch of this term.', 'pinkmart' ); ?></p>
			</td>
		</tr>
		
		<tr class="form-field term-image-wrap">
			<th scope="row"><label for="Image"><?php esc_html_e( 'Image swatch', 'pinkmart' ); ?></label></th>
			<td>
				<div class="form-field term-header-image-wrap">
					<div id="product_cat_background_image" data-default-img="<?php echo wc_placeholder_img_src(); ?>" style="float: left; margin-right: 10px;"><img src="<?php echo esc_url( $image ); ?>" width="60px"/></div>
					<div style="line-height: 60px;">
							<input type="hidden" id="header-background-image" name="term-image-id" value="<?php echo esc_attr( $term_image_id ); ?>" />
							<button type= type="button" class="upload_wc_cat_header_image_button button"><?php esc_html_e( 'Upload/Add image', 'pinkmart' ); ?></button>
							<button type="button" class="remove_wc_cat_header_image_button button"><?php esc_html_e( 'Remove image', 'pinkmart' ); ?></button>
					</div>
				</div>
				<p class="image"><?php esc_html_e( 'Select an Image as a swatch of this term.', 'pinkmart' ); ?></p>
			</td>       
		</tr>
		<?php
	}

	function save_custom_meta( $term_id, $tt_id = '', $taxonomy = '' ) {
		if ( isset( $_POST['term-color'] ) ) {
			update_term_meta( $term_id, 'term-color', sanitize_text_field( $_POST['term-color'] ) );
		}

		if ( isset( $_POST['term-image-id'] ) ) {
			update_term_meta( $term_id, 'term-image-id', sanitize_text_field( $_POST['term-image-id'] ) );
		}
		delete_transient( 'wc_term_counts' );
	}
}

new Kite_Attribute_settings();
