<?php
/**
 * The template for displaying product content in the single-product.php template
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/content-single-product.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see     https://docs.woocommerce.com/document/template-structure/
 * @package WooCommerce/Templates
 * @version 3.6.0
 */

defined( 'ABSPATH' ) || exit;

global $product;

// KiteSt codes
if ( kite_get_meta( 'product_detail_style_inherit' ) == '1' ) {
	$product_detail_style              = kite_get_meta( 'product_detail_style' ); // style of product detail in product page
	$product_detail_sidebar_position   = kite_get_meta( 'product-detail-sidebar-position' ); // style of sidebar in product page
	$product_detail_sidebar_responsive = kite_get_meta( 'product-detail-sidebar-responsive' ); // style of sidebar in product page
	$product_detail_txt_color          = kite_get_meta( 'product_detail_txt_color' );

} else {
	$product_detail_style              = kite_opt( 'product-detail-style' ); // style of product detail in theme settings
	$product_detail_sidebar_position   = kite_opt( 'product-detail-sidebar-position' ); // style of sidebar in product page
	$product_detail_sidebar_responsive = kite_opt( 'product-detail-sidebar-responsive' ); // style of sidebar in product page
	$product_detail_txt_color          = kite_opt( 'product_detail_txt_color' );

}

$catalog_mode                 = kite_opt( 'catalog_mode', false );
$product_breadcrumb           = kite_opt( 'product_breadcrumb', true );
$compare_wishlist_style_class = 'seperate_rows_wishlist_compare';
$text_color = '';
if ( $product_detail_txt_color != 1 ) {
		$text_color = 'light_text';
}
$custom_label             = '';
	$custom_product_label = get_post_meta( get_the_ID(), 'custom_product_label', true );
if ( ! empty( $custom_product_label ) ) {
	$custom_label = 'custom_label';
}



// End of KiteSt codes
?>

<?php
	/**
	 * woocommerce_before_single_product hook
	 *
	 * @hooked wc_print_notices - 10
	 */
	 do_action( 'woocommerce_before_single_product' );

if ( post_password_required() ) {
	echo get_the_password_form();
	return;
}

?>

<div id="product-<?php the_ID(); ?>" <?php wc_product_class( array( $product_detail_style, $compare_wishlist_style_class, $text_color, $custom_label, 'parent_div_product' ), $product ); ?>>
	<div class="product-detail-bg">
		<div class="container">
			<?php
			if ( $product_detail_style == 'pd_classic_sidebar' ) {
				echo '<div class="product-detail-content-with-sidebar ' . $product_detail_sidebar_position . '">';// Put wrapper around image & summary
			}
			?>
			<?php

			if ( ! isset( $is_product_shortcode ) ) {
				if ( ( $product_detail_style == 'pd_classic_sidebar' ) || ( $product_detail_style == 'pd_classic' ) || ( $product_detail_style == 'pd_kt_classic' ) ) {
					if ( ( ! wp_is_mobile() ) && $product_breadcrumb == true ) {
						/* Breadcrumb */
						woocommerce_breadcrumb(
							array(
								'delimiter'   => '<span class="delimiter">/</span>',
								'wrap_before' => '<nav id="breadcrumb" class="woocommerce-breadcrumb" ' . ( is_single() ? 'itemprop="breadcrumb"' : '' ) . '>',
								'wrap_after'  => '</nav>',
							)
						);
					}
				}
				/* Prev/next product buttons */
				$thumbnail = '';
				$product_navigation = kite_opt( 'product_navigation', true );
				if ( $product_navigation != 0 ) {
					$prevPost = get_previous_post();
					if ( $prevPost ) {
						$thumbnail = get_the_post_thumbnail( $prevPost->ID, 'shop_thumbnail' );
					}
					echo '<span id="next-product" class="hidden-phone">';
					previous_post_link( '%link', '<span></span>' . $thumbnail );
					echo '</span>';

					$nextPost = get_next_post();
					if ( $nextPost ) {
						$thumbnail = get_the_post_thumbnail( $nextPost->ID, 'shop_thumbnail' );
					}
					echo '<span id="prev-product" class="hidden-phone">';
					next_post_link( '%link', '<span></span>' . $thumbnail );
					echo '</span>';
				}
			}

				/**
				 * woocommerce_before_single_product_summary hook
				 *
				 * @hooked woocommerce_show_product_sale_flash - 10
				 * @hooked woocommerce_show_product_images - 20
				 */
				do_action( 'woocommerce_before_single_product_summary' );
			?>
	<?php
	if ( $product_detail_style == 'pd_top' ) {
		?>
		</div>
	</div>
	<div class="container">
		<?php
	}
	$align = '';
	if ( kite_opt( 'product_description_align', true ) == 0 ) {
		$align = 'center';
	}
	?>
			<div class="summary entry-summary <?php echo esc_attr( $align ); ?>">
				<?php
				if ( wp_is_mobile() || ( $product_detail_style == 'pd_fixed_summary' ) || ( $product_detail_style == 'pd_top' ) || ( $product_detail_style == 'pd_background' ) ) {
					/* Breadcrumb */
					if ( $product_breadcrumb == true ) {
						woocommerce_breadcrumb(
							array(
								'delimiter'   => '<span class="delimiter">/</span>',
								'wrap_before' => '<nav id="breadcrumb" class="woocommerce-breadcrumb" ' . ( is_single() ? 'itemprop="breadcrumb"' : '' ) . '>',
								'wrap_after'  => '</nav>',
							)
						);
					}
				}

					/**
					 * woocommerce_single_product_summary hook
					 *
					 * @hooked woocommerce_template_single_title - 5
					 * @hooked woocommerce_template_single_rating - 10
					 * @hooked woocommerce_template_single_price - 10
					 * @hooked woocommerce_template_single_excerpt - 20
					 * @hooked add_deal_count_down Timer - 25
					 * @hooked woocommerce_template_single_add_to_cart - 30
					 * @hooked woocommerce_template_single_meta - 40
					 * @hooked woocommerce_template_single_sharing - 50
					 */
					do_action( 'woocommerce_single_product_summary' );
				?>

			</div><!-- .summary -->
		<?php

		if ( $product_detail_style == 'pd_classic_sidebar' ) {
			echo '</div>';// Put wrapper around image & summary
		}


		if ( $product_detail_style == 'pd_top' ) {
			?>
		</div>
			<?php
		} elseif ( $product_detail_style == 'pd_classic_sidebar' ) {
			$pd_sidebar_in_responsive_class = '';
			if ( $product_detail_sidebar_responsive == 0 ) {
				$pd_sidebar_in_responsive_class = ' visible-desktop';
			}
			?>
			<div id="woocommerce-product-sidebar" class="span3<?php echo esc_attr( $pd_sidebar_in_responsive_class ); ?>"><?php echo kite_get_sidebar( 'woocommerce-product-sidebar' ); ?></div>
			<?php
		}

		?>

	<?php
	if ( $product_detail_style != 'pd_top' ) {
		?>
		</div>
	</div>
	<?php } ?>

		<?php
			/**
			 * woocommerce_after_single_product_summary hook
			 *
			 * @hooked woocommerce_output_product_data_tabs - 10
			 * @hooked woocommerce_upsell_display - 15
			 * @hooked woocommerce_output_related_products - 20
			 */
			do_action( 'woocommerce_after_single_product_summary' );
		?>

		<meta itemprop="url" content="<?php the_permalink(); ?>" />

</div><!-- #product-<?php the_ID(); ?> -->

<?php do_action( 'woocommerce_after_single_product' ); ?>
