<?php
namespace KiteProTools;
use KiteStudioCore as Core;

class Dashboard extends Core\Dashboard {

    /**
	 * Holds the current instance of the dashboard
	 *
	 */
    protected static $instance 	= null;

    /**
	 * Retrieves class instance
	 *
	 * @return KiteProTools\Dashboard
	 */
	public static function get_instance() {
		if ( ! self::$instance ) {
			self::$instance 	= new self;
		}

		return self::$instance;
	}

    /**
     * __construct method
     */
    public function __construct() {
        
        add_action( 'wp_ajax_activate_theme', array( $this, 'check_activation_state') );
        add_action( 'kite_add_dashboard_menus', array( $this, 'add_dashboard_menu' ) );
        add_action( 'kite_dashboard_welcome_info', array( $this, 'add_success_activation_notice' ) );
        add_filter( 'kite_dashboard_header_page_sections', array( $this, 'header_sections' ), 1, 1 );
        add_filter( 'kite_dashboard_tabs_menu', array( $this, 'tabs_menu'), 1 , 1 );
        add_filter( 'kite_dashboard_footer_page_sections', array( $this, 'footer_sections' ), 1, 1 );
        add_filter( 'kite_demo_item', array( $this, 'add_demo_item'), 1, 3 );
    }

    /**
     * Add Dashboard Menus
     */
    public function add_dashboard_menu() {
        add_submenu_page( 'pinkmart-dashboard', __( 'Pinkmart - Support', 'kt-pro-tools' ), __( 'Support', 'kt-pro-tools' ), 'manage_options', 'pinkmart-dashboard-support', array( $this, 'support_page'), 15 );
    }

    /**
     * Add Pro Header Sections
     */
    public function header_sections( $sections ) {
        $sections[0] = array(
            'class' => $this,
            'func'  => 'add_activation_section'
        ); 
        return $sections;
    }

    /**
     * Add Pro Footer Sections
     */
    public function footer_sections( $sections ) {
        $sections[0] = array(
            'class' => $this,
            'func'  => 'activation_form'
        ); 
        return $sections;
    }

    /**
     * Add Pro Tabs Menu To Dashboard
     */
    public function tabs_menu( $tabs_menu ) {
        $tabs_menu['15'] = array(
            'title' => __( 'Support', 'kt-pro-tools' ),
            'link'  => add_query_arg( array( 'page' => 'pinkmart-dashboard-support' ) ),
            'class' => 'kt-support '. ( ( $_GET['page'] == 'pinkmart-dashboard-support') ? 'active' : '' ) 
        );

        return $tabs_menu;
    }

    public function add_success_activation_notice() {
        $class = 'kt-activated';
        $class .= ( get_option( 'license_verified', false ) || get_option( 'pinkmart_license_verified', false ) ) ? ' show' : '';
        ?>
        <span class="<?php echo esc_attr( $class ); ?>"><span class="icon icon-checkmark-circle"></span> <?php esc_html_e( 'Activated', 'kt-pro-tools' ); ?></span>
        <?php
    }

    /**
     * Add activation section
     */
    public function add_activation_section() {
        if ( get_option( 'license_verified', false ) || get_option( 'pinkmart_license_verified', false ) ) {
            return;
        }
        ?>
        <div class="kt-activation-section">
            <div class="kt-activation-notice-icon">
                <span class="icon icon-warning"></span>
            </div>
            <div class="kt-activation-notice">
                <span><?php esc_html_e( 'Your Pinkmart is not activated. To unlock all features activate now.', 'kt-pro-tools' ); ?></span>
                <a href="#" class="kt-activate-now"><?php esc_html_e( 'Activate Now', 'kt-pro-tools' ); ?></a>
                <a href="https://build.envato.com/create-token/?purchase:download=t&purchase:verify=t&purchase:list=t" class="kt-get-token" target="_blank"><?php esc_html_e( 'Get A Token', 'kt-pro-tools' ); ?></a>
            </div>
        </div>
        <?php
    }

    /**
     * Create activation form
     */
    public function activation_form() {
        if ( get_option( 'license_verified', false ) || get_option( 'pinkmart_license_verified', false ) ) {
            return;
        }
        ?>
        <div id="kt-activation-modal">
            <div class="kt-activation-form">
                <div class="kt-activation-form-title">
                    <span class="icon icon-license2"></span>
                    <span class="kt-title"><?php esc_html_e( 'License Activation', 'kt-pro-tools' ); ?></span>
                </div>
                <div class="kt-activation-body">
                    <span class="kt-text">
                        <?php esc_html_e( 'Activate your license to get automatice updates, premium support and ultimate access to demo importer.', 'kt-pro-tools' ); ?>
                    </span>
                    <br>
                    <span class="kt-token kt-has-hint">
                        <?php esc_html_e( 'How to get a token?', 'kt-pro-tools' );?>
                        <span class="kt-hint">
                            <?php
                            esc_html_e( '1. Generate an Envato API personal Token by clicking bottom button.', 'kt-pro-tools' );
                            echo "<br><br>";
                            esc_html_e( '2. Copy the token into the box below.', 'kt-pro-tools' );
                            ?>
                        </span>
                    </span>
                </div>
                <form method="post">
                    <div class="kt-input">
                        <input type="text" name='token' placeholder="<?php esc_attr_e( 'Enter your token', 'kt-pro-tools' ); ?>">
                    </div>
                    <p class="kt-result"></p>
                    <span class="submit"><?php esc_attr_e( 'Activate', 'kt-pro-tools' );?></span>
                </form>
                <span class="kt-token"><?php esc_html_e( 'Don\'t have a token?', 'kt-pro-tools' );?></span><br>
                <button><a href="https://build.envato.com/create-token/?purchase:download=t&purchase:verify=t&purchase:list=t" target="_blank"><?php esc_html_e( 'Get A Token', 'kt-pro-tools' );?></a></button>
            </div>
        </div>
        <?php
    }

    /**
     * Check Ativation State
     */
    public function check_activation_state() {
        $token = sanitize_text_field( $_POST['token'] );

        if ( empty( $token ) ) {
            wp_send_json_error( array( 'message' => __( 'Token field required', 'kt-pro-tools' ) ) );
        }

        $verify = new Updater( trim( $token ) );
        $verification = $verify->verify_activation_by_kite();
        if ( $verification['status'] ) {
            update_option( 'envato_token_24735635', $token );
            // fetch demos after activation
            delete_transient( 'kite_demos_list' );
            wp_send_json_success( array( 'message' => $verification['message'] ) );
        } else {
            update_option( 'envato_verify', false );
            wp_send_json_error( array( 'message' => $verification['message'] ) );
        }
    }

    /**
     * generate support page
     */
    public function support_page() {
        $this->header_page_section();
        ?>
        <div class='kt-support-page'>
            <h1><?php esc_html_e( 'Help and Support', 'kt-pro-tools' );?></h1>
            <p><?php esc_html_e( 'This theme comes with 6 months item support from purchase date (with the option to extend this period).
                This license allows you to use this theme on a single website. Please purchase an additional license to
                use this theme on another website.', 'kt-pro-tools' );?></p>
            <p><?php echo sprintf( esc_html__( 'Item Support can be accessed from %s and includes: ', 'kt-pro-tools'), '<a href = "http://kitestudio.help" target = "_blank" > http:// kitestudio.help </a>');?></p>
            <ul class="kt-supports-item">
                <li><?php esc_html_e( 'Availability of the author to answer questions', 'kt-pro-tools' );?></li>
                <li><?php esc_html_e( 'Answering technical questions about item features', 'kt-pro-tools' );?></li>
                <li><?php esc_html_e( 'Assistance with reported bugs and issues', 'kt-pro-tools' );?></li>
                <li><?php esc_html_e( 'Help with bundled 3rd party plugins', 'kt-pro-tools' );?></li>
            </ul>
            <p><?php echo sprintf( esc_html__( 'More details about item support can be found in the ThemeForest %s.', 'kt-pro-tools' ), '<a href="http://themeforest.net/page/item_support_policy" target="_blank">Item Support Policy</a>' );?></p> 
        </div>
        <?php
        $this->footer_page_section();
    }

    /**
     * Generate Demo Item with xd Button
     */
    public function add_demo_item( $demo_item, $demo_id, $demo_info ) {
        $demo_item = '<li class="kt-demo-item kt-lazy">
                        <input type="radio" name="demo_name" value="'.$demo_id.'" id="demo'.$demo_id.'" class="input-hidden"/>
                        <img src="data:image/gif;base64,R0lGODlhCQAHAIAAAP///wAAACH5BAEAAAEALAAAAAAJAAcAAAIHjI+py+1cAAA7" data-src="'.$demo_info['image'].'" alt="Demo'.$demo_id.'" />
                        <div class="kt-demo-info">
                            <div class="kt-demo-title">
                                <span class="kt-demo-name">'.$demo_info['Name'].'</span>
                            </div>
                            <div class="kt-demo-buttons">
                                <a href="#" class="kt-import">'.__( 'Import', 'kitestudio-core' ).'</a> 
                                <a href="'.$demo_info['url'].'" class="kt-preview" target="_blank">'.__( 'Preview', 'kitestudio-core' ).'</a>
                                <a href="'.$demo_info['xd'].'" class="kt-xd" target="_blank">'.__( '.XD', 'kitestudio-core' ).'<span class="icon icon-download2"></span></a>
                            </div>
                        </div>
                    </li>';

        return $demo_item;
    }
}
?>