<?php
namespace KiteProTools;
use KiteStudioCore as Core;

class Updater extends Core\Updater {

    public $token;
    public $kite_token;
    
    /** Constructor */
    function __construct( $token = '' ) {
        parent::__construct( $token );
        $this->set_kite_token();        
        $this->token = $token;  
    }

    /**
     * Set Kite Token
     */
    public function set_kite_token() {
        $this->kite_token = get_option('kite_token_24735635','');
    }

    /**
     * Verify Activation
     */
    public function verify_activation_by_kite() {
        $envato_token = $this->token;
        $siteAddr = $this->siteAddr;
        if ( empty( $envato_token ) || empty( $siteAddr ) ) {
            update_option( 'pinkmart_license_verified', false );
            $returnVar = array(
                "status"	=> false,
                'message'	=> esc_html( 'All Fields Required!', 'kt-pro-tools' )
            );
            return $returnVar;
        } 

        $url = $this->kite_api_url . '/activate';
        $headers = array(
            'headers' => array(
                'Content-length'	=> '0',
                "Content-type"		=> 'application/json',
                "Requested-domain"	=> $siteAddr,
                "token"				=> $envato_token
            )
        );
        $response = $this->curl( $url,$headers);
        
        if ($response['status']) {
            if ($response['body']['status']) {
                update_option( 'kite_token_24735635',$response['body']['token']);
                update_option( 'pinkmart_license_verified',true);
                return array(
                    "status"	=> true,
                    'message'	=> esc_html('Your theme activated and is ready to use.','kt-pro-tools')
                );

            } else {
                update_option( 'pinkmart_license_verified',false);
                return array( 
                    "status" 	=> false,
                    'message'	=> $response['body']['message']
                );
            }
        } else {
            update_option( 'pinkmart_license_verified',false);
            return array(
                "status"	=> false,
                'message'	=> $response['message']
            );
        }
    }

    /**
     * Download Pro Plugins
     */
    public function plugins_download_pack() {
        $siteAddr = $this->siteAddr;
        $kite_token = $this->kite_token;

        $url = $this->kite_api_url . '/download/plugins';
        $headers = array(
            'headers' => array(
                'Content-length'	=> '0',
                "Content-type"		=> 'application/json',
                "Requested-domain"	=> $siteAddr,
                'token'				=> $kite_token
            )
        );
        $response = $this->curl( $url, $headers );
        if ($response['status']) {
            if ($response['body']['status']) {
                $plugins_info = $response['body']['plugins'];
                return array('status'=> true,'plugins' => $plugins_info );
            } else {
                // @TODO: set transient to check license verification
                // update_option( 'kite_token_24735635', '' );
                // update_option( 'pinkmart_license_verified', false );
                return array( 'status' => false, 'message' => $response['body']['message'] );
            }
        } else {
            // Theme is not active on kitestudio.help So deactiving it here
            return array('status'=>false,'message'=>$response['message']);			
        } 
    }

    /**
     * Download Pro Theme
     */
    public function theme_download_pack() {
        $siteAddr = $this->siteAddr;
        $kite_token = $this->kite_token;

        $url = $this->kite_api_url . '/download/theme';
        $headers = array(
            'headers' => array(
                'Content-length'	=> '0',
                "Content-type"		=> 'application/json',
                "Requested-domain"	=> $siteAddr,
                'token'				=> $kite_token
            )
        );
        $response = $this->curl( $url, $headers );
        if ($response['status']) {
            if ($response['body']['status']) {
                $theme_info = $response['body']['theme-info'];
                return array('status'=> true,'theme-info' => $theme_info );
            } else {
                // @TODO: set transient to check license verification
                // update_option( 'kite_token_24735635', '' );
                // update_option( 'pinkmart_license_verified', false );
                return array( 'status' => false, 'message' => $response['body']['message'] );
            }
        } else {
            // Theme is not active on kitestudio.help So deactiving it here
            return array('status'=>false,'message'=>$response['message']);			
        } 
    }    

}
?>