<?php 
/**
 * Social network authentication
 */

class Social_Network_Authentication {

    private $current_url;

    private $available_networks = array( 'facebook', 'google' );

	public function __construct() {
        /*global $wp;  
        $this->current_url = home_url(add_query_arg($_SERVER['QUERY_STRING'], '',$wp->request));*/
        $this->current_url =get_site_url()."{$_SERVER['REQUEST_URI']}";
    	add_action('init', array( $this, 'authenticate' ), 20);
    	add_action('init', array( $this, 'authenticate_callback' ), 30);
	}
    public function authenticate() {
        if( empty( $_GET['social_auth'] ) && empty( $_GET['code'] ) ) {
            return;
        }
        $network = ( empty( $_GET['social_auth'] ) ) ? $this->get_current_callback_network() : sanitize_key( $_GET['social_auth'] );

        if( ! in_array( $network, $this->available_networks) ) return;

        $account_url    = $this->get_account_url();
        $security_salt  = 'rmWB3zhyCHLOo1IgaV8Ks5ncRD04QTj9pxX7itMY';

        $callback_param = 'int_callback';
        $strategy = array();
        switch ( $network ) {
            case 'google':
                $app_id         = kite_opt('google_app_id');
                $app_secret     = kite_opt('google_app_secret');

                if( empty( $app_secret ) || empty( $app_id ) ) return;

                $strategy       = array(
                    'Google' => array(
                        'client_id' => $app_id,
                        'client_secret' => $app_secret,
                    ),
                );

                $callback_param = 'oauth2callback';

            break;

            default:
                $app_id         = kite_opt('facebook_app_id');
                $app_secret     = kite_opt('facebook_app_secret');

                if( empty( $app_secret ) || empty( $app_id ) ) return;

                $strategy       = array(
                    'Facebook' => array(
                        'app_id' => $app_id,
                        'app_secret' => $app_secret,
                        'scope' => 'email'
                    ),
                );
            break;
        }

        $config = array(
            'security_salt'         => $security_salt,
            'host'                  => $account_url,
            'path'                  => '/',
            'callback_url'          => $account_url,
            'callback_transport'    => 'get',
            'strategy_dir'          => plugins_url('kt-core/includes/sociallogin/opauth/') ,
            'Strategy'              => $strategy
        );

        //social media resopnd with code variable 
        if( empty( $_GET['code'] ) ) {
            $config['request_uri'] = '/' . $network;
        } else {
            $config['request_uri'] = '/' . $network . '/' . $callback_param . '?code=' . $_GET['code'];
        }

        new Opauth( $config );
    }

    public function authenticate_callback() {
        if ( isset( $_GET['error_reason'] ) && $_GET['error_reason'] == 'user_denied' ) {
            wp_redirect( $this->get_account_url() );
            exit;
        }
        if( empty( $_GET['opauth'] ) || is_user_logged_in() ) return;

        $opauth = unserialize(base64_decode($_GET['opauth']));

        switch ( $opauth['auth']['provider'] ) {
            case 'Facebook':
                if( empty( $opauth['auth']['info'] ) ) {
                    wc_add_notice( __( 'Can\'t login with Facebook. Please, try again later.', 'kt-core' ), 'error' );
                    return;
                }

                $email = $opauth['auth']['info']['email'];

                if( empty( $email ) ) {
                    wc_add_notice( __( 'Facebook doesn\'t provide your email. Try to register manually.', 'kt-core' ), 'error' );
                    return;
                }

                $this->authenticated_user( $email );
            break;
            case 'Google':

                if( empty( $opauth['auth']['info'] ) ) {
                    wc_add_notice( __( 'Can\'t login with Google. Please, try again later.', 'kt-core' ), 'error' );
                    return;
                }

                $email = $opauth['auth']['info']['email'];

                if( empty( $email ) ) {
                    wc_add_notice( __( 'Google doesn\'t provide your email. Try to register manually.', 'kt-core' ), 'error' );
                    return;
                }

                $this->authenticated_user( $email );
            break;
            
            default:
            break;
        }
    }

    //If User Authenticated then If user is already a member login otherwise register the user
    public function authenticated_user( $email ) {

        add_filter('pre_option_woocommerce_registration_generate_username', array( $this, 'return_yes' ), 10);
        $password = wp_generate_password();
        $customer = wc_create_new_customer( $email, '', $password);

        $user = get_user_by('email', $email);

        if( is_wp_error( $customer ) ) {
            if( isset( $customer->errors['registration-error-email-exists'] ) ) {
                wc_set_customer_auth_cookie( $user->ID );
            }
        } else {
            wc_set_customer_auth_cookie( $customer );
        }

        wc_add_notice( sprintf( __( 'You are now logged in as <strong>%s</strong>', 'kt-core' ), $user->display_name ) );

        remove_filter('pre_option_woocommerce_registration_generate_username', array( $this, 'return_yes' ), 10);
    }

    public function get_current_callback_network() {
        $account_url = $this->get_account_url();

        foreach ($this->available_networks as $network) {
            if( strstr( $this->current_url, trailingslashit( $account_url ) . $network ) ) {
                return $network;
            }
        }

        return false;
    }

    //get woocommerce account url 
    public function get_account_url() {
        return untrailingslashit( wc_get_page_permalink('myaccount') );
    }

    public function return_yes() {
        return 'yes';
    }
}
new Social_Network_Authentication();
