<?php
/*-----------------------------------------------------------------------------------

	Theme Shortcodes

-----------------------------------------------------------------------------------*/

/*-----------------------------------------------------------------------------------*/
/*  Allowed tags for wp_kses
/*-----------------------------------------------------------------------------------*/
function kite_allowed_tags() {
	return array(
		'strong' => array(),
		'br'     => array(),
		'em'     => array(),
		'a'      => array(
			'href'  => array(),
			'title' => array(),
		),
	);
}
$allowed_html = kite_allowed_tags();


/*-----------------------------------------------------------------------------------*/
/*  Shortcode helpers
/*-----------------------------------------------------------------------------------*/

// Generate ID for shortcodes
function kite_sc_id( $key ) {
	$globalKey = "kt_sc_$key";

	if ( array_key_exists( $globalKey, $GLOBALS ) ) {
		$GLOBALS[ $globalKey ]++;
	} else {
		$GLOBALS[ $globalKey ] = 1;
	}

	$id = $GLOBALS[ $globalKey ];
	return $key . '_' . $id;
}
function kite_sc_ss_id( $key ) {
	$globalKey = "kt_sc_$key";
	if ( session_status() == PHP_SESSION_NONE ) {
		session_start();
	}
	if ( isset( $_SESSION[ $globalKey ] ) && ! empty( $_SESSION[ $globalKey ] ) ) {
		$_SESSION[ $globalKey ] = $_SESSION[ $globalKey ] + 1;
	} else {
		$_SESSION[ $globalKey ] = 1;
	}
	$id = $_SESSION[ $globalKey ];
	return $key . '_' . $id;
}
/*-----------------------------------------------------------------------------------*/
/*  Separators
/*-----------------------------------------------------------------------------------*/

function kite_sc_separator( $atts, $content = null ) {
	extract(
		shortcode_atts(
			array(
				'size'                    => 'full',  // small, small-center, medium, medium-center
				'pxthickness'             => '1',
				'color'                   => '#888',
				'separator_margin_bottom' => '30',
				'separator_margin_top'    => '30',
				'border_style'            => 'solid',
			),
			$atts
		)
	);

	$id    = kite_sc_id( 'vc_separator' );
	$class = array();

	switch ( $size ) {
		case 'small':
			$class[] = 'hr-small';
			break;
		case 'small-center':
			$class[] = 'hr-small hr-center';
			break;
		case 'extra-small':
			$class[] = 'hr-extra-small';
			break;
		case 'extra-small-center':
			$class[] = 'hr-extra-small hr-center   ';
			break;
		case 'medium':
			$class[] = 'hr-medium';
			break;
		case 'medium-center':
			$class[] = 'hr-medium hr-center';
			break;
		case 'full':
			$class[] = ' full';
			break;
	}

	$hasStyle        = '' != $color || '' != $pxthickness;
	$kiteInlineStyle = '';
	if ( $hasStyle ) {
		$hr = '';
		$hr = '
		border-color: ' . esc_attr( $color ) . ';
        margin-top: ' . esc_attr( $separator_margin_top ) . 'px;
        margin-bottom: ' . esc_attr( $separator_margin_bottom ) . 'px;
        border-style: ' . esc_attr( $border_style ) . ';
        border-width: ' . esc_attr( $pxthickness ) . 'px;
		';
		if ( $pxthickness == 1 ) {
			$kiteInlineStyle .= "hr#$id{border-bottom-width:0px;}";
		}
	}//End of if
	wp_add_inline_style( 'kite-inline-style', $kiteInlineStyle );
	ob_start();
	?>

		<hr id="<?php echo esc_attr( $id ); ?>"  class="vc_separator <?php echo implode( ' ', $class ); ?>" style="<?php echo esc_attr( $hr ); ?>" />

	<?php
	return ob_get_clean();
}

/*-----------------------------------------------------------------------------------*/
/*  Title with horizontal line
/*-----------------------------------------------------------------------------------*/

function kite_sc_title( $atts, $content = null ) {
	extract(
		shortcode_atts(
			array(
				'title'                   => 'Title',
				'title_align'             => 'separator_align_center',
				'title_font_size'         => '20',
				'title_weight'            => 'bold',
				'title_border_enable'     => 'disable',
				'pxthickness'             => '1',
				'title_color'             => '#464646',
				'color'                   => '#888',
				'separator_margin_bottom' => '30',
				'separator_margin_top'    => '30',
				'border_style'            => 'solid',
			),
			$atts
		)
	);

	$id = kite_sc_id( 'vc_text_separator' );

	$hasStyle    = '' != $color || '' != $pxthickness;
	$vc_sep_line = '<span class="vc_sep_line" style=" border-color: ' . esc_attr( $color ) . ';border-style: ' . esc_attr( $border_style ) . ';border-top-width: ' . esc_attr( $pxthickness ) . 'px;height:' . esc_attr( $pxthickness ) . 'px;top:' . ceil( ( (int) esc_attr( -( $pxthickness ) ) ) / 2 ) . 'px;"></span>';
	ob_start();
	?>

	<div id=<?php echo esc_attr( $id ); ?> class="vc_separator <?php echo esc_attr( $title_align ); ?> <?php echo esc_attr( $title_border_enable ); ?>" style=" margin-top: <?php echo esc_attr( $separator_margin_top ); ?>px; margin-bottom: <?php echo esc_attr( $separator_margin_bottom ); ?>px;">
		<span class="vc_sep_holder vc_sep_holder_l">
			<?Php echo '' . $vc_sep_line; ?>
		</span>
		<div class="title" style ="border-left-color:<?php echo esc_attr( $color ); ?>; border-right-color:<?php echo esc_attr( $color ); ?>; font-size:<?php echo esc_attr( $title_font_size ); ?>px; font-weight:<?php echo esc_attr( $title_weight ); ?>; color:<?php echo esc_attr( $title_color ); ?>;"><?php echo esc_html( $title ); ?></div>
		<span class="vc_sep_holder vc_sep_holder_r">
			<?Php echo '' . $vc_sep_line; ?>
		</span>
	</div>

	<?php
	return ob_get_clean();
}

/*-----------------------------------------------------------------------------------*/
/*  Team Member
/*-----------------------------------------------------------------------------------*/

function kite_sc_team_member( $atts, $content = null ) {

	extract(
		shortcode_atts(
			array(
				'name'                 => 'JOHN DOE',
				'job_title'            => 'Designer',
				'image'                => '',
				'signature'            => '',
				'style'                => 'dark',
				'team_color_preset'    => 'd02d48',
				'team_color'           => '#cccccc',
				'description'          => '',
				'url'                  => '',
				'elementor_url_title'  => '',
				'new_tab'              => false,
				'team_animation'       => 'none',
				'team_animation_delay' => '0',
				'responsive_animation' => 'disable',
				'team_icon1'           => '',
				'team_icon2'           => '',
				'team_icon3'           => '',
				'team_icon4'           => '',
				'team_icon5'           => '',
				'team_icon_url1'       => '',
				'team_icon_url2'       => '',
				'team_icon_url3'       => '',
				'team_icon_url4'       => '',
				'team_icon_url5'       => '',
				'team_icon_target1'    => '_self',
				'team_icon_target2'    => '_self',
				'team_icon_target3'    => '_self',
				'team_icon_target4'    => '_self',
				'team_icon_target5'    => '_self',
			),
			$atts
		)
	);

	if ( is_numeric( $image ) ) {
		$image = wp_get_attachment_url( $image );
	}

	if ( is_numeric( $signature ) ) {
		$signature = wp_get_attachment_url( $signature );
	}

	$hasTeamIcon = '' != $team_icon1 || '' != $team_icon2 || '' != $team_icon3 || '' != $team_icon4 || '' != $team_icon5;

	$hasStyle = '' != $team_color || '' != $team_color_preset;
	$id       = kite_sc_id( 'team_member' );

	ob_start();
	$allowed_html     = kite_allowed_tags();
	 $color           = '';
	 $kiteInlineStyle = '';
	if ( $hasStyle ) {
		if ( strlen( esc_attr( $team_color_preset ) ) ) {
			if ( $team_color_preset == 'custom' ) {
				$color = $team_color;
			} else {
				$color = '#' . $team_color_preset;
			}
		}

		$kiteInlineStyle .= "#$id.team-member:hover .member-plus{background-color: $color;}";
		$kiteInlineStyle .= "#$id.team-member .member-line{background-color: $color;}";
		$kiteInlineStyle .= "#$id.team-member .icons li:hover a{color:$color;}";
	}//End of if
	wp_add_inline_style( 'kite-inline-style', $kiteInlineStyle );
	?>
		<div id="<?php echo esc_attr( $id ); ?>" class="team-member 
							<?php
							if ( strlen( $style ) ) {
								echo esc_attr( $style );  }
							?>
		 <?php
			if ( $team_animation != 'none' ) {
						echo 'shortcodeanimation';
				if ( $responsive_animation != '' ) {
					echo ' no-responsive-animation';}
			}
			?>
"  
	<?php
	if ( $team_animation != 'none' ) {
		?>
	 data-delay="<?php echo esc_attr( $team_animation_delay ); ?>" data-animation="<?php echo esc_attr( $team_animation ); ?>" <?php } ?>>

			<?php
			if ( $image ) {
				?>
			<div class="member-pic-container">

				<div class="member-line"></div>

				<div class="member-pic">
					<?php
					if ( $image ) {
						?>
							<img class ="bg-image" src="<?php echo esc_url( $image ); ?>" alt="<?php echo esc_attr( $name ); ?>">
						<?php
					}
					?>
				</div>

				<div class="member-plus">
					<span class="member-plus-line"></span>
				</div>
							
				<?php if ( $hasTeamIcon ) { ?>
						<ul class="icons">
						   
							<?php if ( $team_icon1 ) { ?>
								<li>
									<a href="<?php echo esc_url( $team_icon_url1 ); ?>" title="<?php echo esc_attr( $job_title ); ?>" 
														<?php
														if ( $team_icon_target1 != '' ) {
															?>
  target="<?php echo esc_attr( $team_icon_target1 ); ?>"<?php } ?>>
										<span class="icon-<?php echo esc_attr( $team_icon1 ); ?>" ></span>
									</a>
								</li>
							 <?php } ?>
							 
							<?php if ( $team_icon2 ) { ?>
								<li>
									<a href="<?php echo esc_url( $team_icon_url2 ); ?>" title="<?php echo esc_attr( $job_title ); ?>" 
														<?php
														if ( $team_icon_target2 != '' ) {
															?>
  target="<?php echo esc_attr( $team_icon_target2 ); ?>"<?php } ?>>
										<span class="icon-<?php echo esc_attr( $team_icon2 ); ?>" ></span>
									</a>
								</li>
							<?php } ?>
							
							<?php if ( $team_icon3 ) { ?>
								<li>
									<a href="<?php echo esc_url( $team_icon_url3 ); ?>" title="<?php echo esc_attr( $job_title ); ?>" 
														<?php
														if ( $team_icon_target3 != '' ) {
															?>
  target="<?php echo esc_attr( $team_icon_target3 ); ?>"<?php } ?>>
										<span class="icon-<?php echo esc_attr( $team_icon3 ); ?>" ></span>
									</a>
								</li>
							<?php } ?>
							
							<?php if ( $team_icon4 ) { ?>
								<li>
									<a href="<?php echo esc_url( $team_icon_url4 ); ?>" title="<?php echo esc_attr( $job_title ); ?>" 
														<?php
														if ( $team_icon_target4 != '' ) {
															?>
 target="<?php echo esc_attr( $team_icon_target4 ); ?>"<?php } ?>>
										<span class="icon-<?php echo esc_attr( $team_icon4 ); ?>" ></span>
									</a>
								</li>
							<?php } ?>
							
							<?php if ( $team_icon5 ) { ?>
								<li>
									<a href="<?php echo esc_url( $team_icon_url5 ); ?>" title="<?php echo esc_attr( $job_title ); ?>" 
														<?php
														if ( $team_icon_target5 != '' ) {
															?>
 target="<?php echo esc_attr( $team_icon_target5 ); ?>"<?php } ?>>
										<span class="icon-<?php echo esc_attr( $team_icon5 ); ?>" ></span>
									</a>
								</li> 
							<?php } ?>
							
						</ul>
				<?php } ?>

				<div class="overlay"></div>
			</div>

			<div class="member-info">

				 <span class="member-name"> <?php echo esc_html( $name ); ?></span>

				<cite><?php echo esc_html( $job_title ); ?></cite>

				<div class="member-description">

					<p><?php echo wp_kses( $description, $allowed_html ); ?></p>

					<?php
					if ( $url ) {
						if ( function_exists( 'vc_build_link' ) && empty( $elementor_url_title ) ) {
							$link = vc_build_link( $atts['url'] );
						} else {
							$link['title'] = $elementor_url_title;
							$link['url']   = $url;
							if ( $new_tab ) {
								$link['target'] = '_blank';
							} else {
								$link['target'] = '_self';
							}
						}

						if ( strlen( $link['url'] ) ) {
							?>
						<a href="<?php echo esc_url( $link['url'] ); ?>" 
											<?php
											if ( $link['target'] != '' ) {
												?>
 target="<?php echo esc_attr( $link['target'] ); ?>"<?php } ?> class="more-link-arrow" title="<?php echo esc_attr( $link['title'] ); ?>">[ <?php echo esc_attr( $link['title'] ); ?> ]</a>
							<?php
						}
					}
					?>

					<?php if ( '' != esc_url( $signature ) ) { ?>

						<div class="signature">

							<img src="<?php echo esc_url( $signature ); ?>" alt="<?php echo esc_attr( $name ); ?>">

						</div>

					<?php } ?>
					
				</div>

			</div>

				<?php
			}
			?>

		</div>
	<?php
	return ob_get_clean();
}

/*-----------------------------------------------------------------------------------*/
/* Testimonials shortcode
/*-----------------------------------------------------------------------------------*/

function kite_sc_testimonial( $atts, $content = null ) {
	$class = '';
	extract(
		shortcode_atts(
			array(
				'style'                       => 'Dark',
				'visible_items'               => '1',
				'testimonial_animation'       => 'none',
				'testimonial_animation_delay' => '0',
				'responsive_animation'        => 'disable',
			),
			$atts
		)
	);

	$class .= 'carousel';

	$class .= ' testimonials-style ';
	$class .= ' testimonials-' . $visible_items;

	$animation_params         = '';
	$testimonialWithAnimation = '';

	if ( $testimonial_animation != 'none' ) {
		$testimonialWithAnimation = ' shortcodeanimation';
		$animation_params         = " data-delay='" . esc_attr( $testimonial_animation_delay ) . "' data-animation='" . esc_attr( $testimonial_animation ) . "'";

		if ( $responsive_animation != '' ) {
			$testimonialWithAnimation .= ' no-responsive-animation';
		}
	};

	$id = kite_sc_id( 'testimonial' );
	ob_start();
	?>
	 

	<div id="<?php echo esc_attr( $id ); ?>" class="<?php echo esc_attr( $class ); ?> <?php
	echo esc_attr( $testimonialWithAnimation );
	if ( $style == 'light' ) {
		echo ' skin-light'; }
	?>
	" data-id="<?php echo esc_attr( $id ); ?>" <?php echo esc_attr( $animation_params ); ?>>
		<div class="swiper-container swiper-container-<?php echo esc_attr( $id ); ?> clearfix" data-visibleitems="
																 <?php
																	if ( strlen( $visible_items ) ) {
																		echo esc_attr( $visible_items ); }
																	?>
		">
			<div class="swiper-wrapper">
				<?php

				echo do_shortcode( $content );
				?>
			</div>
		</div>

		<!-- Next Arrows -->
		<div class="arrows-button-next no-select arrows-button-next-<?php echo esc_attr( $id ); ?>">
		</div>
		<!-- Prev Arrows -->
		<div class="arrows-button-prev no-select arrows-button-prev-<?php echo esc_attr( $id ); ?>">
		</div>

	</div>

	<?php

	return ob_get_clean();
}

/*-----------------------------------------------------------------------------------*/
/* Testimonial item shortcode
/*-----------------------------------------------------------------------------------*/

function kite_sc_testimonial_item( $atts, $content = null ) {

	extract(
		shortcode_atts(
			array(
				'author'    => '',
				'text'      => '',
				'job'       => '',
				'image_url' => '',
			),
			$atts
		)
	);

	$html = $authorimg = '';
	if ( is_numeric( $image_url ) ) {
		$authorimg = wp_get_attachment_url( $image_url );
	}

	ob_start();
	$allowed_html = kite_allowed_tags();

	?>

	<div class="swiper-slide testimonial">
		<div class="quote">
		
		<blockquote><?php echo wp_kses( $text, $allowed_html ); ?> </blockquote>
			<div class="head">
				<div class="author-image" style="background-image:url(<?php echo esc_attr( $authorimg ); ?>)"></div>
				<div class="author">
					<h4 class="name"><?php echo esc_html( $author ); ?> </h4>
					<cite class="job"><?php echo esc_html( $job ); ?> </cite>
				</div>
			</div>
			
		</div>                 
	</div>

	<?php

	return ob_get_clean();
}



/*-----------------------------------------------------------------------------------*/
/*  Pie Chart
/*-----------------------------------------------------------------------------------*/

function kite_sc_piechart( $atts, $content = null ) {
	extract(
		shortcode_atts(
			array(
				'title'                    => '',
				'title_color'              => '',
				'subtitle'                 => '',
				'subtitle_color'           => '',
				'piechart_percent'         => '70',
				'piechart_percent_display' => 'enable',
				'piechart_color_preset'    => 'd02d48',
				'piechart_color'           => '',
				'main_color'               => '',
				'piechart_icon'            => '',
				'piechart_animation'       => 'none',
				'piechart_animation_delay' => '0',
				'responsive_animation'     => 'disable',
			),
			$atts
		)
	);

	if ( $piechart_color_preset != 'custom' ) {
		$piechart_color = '#' . $piechart_color_preset;
	}

	$hasTitle              = '' != $title;
	$class                 = 'piechart easypiechart';
	$piechartWithAnimation = '';
	$id                    = kite_sc_id( 'piechart' );
	$responsiveid          = kite_sc_id( 'piechartResponsive' );

	if ( $piechart_animation != 'none' ) {
		$piechartWithAnimation = ' shortcodeanimation';

		if ( $responsive_animation != '' ) {
			$piechartWithAnimation .= ' no-responsive-animation';
		}
	}

	ob_start();
	?>

	<div id="<?php echo esc_attr( $id ); ?>" class="piechartbox <?php echo esc_attr( $piechartWithAnimation ); ?> <?php
	if ( $piechart_percent_display == 'disable' ) {
		?>
		 disablepercent <?php } ?>" 
		<?php
		if ( strlen( esc_attr( $piechart_animation ) ) ) {
			?>
	 data-delay="<?php echo esc_attr( $piechart_animation_delay ); ?>" data-animation="<?php echo esc_attr( $piechart_animation ); ?>" <?php } ?> <?php
		if ( esc_attr( $piechart_color ) ) {
			?>
	 data-barColor=<?php echo esc_attr( $piechart_color ); } ?>>
		<div class="<?php if ( $piechart_icon ) { ?>iconpchart <?php } ?> <?php echo esc_attr( $class ); ?>" data-percent="<?php echo esc_attr( $piechart_percent ); ?>">
			<?php if ( $piechart_icon ) { ?>
				<span class="icon icon-<?php echo esc_attr( $piechart_icon ); ?>" <?php if ( strlen( esc_attr( $main_color ) ) ) { ?> style="color:<?php echo esc_attr( $main_color ); ?>;" <?php } ?>></span>
			<?php } ?>
			<?php if ( $piechart_percent_display == 'enable' ) { ?>
				<span class="perecent" <?php if ( strlen( esc_attr( $main_color ) ) ) { ?> style="color:<?php echo esc_attr( $main_color ); ?>;" <?php } ?>><?php echo esc_html( $piechart_percent ); ?><span class="piechart_percent">%</span></span>
			<?php } ?>
			<div class="dot-container">
				<div class="dot" <?php if ( strlen( esc_attr( $main_color ) ) ) { ?> style="background-color:<?php echo esc_attr( $main_color ); ?>;" <?php } ?>></div>
			</div>
		</div>
		<p class="title" <?php if ( strlen( esc_attr( $title_color ) ) ) { ?> style="color:<?php echo esc_attr( $title_color ); ?>;" <?php } ?>><?php echo esc_html( $title ); ?></p>
		<p class="subtitle" <?php if ( strlen( esc_attr( $subtitle_color ) ) ) { ?> style="color:<?php echo esc_attr( $subtitle_color ); ?>;" <?php } ?>><?php echo esc_html( $subtitle ); ?></p>
	</div>

	<?php
	return ob_get_clean();
}

/*-----------------------------------------------------------------------------------*/
/*  Horizontal progress bar
/*-----------------------------------------------------------------------------------*/

function kite_sc_progressbar( $atts, $content = null ) {
	extract(
		shortcode_atts(
			array(
				'title'                       => '',
				'title_color'                 => '',
				'percent'                     => '50',
				'active_bg_color'             => '',
				'inactive_bg_color'           => '',
				'progressbar_animation'       => 'none',
				'progressbar_animation_delay' => '0',
				'responsive_animation'        => 'disable',
			),
			$atts
		)
	);

	$hasStyle                 = '' != $title_color || '' != $active_bg_color || '' != $inactive_bg_color;
	$id                       = kite_sc_id( 'progressbar' );
	$progressbarWithAnimation = '';

	if ( $progressbar_animation != 'none' ) {
		$progressbarWithAnimation = ' shortcodeanimation';

		if ( $responsive_animation != '' ) {
			$progressbarWithAnimation .= ' no-responsive-animation';
		}
	}

	ob_start();
	$kiteInlineStyle = '';
	if ( $hasStyle ) {
		if ( strlen( esc_attr( $active_bg_color ) ) ) {
			$kiteInlineStyle .= "#$id.progress_bar .progressbar_percent:after{background-color:$active_bg_color;}";
		}

		if ( strlen( esc_attr( $inactive_bg_color ) ) ) {
			$kiteInlineStyle .= "#$id.progress_bar .progressbar_holder:after{background-color:$inactive_bg_color;}";
		}
	}
	if ( strlen( esc_attr( $title_color ) ) ) {
		$kiteInlineStyle .= "#$id .progress_title,#$id .progress_percent_value{color:" . esc_attr( $title_color ) . ';}';
	}
	if ( strlen( esc_attr( $active_bg_color ) ) ) {
		$kiteInlineStyle .= "#$id .progressbar_percent{background-color:" . esc_attr( $active_bg_color ) . ';}';
	}
	wp_add_inline_style( 'kite-inline-style', $kiteInlineStyle );
	?>

	<div id="<?php echo esc_attr( $id ); ?>"  class="progress_bar <?php echo esc_attr( $progressbarWithAnimation ); ?>" data-delay="<?php echo esc_attr( $progressbar_animation_delay ); ?>" data-animation="<?php echo esc_attr( $progressbar_animation ); ?>">
		<div class="progressbar_holder">
			<?php
			if ( $title ) {
				?>
				<span class="progress_title">
				<?php
				if ( esc_attr( $title ) ) {
								echo esc_attr( $title ); }
				?>
				</span><?php } ?>
			<span class="progress_percent_value" style="<?php echo '',( is_rtl() ) ? 'right:' . esc_attr( $percent ) . '%;left:auto;' : 'left:' . esc_attr( $percent ) . '%;right:auto;'; ?>"><?php echo esc_html( $percent ); ?>%</span>
			<div class="progressbar_percent" data-percentage="
			<?php
			if ( esc_attr( $percent ) ) {
				echo esc_attr( $percent ); }
			?>
				" style="width:<?php echo esc_attr( $percent ); ?>%;"></div>
		</div>
	</div>
	
	<?php
	return ob_get_clean();
}

/*-----------------------------------------------------------------------------------*/
/*  Social Icon
/*-----------------------------------------------------------------------------------*/

function kite_sc_socialIocn( $atts, $content = null ) {
	extract(
		shortcode_atts(
			array(
				'sociallink_url'   => '',
				'sociallink_type'  => 'facebook',
				'sociallink_style' => 'dark',
				'sociallink_image' => '',
			),
			$atts
		)
	);

	$id = kite_sc_id( 'socialIcon' );
	if ( is_numeric( $sociallink_image ) ) {
		$sociallink_image = wp_get_attachment_url( $sociallink_image );
	}

	if ( esc_attr( $sociallink_type ) == 'custom' ) {
		$sociallink_type = $id;
	}//if social network name was custom

	ob_start();

	?>
	
	<div class="sociallink-shortcode iconstyle <?php echo esc_attr( $sociallink_type ); ?> <?php echo esc_attr( $sociallink_style ); ?>">
		<a id="<?php echo esc_attr( $id ); ?>" href="<?php echo esc_url( $sociallink_url ); ?>" target="_blank">
			<span class="icon icon-<?php echo esc_attr( $sociallink_type ); ?>" style="background-image: url('<?php echo esc_url( $sociallink_image ); ?>') !important;"></span>
		</a>
	</div>

	<?php
	return ob_get_clean();
}

/*-----------------------------------------------------------------------------------*/
/*  Social Link
/*-----------------------------------------------------------------------------------*/

function kite_sc_socialLink( $atts, $content = null ) {
	extract(
		shortcode_atts(
			array(
				'sociallink_url'   => '',
				'sociallink_type'  => 'facebook',
				'sociallink_style' => 'dark',
				'sociallink_text'  => '',
			),
			$atts
		)
	);

	$id = kite_sc_id( 'socialLink' );

	switch ( $sociallink_type ) {
		case 'facebook':
			$sociallink_text = 'facebook';
			break;
		case 'twitter':
			$sociallink_text = 'Twitter';
			break;
		case 'vimeo':
			$sociallink_text = 'Vimeo';
			break;
		case 'youtube-play':
			$sociallink_text = 'YouTube';
			break;
		case 'google-plus':
			$sociallink_text = 'Google+';
			break;
		case 'dribbble':
			$sociallink_text = 'Dribbble';
			break;
		case 'tumblr':
			$sociallink_text = 'Tumblr';
			break;
		case 'linkedin':
			$sociallink_text = 'LinkedIn';
			break;
		case 'flickr':
			$sociallink_text = 'Flickr';
			break;
		case 'forrst':
			$sociallink_text = 'Forrst';
			break;
		case 'github':
			$sociallink_text = 'GitHub';
			break;
		case 'lastfm':
			$sociallink_text = 'Last.FM';
			break;
		case 'paypal':
			$sociallink_text = 'PaypPal';
			break;
		case 'feed':
			$sociallink_text = 'RSS';
			break;
		case 'WordPress':
			$sociallink_text = 'WordPress';
			break;
		case 'skype':
			$sociallink_text = 'Skype';
			break;
		case 'yahoo':
			$sociallink_text = 'Yahoo';
			break;
		case 'steam':
			$sociallink_text = 'Steam';
			break;
		case 'reddit-alien':
			$sociallink_text = 'Reddit';
			break;
		case 'stumbleupon':
			$sociallink_text = 'StumbleUpon';
			break;
		case 'pinterest':
			$sociallink_text = 'Pinterest';
			break;
		case 'deviantart':
			$sociallink_text = 'DeviantArt';
			break;
		case 'xing':
			$sociallink_text = 'Xing';
			break;
		case 'blogger':
			$sociallink_text = 'Blogger';
			break;
		case 'soundcloud':
			$sociallink_text = 'SoundCloud';
			break;
		case 'delicious':
			$sociallink_text = 'Delicious';
			break;
		case 'foursquare':
			$sociallink_text = 'Foursquare';
			break;
		case 'instagram':
			$sociallink_text = 'Instagram';
			break;
		case 'behance':
			$sociallink_text = 'Behance';
			break;
		case 'custom':
			$sociallink_text = esc_attr( $sociallink_text );
			break;
		default:
			$sociallink_text = 'facebook';
	}

	if ( esc_attr( $sociallink_type ) == 'custom' ) {
		$sociallink_type = $id;
	}//if social network name was custom

	ob_start();

	?>

	<div class="sociallink-shortcode textstyle <?php echo esc_attr( $sociallink_type ); ?> <?php echo esc_attr( $sociallink_style ); ?>">
		<a id="<?php echo esc_attr( $id ); ?>" href="<?php echo esc_url( $sociallink_url ); ?>" target="_blank">
			<span><?php echo esc_html( $sociallink_text ); ?></span>
		</a>
	</div>

	<?php
	return ob_get_clean();
}

/*-----------------------------------------------------------------------------------*/
/*  Text-Box
/*-----------------------------------------------------------------------------------*/

function kite_sc_textbox( $atts, $content ) {
	extract(
		shortcode_atts(
			array(
				'content_align'              => 'left',
				'content_size'               => '100',
				'custom_color_check'         => '',
				'text_content_color'         => '',
				'typing_animation_check'     => '',
				'type_speed'                 => 'very_slow',
				'loop_animation_check'       => '',
				'content_fontsize'           => '16',
				'content_font_type'          => 'default',
				'content_google_fonts'       => '',
				'text_animation'             => 'none',
				'text_animation_delay'       => '0',
				'responsive_animation'       => 'disable',
				'content_custom_font_size'   => '',
				'content_custom_line_height' => '',
			),
			$atts
		)
	);

	$hasContent = '' != $content;
	$hasStyle   = '' != $text_content_color || 'custom' == $content_fontsize || '100' != $content_size;

	$id             = kite_sc_id( 'textbox' );
	$class          = array();
	$contentFSClass = 'fontsize' . $content_fontsize;
	$type           = array();
	$loop           = '0';
	if ( strlen( esc_attr( $loop_animation_check ) ) ) {
		$loop = '1';
	}
	switch ( $type_speed ) {
		case 'very_slow':
			$type = array(
				'type'  => 140,
				'delay' => 7500,
				'back'  => 20,
			);
			break;
		case 'slow':
			$type = array(
				'type'  => 100,
				'delay' => 5000,
				'back'  => 15,
			);
			break;
		case 'normal':
			$type = array(
				'type'  => 60,
				'delay' => 3000,
				'back'  => 10,
			);
			break;
		case 'fast':
			$type = array(
				'type'  => 30,
				'delay' => 2500,
				'back'  => 0,
			);
			break;
		case 'very_fast':
		default:
			$type = array(
				'type'  => 0,
				'delay' => 1500,
				'back'  => 0,
			);
			break;
	}
	$typeSpeed = $type['type'];
	$backDelay = $type['delay'];
	$backSpeed = $type['back'];

	switch ( $content_align ) {
		case 'right':
			$class[] = 'textboxright';
			break;
		case 'center':
			$class[] = 'textboxcenter';
			break;
		case 'left':
		default:
			$class[] = 'textboxleft';

	}

	if ( $text_animation != 'none' ) {

		$class[] = 'shortcodeanimation';
		if ( $responsive_animation != '' ) {
			$class[] = 'no-responsive-animation';
		}
	}

	$content_google_fonts_inline_style = '';
	if ( $content_font_type != 'default' && function_exists( 'kite_get_fonts_data' ) ) {
		$google_fonts_data                 = kite_get_fonts_data( $content_google_fonts );
		$content_google_fonts_inline_style = kite_google_fonts_styles( $google_fonts_data );
		kite_enqueue_google_fonts( $google_fonts_data );
	}

	ob_start();

	$kiteInlineStyle = '';
	if ( $hasStyle ) {
		if ( $content_size != '100' ) {
			$kiteInlineStyle .= '#' . esc_attr( $id ) . ' .text {width:' . $content_size . '%;}';
		}

		if ( $content_fontsize == 'custom' && ! empty( $content_custom_font_size ) ) {
			$contentSelector  = "#$id.textbox .text";
			$kiteInlineStyle .= kite_responsive_font_size( $contentSelector, $content_custom_font_size, $content_custom_line_height );
		}

		if ( $custom_color_check == 'enable' ) {
			$kiteInlineStyle .= '.textbox h1,.textbox h2,.textbox h3,.textbox h4,.textbox h5,.textbox h6, .textbox span:not(#txtbox),.textbox blockquote,.textbox p { color: inherit !important;}';
		}
	}//End of if
	wp_add_inline_style( 'kite-inline-style', $kiteInlineStyle );
	?>

	<div id="<?php echo esc_attr( $id ); ?>" class="textbox <?php echo implode( ' ', $class ); ?>"  
						<?php
						if ( strlen( esc_attr( $text_animation ) ) ) {
							?>
		 data-delay="<?php echo esc_attr( $text_animation_delay ); ?>" data-animation="<?php echo esc_attr( $text_animation ); ?>" <?php } ?> <?php
			if ( strlen( esc_attr( $typing_animation_check ) ) ) {
				?>
	 data-animation-txt="true" data-loop="<?php echo ( esc_attr( $loop ) ); ?>" data-speed = "<?php echo esc_attr( $typeSpeed ); ?>" data-backspeed ="<?php echo esc_attr( $backSpeed ); ?>"<?php } ?> >
		
		<?php
		if ( $hasContent ) {
			if ( strlen( esc_attr( $typing_animation_check ) ) ) {
				?>
			<div class="text">
				<span id="txtbox" class="<?php echo esc_attr( $contentFSClass ); ?> txt" style="
													<?php
													if ( strlen( esc_attr( $text_content_color ) ) ) {
														?>
					color: <?php echo esc_attr( $text_content_color ); ?>; <?php } echo esc_attr( $content_google_fonts_inline_style ); ?>" data-text='<?php echo strip_tags( $content ); ?>'>
				</span>
				</div>
				<?php
			} else {
				?>
				<div class="<?php echo esc_attr( $contentFSClass ); ?> text" style="
									   <?php
										if ( strlen( esc_attr( $text_content_color ) ) ) {
											?>
					color: <?php echo esc_attr( $text_content_color ); ?>; <?php } echo esc_attr( $content_google_fonts_inline_style ); ?>"><?php echo '' . $content; ?></div>
			<?php } ?>
		<?php } ?>
		
	</div>

	<?php
	return ob_get_clean();
}

/*-----------------------------------------------------------------------------------*/
/*  Custom Title
/*-----------------------------------------------------------------------------------*/

function kite_sc_customTitle( $atts ) {
	extract(
		shortcode_atts(
			array(
				'title'                  => '',
				'font_type'              => 'default',
				'google_fonts'           => '',
				'title_color'            => '',
				'title_fontsize'         => '2',
				'hoverline_color'        => '',
				'title_background_style' => 'iconbackground',
				'bg_title'               => '',
				'bg_title_font_size'     => '',
				'bg_title_color'         => '',
				'bg_icon_color'          => '',
				'icon'                   => '',
				'shape_fill_color'       => '',
				'shape_border_color'     => '',
				'letter_spacing'         => '0',
				'style'                  => 'line',
				'title_animation'        => 'none',
				'title_animation_delay'  => '0',
				'responsive_animation'   => 'disable',
			),
			$atts
		)
	);

	if ( ! empty( $bg_title_font_size ) ) {
		$classs[] = 'bgTitleHasFontSize';
	}

	$id = kite_sc_id( 'custom-title' );

	$hasStyle = '' != $title_color || '' != $hoverline_color || '' != $shape_fill_color || '' != $shape_border_color || '';

	switch ( $letter_spacing ) {
		case '0':
			$class[] = 'letterspacing0';
			break;
		case '1':
			$class[] = 'letterspacing1';
			break;
		case '2':
			$class[] = 'letterspacing2';
			break;
		case '3':
			$class[] = 'letterspacing3';
			break;
		default:
			$class[] = 'letterspacing4';

	}

	switch ( $title_background_style ) {
		case 'iconbackground':
			$class[] = 'iconbackgroundstyle';
			break;
		case 'shapebackground':
			$class[] = 'shapebackgroundstyle';
			break;
		case 'textbackground':
			$class[] = 'textbackgroundstyle';
			break;
	}

	if ( $title_animation != 'none' ) {

		$class[] = 'shortcodeanimation';

		if ( $responsive_animation != '' ) {
			$class[] = 'no-responsive-animation';
		}
	}
	if ( $title_background_style == 'iconbackground' ) {
		$line_height = ( intval( esc_attr( $title_fontsize ) * 3 ) ) . 'vmax';
		$font_size   = ( intval( esc_attr( $title_fontsize ) * 3 ) ) . 'vw';
	} elseif ( $title_background_style == 'textbackground' ) {
		$line_height = ( esc_attr( $bg_title_font_size ) ) . 'vmax';
		$font_size   = ( esc_attr( $bg_title_font_size ) ) . 'vw';
	} elseif ( $title_background_style == 'shapebackground' ) {
		$line_height = ( esc_attr( $title_fontsize ) ) . 'vmax';
		$width       = ( esc_attr( $title_fontsize ) ) . 'vw';
	}

	$google_fonts_inline_style = '';

	if ( $font_type != 'default' && function_exists( 'kite_get_fonts_data' ) ) {
		$google_fonts_data         = kite_get_fonts_data( $google_fonts );
		$google_fonts_inline_style = kite_google_fonts_styles( $google_fonts_data );
		kite_enqueue_google_fonts( $google_fonts_data );
	}

	ob_start();
	$allowed_html = kite_allowed_tags();
	?>
	<?php
	$fontstyle       = 'calc(' . esc_attr( $title_fontsize ) . 'vw + ' . esc_attr( $title_fontsize - 18 ) . ' * ((100vw - 979px) / 960))!important';
	$kiteInlineStyle = '';
	if ( strlen( esc_attr( $shape_border_color ) ) && $style == 'triangle' ) {
		$kiteInlineStyle .= "#$id.custom-title .shape-container .shape-line:after{border-color:$shape_border_color;}";
		$kiteInlineStyle .= "#$id.custom-title .shape-container .shape-line:before{border-color:$shape_border_color;}";
	}
	$kiteInlineStyle .= '@media (max-width:979px) {';
	$kiteInlineStyle .= "#$id.custom-title .title{font-size:$fontstyle;}";
	if ( $title_background_style == 'shapebackground' ) {
		$kiteInlineStyle .= "#$id.custom-title .shape-container{width:$fontstyle;height:$fontstyle;}";
	}
	$kiteInlineStyle .= '}';
	wp_add_inline_style( 'kite-inline-style', $kiteInlineStyle );
	?>
		
	<div id="<?php echo esc_attr( $id ); ?>" class="custom-title <?php echo implode( ' ', $class ); ?>" 
						<?php
						if ( strlen( esc_attr( $title_animation ) ) ) {
							?>
		 data-delay="<?php echo esc_attr( $title_animation_delay ); ?>" data-animation="<?php echo esc_attr( $title_animation ); ?>" <?php } ?> style="line-height:<?php echo esc_attr( $line_height ); ?>">    
		<?php if ( strlen( $title ) ) { ?>


		<div class="title" style="
			<?php
			if ( strlen( $title_color ) ) {
				?>
			color: <?php echo esc_attr( $title_color ); ?>; <?php }  echo esc_attr( $google_fonts_inline_style ); ?>
							  <?php
								if ( ! empty( $title_fontsize ) ) {
									echo 'font-size:' . $title_fontsize . 'vw';}
								?>
	">
			<span>
				<?php echo wp_kses( $title, $allowed_html ); ?>
			</span>


			<?php if ( $title_background_style == 'shapebackground' ) { ?>  


				<div class="shape-container <?php echo esc_attr( $style ); ?> " style="height:<?php echo esc_attr( $width ); ?>; width:<?php echo esc_attr( $width ); ?>">

					<?php
					if ( $style == 'line' ) {
						?>
							<div class="back-line" 
							<?php
							if ( strlen( $title_color ) ) {
								?>
								 style="background-color: <?php echo esc_attr( $title_color ); ?>;" <?php } ?>></div>
							<div class="hover-line" 
							<?php
							if ( strlen( $hoverline_color ) ) {
								?>
								 style="background-color: <?php echo esc_attr( $hoverline_color ); ?>;" <?php } ?>></div>
						<?php
					} elseif ( $style == 'triangle' ) {
						?>
							<div class="shape-line" 
							<?php
							if ( strlen( $shape_border_color ) ) {
								?>
								 style="border-color: <?php echo esc_attr( $shape_border_color ); ?>;" <?php } ?>></div>
							<div class="shape-fill" 
							<?php
							if ( strlen( $shape_fill_color ) ) {
								?>
								 style="border-bottom-color: <?php echo esc_attr( $shape_fill_color ); ?>;" <?php } ?>></div>

						<?php
					} else {
						?>
							<div class="shape-line" style="
							<?php
							if ( strlen( $shape_fill_color ) && $style != 'triangle' ) {
								?>
								 background-color: <?php echo esc_attr( $shape_fill_color ); ?>; <?php } ?> <?php
									if ( strlen( $shape_border_color ) ) {
										?>
	 border-color: <?php echo esc_attr( $shape_border_color ); ?>; <?php } ?>"></div>
						<?php
					}
					?>

				</div>

			<?php } ?>

		</div>

			<?php 
			if ( $title_background_style == 'textbackground' ) { 
				$style  = strlen( $bg_title_color ) ? 'color:' . $bg_title_color.';' : '';
				$style .= $google_fonts_inline_style . ';' ;
				$style .= 'font-size:' . $font_size . ';';
			?>

			<span class="textbackground"  style="<?php echo esc_attr( $style );?>"> <?php echo esc_html( $bg_title ); ?> </span>

			<?php } elseif ( $title_background_style == 'iconbackground' ) { ?>

			<span class="iconbackground" style="font-size:<?php echo esc_attr( $font_size ); ?>">
				<span class="glyph icon-<?php echo esc_attr( $icon ); ?>" <?php if ( strlen( $bg_icon_color ) ) { ?> style="color: <?php echo esc_attr( $bg_icon_color ); ?>;" <?php } ?>></span>
			</span>
			 
			<?php } ?> 

		<?php } ?>
	</div>

	<?php
	return ob_get_clean();
}

/*-----------------------------------------------------------------------------------*/
/*  Image-Box
/*-----------------------------------------------------------------------------------*/

function kite_sc_imagebox( $atts ) {
	extract(
		shortcode_atts(
			array(
				'image_url'                   => '',
				'image_size'                  => 'full',
				'image_size_width'            => '',
				'image_size_height'           => '',
				'image_size_crop'             => '',
				'image_hover'                 => 'enable',
				'image_hover_shadow'          => 'disable',
				'image_hover_color_preset'    => 'c0392b',
				'image_hover_color_custom'    => '',
				'image_animation'             => 'none',
				'image_animation_delay'       => '0',
				'responsive_animation'        => 'disable',
				'title'                       => '',
				'image_title_size'            => '16',
				'font_type'                   => 'default',
				'google_fonts'                => '',
				'title_color'                 => '',
				'subtitle'                    => '',
				'subtitle_fontsize'           => '16',
				'subtitle_color'              => '',
				'image_text_color'            => '',
				'image_text_align'            => 'left',
				'image_text_background_color' => '',
				'image_text_border'           => 'disable',
				'imagebox_content_border'     => 'enable',
				'image_text_border_color'     => '',
				'vccontent'                   => '',
				'content_fontsize'            => '16',
				'url'                         => '',
				'target'                      => '_self',
				'title_custom_font_size'      => '',
				'title_custom_line_height'    => '',
				'subtitle_custom_font_size'   => '',
				'subtitle_custom_line_height' => '',
				'content_custom_font_size'    => '',
				'content_custom_line_height'  => '',
			),
			$atts
		)
	);

	if ( is_numeric( $image_url ) ) {
		$image_url = wp_get_attachment_image_src( $image_url, $image_size );
	}

	if ( ! function_exists( 'aq_resize' ) && $image_size == 'custom' ) {
		$image_size = 'full';
	}

	if ( $image_size == 'custom' && $image_size_width != '' && $image_size_height != '' ) {
		if ( $image_size_crop == 'yes' ) {
				$image_size_crop = true;
		} else {
			$image_size_crop = false;
		}

			$image_link = aq_resize( $image_url[0], $image_size_width, $image_size_height, $image_size_crop, false, true );
		if ( $image_link ) {
			$image_url = $image_link;
		}
	} else {
		$image_size = esc_attr( $image_size );
	}

	$hasTitle    = '' != $title;
	$hasUrl      = '' != $url;
	$hasSubTitle = '' != $subtitle;
	$hasStyle    = '' != $title_color || '' != $subtitle_color || '' != $image_text_color || '' != $image_text_background_color || '' != $image_text_border_color || 'c0392b' != $image_hover_color_preset || 'custom' == $image_title_size || 'custom' == $subtitle_fontsize || 'custom' == $content_fontsize;

	$hasTSContent   = '' != $title || '' != $subtitle || '' != $vccontent;
	$hasVCContent   = '' != $vccontent;
	$contentFSClass = 'fontsize' . $content_fontsize;

	$id    = kite_sc_id( 'imagebox' );
	$class = array();

	$title_font_size    = 'fontsize' . $image_title_size;
	$subtitle_font_size = 'fontsize' . $subtitle_fontsize;

	switch ( $image_text_align ) {
		case 'right':
			$class[] = 'imageboxright';
			break;
		case 'center':
			$class[] = 'imageboxcenter';
			break;
		case 'left':
		default:
			$class[] = 'imageboxleft';
	}

	if ( $image_animation != 'none' ) {

		$class[] = 'shortcodeanimation';

		if ( $responsive_animation != '' ) {
			$class[] = 'no-responsive-animation';
		}
	}

	if ( $image_hover == 'enable' ) {
		$class[] = 'imgboxhover';
	}

	if ( $image_hover_shadow == 'enable' ) {
		$class[] = 'image_hover_shadow';
	}

	if ( $imagebox_content_border == 'disable' ) {

		 $class[] = 'disablecontentborder';

	}

	$google_fonts_inline_style = '';
	if ( $font_type != 'default' && function_exists( 'kite_get_fonts_data' ) ) {
		$google_fonts_data         = kite_get_fonts_data( $google_fonts );
		$google_fonts_inline_style = kite_google_fonts_styles( $google_fonts_data );
		kite_enqueue_google_fonts( $google_fonts_data );
	}

	ob_start();
	$allowed_html = kite_allowed_tags();
	$color        = '';

	$kiteInlineStyle = '';
	if ( $hasStyle ) {
		if ( $image_hover == 'enable' ) {

			if ( esc_attr( $image_hover_color_preset ) == 'custom' ) {
				$color = $image_hover_color_custom;
			} else {
				$color = '#' . $image_hover_color_preset;
			}
		}
		if ( $image_title_size == 'custom' && ! empty( $title_custom_font_size ) ) {
			$titleSelector    = "#$id.imagebox .content .title";
			$kiteInlineStyle .= kite_responsive_font_size( $titleSelector, $title_custom_font_size, $title_custom_line_height );

		}

		if ( $subtitle_fontsize == 'custom' && ! empty( $subtitle_custom_font_size ) ) {
			$subtitleSelector = "#$id.imagebox .content .subtitle";
			$kiteInlineStyle .= kite_responsive_font_size( $subtitleSelector, $subtitle_custom_font_size, $subtitle_custom_line_height );

		}

		if ( $content_fontsize == 'custom' && ! empty( $content_custom_font_size ) ) {
			$contentSelector  = "#$id.imagebox .content .text";
			$kiteInlineStyle .= kite_responsive_font_size( $contentSelector, $content_custom_font_size, $content_custom_line_height );

		}
	}//if($hasStyle)
	wp_add_inline_style( 'kite-inline-style', $kiteInlineStyle );
	?>

	<?php if ( $hasUrl ) { ?>
		
		 <a id="<?php echo esc_attr( $id ); ?>" class="imagebox 
						   <?php
							if ( $hasTSContent ) {
								?>
				 textbox textLeftBorder <?php } ?> <?php
					if ( strlen( esc_attr( $subtitle ) ) == 0 ) {
						?>
	  nosubtitle  <?php } ?> <?php echo implode( ' ', $class ); ?>"  
						  <?php
							if ( strlen( esc_attr( $image_animation ) ) ) {
								?>
	 data-delay="<?php echo esc_attr( $image_animation_delay ); ?>" data-animation="<?php echo esc_attr( $image_animation ); ?>" <?php } ?>  href="<?php echo esc_url( $url ); ?>" 
							<?php
							if ( $target != '' ) {
								?>
	target="<?php echo esc_attr( $target ); ?>"<?php } ?>>

	<?php } else { ?>          
		
		 <div id="<?php echo esc_attr( $id ); ?>" class="imagebox 
							 <?php
								if ( $hasTSContent ) {
									?>
				 textbox textLeftBorder <?php } ?> <?php
					if ( strlen( esc_attr( $subtitle ) ) == 0 ) {
						?>
	  nosubtitle  <?php } ?> <?php echo implode( ' ', $class ); ?>"  
						  <?php
							if ( strlen( esc_attr( $image_animation ) ) ) {
								?>
	 data-delay="<?php echo esc_attr( $image_animation_delay ); ?>" data-animation="<?php echo esc_attr( $image_animation ); ?>" <?php } ?> >
	
	<?php } ?>  
	
	<?php
	if ( isset( $image_url[0] ) && strlen( esc_url( $image_url[0] ) ) ) {
		?>
		<div class="image">

			<?php if ( $image_hover == 'enable' ) { ?> 
				<!-- imagebox Hover  -->
				<div class="imagebox-hover"  style="background-color:<?php echo esc_attr( $color ); ?>;"></div>
			<?php } ?>

			<img src="<?php echo esc_url( $image_url[0] ); ?>" 
								 <?php
									if ( esc_attr( $title ) ) {
										?>
				 alt="<?php echo esc_attr( $title ); ?>" 
										<?php
									} else {
										?>
							 alt="
										<?php
										if ( get_the_title( attachment_url_to_postid( $image_url[0] ) ) ) {
											echo get_the_title( attachment_url_to_postid( $image_url[0] ) );}
										?>
						" <?php } ?>>
		</div>
	<?php } ?>
  
		 <?php if ( $hasTSContent ) { ?>
			<div class="content" style="
				<?php
				if ( strlen( esc_attr( $image_text_border_color ) ) ) {
					?>
				border:solid 1px <?php echo esc_attr( $image_text_border_color ); ?>; 
					<?php
				} if ( strlen( esc_attr( $image_text_background_color ) ) ) {
					?>
				 background-color: <?php echo esc_attr( $image_text_background_color ); ?>;<?php } ?> ">
				<?php if ( $hasTitle ) { ?>

					<div class="clearfix">
						<div class="title clearfix <?php echo esc_attr( $title_font_size ); ?>"  style="
															  <?php
																if ( strlen( esc_attr( $title_color ) ) ) {
																	?>
							color:<?php echo esc_attr( $title_color ); ?>; <?php } echo esc_attr( $google_fonts_inline_style ); ?>">

							<?php echo wp_kses( $title, $allowed_html ); ?>

							<?php if ( $hasSubTitle ) { ?>
								<!-- subtitle -->
								<span class="subtitle <?php echo esc_attr( $subtitle_font_size ); ?>" style="
																 <?php
																	if ( strlen( esc_attr( $subtitle_color ) ) ) {
																		?>
									color: <?php echo esc_attr( $subtitle_color ); ?>; <?php } echo esc_attr( $google_fonts_inline_style ); ?> "><?php echo esc_html( $subtitle ); ?></span>
							<?php } ?>

						</div>
					</div>

				<?php } ?>
				<?php if ( $hasVCContent ) { ?>
				
				<div class="<?php echo esc_attr( $contentFSClass ); ?> text" style="
									   <?php
										if ( strlen( esc_attr( $image_text_color ) ) ) {
											?>
					color: <?php echo esc_attr( $image_text_color ); ?>; <?php } echo esc_attr( $google_fonts_inline_style ); ?>"><?php echo wp_kses( $vccontent, $allowed_html ); ?></div>
					
				<?php } ?>
			</div>
		<?php } ?>
	
	<?php if ( $hasUrl ) { ?>
		
		 </a>
	   
	<?php } else { ?>          
		
		</div>

	<?php } ?>  
	

	<?php
	return ob_get_clean();
}

/*-----------------------------------------------------------------------------------*/
/*  Animated Text
/*-----------------------------------------------------------------------------------*/

function kite_sc_animated_text( $atts ) {
	extract(
		shortcode_atts(
			array(
				'image_url'              => '',
				'title'                  => '',
				'title_front_color'      => '#ffffff',
				'title_back_color'       => '#272727',
				'animatedtext_font_size' => '30',
				'animatedtext_style'     => 'with_image',
				'font_type'              => 'default',
				'google_fonts'           => '',
				'animatedtext_speed'     => '8',
			),
			$atts
		)
	);
	$image_url = wp_get_attachment_url( $image_url );
	$id        = kite_sc_id( 'animatedtext' );

	// let us show the animation even if there is no image
	if ( $image_url ) {
		$text_height = 'auto';
		$imageOutput = '<img src="' . esc_url( $image_url ) . '" alt="' . esc_attr( $title ) . '">';// echo image tag if this is of type with image
	} else {
		$text_height = ( intval( esc_attr( $animatedtext_font_size ) * 1.5 ) ) . 'vw';
		$imageOutput = '';
	}
	$animation_duration = strlen( $title ) * intval( esc_attr( $animatedtext_speed ) );// Duration of cycling

	$google_fonts_inline_style = '';
	if ( $font_type != 'default' && function_exists( 'kite_get_fonts_data' ) ) {
		$google_fonts_data         = kite_get_fonts_data( $google_fonts );
		$google_fonts_inline_style = kite_google_fonts_styles( $google_fonts_data );
		kite_enqueue_google_fonts( $google_fonts_data );
	}
	$kite_inline_style  = "#$id .firsttitle {color:$title_front_color;}";
	$kite_inline_style .= "#$id .secondtitle {color:$title_back_color;}";
	wp_add_inline_style( 'kite-inline-style', $kite_inline_style );
	ob_start();
	?>
	<div class="animatedtext_content" style="height:<?php echo esc_attr( $text_height ); ?>;">
	<div id="<?php echo esc_attr( $id ); ?>" class="animatedtext">
	   <div class="image">
		   <?php
			// sanitization performed in above lines!
			echo '' . $imageOutput;
			?>
	   </div>
	   <span class="slideshowcontent" style="font-size:<?php echo esc_attr( $animatedtext_font_size ) . 'vw'; ?>;">
		   <span class="firsttitle" style="animation-duration:<?php echo esc_attr( $animation_duration ) . 's'; ?>; <?php echo esc_attr( $google_fonts_inline_style ); ?>">
			   <span class="immediate"><?php echo esc_html( $title ); ?><?php echo esc_html( $title ); ?><?php echo esc_html( $title ); ?><?php echo esc_html( $title ); ?></span> 
			   <span class="immediate"><?php echo esc_html( $title ); ?><?php echo esc_html( $title ); ?><?php echo esc_html( $title ); ?><?php echo esc_html( $title ); ?></span> 
		   </span> 
	   </span>
	</div>
	<span class="secondtitle" style="animation-duration:<?php echo esc_attr( $animation_duration ) . 's'; ?>; font-size:<?php echo esc_attr( $animatedtext_font_size ) . 'vw'; ?>; <?php echo esc_attr( $google_fonts_inline_style ); ?>">
		 <span class="immediate"><?php echo esc_html( $title ); ?><?php echo esc_html( $title ); ?><?php echo esc_html( $title ); ?><?php echo esc_html( $title ); ?></span> 
		 <span class="immediate"><?php echo esc_html( $title ); ?><?php echo esc_html( $title ); ?><?php echo esc_html( $title ); ?><?php echo esc_html( $title ); ?></span> 
	</span>
	</div>
	<?php
	return ob_get_clean();
}

/*-----------------------------------------------------------------------------------*/
/*  Banner
/*-----------------------------------------------------------------------------------*/

function kite_sc_banner( $atts ) {
	extract(
		shortcode_atts(
			array(

				'image_url'                   => '',
				'heading'                     => '',
				'heading_size'                => '16',
				'heading_color'               => '',
				'heading_font_type'           => 'default',
				'heading_google_fonts'        => '',
				'title'                       => '',
				'title_size'                  => '16',
				'title_color'                 => '',
				'subtitle'                    => '',
				'subtitle_size'               => '16',
				'font_type'                   => 'default',
				'sub_font_type'               => 'default',
				'google_fonts'                => '',
				'sub_google_fonts'            => '',
				'subtitle_color'              => '',
				'alignment'                   => 'top_left',
				'image_size'                  => 'full',
				'size'                        => 'default',
				'image_size_width'            => '',
				'image_size_height'           => '',
				'image_size_crop'             => '',
				'hover'                       => 'enable',
				'hover_color_preset'          => 'd02d48',
				'hover_color'                 => '',
				'hover_zoom'                  => 'disable',
				'url'                         => '',
				'new_tab'                     => false,
				'url_title'                   => '',
				'link_color'                  => '',
				'link_bg_color'               => '',
				'button_style'                => 'link',
				'show_button'                 => '',
				'animation'                   => 'none',
				'responsive_animation'        => 'disable',
				'delay'                       => '0',
				'badge'                       => 'disable',
				'badge_content'               => '',
				'badge_bg_color'              => '',
				'badge_content_color'         => '',
				'badge_position'              => 'top left',
				'heading_custom_font_size'    => '',
				'heading_custom_line_height'  => '',
				'title_custom_font_size'      => '',
				'title_custom_line_height'    => '',
				'subtitle_custom_font_size'   => '',
				'subtitle_custom_line_height' => '',
				'content_margin_top'          => '',
				'content_margin_bottom'       => '',
				'content_margin_left'         => '',
				'content_margin_right'        => '',
				'res_content_margin_top'      => '',
				'res_content_margin_bottom'   => '',
				'res_content_margin_left'     => '',
				'res_content_margin_right'    => '',
				'link_size'                   => '16',
				'link_font_type'              => 'default',
				'link_google_fonts'           => '',
				'link_custom_font_size'       => '',
				'link_custom_line_height'     => '',

			),
			$atts
		)
	);

	if ( is_numeric( $image_url ) ) {
		$image_url = wp_get_attachment_image_src( $image_url, $image_size );
	}

	if ( ! function_exists( 'aq_resize' ) && $image_size == 'custom' ) {
		$image_size = 'full';
	}

	if ( $image_size == 'custom' && $image_size_width != '' && $image_size_height != '' ) {
		if ( $image_size_crop == 'yes' ) {
				$image_size_crop = true;
		} else {
			$image_size_crop = false;
		}

			$image_link = aq_resize( $image_url[0], $image_size_width, $image_size_height, $image_size_crop, false, true );
		if ( $image_link ) {
			$image_url = $image_link;
		}
	} else {
		$image_size = esc_attr( $image_size );
	}

	$id    = kite_sc_id( 'banner' );
	$class = array();

	$class[] = 'fontsize' . $title_size;

	if ( $animation != 'none' ) {

		$class[] = 'shortcodeanimation';

		if ( $responsive_animation != '' ) {
			$class[] = 'no-responsive-animation';
		}
	}
	if ( ! $image_url ) {
			$class[] = 'no-image';
	}
	$class[] = $alignment;

	$google_fonts_inline_style         = '';
	$sub_google_fonts_inline_style     = '';
	$heading_google_fonts_inline_style = '';
	$link_google_fonts_inline_style    = '';

	if ( $font_type != 'default' && function_exists( 'kite_get_fonts_data' ) ) {
		$google_fonts_data         = kite_get_fonts_data( $google_fonts );
		$google_fonts_inline_style = kite_google_fonts_styles( $google_fonts_data );
		kite_enqueue_google_fonts( $google_fonts_data );
	}
	if ( $sub_font_type != 'default' && function_exists( 'kite_get_fonts_data' ) ) {
		$sub_google_fonts_data         = kite_get_fonts_data( $sub_google_fonts );
		$sub_google_fonts_inline_style = kite_google_fonts_styles( $sub_google_fonts_data );
		kite_enqueue_google_fonts( $sub_google_fonts_data );
	}
	if ( $heading_font_type != 'default' && function_exists( 'kite_get_fonts_data' ) ) {
		$heading_google_fonts_data         = kite_get_fonts_data( $heading_google_fonts );
		$heading_google_fonts_inline_style = kite_google_fonts_styles( $heading_google_fonts_data );
		kite_enqueue_google_fonts( $heading_google_fonts_data );
	}
	if ( $link_font_type != 'default' && function_exists( 'kite_get_fonts_data' ) ) {
		$link_google_fonts_data         = kite_get_fonts_data( $link_google_fonts );
		$link_google_fonts_inline_style = kite_google_fonts_styles( $link_google_fonts_data );
		kite_enqueue_google_fonts( $link_google_fonts_data );
	}
	if ( function_exists( 'vc_build_link' ) && $url && empty( $url_title ) ) {
		$link = vc_build_link( $url );
		if ( ! empty( esc_attr( $link['title'] ) ) && ! empty( $link['url'] ) ) {
			$class[] = 'has_button';
			if ( $show_button == 'enable' ) {
				$class[] = 'show_button';
			}
		}
	} else {
		$link['title'] = $url_title;
		$link['url']   = $url;
		if ( ! empty( esc_attr( $link['title'] ) ) && ! empty( $link['url'] ) ) {
			$class[] = 'has_button';
			if ( $show_button == 'enable' ) {
				$class[] = 'show_button';
			}
		}
	}

	if ( $heading_size != 'custom' ) {
		$headingFontSize = 'fontsize' . $heading_size;
	} else {
		$headingFontSize = '';
	}

	if ( $title_size != 'custom' ) {
		$titleFontSize = 'fontsize' . $title_size;
	} else {
		$titleFontSize = '';
	}

	if ( $subtitle_size != 'custom' ) {
		$subtitleFontSize = 'fontsize' . $subtitle_size;
	} else {
		$subtitleFontSize = '';
	}

	if ( $link_size != 'custom' && $button_style != 'fill' ) {
		$linkFontSize = 'fontsize' . $link_size;
	} else {
		$linkFontSize = '';
	}
	$bsize = array();
	switch ( $size ) {
		case 'small':
			$bsize[] = 'button-small';
			break;
		case 'standard':
			$bsize[] = 'button-medium';
			break;
		case 'default':
			$bsize[] = 'button-default';
			break;
		case 'large':
			$bsize[] = 'button-large';
			break;
	}
	$buttonclass = '';
	if ( $button_style == 'fill' ) {
		$buttonclass = 'kt_button style2 text ' . implode( ' ', $bsize ) . ' ';
	}

	$hasStyle = '' != $title_color || '' != $subtitle_color || 'enable' == $hover || in_array( 'has_button', $class ) || $title_size == 'custom' || $heading_size == 'custom' || $link_size == 'custom' || 'custom' == $subtitle_size;
	ob_start();
	$allowed_html    = kite_allowed_tags();
	$kiteInlineStyle = '';
	if ( $hasStyle ) {
		if ( strlen( esc_attr( $link_color ) ) ) {
			$kiteInlineStyle .= "#$id.banner a span{color:$link_color;}";
		}
		$color = '';
		if ( ( $hover == 'enable' ) && ( ! empty( $hover_color ) ) ) {
			/*
			 if($hover_color_preset == 'custom')
			{
				$color = $hover_color;
			}
			else
			{ */
				$color = $hover_color;
			// }

			$kiteInlineStyle .= "#$id:hover .hover{background-color:$color;} ";
		}
		if ( in_array( 'has_button', $class ) ) {
			$acc              = kite_opt( 'style-accent-color' );
			$kiteInlineStyle .= '#' . $id . ".banner a.link:hover span{color: $acc !important;}";

			$kiteInlineStyle .= '#' . $id . ".banner a.link:hover span.txt:after {border-bottom-color : $acc;}";
			if ( ! empty( $link_color ) ) {
				$kiteInlineStyle .= '#' . $id . ".banner a.link span:after {border-bottom-color: $link_color;}";
			}
			$kiteInlineStyle .= '#' . $id . '.banner a.fill {';

			if ( ! empty( $link_bg_color ) ) {
				$kiteInlineStyle .= "background-color: $link_bg_color;border-color: $link_bg_color;";
			}
			$kiteInlineStyle .= '}';
			$kiteInlineStyle .= '#' . $id . ".banner a.fill:hover {background-color: $acc;border-color:$acc;}";

		}
		?>
		<?php
		// heading custom font sizes
		$headingSelector  = "#$id.banner .content .heading";
		$kiteInlineStyle .= kite_responsive_font_size( $headingSelector, $heading_custom_font_size, $heading_custom_line_height );

		// title custom font sizes
		$titleSelector    = "#$id.banner .content .title";
		$kiteInlineStyle .= kite_responsive_font_size( $titleSelector, $title_custom_font_size, $title_custom_line_height );

		// subtitle custom font sizes
		$subtitleSelector = "#$id.banner .content .subtitle";
		$kiteInlineStyle .= kite_responsive_font_size( $subtitleSelector, $subtitle_custom_font_size, $subtitle_custom_line_height );

		$linkSelector     = "#$id.banner a";
		$kiteInlineStyle .= kite_responsive_font_size( $linkSelector, $link_custom_font_size, $link_custom_line_height );

		$kiteInlineStyle     .= '@media (min-width:1025px) {';
			$kiteInlineStyle .= '#' . $id . '.banner .content{';
		if ( $content_margin_top != '' ) {
			$kiteInlineStyle .= "margin-top: $content_margin_top" . 'px;';
		}
		if ( $content_margin_bottom != '' ) {
			$kiteInlineStyle .= "margin-bottom: $content_margin_bottom" . 'px;';
		}
		if ( $content_margin_left != '' ) {
			$kiteInlineStyle .= "margin-left: $content_margin_left" . 'px;';
		}
		if ( $content_margin_right != '' ) {
			$kiteInlineStyle .= "margin-right: $content_margin_right" . 'px;';
		}
			$kiteInlineStyle .= '}';
		$kiteInlineStyle     .= '}';
		$kiteInlineStyle     .= '@media (max-width:1024px) {';
			$kiteInlineStyle .= '#' . $id . '.banner .content{';
		if ( $res_content_margin_top != '' ) {
			$kiteInlineStyle .= "margin-top: $res_content_margin_top" . 'px;';
		}
		if ( $res_content_margin_bottom != '' ) {
			$kiteInlineStyle .= "margin-bottom: $res_content_margin_bottom" . 'px;';
		}
		if ( $res_content_margin_left != '' ) {
			$kiteInlineStyle .= "margin-left: $res_content_margin_left" . 'px;';
		}
		if ( $res_content_margin_right != '' ) {
			$kiteInlineStyle .= "margin-right: $res_content_margin_right" . 'px;';
		}
			$kiteInlineStyle .= '}';
		$kiteInlineStyle     .= '}';

	}//End of if
	wp_add_inline_style( 'kite-inline-style', $kiteInlineStyle );

	?>
			 
	<div id="<?php echo esc_attr( $id ); ?>" class="banner  <?php echo implode( ' ', $class ); ?> <?php
	if ( $hover_zoom != 'disable' ) {
		echo 'zoom';}
	?>
	"  
	<?php
	if ( wp_is_mobile() ) {
		?>
		  style="background-image:url('<?php echo esc_url( $image_url[0] ); ?> ');" <?php } ?> <?php
			if ( strlen( esc_attr( $animation ) ) ) {
				?>
		 data-delay="<?php echo esc_attr( $delay ); ?>" data-animation="<?php echo esc_attr( $animation ); ?>" <?php } ?>>
		<?php if ( isset( $image_url[0] ) && strlen( esc_url( $image_url[0] ) ) ) { ?>
			<div class="image">

				<?php if ( $hover == 'enable' ) { ?> 
					<!-- imagebox Hover  -->
					<div class="hover"></div>
				<?php } ?>
		<img src="<?php echo esc_url( $image_url[0] ); ?>" 
							 <?php
								if ( esc_attr( $title ) ) {
									?>
			 alt="<?php echo esc_attr( $title ); ?>" 
									<?php
								} else {
									?>
						 alt="
									<?php
									if ( get_the_title( attachment_url_to_postid( $image_url[0] ) ) ) {
										echo get_the_title( attachment_url_to_postid( $image_url[0] ) );}
									?>
						" <?php } ?>>
			</div>
			<?php
		}
		?>
		<div class="content-container">
			<?php if ( $badge == 'enable' && ! empty( $badge_content ) ) { ?>
				<div class="badge <?php echo esc_attr( $badge_position ); ?>" style="
											 <?php
												if ( ! empty( $badge_bg_color ) ) {
													echo 'background-color:' . esc_attr( $badge_bg_color ) . ';';}
												?>
				<?php
				if ( ! empty( $badge_content_color ) ) {
					echo 'color:' . esc_attr( $badge_content_color ) . ';';}
				?>
"><span><?php echo '' . $badge_content; ?></span></div>
			<?php } ?>
			<div class="content">
						<?php if ( $heading != '' ) { ?>
						<span class="heading clearfix <?php echo esc_attr( $headingFontSize ); ?>" style="
																 <?php
																	echo esc_attr( $heading_google_fonts_inline_style ); if ( strlen( esc_attr( $heading_color ) ) ) {
																		?>
							  color: <?php echo esc_attr( $heading_color ); ?>; <?php } ?>">
							<?php echo wp_kses( $heading, $allowed_html ); ?>
						</span>
						<?php } ?>
						<?php if ( $title != '' ) { ?>
						<span class="title clearfix <?php echo esc_attr( $titleFontSize ); ?>" style="
															   <?php
																echo esc_attr( $google_fonts_inline_style ); if ( strlen( esc_attr( $title_color ) ) ) {
																	?>
							  color: <?php echo esc_attr( $title_color ); ?>; <?php } ?>">
							<?php echo wp_kses( $title, $allowed_html ); ?>
						</span>
						<?php } ?>
						<?php if ( $subtitle != '' ) { ?>
							<span class="subtitle <?php echo esc_attr( $subtitleFontSize ); ?>" style="
															 <?php
																echo esc_attr( $sub_google_fonts_inline_style ); if ( strlen( esc_attr( $subtitle_color ) ) ) {
																	?>
								color: <?php echo esc_attr( $subtitle_color ); ?>; <?php } ?>">
							<?php
							echo wp_kses( $subtitle, $allowed_html );
							?>
							</span>
							<?php
						}

						?>

					<?php

					if ( $url && function_exists( 'vc_build_link' ) && empty( $url_title ) ) {

						$link = vc_build_link( $atts['url'] );
						if ( strlen( $link['url'] ) ) {
							?>

						<a class="
							<?php
							echo esc_attr( $buttonclass );
							echo esc_attr( $button_style );
							?>
							<?php echo esc_attr( $linkFontSize ); ?>" href="<?php echo esc_url( $link['url'] ); ?>" 
							<?php
							if ( $link['target'] != '' ) {
								?>
	target="<?php echo esc_attr( $link['target'] ); ?>"
								<?php
							} else {
								?>
							target="_self" <?php } ?> style ="
							<?php
							if ( strlen( esc_attr( $link_color ) ) ) {
								?>
		color: <?php echo esc_attr( $link_color ); ?>; 
								<?php
								if ( $button_style == 'link' ) {
									?>
	 border-color: <?php echo esc_attr( $link_color ); ?>;<?php } ?> <?php
							} if ( empty( esc_attr( $link['title'] ) ) ) {
									   echo 'display:none;';}
							?>
"><span class="txt" style="<?php echo esc_attr( $link_google_fonts_inline_style ); ?>"><?php echo esc_html( $link['title'] ); ?></span></a>

							<?php
						}
					} else {
						if ( $url ) {
							$link['url'] = $url;
							if ( $new_tab ) {
								$link['target'] = '_blank';
							} else {
								$link['target'] = '_self';
							}
							$link['title'] = $url_title;
							if ( strlen( $link['url'] ) ) {
								if ( empty( $url_title ) ) {
									$buttonclass  = '';
									$button_style = 'link';
								}

								?>
				
							<a class="
								<?php
								echo esc_attr( $buttonclass );
								echo esc_attr( $button_style );
								?>
								<?php echo esc_attr( $linkFontSize ); ?>" href="<?php echo esc_url( $link['url'] ); ?>" 
								<?php
								if ( $link['target'] != '' ) {
									?>
	target="<?php echo esc_attr( $link['target'] ); ?>"<?php } ?> style ="
								<?php
								if ( strlen( esc_attr( $link_color ) ) ) {
									?>
		color: <?php echo esc_attr( $link_color ); ?>; 
									<?php
									if ( $button_style == 'link' ) {
										?>
	 border-color: <?php echo esc_attr( $link_color ); ?>; 
										<?php
									}
								} if ( empty( esc_attr( $link['title'] ) ) ) {
									echo 'display:none;';}
								?>
	"><span class="txt" style="<?php echo esc_attr( $link_google_fonts_inline_style ); ?>"><?php echo esc_html( $link['title'] ); ?></span></a>

								<?php
							}
						}
					}
					?>
			</div>

		</div>
	</div> 
	

	<?php
	return ob_get_clean();
}
/*-----------------------------------------------------------------------------------*/
/*  Modern Banner
/*-----------------------------------------------------------------------------------*/

function kite_sc_modern_banner( $atts ) {
	extract(
		shortcode_atts(
			array(

				'image_url'                   => '',
				'second_image_url'            => '',
				'heading'                     => '',
				'heading_size'                => '16',
				'heading_color'               => '',
				'heading_font_type'           => 'default',
				'heading_google_fonts'        => '',
				'title'                       => '',
				'title_size'                  => '16',
				'title_color'                 => '',
				'subtitle'                    => '',
				'subtitle_size'               => '16',
				'font_type'                   => 'default',
				'sub_font_type'               => 'default',
				'google_fonts'                => '',
				'sub_google_fonts'            => '',
				'subtitle_color'              => '',
				'alignment'                   => 'top_left',
				'image_size'                  => 'full',
				'size'                        => 'default',
				'image_size_width'            => '',
				'image_size_height'           => '',
				'image_size_crop'             => '',
				'hover'                       => 'enable',
				'hover_color_preset'          => 'd02d48',
				'hover_color'                 => '',
				'hover_effect'                => '1',
				'url'                         => '',
				'new_tab'                     => false,
				'url_title'                   => '',
				'link_color'                  => '',
				'link_bg_color'               => '',
				'button_style'                => 'link',
				'show_button'                 => '',
				'animation'                   => 'none',
				'responsive_animation'        => 'disable',
				'delay'                       => '0',
				'badge'                       => 'disable',
				'badge_content'               => '',
				'badge_bg_color'              => '',
				'badge_content_color'         => '',
				'badge_position'              => 'top left',
				'heading_custom_font_size'    => '',
				'heading_custom_line_height'  => '',
				'title_custom_font_size'      => '',
				'title_custom_line_height'    => '',
				'subtitle_custom_font_size'   => '',
				'subtitle_custom_line_height' => '',
				'content_margin_top'          => '',
				'content_margin_bottom'       => '',
				'content_margin_left'         => '',
				'content_margin_right'        => '',
				'res_content_margin_top'      => '',
				'res_content_margin_bottom'   => '',
				'res_content_margin_left'     => '',
				'res_content_margin_right'    => '',
				'link_size'                   => '16',
				'link_font_type'              => 'default',
				'link_google_fonts'           => '',
				'link_custom_font_size'       => '',
				'link_custom_line_height'     => '',

			),
			$atts
		)
	);
	if ( is_numeric( $image_url ) ) {
		$image_url = wp_get_attachment_image_src( $image_url, $image_size );
	}
	if ( is_numeric( $second_image_url ) ) {
		$second_image_url = wp_get_attachment_image_src( $second_image_url, $image_size );
	}
	if ( $image_size == 'custom' && $image_size_width != '' && $image_size_height != '' ) {
		if ( $image_size_crop == 'yes' ) {
				$image_size_crop = true;
		} else {
			$image_size_crop = false;
		}

			$image_link        = aq_resize( $image_url[0], $image_size_width, $image_size_height, $image_size_crop, false, true );
			$second_image_link = aq_resize( $second_image_url[0], $image_size_width, $image_size_height, $image_size_crop, false, true );

		if ( $image_link ) {
			$image_url = $image_link;
		}
		if ( $second_image_link ) {
			$second_image_url = $second_image_link;
		}
	} else {
		$image_size = esc_attr( $image_size );
	}

	$id    = kite_sc_id( 'modernBanner' );
	$class = array();

	$class[] = 'fontsize' . $title_size;

	if ( $animation != 'none' ) {

		$class[] = 'shortcodeanimation';

		if ( $responsive_animation != '' ) {
			$class[] = 'no-responsive-animation';
		}
	}
	if ( ! $image_url ) {
			$class[] = 'no-image';
	}
	$class[] = $alignment;

	$google_fonts_inline_style         = '';
	$sub_google_fonts_inline_style     = '';
	$heading_google_fonts_inline_style = '';
	$link_google_fonts_inline_style    = '';

	if ( $font_type != 'default' && function_exists( 'kite_get_fonts_data' ) ) {
		$google_fonts_data         = kite_get_fonts_data( $google_fonts );
		$google_fonts_inline_style = kite_google_fonts_styles( $google_fonts_data );
		kite_enqueue_google_fonts( $google_fonts_data );
	}
	if ( $sub_font_type != 'default' && function_exists( 'kite_get_fonts_data' ) ) {
		$sub_google_fonts_data         = kite_get_fonts_data( $sub_google_fonts );
		$sub_google_fonts_inline_style = kite_google_fonts_styles( $sub_google_fonts_data );
		kite_enqueue_google_fonts( $sub_google_fonts_data );
	}
	if ( $heading_font_type != 'default' && function_exists( 'kite_get_fonts_data' ) ) {
		$heading_google_fonts_data         = kite_get_fonts_data( $heading_google_fonts );
		$heading_google_fonts_inline_style = kite_google_fonts_styles( $heading_google_fonts_data );
		kite_enqueue_google_fonts( $heading_google_fonts_data );
	}
	if ( $link_font_type != 'default' && function_exists( 'kite_get_fonts_data' ) ) {
		$link_google_fonts_data         = kite_get_fonts_data( $link_google_fonts );
		$link_google_fonts_inline_style = kite_google_fonts_styles( $link_google_fonts_data );
		kite_enqueue_google_fonts( $link_google_fonts_data );
	}
	if ( function_exists( 'vc_build_link' ) && $url && empty( $url_title ) ) {
		$link = vc_build_link( $url );
		if ( ! empty( esc_attr( $link['title'] ) ) && ! empty( $link['url'] ) ) {
			$class[] = 'has_button';
			if ( $show_button == 'enable' ) {
				$class[] = 'show_button';
			}
		}
	} else {
		$link['title'] = $url_title;
		$link['url']   = $url;
		if ( ! empty( esc_attr( $link['title'] ) ) && ! empty( $link['url'] ) ) {
			$class[] = 'has_button';
			if ( $show_button == 'enable' ) {
				$class[] = 'show_button';
			}
		}
	}

	if ( $heading_size != 'custom' ) {
		$headingFontSize = 'fontsize' . $heading_size;
	} else {
		$headingFontSize = '';
	}

	if ( $title_size != 'custom' ) {
		$titleFontSize = 'fontsize' . $title_size;
	} else {
		$titleFontSize = '';
	}

	if ( $subtitle_size != 'custom' ) {
		$subtitleFontSize = 'fontsize' . $subtitle_size;
	} else {
		$subtitleFontSize = '';
	}

	if ( $link_size != 'custom' && $button_style != 'fill' ) {
		$linkFontSize = 'fontsize' . $link_size;
	} else {
		$linkFontSize = '';
	}
	$bsize = array();
	switch ( $size ) {
		case 'small':
			$bsize[] = 'button-small';
			break;
		case 'standard':
			$bsize[] = 'button-medium';
			break;
		case 'default':
			$bsize[] = 'button-default';
			break;
		case 'large':
			$bsize[] = 'button-large';
			break;
	}
	$buttonclass = '';
	if ( $button_style == 'fill' ) {
		$buttonclass = 'kt_button style2 text ' . implode( ' ', $bsize ) . ' ';
	}

	$hasStyle = '' != $title_color || '' != $subtitle_color || 'enable' == $hover || in_array( 'has_button', $class ) || $title_size == 'custom' || $heading_size == 'custom' || $link_size == 'custom' || 'custom' == $subtitle_size;
	ob_start();
	$allowed_html    = kite_allowed_tags();
	$kiteInlineStyle = '';
	if ( $hasStyle ) {
		if ( strlen( esc_attr( $link_color ) ) ) {
			$kiteInlineStyle .= "#$id.banner a span{color:$link_color;}";
		}
		$color = '';
		if ( ( $hover == 'enable' ) && ( ! empty( $hover_color ) ) ) {
			/*
			 if($hover_color_preset == 'custom')
			{
				$color = $hover_color;
			}
			else
			{ */
				$color = $hover_color;
			// }

			$kiteInlineStyle .= "#$id:hover .hover{background-color:$color;} ";
		}
		if ( in_array( 'has_button', $class ) ) {
			$acc              = kite_opt( 'style-accent-color' );
			$kiteInlineStyle .= '#' . $id . '.banner a.link span:hover,#' . $id . ".banner a.link span:hover span {color: $acc !important;}";

			$kiteInlineStyle .= '#' . $id . ".banner a.link span:hover:after {border-bottom-color : $acc;}";
			if ( ! empty( $link_color ) ) {
				$kiteInlineStyle .= '#' . $id . ".banner a.link span:after {border-bottom-color: $link_color;}";
			}
			$kiteInlineStyle .= '#' . $id . '.banner a.fill {';

			if ( ! empty( $link_bg_color ) ) {
				$kiteInlineStyle .= "background-color: $link_bg_color;border-color: $link_bg_color;";
			}
			$kiteInlineStyle  .= '}';
			 $kiteInlineStyle .= '#' . $id . '.banner a.fill:hover span.txt {color: #FFF;}';
			$kiteInlineStyle  .= '#' . $id . ".banner a.fill:hover {background-color: $acc;border-color:$acc;}";

		}
		?>
		<?php
		// heading custom font sizes
		$headingSelector  = "#$id.banner .content .heading";
		$kiteInlineStyle .= kite_responsive_font_size( $headingSelector, $heading_custom_font_size, $heading_custom_line_height );

		// title custom font sizes
		$titleSelector    = "#$id.banner .content .title";
		$kiteInlineStyle .= kite_responsive_font_size( $titleSelector, $title_custom_font_size, $title_custom_line_height );

		// subtitle custom font sizes
		$subtitleSelector = "#$id.banner .content .subtitle";
		$kiteInlineStyle .= kite_responsive_font_size( $subtitleSelector, $subtitle_custom_font_size, $subtitle_custom_line_height );

		// link custom font sizes
		$linkSelector     = "#$id.banner a";
		$kiteInlineStyle .= kite_responsive_font_size( $linkSelector, $link_custom_font_size, $link_custom_line_height );

		$kiteInlineStyle     .= '@media (min-width:1025px) {';
			$kiteInlineStyle .= '#' . $id . '.banner .content{';
		if ( $content_margin_top != '' ) {
			$kiteInlineStyle .= "margin-top: $content_margin_top" . 'px;';
		}
		if ( $content_margin_bottom != '' ) {
			$kiteInlineStyle .= "margin-bottom: $content_margin_bottom" . 'px;';
		}
		if ( $content_margin_left != '' ) {
			$kiteInlineStyle .= "margin-left: $content_margin_left" . 'px;';
		}
		if ( $content_margin_right != '' ) {
			$kiteInlineStyle .= "margin-right: $content_margin_right" . 'px;';
		}
			$kiteInlineStyle .= '}';
		$kiteInlineStyle     .= '}';
		$kiteInlineStyle     .= '@media (max-width:1024px) {';
			$kiteInlineStyle .= '#' . $id . '.banner .content{';
		if ( $res_content_margin_top != '' ) {
			$kiteInlineStyle .= "margin-top: $res_content_margin_top" . 'px;';
		}
		if ( $res_content_margin_bottom != '' ) {
			$kiteInlineStyle .= "margin-bottom: $res_content_margin_bottom" . 'px;';
		}
		if ( $res_content_margin_left != '' ) {
			$kiteInlineStyle .= "margin-left: $res_content_margin_left" . 'px;';
		}
		if ( $res_content_margin_right != '' ) {
			$kiteInlineStyle .= "margin-right: $res_content_margin_right" . 'px;';
		}
			$kiteInlineStyle .= '}';
		$kiteInlineStyle     .= '}';
	}//if($hasStyle)
	wp_add_inline_style( 'kite-inline-style', $kiteInlineStyle );
	?>
			 
	<div id="<?php echo esc_attr( $id ); ?>" class="banner modernbanner  <?php echo implode( ' ', $class ); ?> "  
						<?php
						if ( wp_is_mobile() ) {
							?>
		  style="background-image:url('<?php echo esc_url( $image_url[0] ); ?> ');" <?php } ?> <?php
			if ( strlen( esc_attr( $animation ) ) ) {
				?>
		 data-delay="<?php echo esc_attr( $delay ); ?>" data-animation="<?php echo esc_attr( $animation ); ?>" <?php } ?>>
		<?php if ( isset( $image_url[0] ) && strlen( esc_url( $image_url[0] ) ) ) { ?>
			<div class="image lazy-load-on-load" data-displacement="<?php echo KITEST_THEME_IMAGES_URI . '/distortion/' . $hover_effect . '.jpg'; ?>" data-intensity="-0.65" data-speedin="1.2" data-speedout="1.2">

				<?php if ( $hover == 'enable' ) { ?> 
					<!-- imagebox Hover  -->
					<div class="hover"></div>
				<?php } ?>
		<img src="<?php echo esc_url( $image_url[0] ); ?>" 
							 <?php
								if ( esc_attr( $title ) ) {
									?>
			 alt="<?php echo esc_attr( $title ); ?>" 
									<?php
								} else {
									?>
						 alt="
									<?php
									if ( get_the_title( attachment_url_to_postid( $image_url[0] ) ) ) {
										echo get_the_title( attachment_url_to_postid( $image_url[0] ) );}
									?>
						" <?php } ?>>
		<img src="<?php echo esc_url( $second_image_url[0] ); ?>" 
							 <?php
								if ( esc_attr( $title ) ) {
									?>
			 alt="<?php echo esc_attr( $title ); ?>" 
									<?php
								} else {
									?>
						 alt="
									<?php
									if ( get_the_title( attachment_url_to_postid( $second_image_url[0] ) ) ) {
										echo get_the_title( attachment_url_to_postid( $second_image_url[0] ) );}
									?>
						" <?php } ?>>
			</div>
			<?php
		}
		?>
		<div class="content-container">
			<?php if ( $badge == 'enable' && ! empty( $badge_content ) ) { ?>
				<div class="badge <?php echo esc_attr( $badge_position ); ?>" style="
											 <?php
												if ( ! empty( $badge_bg_color ) ) {
													echo 'background-color:' . esc_attr( $badge_bg_color ) . ';';}
												?>
				<?php
				if ( ! empty( $badge_content_color ) ) {
					echo 'color:' . esc_attr( $badge_content_color ) . ';';}
				?>
"><span><?php echo '' . $badge_content; ?></span></div>
			<?php } ?>
			<div class="content">
						<?php if ( $heading != '' ) { ?>
						<span class="heading clearfix <?php echo esc_attr( $headingFontSize ); ?>" style="
																 <?php
																	echo esc_attr( $heading_google_fonts_inline_style ); if ( strlen( esc_attr( $heading_color ) ) ) {
																		?>
							  color: <?php echo esc_attr( $heading_color ); ?>; <?php } ?>">
							<?php echo wp_kses( $heading, $allowed_html ); ?>
						</span>
						<?php } ?>
						<?php if ( $title != '' ) { ?>
						<span class="title clearfix <?php echo esc_attr( $titleFontSize ); ?>" style="
															   <?php
																echo esc_attr( $google_fonts_inline_style ); if ( strlen( esc_attr( $title_color ) ) ) {
																	?>
							  color: <?php echo esc_attr( $title_color ); ?>; <?php } ?>">
							<?php echo wp_kses( $title, $allowed_html ); ?>
						</span>
						<?php } ?>
						<?php if ( $subtitle != '' ) { ?>
							<span class="subtitle <?php echo esc_attr( $subtitleFontSize ); ?>" style="
															 <?php
																echo esc_attr( $sub_google_fonts_inline_style ); if ( strlen( esc_attr( $subtitle_color ) ) ) {
																	?>
								color: <?php echo esc_attr( $subtitle_color ); ?>; <?php } ?>">
							<?php
							echo wp_kses( $subtitle, $allowed_html );
							?>
							</span>
							<?php
						}

						?>

					<?php

					if ( $url && function_exists( 'vc_build_link' ) && empty( $url_title ) ) {

						$link = vc_build_link( $atts['url'] );
						if ( strlen( $link['url'] ) ) {
							?>

						<a class="
							<?php
							echo esc_attr( $buttonclass );
							echo esc_attr( $button_style );
							?>
							<?php echo esc_attr( $linkFontSize ); ?>" href="<?php echo esc_url( $link['url'] ); ?>" 
							<?php
							if ( $link['target'] != '' ) {
								?>
	target="<?php echo esc_attr( $link['target'] ); ?>"<?php } ?> style ="
							<?php
							if ( strlen( esc_attr( $link_color ) ) ) {
								?>
		color: <?php echo esc_attr( $link_color ); ?>; 
								<?php
								if ( $button_style == 'link' ) {
									?>
	 border-color: <?php echo esc_attr( $link_color ); ?>;<?php } ?> <?php
							} if ( empty( esc_attr( $link['title'] ) ) ) {
									   echo 'display:none;';}
							?>
	"><span class="txt" style="<?php echo esc_attr( $link_google_fonts_inline_style ); ?>"><?php echo esc_html( $link['title'] ); ?></span>
						</a>

							<?php
						}
					} else {
						if ( $url ) {
							$link['url'] = $url;
							if ( $new_tab ) {
								$link['target'] = '_blank';
							} else {
								$link['target'] = '_self';
							}
							$link['title'] = $url_title;
							if ( strlen( $link['url'] ) ) {
								if ( empty( $url_title ) ) {
									$buttonclass  = '';
									$button_style = 'link';
								}
								?>

							<a class="
								<?php
								echo esc_attr( $buttonclass );
								echo esc_attr( $button_style );
								?>
								<?php echo esc_attr( $linkFontSize ); ?>" href="<?php echo esc_url( $link['url'] ); ?>" 
								<?php
								if ( $link['target'] != '' ) {
									?>
	target="<?php echo esc_attr( $link['target'] ); ?>"<?php } ?> style ="
								<?php
								if ( strlen( esc_attr( $link_color ) ) ) {
									?>
		color: <?php echo esc_attr( $link_color ); ?>; 
									<?php
									if ( $button_style == 'link' ) {
										?>
	 border-color: <?php echo esc_attr( $link_color ); ?>; 
										<?php
									}
								} if ( empty( esc_attr( $link['title'] ) ) ) {
									echo 'display:none !important;';}
								?>
	"><span class="txt" style="<?php echo esc_attr( $link_google_fonts_inline_style ); ?>"><?php echo esc_html( $link['title'] ); ?></span>
							</a>

								<?php
							}
						}
					}
					?>
			</div>

		</div>
	</div> 
	

	<?php
	wp_enqueue_script( 'three' );
	wp_enqueue_script( 'gsap' );
	wp_enqueue_script( 'kite-hover' );
	return ob_get_clean();
}
/*-----------------------------------------------------------------------------------*/
/*  Icon-Box-custom ( creative iconbox )
/*-----------------------------------------------------------------------------------*/

function kite_sc_iconbox_custom( $atts, $content = null ) {
	extract(
		shortcode_atts(
			array(
				'title'                  => '',
				'title_font_type'        => 'default',
				'title_google_fonts'     => '',
				'title_color'            => '',
				'icon'                   => 'keyboard-o',
				'bg_hover_color'         => '#d02d48',
				'icon_color'             => '#d02d48',
				'hover_style'            => 'style1',
				'bg_color'               => 'fff',
				'border_color'           => '252525',
				'text_color_hover_state' => '',
				'image'                  => '',
				'url'                    => '',
				'whole_box_link'         => 'disable',
				'content_text'           => '',
				'content_font_type'      => 'default',
				'content_google_fonts'   => '',
				'elementor_link_title'   => '',
				'new_tab'                => false,
			),
			$atts
		)
	);

	$id    = kite_sc_id( 'iconbox' );
	$class = array( 'custom-iconbox', $hover_style );

	if ( is_numeric( $image ) ) {
		$class[] = 'hasimagebackground';
	}

	if ( $url && $whole_box_link == 'enable' ) {
		$class[] = 'whole_link_enable';
	}

	ob_start();
	$allowed_html = kite_allowed_tags();

	$color = $bg_hover_color;

	$title_google_fonts_inline_style   = '';
	$content_google_fonts_inline_style = '';

	if ( $title_font_type != 'default' && function_exists( 'kite_get_fonts_data' ) ) {
		$title_google_fonts_data         = kite_get_fonts_data( $title_google_fonts );
		$title_google_fonts_inline_style = kite_google_fonts_styles( $title_google_fonts_data );
		kite_enqueue_google_fonts( $title_google_fonts_data );
	}

	if ( $content_font_type != 'default' && function_exists( 'kite_get_fonts_data' ) ) {
		$content_google_fonts_data         = kite_get_fonts_data( $content_google_fonts );
		$content_google_fonts_inline_style = kite_google_fonts_styles( $content_google_fonts_data );
		kite_enqueue_google_fonts( $content_google_fonts_data );
	}
	$kiteInlineStyle = '';
	if ( is_numeric( $image ) ) {
		$image_url = wp_get_attachment_url( $image );

		$kiteInlineStyle .= ".custom-iconbox#$id .hover-content{background: url($image_url);}";
	}

	if ( strlen( esc_attr( $color ) ) ) {

		$kiteInlineStyle .= "#$id .overlay:before{background-color:$color;}";
	}
	if ( strlen( $title_color ) ) {
		$kiteInlineStyle .= "#$id .icon-container h3.title {color:$title_color;}";
	}

	if ( strlen( $bg_color ) ) {
		$kiteInlineStyle .= "#$id {background-color:$bg_color;}";
	}
	if ( strlen( $icon_color ) ) {
		$kiteInlineStyle .= "#$id .icon-container .glyph{color:$icon_color;}";
	}
	if ( strlen( $border_color ) ) {
		$kiteInlineStyle .= "#$id .icon-container{border-color:$border_color;}";
	}
	if ( ! empty( $text_color_hover_state ) ) {
		$kiteInlineStyle .= "#$id .hover-content .title,#$id .hover-content .content-wrap .content,#$id .hover-content .content-wrap .more-link a {color:$text_color_hover_state;}";
		$kiteInlineStyle .= "#$id .hover-content .content-wrap .more-link a:before {background-color:$text_color_hover_state;}";
	}
	wp_add_inline_style( 'kite-inline-style', $kiteInlineStyle );
	?>
<div id="<?php echo esc_attr( $id ); ?>" class="<?php echo implode( ' ', $class ); ?>" >
		<div class="icon">
			<div class="icon-container">
				<span class="glyph icon-<?php echo esc_attr( $icon ); ?>"></span>
				<?php if ( $title != '' ) { ?>
				<h3 class="title" style="<?php echo esc_attr( $title_google_fonts_inline_style ); ?>" ><?php echo esc_html( $title ); ?></h3>
				<?php } ?>
			</div>
		</div>
		<div class="hover-content">
			<span class="overlay"></span>
			<div class="icon">
				<span class="glyph icon-<?php echo esc_attr( $icon ); ?>"></span>
			</div>
			<?php if ( $title != '' ) { ?>
				<h3 class="title" style="<?php echo esc_attr( $title_google_fonts_inline_style ); ?>"><?php echo esc_html( $title ); ?></h3>
			<?php } ?>
			
			<!-- iconbox content -->
			<div class="content-wrap">
				<?php if ( strlen( $content_text ) ) { ?>
					
					<div class="content" style="<?php echo esc_attr( $content_google_fonts_inline_style ); ?>">
						<?php echo wp_kses( $content_text, $allowed_html ); ?>
					</div>
				
				<?php } ?>
			

				<!-- icon box read more button -->
			<?php
			if ( $url && function_exists( 'vc_build_link' ) && $elementor_link_title == '' ) {

					$link = vc_build_link( $atts['url'] );
				if ( strlen( $link['url'] ) ) {
					?>

					<div class="more-link">
						<a href="<?php echo esc_url( $link['url'] ); ?>" 
											<?php
											if ( $link['target'] != '' ) {
												?>
							target="<?php echo esc_attr( $link['target'] ); ?>"<?php } ?>><?php echo esc_html( $link['title'] ); ?></a>
					</div>

					<?php
				}
			} elseif ( $url ) {
				$link['url']    = $url;
				$link['title']  = $elementor_link_title;
				$link['target'] = ( $new_tab ) ? '_blank' : '_self';
				if ( strlen( $link['url'] ) ) {
					?>

					<div class="more-link">
						<a href="<?php echo esc_url( $link['url'] ); ?>" 
											<?php
											if ( $link['target'] != '' ) {
												?>
							target="<?php echo esc_attr( $link['target'] ); ?>"<?php } ?>><?php echo esc_html( $link['title'] ); ?></a>
					</div>

					<?php
				}
			}
			?>

			</div>
		</div>
	</div>

	<?php
	return ob_get_clean();
}

/*-----------------------------------------------------------------------------------*/
/*  Icon-Box-top No border
/*-----------------------------------------------------------------------------------*/

function kite_sc_iconbox_noborder( $atts, $content = null ) {
	extract(
		shortcode_atts(
			array(
				'title'                => '',
				'title_font_type'      => 'default',
				'title_google_fonts'   => '',
				'title_color'          => '',
				'icon_animation'       => 'none',
				'icon_animation_delay' => '0',
				'responsive_animation' => 'disable',
				'icon'                 => 'keyboard-o',
				'icon_color'           => '',
				'icon_border_color'    => '',
				'icon_position'        => 'top',
				'alignment'            => 'right_alignment',
				'alignment_resp'       => '',
				'url'                  => '',
				'whole_box_link'       => 'disable',
				'content_text'         => '',
				'content_font_type'    => 'default',
				'content_google_fonts' => '',
				'content_color'        => '',
				'elementor_link_title' => '',
			),
			$atts
		)
	);

	$hasTitle = '' != $title;
	$hasStyle = '' != $title_color || '' != $icon_color || '' != $content_color;

	$id    = kite_sc_id( 'iconbox' );
	$class = array( 'iconbox' );

	if ( strlen( $icon_position ) ) {

		$class[] = 'iconbox-top';

	}

	if ( $icon_animation != 'none' ) {

		$class[] = ' shortcodeanimation';

		if ( $responsive_animation != '' ) {
			$class[] = 'no-responsive-animation';
		}
	}

	if ( strlen( $alignment ) ) {

			$class[] = " $alignment";

	}
	$kiteInlineStyle      = '';
		$kiteInlineStyle .= '@media (max-width:1024px) {';
			$class[]      = "$alignment_resp";
		$kiteInlineStyle .= '}';
	wp_add_inline_style( 'kite-inline-style', $kiteInlineStyle );

	$title_google_fonts_inline_style   = '';
	$content_google_fonts_inline_style = '';

	if ( $title_font_type != 'default' && function_exists( 'kite_get_fonts_data' ) ) {
		$title_google_fonts_data         = kite_get_fonts_data( $title_google_fonts );
		$title_google_fonts_inline_style = kite_google_fonts_styles( $title_google_fonts_data );
		kite_enqueue_google_fonts( $title_google_fonts_data );
	}

	if ( $content_font_type != 'default' && function_exists( 'kite_get_fonts_data' ) ) {
		$content_google_fonts_data         = kite_get_fonts_data( $content_google_fonts );
		$content_google_fonts_inline_style = kite_google_fonts_styles( $content_google_fonts_data );
		kite_enqueue_google_fonts( $content_google_fonts_data );
	}
	if ( $url && function_exists( 'vc_build_link' ) && $whole_box_link == 'enable' && $elementor_link_title == '' ) {
		$class[] = 'whole_link_enable';
	} elseif ( $url && $elementor_link_title && $whole_box_link == 'enable' ) {
		$class[] = 'whole_link_enable';
	}

	ob_start();
	$allowed_html = kite_allowed_tags();
	?>

	<div id="<?php echo esc_attr( $id ); ?>" class="<?php echo implode( ' ', $class ); ?>"  
						<?php
						if ( strlen( $icon_animation ) ) {
							?>
		 data-delay="<?php echo esc_attr( $icon_animation_delay ); ?>" data-animation="<?php echo esc_attr( $icon_animation ); ?>" <?php } ?>>
		<div class="icon">
			<span class="glyph icon-<?php echo esc_attr( $icon ); ?>" 
											   <?php
												if ( strlen( $icon_color ) ) {
													?>
				 style="
													 <?php
														if ( strlen( $icon_border_color ) ) {
															?>
	 border-color: <?php echo esc_attr( $icon_border_color ); ?>; background-color: <?php echo esc_attr( $icon_border_color ); ?>;<?php } ?> color: <?php echo esc_attr( $icon_color ); ?>;" <?php } ?>></span>
		</div>
		<div class="content-wrap">
			<?php if ( $hasTitle ) { ?>
				<h3 class="title" style=" 
				<?php
				if ( strlen( $title_color ) ) {
					?>
					 color: <?php echo esc_attr( $title_color ); ?>;<?php } ?> <?php echo esc_attr( $title_google_fonts_inline_style ); ?>" ><?php echo esc_html( $title ); ?></h3>
			<?php } ?>
			
			<!-- iconbox content -->
			<?php if ( strlen( esc_attr( $content_text ) ) ) { ?>
				
				<div class="content"  style="
				<?php
				if ( strlen( $content_color ) ) {
					?>
					color: <?php echo esc_attr( $content_color ); ?>;<?php } ?> <?php echo esc_attr( $content_google_fonts_inline_style ); ?>" >
					<?php echo wp_kses( $content_text, $allowed_html ); ?>
				</div>
				
			<?php } ?>

			 <!-- icon box read more button -->
			<?php
			if ( $url && function_exists( 'vc_build_link' ) && $elementor_link_title == '' ) {

					$link = vc_build_link( $atts['url'] );
				if ( strlen( $link['url'] ) ) {
					?>

					<div class="more-link">
						<a href="<?php echo esc_url( $link['url'] ); ?>" 
											<?php
											if ( strlen( $content_color ) ) {
												?>
							 style="color: <?php echo esc_attr( $content_color ); ?>;" <?php } ?> <?php
								if ( $link['target'] != '' ) {
									?>
	target="<?php echo esc_attr( $link['target'] ); ?>"<?php } ?>>[ <?php echo esc_html( $link['title'] ); ?> ]</a>
					</div>

					<?php
				}
			} elseif ( ! empty( $url ) && ! empty( $elementor_link_title ) ) {
				$link['url']    = $url;
				$link['title']  = $elementor_link_title;
				$link['target'] = '_blank';
				if ( strlen( $link['url'] ) ) {
					?>

					<div class="more-link">
						<a href="<?php echo esc_url( $link['url'] ); ?>" 
											<?php
											if ( strlen( $content_color ) ) {
												?>
							 style="color: <?php echo esc_attr( $content_color ); ?>;" <?php } ?> <?php
								if ( $link['target'] != '' ) {
									?>
	target="<?php echo esc_attr( $link['target'] ); ?>"<?php } ?>>[ <?php echo esc_html( $link['title'] ); ?> ]</a>
					</div>

					<?php
				}
			}
			?>

		</div>
	</div>

	<?php
	return ob_get_clean();
}

/*-----------------------------------------------------------------------------------*/
/*  Icon-Box-Rectangle
/*-----------------------------------------------------------------------------------*/

function kite_sc_iconbox_rectangle( $atts, $content = null ) {
	extract(
		shortcode_atts(
			array(
				'title'                => '',
				'title_font_type'      => 'default',
				'title_google_fonts'   => '',
				'title_color'          => '',
				'icon_animation'       => 'none',
				'icon_animation_delay' => '0',
				'responsive_animation' => 'disable',
				'icon'                 => 'keyboard-o',
				'icon_color'           => '',
				'icon_border'          => 'rectangle',
				'icon_border_color'    => '',
				'icon_background_fill' => 'fillbackground',
				'icon_position'        => 'top',
				'url'                  => '',
				'whole_box_link'       => 'disable',
				'content_text'         => '',
				'content_font_type'    => 'default',
				'content_google_fonts' => '',
				'content_color'        => '',
				'elementor_link_title' => '',
			),
			$atts
		)
	);

	$hasTitle = '' != $title;
	$hasStyle = '' != $title_color || '' != $icon_color || '' != $content_color;

	$id    = kite_sc_id( 'iconbox' );
	$class = array( 'iconbox' );

	if ( strlen( $icon_position ) ) {

		$class[] = 'iconbox-top';

	}

	if ( $icon_animation != 'none' ) {

		$class[] = ' shortcodeanimation';
		if ( $responsive_animation != '' ) {
			$class[] = 'no-responsive-animation';
		}
	}

	if ( strlen( $icon_border ) ) {

		$class[] = " $icon_border";

	}

	if ( strlen( $icon_background_fill ) ) {

		$class[] = " $icon_background_fill";

	}
	$title_google_fonts_inline_style   = '';
	$content_google_fonts_inline_style = '';

	if ( $title_font_type != 'default' && function_exists( 'kite_get_fonts_data' ) ) {
		$title_google_fonts_data         = kite_get_fonts_data( $title_google_fonts );
		$title_google_fonts_inline_style = kite_google_fonts_styles( $title_google_fonts_data );
		kite_enqueue_google_fonts( $title_google_fonts_data );
	}

	if ( $content_font_type != 'default' && function_exists( 'kite_get_fonts_data' ) ) {
		$content_google_fonts_data         = kite_get_fonts_data( $content_google_fonts );
		$content_google_fonts_inline_style = kite_google_fonts_styles( $content_google_fonts_data );
		kite_enqueue_google_fonts( $content_google_fonts_data );
	}

	if ( $url && function_exists( 'vc_build_link' ) && $whole_box_link == 'enable' && $elementor_link_title == '' ) {
		$class[] = 'whole_link_enable';
	} elseif ( $url && $elementor_link_title ) {
		$class[] = 'whole_link_enable';
	}
	ob_start();
	$allowed_html = kite_allowed_tags();
	?>

	<div id="<?php echo esc_attr( $id ); ?>" class="<?php echo implode( ' ', $class ); ?>"  
						<?php
						if ( strlen( $icon_animation ) ) {
							?>
		 data-delay="<?php echo esc_attr( $icon_animation_delay ); ?>" data-animation="<?php echo esc_attr( $icon_animation ); ?>" <?php } ?>>
		<div class="icon">
			<span class="glyph icon-<?php echo esc_attr( $icon ); ?>" style="
											   <?php
												if ( strlen( esc_attr( $icon_border_color ) ) ) {
													?>
				border-color: <?php echo esc_attr( $icon_border_color ); ?>;background-color: <?php echo esc_attr( $icon_border_color ); ?>; 
													<?php
												} if ( strlen( esc_attr( $icon_color ) ) ) {
													?>
				 color: <?php echo esc_attr( $icon_color ); ?>; <?php } ?>"></span>
		</div>
		<div class="content-wrap">
			<?php if ( $hasTitle ) { ?>
				<h3 class="title" style =" 
				<?php
				if ( strlen( esc_attr( $title_color ) ) ) {
					?>
					color: <?php echo esc_attr( $title_color ); ?>;<?php } ?> <?php echo esc_attr( $title_google_fonts_inline_style ); ?>" ><?php echo esc_html( $title ); ?></h3>
			<?php } ?>
			
			<!-- iconbox content -->
			<?php if ( strlen( esc_attr( $content_text ) ) ) { ?>
			
			<div class="content" style="
				<?php
				if ( strlen( esc_attr( $content_color ) ) ) {
					?>
				  color: <?php echo esc_attr( $content_color ); ?>;<?php } ?> <?php echo esc_attr( $content_google_fonts_inline_style ); ?>" >
					<?php echo wp_kses( $content_text, $allowed_html ); ?>
				</div>
				
			<?php } ?>
		   
			<!-- icon box read more button -->
			<?php
			if ( $url && function_exists( 'vc_build_link' ) && $elementor_link_title == '' ) {

					$link = vc_build_link( $atts['url'] );
				if ( strlen( $link['url'] ) ) {
					?>

					<div class="more-link">
						<a href="<?php echo esc_url( $link['url'] ); ?>" 
											<?php
											if ( $link['target'] != '' ) {
												?>
							target="<?php echo esc_attr( $link['target'] ); ?>"
												<?php
											} if ( strlen( esc_attr( $content_color ) ) ) {
												?>
							 style="color: <?php echo esc_attr( $content_color ); ?>;" <?php } ?>>[ <?php echo esc_html( $link['title'] ); ?> ]</a>
					</div>

					<?php
				}
			} elseif ( $url && $elementor_link_title ) {
				$link['url']    = $url;
				$link['title']  = $elementor_link_title;
				$link['target'] = '_blank';
				if ( strlen( $link['url'] ) ) {
					?>

					<div class="more-link">
						<a href="<?php echo esc_url( $link['url'] ); ?>" 
											<?php
											if ( $link['target'] != '' ) {
												?>
							target="<?php echo esc_attr( $link['target'] ); ?>"
												<?php
											} if ( strlen( esc_attr( $content_color ) ) ) {
												?>
							 style="color: <?php echo esc_attr( $content_color ); ?>;" <?php } ?>>[ <?php echo esc_html( $link['title'] ); ?> ]</a>
					</div>

					<?php
				}
			}
			?>

		</div>
	</div>

	<?php
	return ob_get_clean();
}

/*-----------------------------------------------------------------------------------*/
/*  Icon-Box-Circle
/*-----------------------------------------------------------------------------------*/

function kite_sc_iconbox_circle( $atts, $content = null ) {
	extract(
		shortcode_atts(
			array(
				'title'                => '',
				'title_font_type'      => 'default',
				'title_google_fonts'   => '',
				'title_color'          => '',
				'icon_animation'       => 'none',
				'icon_animation_delay' => '0',
				'responsive_animation' => 'disable',
				'icon'                 => 'keyboard-o',
				'icon_color'           => '',
				'icon_border'          => 'circle',
				'icon_border_color'    => '',
				'icon_background_fill' => 'fillbackground',
				'icon_position'        => 'top',
				'url'                  => '',
				'whole_box_link'       => 'disable',
				'content_text'         => '',
				'content_font_type'    => 'default',
				'content_google_fonts' => '',
				'content_color'        => '',
				'elementor_link_title' => '',
			),
			$atts
		)
	);

	$hasTitle = '' != $title;
	$hasStyle = '' != $title_color || '' != $icon_color || '' != $content_color;

	$id    = kite_sc_id( 'iconbox' );
	$class = array( 'iconbox' );

	if ( strlen( $icon_position ) ) {

		$class[] = 'iconbox-top';

	}

	if ( $icon_animation != 'none' ) {

		$class[] = ' shortcodeanimation';

		if ( $responsive_animation != '' ) {
			$class[] = 'no-responsive-animation';
		}
	}

	if ( strlen( $icon_border ) ) {

		$class[] = " $icon_border";

	}

	if ( strlen( $icon_background_fill ) ) {

		$class[] = " $icon_background_fill";

	}
	$title_google_fonts_inline_style   = '';
	$content_google_fonts_inline_style = '';

	if ( $title_font_type != 'default' && function_exists( 'kite_get_fonts_data' ) ) {
		$title_google_fonts_data         = kite_get_fonts_data( $title_google_fonts );
		$title_google_fonts_inline_style = kite_google_fonts_styles( $title_google_fonts_data );
		kite_enqueue_google_fonts( $title_google_fonts_data );
	}

	if ( $content_font_type != 'default' && function_exists( 'kite_get_fonts_data' ) ) {
		$content_google_fonts_data         = kite_get_fonts_data( $content_google_fonts );
		$content_google_fonts_inline_style = kite_google_fonts_styles( $content_google_fonts_data );
		kite_enqueue_google_fonts( $content_google_fonts_data );
	}
	if ( $url && function_exists( 'vc_build_link' ) && $whole_box_link == 'enable' && $elementor_link_title == '' ) {
		$class[] = 'whole_link_enable';
	} elseif ( $url && $elementor_link_title && $whole_box_link == 'enable' ) {
		$class[] = 'whole_link_enable';
	}

	ob_start();
	$allowed_html = kite_allowed_tags();

	?>

	<div id="<?php echo esc_attr( $id ); ?>" class="<?php echo implode( ' ', $class ); ?>"  
						<?php
						if ( strlen( $icon_animation ) ) {
							?>
		 data-delay="<?php echo esc_attr( $icon_animation_delay ); ?>" data-animation="<?php echo esc_attr( $icon_animation ); ?>" <?php } ?>>
		<div class="icon">
			<span class="glyph icon-<?php echo esc_attr( $icon ); ?>" style="
											   <?php
												if ( strlen( esc_attr( $icon_color ) ) ) {
													?>
				color: <?php echo esc_attr( $icon_color ); ?>;
													<?php
												} if ( strlen( esc_attr( $icon_border_color ) ) ) {
													?>
				 border-color: <?php echo esc_attr( $icon_border_color ); ?>;background-color: <?php echo esc_attr( $icon_border_color ); ?>;<?php } ?>"></span>
		</div>
		<div class="content-wrap">
			<?php if ( $hasTitle ) { ?>
			<h3 class="title" style="
				<?php
				if ( strlen( esc_attr( $title_color ) ) ) {
					?>
				 color: <?php echo esc_attr( $title_color ); ?>;<?php } ?> <?php echo esc_attr( $title_google_fonts_inline_style ); ?>" ><?php echo esc_html( $title ); ?></h3>
			<?php } ?>
		   
			<!-- iconbox content -->
			<?php if ( strlen( esc_attr( $content_text ) ) ) { ?>

				<div class="content" style="
				<?php
				if ( strlen( esc_attr( $content_color ) ) ) {
					?>
					color: <?php echo esc_attr( $content_color ); ?>;<?php } ?> <?php echo esc_attr( $content_google_fonts_inline_style ); ?>" >
					<?php echo wp_kses( $content_text, $allowed_html ); ?>
				</div>
				
			<?php } ?>
			
			<!-- icon box read more button -->
			<?php
			if ( $url && function_exists( 'vc_build_link' ) && $elementor_link_title == '' ) {

					$link = vc_build_link( $atts['url'] );
				if ( strlen( $link['url'] ) ) {
					?>

					<div class="more-link">
						<a href="<?php echo esc_url( $link['url'] ); ?>" 
											<?php
											if ( $link['target'] != '' ) {
												?>
							target="<?php echo esc_attr( $link['target'] ); ?>"
												<?php
											} if ( strlen( esc_attr( $content_color ) ) ) {
												?>
							 style="color: <?php echo esc_attr( $content_color ); ?>;" <?php } ?>>[ <?php echo esc_html( $link['title'] ); ?> ]</a>
					</div>

					<?php
				}
			} elseif ( $url && $elementor_link_title ) {
				$link['url']    = $url;
				$link['title']  = $elementor_link_title;
				$link['target'] = '_blank';
				if ( strlen( $link['url'] ) ) {
					?>

					<div class="more-link">
						<a href="<?php echo esc_url( $link['url'] ); ?>" 
											<?php
											if ( $link['target'] != '' ) {
												?>
							target="<?php echo esc_attr( $link['target'] ); ?>"
												<?php
											} if ( strlen( esc_attr( $content_color ) ) ) {
												?>
							 style="color: <?php echo esc_attr( $content_color ); ?>;" <?php } ?>>[ <?php echo esc_html( $link['title'] ); ?> ]</a>
					</div>

					<?php
				}
			}
			?>

		</div>
	</div>

	<?php
	return ob_get_clean();
}

/*-----------------------------------------------------------------------------------*/
/*  Icon-Box-left
/*-----------------------------------------------------------------------------------*/

function kite_sc_iconbox_left( $atts, $content = null ) {
	extract(
		shortcode_atts(
			array(
				'title'                => '',
				'title_font_type'      => 'default',
				'title_google_fonts'   => '',
				'title_color'          => '',
				'icon_animation'       => 'none',
				'icon_animation_delay' => '0',
				'responsive_animation' => 'disable',
				'icon'                 => 'keyboard-o',
				'icon_color'           => '',
				'icon_border_color'    => '',
				'icon_position'        => 'left',
				'url'                  => '',
				'whole_box_link'       => 'disable',
				'content_text'         => '',
				'content_font_type'    => 'default',
				'content_google_fonts' => '',
				'content_color'        => '',
				'elementor_link_title' => '',
			),
			$atts
		)
	);

	$hasTitle = '' != $title;
	$hasStyle = '' != $title_color || '' != $icon_color || '' != $content_color;

	$id    = kite_sc_id( 'iconbox' );
	$class = array( 'iconbox' );

	if ( strlen( $icon_position ) ) {

		$class[] = 'iconbox-left';

	}

	if ( $icon_animation != 'none' && strlen( $icon_animation ) ) {

		$class[] = ' shortcodeanimation';

		if ( $responsive_animation != '' ) {
			$class[] = 'no-responsive-animation';
		}
	}

	$title_google_fonts_inline_style   = '';
	$content_google_fonts_inline_style = '';

	if ( $title_font_type != 'default' && function_exists( 'kite_get_fonts_data' ) ) {
		$title_google_fonts_data         = kite_get_fonts_data( $title_google_fonts );
		$title_google_fonts_inline_style = kite_google_fonts_styles( $title_google_fonts_data );
		kite_enqueue_google_fonts( $title_google_fonts_data );
	}

	if ( $content_font_type != 'default' && function_exists( 'kite_get_fonts_data' ) ) {
		$content_google_fonts_data         = kite_get_fonts_data( $content_google_fonts );
		$content_google_fonts_inline_style = kite_google_fonts_styles( $content_google_fonts_data );
		kite_enqueue_google_fonts( $content_google_fonts_data );
	}

	if ( $url && function_exists( 'vc_build_link' ) && $whole_box_link == 'enable' && $elementor_link_title == '' ) {
		$class[] = 'whole_link_enable';
	} elseif ( $url && $elementor_link_title ) {
		$class[] = 'whole_link_enable';
	}
	if ( empty( $content_text ) ) {
		$class[] = 'empty_content';
	}

	ob_start();
	$allowed_html = kite_allowed_tags();
	?>

	<div id="<?php echo esc_attr( $id ); ?>" class="<?php echo implode( ' ', $class ); ?>"  
						<?php
						if ( strlen( esc_attr( $icon_animation ) ) ) {
							?>
		 data-delay="<?php echo esc_attr( $icon_animation_delay ); ?>" data-animation="<?php echo esc_attr( $icon_animation ); ?>" <?php } ?>>
		<div class="icon">
			<span class="glyph icon-<?php echo esc_attr( $icon ); ?>" 
											   <?php
												if ( strlen( esc_attr( $icon_color ) ) ) {
													?>
				style="color: <?php echo esc_attr( $icon_color ); ?>;" <?php } ?>></span>
		</div>
		<div class="content-wrap">
			<?php if ( esc_attr( $hasTitle ) ) { ?>
			<h3 class="title" style="
				<?php
				if ( strlen( esc_attr( $title_color ) ) ) {
					?>
				color: <?php echo esc_attr( $title_color ); ?>;<?php } ?> <?php echo esc_attr( $title_google_fonts_inline_style ); ?>" ><?php echo esc_html( $title ); ?></h3>
			<?php } ?>
			<!-- iconbox content -->
			<?php if ( strlen( esc_attr( $content_text ) ) ) { ?>
				
				<div class="content" style="
				<?php
				if ( strlen( $content_color ) ) {
					?>
					 color: <?php echo esc_attr( $content_color ); ?>;<?php } ?> <?php echo esc_attr( $content_google_fonts_inline_style ); ?>" >
					<?php echo wp_kses( $content_text, $allowed_html ); ?>
				</div>
					
			<?php } ?>      
			
			<!-- icon box read more button -->
			<?php
			if ( $url && function_exists( 'vc_build_link' ) && $elementor_link_title == '' ) {

					$link = vc_build_link( $atts['url'] );
				if ( strlen( $link['url'] ) ) {
					?>

					<div class="more-link">
						<a href="<?php echo esc_url( $link['url'] ); ?>" 
											<?php
											if ( $link['target'] != '' ) {
												?>
							target="<?php echo esc_attr( $link['target'] ); ?>"
												<?php
											} if ( strlen( esc_attr( $content_color ) ) ) {
												?>
							 style="color: <?php echo esc_attr( $content_color ); ?>;" <?php } ?>>[ <?php echo esc_html( $link['title'] ); ?> ]</a>
					</div>

					<?php
				}
			} elseif ( $url && $elementor_link_title ) {
				$link['url']    = $url;
				$link['title']  = $elementor_link_title;
				$link['target'] = '_blank';
				if ( strlen( $link['url'] ) ) {
					?>

					<div class="more-link">
						<a href="<?php echo esc_url( $link['url'] ); ?>" 
											<?php
											if ( $link['target'] != '' ) {
												?>
							target="<?php echo esc_attr( $link['target'] ); ?>"
												<?php
											} if ( strlen( esc_attr( $content_color ) ) ) {
												?>
							 style="color: <?php echo esc_attr( $content_color ); ?>;" <?php } ?>>[ <?php echo esc_html( $link['title'] ); ?> ]</a>
					</div>

					<?php
				}
			}
			?>

		</div>
	</div>

	<?php
	return ob_get_clean();
}

/*-----------------------------------------------------------------------------------*/
/*  Countdown
/*-----------------------------------------------------------------------------------*/

function kite_sc_countdown( $atts, $content = null ) {
	extract(
		shortcode_atts(
			array(
				'end_date'             => '',
				'style'                => '',
				'fontsize'             => '16',
				'bg_color'             => '',
				'color'                => '',
				'label_color'          => '',
				'alignment'            => 'center',
				'animation'            => 'none',
				'animation_delay'      => '1000',
				'responsive_animation' => 'disable',
			),
			$atts
		)
	);

	if ( $end_date == '' ) {
		return;
	}

	$id = kite_sc_id( 'countdown' );

	$class = array( 'countdown-timer' );

	$class[] = 'fontsize' . $fontsize;

	if ( $animation != 'none' ) {
		$class[] = 'shortcodeanimation';

		if ( $responsive_animation != '' ) {
			$class[] = 'no-responsive-animation';
		}
	}

	if ( $style == 'deal_style' ) {
		$class[] = 'secondstyle';
	}

	$colorStyle = $labelColorStyle = '';

	if ( $color != '' ) {
		$colorStyle = ' style="color:' . $color . '"';
	}

	if ( $label_color != '' ) {
		$labelColorStyle = ' style="color:' . $label_color . '"';
	}

	switch ( $alignment ) {
		case 'right':
			$class[] = 'right';
			break;
		case 'center':
			$class[] = 'center';
			break;
		case 'left':
			$class[] = 'left';
			break;
	}

	ob_start();

	?>
	<?php
	$kiteInlineStyle = '';
	if ( ! empty( $bg_color ) ) {
		$kiteInlineStyle .= "#$id{background-color:$bg_color}";
	}
	wp_add_inline_style( 'kite-inline-style', $kiteInlineStyle );
	?>
	<div id="<?php echo esc_attr( $id ); ?>" class="<?php echo implode( ' ', $class ); ?>" 
						<?php
						if ( strlen( esc_attr( $animation ) ) ) {
							?>
		 data-delay="<?php echo esc_attr( $animation_delay ); ?>" data-animation="<?php echo esc_attr( $animation ); ?>" <?php } ?> data-end="<?php echo esc_attr( $end_date ); ?>">
		<div class="time-block">
			<span class="days number"<?php echo '' . $colorStyle; ?>>0</span>
			<span class="label"<?php echo '' . $labelColorStyle; ?>><?php echo esc_html__( 'Days', 'pinkmart' ); ?></span>
		</div>
		<div class="time-block">
			<span class="hours number"<?php echo '' . $colorStyle; ?>>0</span>
			<span class="label"<?php echo '' . $labelColorStyle; ?>><?php echo esc_html__( 'Hours', 'pinkmart' ); ?></span>
		</div>
		<div class="time-block">
			<span class="minutes number"<?php echo '' . $colorStyle; ?>>0</span>
			<span class="label"<?php echo '' . $labelColorStyle; ?>><?php echo esc_html__( 'Mins', 'pinkmart' ); ?></span>
		</div>
		<div class="time-block">
			<span class="seconds number"<?php echo '' . $colorStyle; ?>>0</span>
			<span class="label"<?php echo '' . $labelColorStyle; ?>><?php echo esc_html__( 'Secs', 'pinkmart' ); ?></span>
		</div>
	</div>

	<?php
	return ob_get_clean();
}

/*-----------------------------------------------------------------------------------*/
/*  Counter Box
/*-----------------------------------------------------------------------------------*/

function kite_sc_conterbox( $atts, $content = null ) {
	extract(
		shortcode_atts(
			array(
				'counter_number'          => '500',
				'counter_number_color'    => '',
				'counter_text_color'      => '',
				'counter_animation'       => 'none',
				'counter_text'            => esc_html__( 'Description', 'pinkmart' ),
				'counter_text2'           => '',
				'counter_animation_delay' => '1000',
				'responsive_animation'    => 'disable',
			),
			$atts
		)
	);

	$hasStyle       = '' != $counter_number_color || '' != $counter_text_color;
	$counter_number = intval( $counter_number );
	$id             = kite_sc_id( 'conterbox' );

	$class = array( 'counterbox' );

	if ( $counter_animation != 'none' ) {

		$class[] = 'shortcodeanimation';

		if ( $responsive_animation != '' ) {
			$class[] = 'no-responsive-animation';
		}
	}
	$kite_inline_style = '';
	if ( strlen( esc_attr( $counter_number_color ) ) ) {
		$kite_inline_style .= "#$id .counterboxnumber {color:" . esc_attr( $counter_number_color ) . ';}';
	}
	if ( strlen( esc_attr( $counter_text_color ) ) ) {
		$kite_inline_style .= "#$id .counterboxdetails,#$id .counterboxdetails2 {color:" . esc_attr( $counter_text_color ) . ';}';
	}
	wp_add_inline_style( 'kite-inline-style', $kite_inline_style );
	ob_start();

	?>
	
	<div id="<?php echo esc_attr( $id ); ?>" class="<?php echo implode( ' ', $class ); ?>" 
						<?php
						if ( strlen( esc_attr( $counter_animation ) ) ) {
							?>
		 data-delay="<?php echo esc_attr( $counter_animation_delay ); ?>" data-animation="<?php echo esc_attr( $counter_animation ); ?>" <?php } ?> data-countNmber="<?php echo esc_attr( $counter_number ); ?>">
		<span class="counterboxnumber highlight">0<?php // echo esc_attr($counter_number); ?></span>
		<h4 class="counterboxdetails"><?php echo esc_html( $counter_text ); ?></h4>


		<?php if ( strlen( esc_attr( $counter_text2 ) ) ) { ?>

			<div class="counterboxdetails2"><?php echo esc_html( $counter_text2 ); ?></div>

		<?php } ?>

	</div>

	<?php
	return ob_get_clean();
}

/*-----------------------------------------------------------------------------------*/
/*  Embed Video
/*-----------------------------------------------------------------------------------*/

function kite_sc_embed_video( $atts ) {
	$class[] = '';
	extract(
		shortcode_atts(
			array(

				'video_display_type'      => 'local_video',
				'video_autoplay'          => 'enable',
				'loop'                    => 'enable',
				'mejs_controls'           => 'enable',
				'video_poster_image'      => '',
				'video_background_image'  => '',
				'video_webm'              => '',
				'video_mp4'               => '',
				'video_ogv'               => '',
				'video_vimeo_id'          => '',
				'video_youtube_id'        => '',
				'alignment'               => '',
				'video_play_button_color' => 'light',
				'animation'               => 'none',
				'delay'                   => '0',
				'responsive_animation'    => 'disable',
				'el_aspect'               => '169',
				'text'                    => '', // Just used in Product detail video ( not included in VC )
			),
			$atts
		)
	);

	switch ( $alignment ) {
		case 'right':
			$class[] = ' right';
			break;
		case 'center':
			$class[] = ' center';
			break;
		case 'left':
			$class[] = ' left';
			break;
	}

	if ( $video_display_type == 'local_video' || $video_display_type == 'local_video_popup' ) {
		if ( $video_webm == '' && $video_mp4 == '' && $video_ogv == '' ) {
			return;
		}
	} elseif ( $video_display_type == 'embeded_video_vimeo' || $video_display_type == 'embeded_video_vimeo_popup' ) {
		if ( $video_vimeo_id == '' ) {
			return;
		}
	} elseif ( $video_display_type == 'embeded_video_youtube' || $video_display_type == 'embeded_video_youtube_popup' ) {
		if ( $video_youtube_id == '' ) {
			return;
		}
	}

	// Video ID extractor
	$vimeoURL = $video_vimeo_id;
	$vimeoId  = preg_replace( '/[^0-9]/', '', $vimeoURL );

	// detect youtube id form url
	$youtubeURL = $video_youtube_id;
	if ( $youtubeURL && ( $video_display_type == 'embeded_video_youtube_popup' || $video_display_type == 'embeded_video_youtube' ) ) {
		$youtubeId = explode( '?v=', $youtubeURL ); // For videos like http://www.youtube.com/watch?v=...
		if ( empty( $youtubeId[1] ) ) {
			$youtubeId = explode( '/v/', $youtubeURL ); // For videos like http://www.youtube.com/watch/v/..
		} else {
			$youtubeId = explode( '&', $youtubeId[1] ); // Deleting any other params
		}
		$youtubeId = $youtubeId[0];
	}

	if ( is_numeric( $video_background_image ) ) {
		$video_background_image = wp_get_attachment_url( $video_background_image );
	}

	if ( is_numeric( $video_poster_image ) ) {
		$video_poster_image = wp_get_attachment_url( $video_poster_image );
	}

	$id = kite_sc_id( 'embed_video' );

	ob_start();

	?>
		

	<?php if ( $video_display_type == 'local_video_popup' ) { ?>

		<!-- Hidden video div -->
		<div style="display:none;" id="video<?php echo esc_attr( $id ); ?>">
			<video class="lg-video-object lg-html5 video-js vjs-default-skin" controls preload="none" 
			<?php
			if ( $video_poster_image ) {
				?>
				 poster="<?php echo esc_url( $video_poster_image ); ?>" <?php } ?>>

				<?php if ( esc_attr( $video_webm ) ) { ?>
					<source src="<?php echo esc_attr( $video_webm ); ?>" type="video/webm">
				<?php } ?>

				<?php if ( esc_attr( $video_mp4 ) ) { ?>
					<source src="<?php echo esc_attr( $video_mp4 ); ?>" type="video/mp4">
				<?php } ?>

				<?php if ( esc_attr( $video_ogv ) ) { ?>
					<source src="<?php echo esc_attr( $video_ogv ); ?>" type="video/ogv">
				<?php } ?>    
		   
			</video>
		</div>

	<?php } ?>

	<?php if ( $video_display_type == 'local_video_popup' || $video_display_type == 'embeded_video_youtube_popup' || $video_display_type == 'embeded_video_vimeo_popup' ) { ?>

		<div id="<?php echo esc_attr( $id ); ?>" class="video_embed_container 
							<?php
							if ( $animation != 'none' ) {
								?>
			  shortcodeanimation 
								  <?php
									if ( $responsive_animation != '' ) {
												echo ' no-responsive-animation';}
							}
							?>
				 "  
				 <?php
					if ( strlen( esc_attr( $animation ) ) ) {
						?>
	 data-delay="<?php echo esc_attr( $delay ); ?>" data-animation="<?php echo esc_attr( $animation ); ?>" <?php } ?>>

			<?php if ( $video_display_type == 'local_video_popup' ) { ?>


				<!-- data-src should not be provided when you use html5 videos -->
				<a data-html="#video<?php echo esc_attr( $id ); ?>">

					<?php if ( esc_attr( $video_background_image ) ) { ?>
						<img src="<?php echo esc_url( $video_background_image ); ?>" alt="
											 <?php
												if ( get_the_title( attachment_url_to_postid( $video_background_image ) ) ) {
													echo get_the_title( attachment_url_to_postid( $video_background_image ) );}
												?>
						" />
					<?php } ?>

					<div class="play-button 
					<?php
					echo esc_attr( $video_play_button_color );
					echo implode( $class );
					?>
					">
						<span class="glyph icon  icon-play2"></span>
					</div>
					<?php
					if ( $text != '' ) {
						echo '<span class="text">' . $text . '</span>';
					}
					?>

				</a>

			<?php } elseif ( $video_display_type == 'embeded_video_youtube_popup' ) { ?> 

				<!-- Youtube popup -->
				<a class="image" href="<?php echo esc_url( 'https://youtu.be/' ) . esc_attr( $youtubeId ); ?>">      

					<?php if ( esc_url( $video_background_image ) ) { ?>
						<img src="<?php echo esc_url( $video_background_image ); ?>" alt="
											 <?php
												if ( get_the_title( attachment_url_to_postid( $video_background_image ) ) ) {
													echo get_the_title( attachment_url_to_postid( $video_background_image ) );}
												?>
						" />
					<?php } ?>

					 <div class="play-button <?php echo esc_attr( $video_play_button_color ); ?>">
						<span class="glyph icon  icon-play2"></span>
					</div>
					<?php
					if ( $text != '' ) {
						echo '<span class="text">' . $text . '</span>';
					}
					?>

				</a>
		
			<?php } elseif ( $video_display_type == 'embeded_video_vimeo_popup' ) { ?> 
			
				<!-- Vimeo popup -->
				<a class="image" href="<?php echo esc_url( 'https://vimeo.com/' ) . esc_attr( $vimeoId ); ?>" >

					<?php if ( esc_url( $video_background_image ) ) { ?>
						<img src="<?php echo esc_url( $video_background_image ); ?>" alt="
											 <?php
												if ( get_the_title( attachment_url_to_postid( $video_background_image ) ) ) {
													echo get_the_title( attachment_url_to_postid( $video_background_image ) );}
												?>
						" />
					<?php } ?>

					 <div class="play-button <?php echo esc_attr( $video_play_button_color ); ?>">
						<span class="glyph icon  icon-play2"></span>
					</div>
					<?php
					if ( $text != '' ) {
						echo '<span class="text">' . $text . '</span>';
					}
					?>

				</a>

			<?php } ?>

		</div> 

	<?php } ?>

	<?php if ( $video_display_type == 'local_video' ) { ?>
		
		<!-- HTML5 Video popup -->
		<div class="inline_video video_embed_container 
		<?php
		if ( $mejs_controls == 'disable' ) {
			?>
			 hide-control <?php } ?>">
			<video id="<?php echo esc_attr( $id ); ?>" class="video" width="320" height="240" 
								  <?php
									if ( $video_poster_image ) {
										?>
				poster="<?php echo esc_url( $video_poster_image ); ?>"<?php } ?> controls="controls" preload="auto"  
								   <?php
									if ( $video_autoplay == 'enable' ) {
										?>
	 autoplay muted="muted" 
										<?php
									} if ( $loop == 'enable' ) {
										?>
					 loop <?php } ?>>
	
				<?php if ( esc_attr( $video_webm ) ) { ?>
					<source src="<?php echo esc_url( $video_webm ); ?>" type="video/webm">
				<?php } ?>

				<?php if ( esc_attr( $video_mp4 ) ) { ?>
					<source src="<?php echo esc_url( $video_mp4 ); ?>" type="video/mp4">
				<?php } ?>

				<?php if ( esc_attr( $video_ogv ) ) { ?>
					<source src="<?php echo esc_url( $video_ogv ); ?>" type="video/ogv">
				<?php } ?>    

				<object width="320" height="240" type="application/x-shockwave-flash" data="<?php echo esc_url( get_template_directory_uri() ); ?>/js/flashmediaelement.swf">
					<param name="movie" value="<?php echo esc_url( get_template_directory_uri() ); ?>/js/flashmediaelement.swf" />
					<param name="flashvars" value="controls=true&file='<?php echo esc_url( $video_mp4 ); ?>" />

					<?php if ( $video_poster_image ) { ?>

						<img src="<?php echo esc_url( $video_poster_image ); ?>" width="1920" height="800" title="No video playback capabilities" alt="Video thumb" />

					<?php } ?>    

				</object>
			</video>    

			<?php if ( esc_attr( $video_poster_image ) ) { ?>

				<div class="play-button <?php echo esc_attr( $video_play_button_color ); ?>">
					<span class="glyph icon  icon-play2"></span>
				</div>

			<?php } ?>
			
	
		</div>

	<?php } elseif ( $video_display_type == 'embeded_video_vimeo' ) { ?>

		<div id="<?php echo esc_attr( $id ); ?>">

			<?php
				$video_w   = 500;
				$video_h   = $video_w / 1.61; // 1.61 golden ratio
				$link      = 'http://vimeo.com/' . $vimeoId;
				$el_aspect = 'vc_video-aspect-ratio-' . $el_aspect;
				global $wp_embed;
				$embed = $wp_embed->run_shortcode( '[embed  width="' . esc_attr( $video_w ) . '"     height="' . esc_attr( $video_h ) . '"]' . $link . '[/embed]' );
			?>
		
			<div class="wpb_video_widget wpb_content_element vc_clearfix <?php echo esc_attr( $el_aspect ); ?>">
				<div class="wpb_wrapper">
					<div class="wpb_video_wrapper"> <?php echo '' . $embed; ?> </div>
				</div>
			</div>
		</div>  

	<?php } elseif ( $video_display_type == 'embeded_video_youtube' ) { ?>

		<div id="<?php echo esc_attr( $id ); ?>">

			<?php
				$el_aspect = 'vc_video-aspect-ratio-169';
			?>

			<div class="wpb_video_widget wpb_content_element vc_clearfix <?php echo esc_attr( $el_aspect ); ?>">
				<div class="wpb_wrapper">
					<div class="wpb_video_wrapper"> 
						<?php echo wp_oembed_get(  'https://www.youtube.com/watch?v=' . $youtubeId ); ?>						
					</div>
				</div>
			</div>
		</div>

	<?php } ?>

	<?php
	return ob_get_clean();
}

/*-----------------------------------------------------------------------------------*/
/*  Audio SoundCloud
/*-----------------------------------------------------------------------------------*/

function kite_sc_audio_soundcloud( $atts, $content = null ) {
	extract(
		shortcode_atts(
			array(
				'soundcloud_id'     => '',
				'soundcloud_height' => 'auto',
				'soundcloud_style'  => 'full_width_thumbnail',
				'soundcloud_color'  => '',
			),
			$atts
		)
	);

	$id = kite_sc_id( 'audio_soundcloud' );
	?>
	
	<?php
	ob_start();
	?>

	<div class="soundcloud_shortcode" id="<?php echo esc_attr( $id ); ?>">
	<?php
	if ( esc_attr( $soundcloud_style ) == 'full_width_thumbnail' ) {
		echo wp_oembed_get( $soundcloud_id , array( 'height' => $soundcloud_height ) );
	} else {
		$soundcloud_id .= '?color=' . str_replace( '#', '', esc_attr( $soundcloud_color ) ) ;
		echo wp_oembed_get( $soundcloud_id );
	}
	?>
	</div>

	<?php
	return ob_get_clean();
}

/*-----------------------------------------------------------------------------------*/
/*  Tabs
/*-----------------------------------------------------------------------------------*/

function kite_sc_tab_group( $atts, $content = null ) {
	$GLOBALS['kt_sc_tab'] = array();
	do_shortcode( $content );
	$tabs = $GLOBALS['kt_sc_tab'];

	ob_start();
	?>
	<div class="tabs">
	<?php if ( count( $tabs ) ) { ?>
		<ul class="head clearfix">
			<?php foreach ( $tabs as $tab ) { ?>
			<li><?php echo esc_html( $tab[0] ); ?></li>
			<?php } ?>
		</ul>
		<div class="content">
			<?php foreach ( $tabs as $tab ) { ?>
				<div class="tab-content"><?php echo esc_html( $tab[1] ); ?></div>
			<?php } ?>
		</div>
	<?php } ?>
	</div>
	<?php
	return ob_get_clean();
}

function kite_sc_tab( $atts, $content = null ) {
	$tabCnt = count( $GLOBALS['kt_sc_tab'] ) + 1;

	extract(
		shortcode_atts(
			array(
				'title' => "Tab $tabCnt",
			),
			$atts
		)
	);

	$GLOBALS['kt_sc_tab'][] = array( $title, do_shortcode( $content ) );
}

/*-----------------------------------------------------------------------------------*/
/*  Button
/*-----------------------------------------------------------------------------------*/

function kite_sc_button( $atts, $content = null ) {
	extract(
		shortcode_atts(
			array(
				'title'                     => '',
				'text'                      => esc_html__( 'View Page', 'pinkmart' ),
				'text_hover'                => esc_html__( 'View Page', 'pinkmart' ),
				'button_hover_style'        => 'style2',
				'button_bg_style'           => 'fill',
				'link_display_style'        => 'text',
				'url'                       => '#',
				'new_tab'                   => false,
				'elementor'                 => '',
				'size'                      => 'default',
				'alignment'                 => 'left',
				'position'                  => '',
				'button_display'            => '',
				'button_icon'               => '',
				'button_icon_position'      => '',
				'button_text_color'         => '',
				'button_text_hover_color'   => '',
				'button_border_color'       => '',
				'button_border_hover_color' => '',
				'button_bg_color'           => '',
				'button_bg_hover_color'     => '',
				'button_border_radius'      => '',
				'button_border_width'       => '',
				'animation'                 => 'none',
				'animation_delay'           => '1000',
				'responsive_animation'      => 'disable',

			),
			$atts
		)
	);

	$class   = array();
	$class[] = 'kt_button';

	switch ( $size ) {
		case 'small':
			$class[] = 'button-small';
			break;
		case 'standard':
			$class[] = 'button-medium';
			break;
		case 'default':
			$class[] = 'button-default';
			break;
		case 'large':
			$class[] = 'button-large';
			break;
	}

	switch ( $alignment ) {
		case 'right':
			$class[] = 'right';
			break;
		case 'center':
			$class[] = 'center';
			break;
		case 'left':
			$class[] = 'left';
			break;
	}

	switch ( $position ) {
		case 'row':
			$class[] = 'row';
			break;
		case 'separate':
			$class[] = 'separate';
			break;
	}
	switch ( $button_display ) {
		case 'box':
			$class[] = 'box';
			break;
		case 'full':
			$class[] = 'full';
			break;
	}

	switch ( $button_hover_style ) {
		case 'style1':
			$class[] = 'style1';
			break;
		case 'style2':
			$class[] = 'style2';
			break;
		case 'link_style':
			$class[] = 'link_style';
			break;
	}

	switch ( $button_bg_style ) {
		case 'fill':
			$class[] = 'fill';
			break;
		case 'transparent':
			$class[] = 'transparent';
			break;
	}
	switch ( $link_display_style ) {
		case 'text':
			$class[] = 'text';
			break;
		case 'icon':
			$class[] = 'icon';
			break;
	}

	if ( strlen( $button_icon ) ) {
		$class[]     = 'hasicon';
		$button_icon = str_replace( 'icon icon-', '', $button_icon );
	}

	switch ( $button_icon_position ) {
		case 'left':
			$class[] = 'buttoniconleft';
			break;
		case 'right':
			$class[] = 'buttoniconright';
			break;
	}

	$id              = kite_sc_id( 'button' );
	$hasStyle        = '' != $button_text_color || '' != $button_text_hover_color || '' != $button_border_color || '' != $button_border_hover_color || '' != $button_bg_color || '' != $button_bg_hover_color || '' != $button_border_radius || '' != $button_border_width;
	$kiteInlineStyle = '';
	if ( $hasStyle ) {
		if ( strlen( esc_attr( $button_bg_color ) ) ) {
			if ( $button_bg_style == 'fill' ) {
				$kiteInlineStyle .= "#$id.kt_button{background-color:$button_bg_color;}";
			}
		}
		if ( strlen( esc_attr( $button_bg_hover_color ) ) ) {
			$kiteInlineStyle .= "#$id.kt_button:hover{background-color:$button_bg_hover_color;}";
		}
		if ( strlen( esc_attr( $button_border_radius ) ) ) {
			$kiteInlineStyle .= "#$id.kt_button{border-radius:$button_border_radius;}";
		}
		if ( strlen( esc_attr( $button_border_width ) ) ) {
			$kiteInlineStyle .= "#$id.kt_button{border-width:$button_border_width;}";
		}

		if ( strlen( esc_attr( $button_border_color ) ) ) {
			$kiteInlineStyle .= "#$id.kt_button{border-color:$button_border_color;}";
		}

		if ( strlen( esc_attr( $button_border_hover_color ) ) ) {
			if ( $button_hover_style == 'link_style' ) {
				$kiteInlineStyle .= "#$id.kt_button.link_style:after {";
			} else {
				$kiteInlineStyle .= "#$id.kt_button:hover {";
			}
			$kiteInlineStyle .= "border-color:$button_border_hover_color;}";
		}
		if ( strlen( esc_attr( $button_text_color ) ) ) {
			$kiteInlineStyle .= "#$id.kt_button{color:$button_text_color;}";
		}
		if ( strlen( esc_attr( $button_text_hover_color ) ) ) {
			$kiteInlineStyle .= "#$id.kt_button:hover{color:$button_text_hover_color;}";
		}
	} // End if
	wp_add_inline_style( 'kite-inline-style', $kiteInlineStyle );
	?>
	
	<?php
	if ( $url && function_exists( 'vc_build_link' ) && empty( $elementor ) ) {
		$link = vc_build_link( $url );
	} else {
		$link['url'] = $url;
		if ( $new_tab ) {
			$link['target'] = '_blank';
		} else {
			$link['target'] = '_self';
		}
	}
	$btntext = '';
	if ( $button_hover_style == 'style1' ) {
		$btntext = esc_attr( $text_hover );
	} else {
		$btntext = esc_attr( $text );
	}

	ob_start();

	?>
	<?php if ( $position == 'row' ) { ?>
			<div class="inlinestyle <?php echo esc_attr( $alignment ); ?>">
	<?php } ?>
	<div class="buttonwrapper 
	<?php
	if ( $button_display == 'full' ) {
		echo 'full'; }
	?>
		 <?php
			if ( $responsive_animation != '' ) {
				echo 'no-responsive-animation';}
			?>
			 <?php
				if ( strlen( esc_attr( $animation ) ) ) {
					echo 'shortcodeanimation';}
				?>
" 
	 <?php
		if ( strlen( esc_attr( $animation ) ) ) {
			?>
	 data-delay="<?php echo esc_attr( $animation_delay ); ?>" <?php } ?>data-animation="<?php echo esc_attr( $animation ); ?>">
	<?php if ( $alignment == 'center' ) { ?>
		<div class="centeralignment">
	<?php } ?>
	<?php if ( ( $button_hover_style == 'link_style' ) && ( $button_display == 'full' ) ) { ?>
		<div class="fullwidth">
	<?php } ?>
	
	 <a id="<?php echo esc_attr( $id ); ?>" class="<?php echo implode( ' ', $class ); ?>" href="<?php echo esc_url( $link['url'] ); ?>" title="<?php echo esc_attr( $title ); ?>" 
					   <?php
						if ( $link['target'] != '' ) {
							?>
			target="<?php echo esc_attr( $link['target'] ); ?>"<?php } ?>>
		<?php if ( strlen( $button_icon ) && ( ( $button_icon_position ) != 'right' || ( $button_hover_style ) == 'style1' ) ) { ?>
				<span class="icon" 
				<?php
				if ( strlen( $button_icon_position ) ) {
					?>
					 data-float="<?php echo esc_attr( $button_icon_position ); ?>" <?php } ?> data-hover="icon-<?php echo esc_attr( $button_icon ); ?>">
					<span class="firsticon glyph icon-<?php echo esc_attr( $button_icon ); ?>"></span>
					<span class="hovericon glyph icon-<?php echo esc_attr( $button_icon ); ?>"></span>                
				</span>
			<?php } ?>
		
		<span class="txt" data-hover="<?php echo esc_attr( $btntext ); ?>">
				<?php echo esc_html( $btntext ); ?>
			</span>

		<?php if ( strlen( $button_icon ) && ( $button_icon_position ) == 'right' ) { ?>
				<span class="icon" 
				<?php
				if ( strlen( $button_icon_position ) ) {
					?>
					 data-float="<?php echo esc_attr( $button_icon_position ); ?>" <?php } ?> data-hover="icon-<?php echo esc_attr( $button_icon ); ?>">
					<span class="firsticon glyph icon-<?php echo esc_attr( $button_icon ); ?>"></span>
					<span class="hovericon glyph icon-<?php echo esc_attr( $button_icon ); ?>"></span>
				</span>
			<?php } ?>

		</a>
		<div class="clearfix"></div>
		
	<?php if ( $alignment == 'center' ) { ?>
		</div>
	<?php } ?>
	<?php if ( ( $button_hover_style == 'link_style' ) && ( $button_display == 'full' ) ) { ?>
		</div>
	<?php } ?>
	
	 </div>
	 <?php if ( $position == 'row' ) { ?>
		</div>
	<?php } ?>
	<?php
	return ob_get_clean();
}


/*-----------------------------------------------------------------------------------*/
/*  VC Toggle Counter Box
/*-----------------------------------------------------------------------------------*/

function kite_sc_vctoggle( $atts, $content = null ) {
	extract(
		shortcode_atts(
			array(
				'title' => '',
				'open'  => 'false',
				'style' => '',
				'color' => 'disable',
			),
			$atts
		)
	);

	$id = kite_sc_id( 'vc_toggle' );

	ob_start();
	?>
	 

	<div class="toggle_wrap 
	<?php
	if ( $open == 'true' ) {
		?>
		 wpb_toggle_open  
		 <?php
	} echo esc_attr( $style );
	if ( $color != 'disable' ) {
		echo ' hasbg ';}
	?>
								">
		<div class="wpb_toggle
		<?php
		if ( $open == 'true' ) {
			?>
			 wpb_toggle_title_active<?php } ?>">
			<div class="border-bottom">
				<div class="icon icon-plus"></div>
				<div class="icon icon-minus"></div>
				<div class="title"><?php echo esc_html( $title ); ?></div>
			</div>
		</div>
		<div class="toggle_content_wrap">
			<div class="wpb_toggle_content" 
			<?php
			if ( $open == 'true' ) {
				?>
				 style="display: block;"  <?php } ?>>
				<?php echo wpb_js_remove_wpautop( $content ); ?>
			</div>
		</div>
	</div>

	<?php
	return ob_get_clean();
}

/*-----------------------------------------------------------------------------------*/
/*  VC carousel
/*-----------------------------------------------------------------------------------*/

function kite_sc_imagecarousel( $atts, $content = null ) {
	extract(
		shortcode_atts(
			array(
				'nav_style'            => 'dark',
				'images'               => '',
				'hover_color'          => 'c0392b',
				'custom_hover_color'   => '',
				'visible_items'        => '1',
				'image_size'           => 'full',
				'image_size_width'     => '',
				'image_size_height'    => '',
				'image_size_crop'      => '',
				'zoom'                 => '',
				'gutter'               => '',
				'naxt_prev_btn'        => 'show',
				'enterance_animation'  => 'fadein',
				'responsive_animation' => 'disable',
				'is_autoplay'          => 'on',
			),
			$atts
		)
	);

	$id = kite_sc_id( 'image_carousel' );

	$gutter = ( $gutter == 'no' ? 'no-gutter' : '' );

	// Make an array of image IDs
	$image_ids = array();
	if ( $images ) {
		$image_ids = explode( ',', esc_attr( $images ) );
	}

	ob_start();

	if ( $hover_color != 'c0392b' ) {

		$color = 'c0392b';
		if ( isset( $hover_color ) ) {
			if ( $hover_color != 'custom' ) {
				$color = '#' . $hover_color;
			} else {
				if ( isset( $custom_hover_color ) ) {
					$color = $custom_hover_color;
				}
			}
		}

		$kiteInlineStyle = "#$id.carousel .swiper-slide .image-container:before{background-color:$color;}";
		wp_add_inline_style( 'kite-inline-style', $kiteInlineStyle );
	}
	?>

	<div id="<?php echo esc_attr( $id ); ?>" class="carousel 
						<?php
						if ( $enterance_animation != 'default' ) {
							echo 'has-animation';
							if ( $responsive_animation != '' ) {
								echo ' no-responsive-animation';}
						}
						?>
			  <?php echo esc_attr( $enterance_animation ); ?> <?php echo esc_attr( $gutter ); ?> <?php
				if ( strlen( $nav_style ) ) {
							 echo esc_attr( $nav_style ); }
				?>
			  <?php echo esc_attr( $zoom != '' ? 'zoom-hover' : '' ); ?>" data-id="<?php echo esc_attr( $id ); ?>"   data-autoplay="<?php echo esc_attr( $is_autoplay ); ?>" >
		<div class="swiper-container swiper-container<?php echo esc_attr( $id ); ?> clearfix"  data-visibleitems="
																<?php
																if ( strlen( $visible_items ) ) {
																	echo esc_attr( $visible_items ); }
																?>
			">
			<div class="swiper-wrapper">
				<?php
				foreach ( $image_ids as $image_id ) {
					$image_url = wp_get_attachment_image_src( $image_id, $image_size );
					if ( ! is_array( $image_url ) ) {
						$image_url[0] = $image_url;
						$image_url[1] = 'auto';
						$image_url[2] = 'auto';
					}
					
					if ( ! function_exists( 'aq_resize' ) && $image_size == 'custom' ) {
						$image_size = 'full';
					}

					if ( $image_size == 'custom' && $image_size_width != '' && $image_size_height != '' ) {
						if ( $image_size_crop == 'yes' ) {
								$image_size_crop = true;
						} else {
							$image_size_crop = false;
						}

							$image_link = aq_resize( $image_url[0], $image_size_width, $image_size_height, $image_size_crop, false, true );
						if ( $image_link ) {
							$image_url = $image_link;
						}
					}
					$image = '<img src="data:image/gif;base64,R0lGODlhAQABAAAAACH5BAEKAAEALAAAAAABAAEAAAICTAEAOw==" width="' . esc_attr( $image_url[1] ) . '" height="' . esc_attr( $image_url[2] ) . '" data-src="' . esc_url( $image_url[0] ) . '" alt="carousel_image' . esc_attr( $image_id ) . '">';
					?>

					<div class="swiper-slide carousel_item">
						<div class="image-container lazy-load lazy-load-on-load" style="padding-top:<?php echo kite_get_height_percentage( $image ); ?>%">
						<?php
						// sanitization performed in above lines!
						echo '' . $image;
						?>
						</div>
					</div>

				<?php } ?>

			</div>
		</div>

		<?php if ( $naxt_prev_btn == 'show' ) { ?>

		<!-- Next Arrows -->
		<div class="arrows-button-next no-select"></div>

		<!-- Prev Arrows -->
		<div class="arrows-button-prev no-select"></div>

		<?php } ?>

	</div>

	<?php

	return ob_get_clean();
}

/*-----------------------------------------------------------------------------------*/
/*  Showcase
/*-----------------------------------------------------------------------------------*/

function kite_sc_showcase( $atts, $content ) {
	extract(
		shortcode_atts(
			array(

				'title'       => '',
				'subtitle'    => '',
				'nextsection' => 'show',
				'bg_effect'   => 'kunburn',
				'direction'   => 'left-align',
				'style'       => 'dark',
				'hover_color' => '',
				'overlay'     => 'show',
			),
			$atts
		)
	);

	$id = kite_sc_id( 'showcase' );

	$GLOBALS['showcase_bgs']    = array();// Set/Reset
	$GLOBALS['showcase_titles'] = array();// Set/Reset

	$hasStyle = '' != $hover_color;

	ob_start();
	$allowed_html    = kite_allowed_tags();
	$kiteInlineStyle = '';
	if ( $hasStyle ) {
		if ( strlen( esc_attr( $hover_color ) ) ) {

			$kiteInlineStyle .= "#$id.showcase .item-list .active span,";
			$kiteInlineStyle .= "#$id.showcase .item-list li:hover span";
			$kiteInlineStyle .= "{color:$hover_color;}";
		}
	}//if($hasStyle)
	wp_add_inline_style( 'kite-inline-style', $kiteInlineStyle );

	$child_content = do_shortcode( $content );

	if ( isset( $GLOBALS['showcase_bgs'][0] ) ) {
		$GLOBALS['showcase_bgs'][0] = preg_replace( '/showcase-bg/', 'showcase-bg active firstactive', $GLOBALS['showcase_bgs'][0], 1 );
	}

	?>

<div id="<?php echo esc_attr( $id ); ?>" class="showcase <?php echo esc_attr( $direction ) . ' ' . esc_attr( $style ) . ' ' . esc_attr( $bg_effect ); ?> " data-effect="<?php echo esc_attr( $bg_effect ); ?>">
	<div class="showcase-backgrounds<?php echo esc_attr( $bg_effect == 'interactive_background' ) ? ' interactive-background-image' : ''; ?>">
		<?php
		if ( esc_attr( $overlay ) == 'show' ) {
			?>

		<div class="overlay"></div>

			<?php
		}
		?>

		<div class="overlay-mobile"></div>

		<?php
		foreach ( $GLOBALS['showcase_bgs'] as $bg ) {
			echo '' . $bg; // showcase_bgs performed before
		}
		?>
	</div>
	<div class="showcase-content-container">
		<div class="container showcase-content-wrapper">

			 <div class="row">
				<div class="span4 showcase-title">
					<h3>
						<?php echo wp_kses( $title, $allowed_html ); ?>
						<span class="showcase_subtitle"><?php echo esc_html( $subtitle ); ?></span>
					</h3>
				</div>
			</div>
			<div class="row">
				<div class="span4 showcase-nav">
					
					<ul class="item-list">

						<?php
						foreach ( $GLOBALS['showcase_titles'] as $showcase_title_html ) {
							echo '' . $showcase_title_html;
						}
						?>

					</ul>
				</div>
				<div class="span5 showcase-items">
					<?php echo '' . $child_content; ?>
				</div>
			</div>
		</div>

		<?php
		if ( esc_attr( $nextsection ) == 'show' ) {
			?>
		<div class="container container-next-showcase">
			<span class="next-showcase">
				<a href="<?php echo esc_url( '#' ); ?>" title="<?php esc_attr_e( 'NEXT', 'pinkmart' ); ?>"></a>
			</span>
		</div>
			<?php
		}
		?>
	</div>
</div>


	<?php
	return ob_get_clean();
}

/*-----------------------------------------------------------------------------------*/
/*  Showcase Items
/*-----------------------------------------------------------------------------------*/

function kite_sc_showcase_item( $atts ) {
	extract(
		shortcode_atts(
			array(

				'button_text' => '',
				'title'       => '',
				'subtitle'    => '',
				'text'        => '',
				'text_bg'     => 'hide',
				'bg'          => '',
				'images'      => '',
				'outer_link'  => '',
				'elementor'   => false,
				'new_tab'     => false,
				'link_title'  => '',

			),
			$atts
		)
	);
	if ( isset( $_REQUEST['action'] ) && $_REQUEST['action'] == 'vc_load_shortcode' ) {
		$id = kite_sc_ss_id( 'showcase-item' );
	} else {
		$id = kite_sc_id( 'showcase-item' );
	}

	// Make an array of image IDs
	$image_ids = array();
	if ( $images ) {
		$image_ids = explode( ',', esc_attr( $images ) );
	}

	// get background image
	$image_url                  = wp_get_attachment_url( esc_attr( $bg ), 'large' );
	$GLOBALS['showcase_bgs'][] .= '<div data-bg-id="' . esc_attr( $id ) . '" class="showcase-bg ' . esc_attr( $id ) . '" style="background-image:url(' . esc_url( $image_url ) . ')" ></div>';

	// get the title
	$GLOBALS['showcase_titles'][] .= '<li class="' . esc_attr( $id ) . '" data-bg-id="' . esc_attr( $id ) . '"><span data-hover="' . esc_attr( $title ) . ' ">' . esc_attr( $title ) . '</span></li>';

	ob_start();
	$allowed_html = kite_allowed_tags();
	?>
	<div class="showcase-item <?php echo esc_attr( $id ); ?>" data-bg-id="<?php echo esc_attr( $id ); ?>">
		<input type="hidden" name="id" value="<?php echo esc_attr( $id ); ?>">
		<input type="hidden" name="bg" value="<?php echo esc_url( $image_url ); ?>">
		<input type="hidden" name="title" value="<?php echo esc_attr( $title ); ?>">
		<div class="item-content 
		<?php
		if ( esc_attr( $text_bg ) == 'show' ) {
			echo 'text_bg'; }
		?>
			">
			<span class="showcase_item_subtitle"><?php echo esc_html( $subtitle ); ?></span>
			<p><?php echo wp_kses( $text, $allowed_html ); ?></p>
		</div>
		<?php
		if ( ! empty( $image_ids ) ) {
			?>
			<div class="item-pics  
			<?php
			if ( esc_attr( $text_bg ) == 'show' ) {
				echo 'had_text_bg'; }
			?>
				">
				<div class="swiper-container">
					<div class="swiper-wrapper kt_lightgallery">
					<?php
					foreach ( $image_ids as $image_id ) {
						$image_url           = wp_get_attachment_url( $image_id );
						$image_thumbnail_url = wp_get_attachment_image_src( $image_id, 'thumbnail' );
						?>
							<div class="swiper-slide ">
						<?php echo '<a href="' . esc_url( $image_url ) . '" class="galleryitem"><img alt="' . ( get_the_title( attachment_url_to_postid( $image_thumbnail_url[0] ) ) ? get_the_title( attachment_url_to_postid( $image_thumbnail_url[0] ) ) : '' ) . '" src="' . esc_url( $image_thumbnail_url[0] ) . '" /></a>'; ?>
							</div>
						<?php
					}
					?>
					</div>
				</div>
				<div class="swiper-button-next"></div>
				<div class="swiper-button-prev"></div>
			</div>
			<?php
		}
		$link = array();
		if ( strlen( $outer_link ) && function_exists( 'vc_build_link' ) && ! $elementor ) {
			$link = vc_build_link( $outer_link );

		} elseif ( $elementor && $outer_link ) {
			$link['url'] = $outer_link;
			if ( $new_tab ) {
				$link['target'] = '_blank';
			} else {
				$link['target'] = '_self';
			}
			$link['title'] = $link_title;
		}
		if ( isset( $link['url'] ) && strlen( $link['url'] ) ) {
			?>
			<a href="<?php echo esc_url( $link['url'] ); ?>" 
								<?php
								if ( $link['target'] != '' ) {
									?>
				target="<?php echo esc_attr( $link['target'] ); ?>"<?php } ?> class="showcase-link" title="<?php echo esc_attr( $link['title'] ); ?>"><?php echo esc_html( $link['title'] ); ?></a>
			<?php
		}
		?>
	</div>
	<?php
	return ob_get_clean();
}

/*-----------------------------------------------------------------------------------*/
/*  Portfolio
/*-----------------------------------------------------------------------------------*/

function kite_sc_portfolio( $atts ) {
	extract(
		shortcode_atts(
			array(
				'type'                        => 'portfolio_space',
				'title_bar'                   => 'show',
				'title_text'                  => '',
				'subtitle_text'               => '',
				'portfolio_filter'            => 'all',
				'filters'                     => '',
				'filter_display'              => 'show',
				'filter_style'                => 'standard',
				'filter_loadmore_style'       => 'darkstyle',
				'filter_toggle_state'         => 'close',
				'portfolio_posts_page'        => '12',
				'enterance_animation'         => 'fadein',
				'responsive_animation'        => 'disable',
				'portfolio_hover'             => 'creativetype',
				'portfolio_hover_style'       => 'lightstyle',
				'portfolio_hover_like_button' => 'show',
				'portfolio_masonry'           => 'perfectMasonry',
			),
			$atts
		)
	);

	$id = kite_sc_id( 'portfolio' );

	$portolio_type = $type;
	$title         = $title_text;
	$subTitle      = $subtitle_text;

	$pDajax = false;

	$portfolioId   = $id;
	$id            = str_replace( 'portfolio_', '', $id );
	$portfolioLoop = 'pLoop_' . $id;
	$ploadmore     = 'ploadmore_' . $id;
	$pagedNum      = 'paged_' . $id;

	$catArr = array();

	$portfolioItemNumber = 0;
	// get Portfolio Skills if there is no selected skills
	if ( $portfolio_filter == 'all' ) {
		$args = array(
			'fields' => 'ids',
		);

		$filters             = get_terms( 'skills', $args );
		$catArr              = $filters;
		$portfolioItemNumber = wp_count_posts( 'portfolio' )->publish;
	} else {
		$catArr = explode( ',', $filters );

		$args                = array(
			'fields'         => 'ids', // we don't really need all post data so just id wil do fine.
			'posts_per_page' => -1, // -1 to get all post
			'post_type'      => 'portfolio',
			'tax_query'      => array(
				array(
					'taxonomy' => 'skills',
					'field'    => 'slug',
					'terms'    => $catArr,
				),
			),
		);
		$ps                  = get_posts( $args );
		$portfolioItemNumber = count( $ps );

		$args = array(
			'fields' => 'ids',
			'slug'   => $catArr,
		);

		$filters = get_terms( 'skills', $args );

	}

	if ( count( $catArr ) == 0 || count( $catArr ) > 1 ) {
		if ( $portfolio_filter == 'all' ) {
			// Generate All Filter Taxonomy
			$listCatsArgs = array(
				'title_li' => '',
				'taxonomy' => 'skills',
				'walker'   => new Kite_Portfolio_Walker(),
				'echo'     => 0,
				'include'  => '',
			);
		} else {
			 // Generate  Selected Taxonomy
			$listCatsArgs = array(
				'title_li' => '',
				'taxonomy' => 'skills',
				'walker'   => new Kite_Portfolio_Walker(),
				'echo'     => 0,
				'include'  => implode( ',', $filters ),
			);
		}

		$catList  = '<li class="current"><span class="filter_item active" data-filter="*" >' . esc_html__( 'All', 'pinkmart' ) . '<span class="filterline"></span><span class="post-count">' . sprintf( '%02d', $portfolioItemNumber ) . '</span></span></li>';
		$catList .= wp_list_categories( $listCatsArgs );
	}

	if ( $portfolio_filter == 'custom' ) {

		$portfolio_skills = array();
		$cat_args         = array(
			'orderby'    => 'term_id',
			'order'      => 'ASC',
			'hide_empty' => false,
			'slug'       => $catArr,
		);

		$terms = get_terms( 'skills', $cat_args );
		foreach ( $terms as $taxonomy ) {
			 $portfolio_skills[] = $taxonomy->term_id;
		}

		// Add some parameters for the JS - portfolio load more .
		$queryArgs = array(
			'post_type'      => 'portfolio', // post type, I used 'product'
			'post_status'    => 'publish', // just tried to find all published post
			'posts_per_page' => -1,
			'fields'         => 'ids',
			'pageVar'        => 'list1',
			'tax_query'      => array(
				array(
					'taxonomy' => 'skills',
					'terms'    => $portfolio_skills,
				),
			),
		);

	} else {

		// Add some parameters for the JS - portfolio load more .
		$queryArgs = array(
			'post_type'      => 'portfolio', // post type, I used 'product'
			'post_status'    => 'publish', // just tried to find all published post
			'posts_per_page' => -1,
			'fields'         => 'ids',
			'pageVar'        => 'list1',
		);
	}

	$query      = new WP_Query( $queryArgs );
	$ppaged     = ( get_query_var( 'paged' ) > 1 ) ? get_query_var( 'paged' ) : 1;
	$pMax       = $query->max_num_pages;
	$countPosts = $query->found_posts;
	$maxPages   = ceil( $countPosts / $portfolio_posts_page );
	wp_reset_postdata();
	ob_start();

	?>

	<!-- Portfolio Section  -->
	<div id="<?php echo esc_attr( $portfolioId ); ?>" data-portfolio-type="<?php echo esc_attr( $type ); ?>" data-value="<?php echo esc_attr( $portfolioId ); ?>"  data-id="<?php echo esc_attr( $id ); ?>" data-startPage="<?php echo esc_attr( $ppaged ); ?>" data-maxPages="<?php echo esc_attr( $maxPages ); ?>" data-nextLink="<?php echo next_posts( $pMax, false ); ?>" class="kitesection portfoliosection <?php echo esc_attr( $filter_loadmore_style ); ?> <?php echo esc_attr( $type ); ?> <?php
	if ( $portfolio_hover_like_button == 'hide' ) {
		?>
		 hidelikebtn <?php } ?>" data-layout-style="<?php echo esc_attr( $portfolio_masonry ); ?>">

		<div  class="portfoliowrap wrap 
		<?php
		if ( ! empty( $subTitle ) ) {
			?>
			 hassubtitle <?php } ?> ">

			<div class="container title_container 
			<?php
			if ( ( $title_bar == 'show' && ! empty( $title ) && ! empty( $subTitle ) ) || $filter_display == 'show' ) {
				?>
				 portfolio_height <?php } ?> clearfix">

				<?php if ( ( ! empty( $subTitle ) || ! empty( $title ) ) || $title_bar == 'show' ) { ?>
				
						<?php if ( $title_bar == 'show' ) { ?>
							<div class="titlespace">
					
								<?php if ( ! empty( $title ) ) { ?>
								
									<div class="title"><h3><?php echo esc_html( $title ); ?></h3></div>
					
								<?php } if ( ! empty( $subTitle ) ) { ?>
						 
									<div class="subtitle"><?php echo esc_html( $subTitle ); ?></div>
						 
								<?php } ?>
						
							</div>
						<?php } ?>
						
					
				<?php } ?>
				
			</div>

			<?php
			if ( $filter_display == 'show' ) {
				if ( count( $catArr ) !== 1 ) {
					?>

					<!-- portfolio filter - desktop -->
					<div class="container title_container visible-desktop clearfix">
						<div class="portfolio-header">
						
							<ul class="filters option-set subnavigation clearfix <?php echo esc_attr( $filter_style ); ?>-style toggleclicked
																							<?php
																							if ( $filter_toggle_state == 'open' ) {
																								echo ' opentoggle'; }
																							?>
							" data-option-key="filter">

								<?php
								// Sanitized in above lines!
								echo '' . $catList;

								if ( $filter_style == 'toggle' ) {
									?>
									<li class="filtertoggle
									<?php
									if ( $filter_toggle_state == 'open' ) {
										echo ' closed'; }
									?>
									">
										<div class="togglelinecontainer">
											<span class="linebarfirst"></span>
											<span class="linebarsecond"></span>
										</div>
										<div class="filterrightline"></div>
										<div class="filterleftline"></div>
									</li>
									<?php
								}

								?>

							</ul>
						</div>
					</div>

					<!-- portfolio filter - tablet & phone -->
					<div class="hidden-desktop clearfix">
						<ul class="filterstablet responsive_filter_dropdown portfolio-filter" data-option-key="filter">
							<li class="">
								<div>
									<span class="text"><?php esc_html_e( 'All', 'pinkmart' ); ?></span>
									<span class="icon icon-angle-down"></span>
								</div>
								<ul class="portfolio-filter-items">
							<?php
							// Sanitized in above lines!
							echo '' . $catList;
							?>
								</ul>
							</li>
						</ul>
					</div>

					<?php
				}
			}
			?>
				
			<div class="portfolio_wrap">

				<!-- portfolio items  -->
				<div class="isotope 
				<?php
				echo esc_attr( $portfolio_hover ) . ' ' . esc_attr( $portfolio_hover_style ) . ' ' . esc_attr( $enterance_animation );
				if ( $responsive_animation != '' ) {
					echo ' no-responsive-animation';
				};
				?>
				" data-skills="
				<?php
				if ( $portfolio_filter == 'all' ) {
								echo 'all';
				} else {
					echo implode( ' ', $filters ); }
				?>
				">
					<div id="<?php echo esc_attr( $portfolioLoop ); ?>">

						<?php

							$paged1 = isset( $_GET[ $pagedNum ] ) ? (int) sanitize_text_field( $_GET[ $pagedNum ] ) : 1;

							$queryArgs = array(

								'post_type'      => 'portfolio',
								'posts_per_page' => $portfolio_posts_page,
								'paged'          => $paged1,
							);

							if ( $portfolio_filter == 'custom' ) {

								// Taxonomy filter
								if ( count( $catArr ) ) {

									$queryArgs['tax_query'] = array(
										// Note: tax_query expects an array of arrays!
										array(
											'taxonomy' => 'skills',
											'field'    => 'slug',
											'terms'    => $catArr,
										),
									);
								}
							}

							$count = 1;
							$query = new WP_Query( $queryArgs );

							while ( $query->have_posts() ) {

								$query->the_post();

								kite_get_template_part(
									'templates/portfolio-thumbnail',
									array(
										'$portolio_type' => $portolio_type,
										'$portfolioLoop' => $portfolioLoop,
										'$count'         => $count,
										'$portfolio_masonry' => $portfolio_masonry,
										'$pDajax '       => $pDajax,
									)
								);

								$count++;
							}

							wp_reset_postdata();

							?>
					</div>
				</div>
			</div>
			<?php

				$query = new WP_Query( $queryArgs );
			if ( $query->have_posts() ) {
				?>

					<!-- portfolio load more button -->
					<div class="ploadmore <?php echo esc_attr( $ploadmore ); ?>  clearfix">
						<div class="readmore clearfix">
							<div class="loadmore" data-id="<?php echo esc_attr( $id ); ?>">
								<span class="text load-more-text"><?php esc_html_e( 'Load more', 'pinkmart' ); ?></span>
								<span class="text loading-text"><?php esc_html_e( 'Loading...', 'pinkmart' ); ?></span>
							</div>
						</div>
					</div>

			<?php } ?>

			<?php wp_reset_postdata(); ?>

		</div>
	</div>
	<!-- End Portfolio  -->

	<?php
	return ob_get_clean();
}

/*-----------------------------------------------------------------------------------*/
/*  Portfolio inner
/*-----------------------------------------------------------------------------------*/

function kite_sc_portfolio_inner( $atts ) {
	extract(
		shortcode_atts(
			array(
				'type'                        => 'portfolio_space',
				'title_bar'                   => 'show',
				'title_text'                  => '',
				'subtitle_text'               => '',
				'portfolio_filter'            => 'all',
				'filters'                     => '',
				'filter_display'              => 'show',
				'filter_style'                => 'standard',
				'filter_loadmore_style'       => 'darkstyle',
				'filter_toggle_state'         => 'close',
				'portfolio_posts_page'        => '12',
				'enterance_animation'         => 'fadein',
				'responsive_animation'        => 'disable',
				'portfolio_hover'             => 'creativetype',
				'portfolio_hover_style'       => 'lightstyle',
				'portfolio_hover_like_button' => 'show',
				'portfolio_masonry'           => 'perfectMasonry',
			),
			$atts
		)
	);

	$id = kite_sc_id( 'portfolio' );

	$portolio_type = $type;
	$title         = $title_text;
	$subTitle      = $subtitle_text;

	$portfolioId   = $id;
	$id            = str_replace( 'portfolio_', '', $id );
	$portfolioLoop = 'pLoop_' . $id;
	$ploadmore     = 'ploadmore_' . $id;
	$pagedNum      = 'paged_' . $id;

	$pDajax = true;

	$catArr = array();

	$portfolioItemNumber = 0;
	// get Portfolio Skills if there is no selected skills
	if ( $portfolio_filter == 'all' ) {
		$args = array(
			'fields' => 'ids',
		);

		$filters             = get_terms( 'skills', $args );
		$catArr              = $filters;
		$portfolioItemNumber = wp_count_posts( 'portfolio' )->publish;
	} else {
		$catArr = explode( ',', $filters );

		$args                = array(
			'fields'         => 'ids', // we don't really need all post data so just id wil do fine.
			'posts_per_page' => -1, // -1 to get all post
			'post_type'      => 'portfolio',
			'tax_query'      => array(
				array(
					'taxonomy' => 'skills',
					'field'    => 'slug',
					'terms'    => $catArr,
				),
			),
		);
		$ps                  = get_posts( $args );
		$portfolioItemNumber = count( $ps );

		$args = array(
			'fields' => 'ids',
			'slug'   => $catArr,
		);

		$filters = get_terms( 'skills', $args );

	}

	if ( count( $catArr ) == 0 || count( $catArr ) > 1 ) {
		if ( $portfolio_filter == 'all' ) {
			// Generate All Filter Taxonomy
			$listCatsArgs = array(
				'title_li' => '',
				'taxonomy' => 'skills',
				'walker'   => new Kite_Portfolio_Walker(),
				'echo'     => 0,
				'include'  => '',
			);
		} else {
			$listCatsArgs = array(
				'title_li' => '',
				'taxonomy' => 'skills',
				'walker'   => new Kite_Portfolio_Walker(),
				'echo'     => 0,
				'include'  => implode( ',', $filters ),
			);
		}

		$catList  = '<li class="current"><span class="filter_item active" data-filter="*" >' . esc_html__( 'All', 'pinkmart' ) . '<span class="filterline"></span><span class="post-count">' . sprintf( '%02d', $portfolioItemNumber ) . '</span></span></li>';
		$catList .= wp_list_categories( $listCatsArgs );
	}

	if ( $portfolio_filter == 'custom' ) {

		$portfolio_skills = array();
		$cat_args         = array(
			'orderby'    => 'term_id',
			'order'      => 'ASC',
			'hide_empty' => false,
			'slug'       => $catArr,
		);

		$terms = get_terms( 'skills', $cat_args );
		foreach ( $terms as $taxonomy ) {
			 $portfolio_skills[] = $taxonomy->term_id;
		}

		// Add some parameters for the JS - portfolio load more .
		$queryArgs = array(
			'post_type'      => 'portfolio', // post type, I used 'product'
			'post_status'    => 'publish', // just tried to find all published post
			'posts_per_page' => -1,
			'fields'         => 'ids',
			'pageVar'        => 'list1',
			'tax_query'      => array(
				array(
					'taxonomy' => 'skills',
					'terms'    => $portfolio_skills,
				),
			),
		);

	} else {

		// Add some parameters for the JS - portfolio load more .
		$queryArgs = array(
			'post_type'      => 'portfolio', // post type, I used 'product'
			'post_status'    => 'publish', // just tried to find all published post
			'fields'         => 'ids',
			'posts_per_page' => -1,
			'pageVar'        => 'list1',
		);
	}

	$query      = new WP_Query( $queryArgs );
	$ppaged     = ( get_query_var( 'paged' ) > 1 ) ? get_query_var( 'paged' ) : 1;
	$pMax       = $query->max_num_pages;
	$countPosts = $query->post_count;
	$maxPages   = ceil( $countPosts / $portfolio_posts_page );
	wp_reset_postdata();
	ob_start();

	?>

	<!-- Portfolio Section  -->
	<div id="<?php echo esc_attr( $portfolioId ); ?>" data-portfolio-type="<?php echo esc_attr( $type ); ?>" data-value="<?php echo esc_attr( $portfolioId ); ?>" data-id="<?php echo esc_attr( $id ); ?>" data-startPage="<?php echo esc_attr( $ppaged ); ?>" data-maxPages="<?php echo esc_attr( $maxPages ); ?>" data-nextLink="<?php echo next_posts( $pMax, false ); ?>" class="kitesection portfoliosection <?php echo esc_attr( $filter_loadmore_style ); ?> <?php echo esc_attr( $type ); ?> <?php
	if ( $portfolio_hover_like_button == 'hide' ) {
		?>
		 hidelikebtn <?php } ?>">

		<div class="portfoliowrap wrap 
		<?php
		if ( ! empty( $subTitle ) ) {
			?>
			 hassubtitle <?php } ?>">

		<div class="pdwrap clearfix">

			<!-- portfolio Detail loader-->
			<div id="loader"></div>
			
			<div id="pderror"><?php esc_html_e( 'Sorry, we ran into a technical problem (unknown error). Please try again...', 'pinkmart' ); ?> </div>

			 <div class="navwrap pdnavigation">
			 
				<a href="<?php echo esc_url( '#' ); ?>" title="<?php esc_attr_e( 'NEXT', 'pinkmart' ); ?>"  class="next no_djax">
					<div class="arrows-button-next no-select">
						<span class="text">
							<?php esc_html_e( 'NEXT', 'pinkmart' ); ?>
						</span>
					</div>
				</a>
				<!-- Back to portfolio -->
				<a id="Pdcloseportfolio" class="no_djax" href="<?php echo esc_url( '#' ); ?>" title="<?php esc_attr_e( 'Back to portfolio', 'pinkmart' ); ?>">
					<div>
						<span class="backToPortfolio" data-name="grid2"></span>
					</div>
				</a>

				<!-- Prev Arrows -->
				<a href="<?php echo esc_url( '#' ); ?>" title="<?php esc_attr_e( 'PREV', 'pinkmart' ); ?>"  class="previous no_djax">
					<div class="arrows-button-prev no-select">
						<span class="text">
							<?php esc_html_e( 'PREV', 'pinkmart' ); ?>
						</span>
					</div>
				</a>

			</div>

			<!-- portfolio Detail Content -->
			<div id="portfoliodetailajax"></div>

		</div>
		
		<div class="container title_container 
		<?php
		if ( $title_bar == 'show' || $filter_display == 'show' ) {
			?>
			 portfolio_height <?php } ?> clearfix">

				<?php if ( ( ! empty( $subTitle ) || ! empty( $title ) ) || $title_bar == 'show' ) { ?>
				
					<?php if ( $title_bar == 'show' ) { ?>
						<div class="titlespace">
					
							<?php if ( ! empty( $title ) ) { ?>
								
								<div class="title"><h3><?php echo esc_html( $title ); ?></h3></div>
					
							<?php } if ( ! empty( $subTitle ) ) { ?>
						 
								<div class="subtitle"><?php echo esc_html( $subTitle ); ?></div>
						 
							<?php } ?>
						
						</div>
					<?php } ?>
					
				<?php } ?>
				
			</div>

			<?php
			if ( $filter_display == 'show' ) {
				if ( count( $catArr ) !== 1 ) {
					?>

					<!-- portfolio filter - desktop -->
					<div class="container title_container visible-desktop clearfix">
						<div class="portfolio-header">
						
							<ul class="filters option-set subnavigation clearfix <?php echo esc_attr( $filter_style ); ?>-style toggleclicked
																							<?php
																							if ( $filter_toggle_state == 'open' ) {
																								echo ' opentoggle'; }
																							?>
							" data-option-key="filter">

								<?php
								// Sanitized in above lines!
								echo '' . $catList;

								if ( $filter_style == 'toggle' ) {
									?>
									<li class="filtertoggle
									<?php
									if ( $filter_toggle_state == 'open' ) {
										echo ' closed'; }
									?>
									">
										<div class="togglelinecontainer">
											<span class="linebarfirst"></span>
											<span class="linebarsecond"></span>
										</div>
										<div class="filterrightline"></div>
										<div class="filterleftline"></div>
									</li>
									<?php
								}

								?>

							</ul>
						</div>
					</div>

					<!-- portfolio filter - tablet & phone -->
					<div class="hidden-desktop clearfix">
						<ul class="filterstablet  responsive_filter_dropdown portfolio-filter" data-option-key="filter">
							<li class="">
								<div>
									<span class="text"><?php esc_html_e( 'All', 'pinkmart' ); ?></span>
									<span class="icon icon-angle-down"></span>
								</div>
								<ul class="portfolio-filter-items">
							<?php
							// Sanitized in above lines!
							echo '' . $catList;
							?>
								</ul>
							</li>
						</ul>
					</div>

					<?php
				}
			}
			?>
				
			<div id="isotopePortfolio" class="portfolio_wrap">
				<!-- portfolio items  -->
				<div class="isotope ajaxpdetail 
				<?php
				echo esc_attr( $portfolio_hover ) . ' ' . esc_attr( $portfolio_hover_style ) . ' ' . esc_attr( $enterance_animation );
				if ( $responsive_animation != '' ) {
					echo ' no-responsive-animation';
				};
				?>
				" data-skills="
				<?php
				if ( $portfolio_filter == 'all' ) {
								echo 'all';
				} else {
					echo implode( ' ', $filters ); }
				?>
				" layout-style="<?php echo esc_attr( $portfolio_masonry ); ?>">
					<div id="<?php echo esc_attr( $portfolioLoop ); ?>" >

						<?php

							$paged1 = isset( $_GET[ $pagedNum ] ) ? (int) sanitize_text_field( $_GET[ $pagedNum ] ) : 1;

							$queryArgs = array(

								'post_type'      => 'portfolio',
								'posts_per_page' => $portfolio_posts_page,
								'paged'          => $paged1,
							);

							if ( $portfolio_filter == 'custom' ) {

								// Taxonomy filter
								if ( count( $catArr ) ) {

									$queryArgs['tax_query'] = array(
										// Note: tax_query expects an array of arrays!
										array(
											'taxonomy' => 'skills',
											'field'    => 'slug',
											'terms'    => $catArr,
										),
									);
								}
							}

							$count = 1;
							$query = new WP_Query( $queryArgs );

							while ( $query->have_posts() ) {

								$query->the_post();

								kite_get_template_part(
									'templates/portfolio-thumbnail',
									array(
										'$portolio_type' => $portolio_type,
										'$portfolioLoop' => $portfolioLoop,
										'$count'         => $count,
										'$portfolio_masonry' => $portfolio_masonry,
										'$pDajax '       => $pDajax,
									)
								);

								$count++;
							}

							wp_reset_postdata();

							?>
					</div>
				</div>
			</div>
			<?php

				$query = new WP_Query( $queryArgs );
			if ( $query->have_posts() ) {
				?>

					<!-- portfolio load more button -->
					<div class="ploadmore <?php echo esc_attr( $ploadmore ); ?>  clearfix">
						<div class="readmore clearfix">
							<div class="loadmore" data-id="<?php echo esc_attr( $id ); ?>">
								<span class="text load-more-text"><?php esc_html_e( 'Load more', 'pinkmart' ); ?></span>
								<span class="text loading-text"><?php esc_html_e( 'Loading...', 'pinkmart' ); ?></span>
							</div>
						</div>
					</div>

			<?php } ?>

			<?php wp_reset_postdata(); ?>

		</div>
	</div>
	<!-- End Portfolio  -->

	<?php
	return ob_get_clean();
}

/*-----------------------------------------------------------------------------------*/
/*  Gallery
/*-----------------------------------------------------------------------------------*/

function kite_sc_gallery( $atts ) {
	extract(
		shortcode_atts(
			array(
				'type'                        => 'portfolio_space',
				'title_bar'                   => 'show',
				'title_text'                  => '',
				'subtitle_text'               => '',
				'portfolio_filter'            => 'all',
				'filters'                     => '',
				'filter_display'              => 'show',
				'filter_style'                => 'standard',
				'filter_loadmore_style'       => 'darkstyle',
				'filter_toggle_state'         => 'close',
				'gallery_posts_page'          => '12',
				'portfolio_hover_like_button' => 'show',
				'portfolio_hover'             => 'simplegallery',
				'portfolio_hover_style'       => 'lightstyle',
				'gallery_pop_up'              => 'darkPopUp',
				'enterance_animation'         => 'fadein',
				'responsive_animation'        => 'disable',
				'animation_style'             => 'lg-fade',
				'portfolio_masonry'           => 'perfectMasonry',
				'gallery_thumbnail_display'   => true,
				'show_more_button'            => 'disable',
			),
			$atts
		)
	);

	$id = kite_sc_id( 'portfolio' );

	$portolio_type = $type;
	$title         = $title_text;

	$pDajax = false;

	$portfolioId   = $id;
	$id            = str_replace( 'portfolio_', '', $id );
	$portfolioLoop = 'pLoop_' . $id;
	$ploadmore     = 'ploadmore_' . $id;
	$pagedNum      = 'paged_' . $id;

	$catArr              = array();
	$portfolioItemNumber = 0;
	// get all of the gallery categories if there is none of them was selected
	if ( $portfolio_filter == 'all' ) {
		$args = array(
			'fields' => 'ids',
		);

		$filters             = get_terms( 'gallery_cat', $args );
		$catArr              = $filters;
		$portfolioItemNumber = wp_count_posts( 'gallery' )->publish;
	} else {
		$catArr = explode( ',', $filters );

		$args                = array(
			'fields'         => 'ids', // we don't really need all post data so just id will do fine.
			'posts_per_page' => -1, // -1 to get all post
			'post_type'      => 'gallery',
			'tax_query'      => array(
				array(
					'taxonomy' => 'gallery_cat',
					'field'    => 'slug',
					'terms'    => $catArr,
				),
			),
		);
		$ps                  = get_posts( $args );
		$portfolioItemNumber = count( $ps );

		$args = array(
			'fields' => 'ids',
			'slug'   => $catArr,
		);

		$filters = get_terms( 'gallery_cat', $args );

	}

	if ( count( $catArr ) == 0 || count( $catArr ) > 1 ) {
		if ( $portfolio_filter == 'all' ) {
			// Generate All Filter Taxonomy
			$listCatsArgs = array(
				'title_li' => '',
				'taxonomy' => 'gallery_cat',
				'walker'   => new Kite_Portfolio_Walker(),
				'echo'     => 0,
				'include'  => '',
			);
		} else {
			 // Generate  Selected Taxonomy
			$listCatsArgs = array(
				'title_li' => '',
				'taxonomy' => 'gallery_cat',
				'walker'   => new Kite_Portfolio_Walker(),
				'echo'     => 0,
				'include'  => implode( ',', $filters ),
			);
		}

		$catList  = '<li class="current"><span class="filter_item active" data-filter="*" >' . esc_html__( 'All', 'pinkmart' ) . '<span class="filterline"></span><span class="post-count">' . sprintf( '%02d', $portfolioItemNumber ) . '</span></span></li>';
		$catList .= wp_list_categories( $listCatsArgs );

	}

	if ( $portfolio_filter == 'custom' ) {

		$gallery_cats = array();
		$cat_args     = array(
			'orderby'    => 'term_id',
			'order'      => 'ASC',
			'hide_empty' => false,
			'slug'       => $catArr,
		);

		$terms = get_terms( 'gallery_cat', $cat_args );
		foreach ( $terms as $taxonomy ) {
			 $gallery_cats[] = $taxonomy->term_id;
		}

		// Add some parameters for the JS - gallery load more .
		$queryArgs = array(
			'post_type'      => 'gallery',
			'post_status'    => 'publish', // just tried to find all published post
			'posts_per_page' => -1,
			'fields'         => 'ids',
			'pageVar'        => 'list1',
			'tax_query'      => array(
				array(
					'taxonomy' => 'gallery_cat',
					'terms'    => $gallery_cats,
				),
			),
		);

	} else {

		// Add some parameters for the JS - gallery load more .
		$queryArgs = array(
			'post_type'      => 'gallery', // post type, I used 'product'
			'post_status'    => 'publish', // just tried to find all published post
			'posts_per_page' => -1,
			'fields'         => 'ids',
			'pageVar'        => 'list1',
		);
	}

	$query      = new WP_Query( $queryArgs );
	$ppaged     = ( get_query_var( 'paged' ) > 1 ) ? get_query_var( 'paged' ) : 1;
	$pMax       = $query->max_num_pages;
	$countPosts = $query->found_posts;
	$maxPages   = ceil( $countPosts / $gallery_posts_page );
	wp_reset_postdata();
	ob_start();

	?>

	<!-- gallery Section  -->
	<div id="<?php echo esc_attr( $portfolioId ); ?>" data-portfolio-type="<?php echo esc_attr( $type ); ?>" data-value="<?php echo esc_attr( $portfolioId ); ?>"  data-id="<?php echo esc_attr( $id ); ?>" data-startPage="<?php echo esc_attr( $ppaged ); ?>" data-maxPages="<?php echo esc_attr( $maxPages ); ?>" data-nextLink="<?php echo next_posts( $pMax, false ); ?>" class="kitesection portfoliosection <?php echo esc_attr( $filter_loadmore_style ); ?> <?php echo esc_attr( $type ); ?> <?php
	if ( $portfolio_hover_like_button == 'hide' ) {
		?>
		 hidelikebtn <?php } ?>" data-layout-style="<?php echo esc_attr( $portfolio_masonry ); ?>">

		<div  class="portfoliowrap wrap">

			<div class="container title_container 
			<?php
			if ( ( $title_bar == 'show' && ! empty( $title ) ) || $filter_display == 'show' ) {
				?>
				 portfolio_height <?php } ?> clearfix">

				<?php if ( ( ! empty( $title ) ) || $title_bar == 'show' ) { ?>
				
						<?php if ( $title_bar == 'show' ) { ?>
							<div class="titlespace">
					
								<?php if ( ! empty( $title ) ) { ?>
								
									<div class="title"><h3><?php echo esc_html( $title ); ?></h3></div>
									
								<?php } ?>
						
							</div>
						<?php } ?>
						
					
				<?php } ?>
				
			</div>

			<?php
			if ( $filter_display == 'show' ) {
				if ( count( $catArr ) !== 1 ) {
					?>

					<!-- gallery filter - desktop -->
					<div class="container title_container visible-desktop clearfix">
						<div class="portfolio-header">
						
							<ul class="filters option-set subnavigation clearfix <?php echo esc_attr( $filter_style ); ?>-style toggleclicked
																							<?php
																							if ( $filter_toggle_state == 'open' ) {
																								echo ' opentoggle'; }
																							?>
							" data-option-key="filter">

								<?php

								echo '' . $catList;

								if ( $filter_style == 'toggle' ) {
									?>
									<li class="filtertoggle
									<?php
									if ( $filter_toggle_state == 'open' ) {
										echo ' closed'; }
									?>
									">
										<div class="togglelinecontainer">
											<span class="linebarfirst"></span>
											<span class="linebarsecond"></span>
										</div>
										<div class="filterrightline"></div>
										<div class="filterleftline"></div>
									</li>
									<?php
								}

								?>

							</ul>
						</div>
					</div>

					<!-- gallery filter - tablet & phone -->
					<div class="hidden-desktop clearfix">
						<ul class="filterstablet responsive_filter_dropdown portfolio-filter" data-option-key="filter">
							<li class="">
								<div>
									<span class="text"><?php esc_html_e( 'All', 'pinkmart' ); ?></span>
									<span class="icon icon-angle-down"></span>
								</div>
								<ul class="portfolio-filter-items">
							<?php echo '' . $catList; ?>
								</ul>
							</li>
						</ul>
					</div>

					<?php
				}
			}
			?>
				
			<div class="portfolio_wrap">

				<!-- gallery items  -->
				<div  class="isotope 
				<?php
				echo esc_attr( $portfolio_hover ) . ' ' . esc_attr( $portfolio_hover_style ) . ' ' . esc_attr( $enterance_animation ) . ' ' . esc_attr( $gallery_pop_up );
				if ( $responsive_animation != '' ) {
					echo ' no-responsive-animation';
				};
				?>
				" data-categories="
				<?php
				if ( $portfolio_filter == 'all' ) {
								echo 'all';
				} else {
					echo implode( ' ', $filters ); }
				?>
				" data-animation-type="<?php echo esc_attr( $animation_style ); ?>" data-gallery-thumbnail="<?php echo esc_attr( $gallery_thumbnail_display ); ?>">
					<div id="<?php echo esc_attr( $portfolioLoop ); ?>" class="kt_lightgallery">

						<?php

							$paged1 = isset( $_GET[ $pagedNum ] ) ? (int) sanitize_text_field( $_GET[ $pagedNum ] ) : 1;

							$queryArgs = array(

								'post_type'      => 'gallery',
								'posts_per_page' => $gallery_posts_page,
								'paged'          => $paged1,
							);

							if ( $portfolio_filter == 'custom' ) {

								// Taxonomy filter
								if ( count( $catArr ) ) {

									$queryArgs['tax_query'] = array(
										// Note: tax_query expects an array of arrays!
										array(
											'taxonomy' => 'gallery_cat',
											'field'    => 'slug',
											'terms'    => $catArr,
										),
									);
								}
							}

							$count = 0;
							$query = new WP_Query( $queryArgs );

							while ( $query->have_posts() ) {

								$query->the_post();

								kite_get_template_part(
									'templates/gallery-thumbnail',
									array(
										'$portolio_type' => $portolio_type,
										'$portfolioLoop' => $portfolioLoop,
										'$count'         => $count,
										'$portfolio_masonry' => $portfolio_masonry,
									)
								);

								$count++;
							}

							wp_reset_postdata();

							?>
					</div>
				</div>
			</div>
			<?php

				$query = new WP_Query( $queryArgs );

			if ( $query->have_posts() && $show_more_button != 'disable' ) {
				?>

					<!-- gallery load more button -->
					<div class="ploadmore <?php echo esc_attr( $ploadmore ); ?>  clearfix">
						<div class="readmore clearfix">
							<div class="loadmore" data-id="<?php echo esc_attr( $id ); ?>">
								<span class="text load-more-text"><?php esc_html_e( 'Load more', 'pinkmart' ); ?></span>
								<span class="text loading-text"><?php esc_html_e( 'Loading...', 'pinkmart' ); ?></span>
							</div>
						</div>
					</div>

			<?php } ?>

			<?php wp_reset_postdata(); ?>

		</div>
	</div>
	<!-- End gallery  -->

	<?php
	return ob_get_clean();
}


/*-----------------------------------------------------------------------------------*/
/*  Carousel Gallery
/*-----------------------------------------------------------------------------------*/

function kite_sc_gallery_carousel( $atts, $content = null ) {
	extract(
		shortcode_atts(
			array(
				'nav_style'            => 'dark',
				'hover_color'          => 'c0392b',
				'custom_hover_color'   => '',
				'visible_items'        => '1',
				'zoom'                 => '',
				'gutter'               => '',
				'naxt_prev_btn'        => 'show',
				'enterance_animation'  => 'fadein',
				'responsive_animation' => 'disable',
				'is_autoplay'          => 'on',
				'portfolio_filter'     => 'all',
				'filters'              => '',
			),
			$atts
		)
	);

	$id     = kite_sc_id( 'image_carousel' );
	$gutter = ( $gutter == 'no' ? 'no-gutter' : '' );
	$catArr = explode( ',', $filters );

	// Add some parameters for the JS - gallery load more .
	$queryArgs = array(
		'post_type'      => 'gallery',
		'post_status'    => 'publish', // just tried to find all published post
		'posts_per_page' => -1,
		'fields'         => 'ids',
	);

	if ( $portfolio_filter == 'custom' ) {

		// Taxonomy filter
		if ( count( $catArr ) ) {

			$queryArgs['tax_query'] = array(
				// Note: tax_query expects an array of arrays!
				array(
					'taxonomy' => 'gallery_cat',
					'field'    => 'slug',
					'terms'    => $catArr,
				),
			);
		}
	}

	ob_start();

	if ( $hover_color != 'c0392b' ) {

		$color = 'c0392b';
		if ( isset( $hover_color ) ) {
			if ( $hover_color != 'custom' ) {
				$color = '#' . $hover_color;
			} else {
				if ( isset( $custom_hover_color ) ) {
					$color = $custom_hover_color;
				}
			}
		}
		$kiteInlineStyle = "#$id.carousel .swiper-slide .image-container:before{background-color:$color;}";
		wp_add_inline_style( 'kite-inline-style', $kiteInlineStyle );
	}
	?>

	<div id="<?php echo esc_attr( $id ); ?>" class="gallery_carousel carousel 
						<?php
						if ( $enterance_animation != 'default' ) {
							echo 'has-animation';
							if ( $responsive_animation != '' ) {
								echo ' no-responsive-animation';}
						}
						?>
			  <?php echo esc_attr( $enterance_animation ); ?> <?php echo esc_attr( $gutter ); ?> <?php
				if ( strlen( $nav_style ) ) {
							 echo esc_attr( $nav_style ); }
				?>
			  <?php echo esc_attr( $zoom != '' ? 'zoom-hover' : '' ); ?>" data-id="<?php echo esc_attr( $id ); ?>"   data-autoplay="<?php echo esc_attr( $is_autoplay ); ?>" >
		<div class="swiper-container swiper-container<?php echo esc_attr( $id ); ?> clearfix"  data-visibleitems="
																<?php
																if ( strlen( $visible_items ) ) {
																	echo esc_attr( $visible_items ); }
																?>
			">
			<div class="swiper-wrapper carousel_gallery" >
			
				 <?php

					$count = 0;
					$query = new WP_Query( $queryArgs );

					while ( $query->have_posts() ) {

							$query->the_post();

							$id = get_the_ID();

							// Gallery title , subtitle and gallery custom purchase link
							$galleryId               = get_the_title( $id );
							$galleryTitleSwitch      = get_post_meta( $id, 'title-bar', true );
							$galleryTitle            = get_post_meta( $id, 'title-text', true );
							$galleryExternalLink     = get_post_meta( $id, 'gallery-external-link', true );
							$galleryExternalLinkText = get_post_meta( $id, 'gallery-external-link-text', true );
							$gallerySubTitle         = get_post_meta( $id, 'subtitle-text', true );

						if ( $galleryTitleSwitch == '1' ) { // Show custom title

							$title = $galleryTitle;

							if ( $galleryExternalLink && $galleryExternalLinkText ) {
								$tilteDOM = "<h4> $galleryTitle </h4><p> $gallerySubTitle </p><p class='galleryexternalwrap'><a href='" . esc_url( $galleryExternalLink ) . "' target='_blank' class='galleryexternallink'> $galleryExternalLinkText  </a></p>";
							} else {
								$tilteDOM = "<h4> $galleryTitle </h4><p> $gallerySubTitle </p>";
							}
						} else {  // Show post type title

							$title = $galleryId;

							if ( $galleryExternalLink && $galleryExternalLinkText ) {
								$tilteDOM = "<h4> $galleryId </h4><p class='galleryexternalwrap'><a  href='" . esc_url( $galleryExternalLink ) . "' target='_blank' class='galleryexternallink'> $galleryExternalLinkText </a></p>";
							} else {
								$tilteDOM = "<h4> $galleryId </h4>";
							}
						}

							// Creating gallery thumbnail image
							$gallery_url[] = '';
							$gallery_url   = get_post_meta( $id, '_thumbnail_id', false );
						if ( ! empty( $gallery_url ) ) {
							$gallery_url = wp_get_attachment_image_src( $gallery_url[0], 'large', false );
						} else { // If we had no gallery image
							$gallery_url[0] = get_template_directory_uri() . '/assets/img/placeholders/noImage.jpg';
						}

							$image     = get_the_post_thumbnail( $id, 'large' );
							$image_url = wp_get_attachment_image_src( get_post_thumbnail_id(), 'large' );

						?>
							 


							<div class="swiper-slide carousel_item  galleryitem  postphoto"  >
								<div class="image-container">
									<a href="<?php echo esc_url( $gallery_url[0] ); ?>"  data-sub-html="<?php echo esc_attr( $tilteDOM ); ?>" data-src="<?php echo esc_url( $gallery_url[0] ); ?>" style="padding-top:<?php echo kite_get_height_percentage( $image ); ?>%"  title="<?php echo esc_attr( $title ); ?>" class="gallerycarousellink overlay thumbnail-square">
										
										<image src="<?php echo esc_url( $gallery_url[0] ); ?>"/>

										<div class="hovercontent">
											<div class="title-wrap">
												<div class="titlecontainer">
													<div class="hover-title" ><?php echo esc_html( $title ); ?></div>
												</div>
											</div>
										</div> 
									</a> 
									<div class="lazy-load lazy-load-on-load bg-lazy-load" data-src="<?php echo esc_url( $image_url[0] ); ?>" style="padding-top:<?php echo kite_get_height_percentage( $image ); ?>%">
										<a href="<?php echo esc_url( $gallery_url[0] ); ?>"></a>
									</div>
								</div>
							</div>


							<?php

							$count++;
					}

					wp_reset_postdata();
					?>

			</div>
		</div>

		<?php if ( $naxt_prev_btn == 'show' ) { ?>

		<!-- Next Arrows -->
		<div class="arrows-button-next no-select"></div>

		<!-- Prev Arrows -->
		<div class="arrows-button-prev no-select"></div>

		<?php } ?>

	</div>

	<?php

	return ob_get_clean();
}


/*-----------------------------------------------------------------------------------*/
/*  Newsletter(subscribtion form)
/*-----------------------------------------------------------------------------------*/

function kite_sc_newsletter( $atts ) {

	extract(
		shortcode_atts(
			array(
				'mail_poet_form'             => '1',
				'mail_poet_form_style'       => 'light',
				'mail_poet_form_width_style' => 'boxed',
				'mail_poet_button_style'     => 'style1',
			),
			$atts
		)
	);

	if ( ! class_exists( 'WYSIJA_NL_Widget' ) ) {
		return;
	}

	ob_start();
	?>
	<div class="kt-newsletter <?php echo esc_attr( $mail_poet_button_style ); ?> <?php echo esc_attr( $mail_poet_form_style ); ?> <?php echo esc_attr( $mail_poet_form_width_style ); ?>">
		<?php
		  $widgetNL = new WYSIJA_NL_Widget( true );
		echo '' . $widgetNL->widget(
			array(
				'form'      => esc_attr( $mail_poet_form ),
				'form_type' => 'php',
			)
		);
		?>
	</div>  
	<?php
	return ob_get_clean();
}

/*-----------------------------------------------------------------------------------*/
/*  Newsletter(subscribtion form) - v3
/*-----------------------------------------------------------------------------------*/

function kite_sc_newsletter_v3( $atts ) {

	extract(
		shortcode_atts(
			array(
				'mailpoet_form'              => '1',
				'mail_poet_form_style'       => 'light',
				'mail_poet_form_width_style' => 'boxed',
				'mail_poet_button_style'     => 'style1',
			),
			$atts
		)
	);

	if ( ! function_exists( 'mailpoet_deactivate_plugin' ) ) {
		return;
	}

	ob_start();
	?>
	<div class="kt-newsletter <?php echo esc_attr( $mail_poet_button_style ); ?> <?php echo esc_attr( $mail_poet_form_style ); ?> <?php echo esc_attr( $mail_poet_form_width_style ); ?>">
		<?php
			$widgetNL = new MailPoet\Form\Widget( true );
			$html     = '' . $widgetNL->widget(
				array(
					'form'      => esc_attr( $mailpoet_form ),
					'form_type' => 'php',
				)
			);
			$start    = strrpos( $html, '<style type=' );
			$last     = strrpos( $html, '</style>' );
		if ( $start > 0 && $last > 0 ) {
			 $found = substr( $html, $start, ( strlen( $html ) - $start ) - ( strlen( $html ) - $last ) );
			 $html  = str_replace( $found, '', $html );
			 $found = str_replace( '<style type="text/css">', '', $found );
			 $found = str_replace( '</style>', '', $found );
			 $html  = str_replace( '</style>', '', $html );
			 $html  = str_replace( '<style type="text/css">', '', $html );
			 wp_add_inline_style( 'kite-inline-style', $found );
		}
			echo '' . $html;
		?>
	</div>  
	<?php
	return ob_get_clean();
}

function kite_sc_newsletter_mailchimp ( $atts ) {
	extract(
		shortcode_atts(
			array(
				'mailchimp_form'              => '',
				'mailchimp_form_style'       => 'light',
				'mailchimp_form_width_style' => 'boxed',
				'mailchimp_button_style'     => 'style1',
			),
			$atts
		)
	);

	if( ! function_exists('mc4wp_get_forms') ) {
		return;
	}

	if ( empty( $mailchimp_form ) || $mailchimp_form == 0 ) {
		$forms  = mc4wp_get_forms();
		foreach( $forms as $form ) {
			$mailchimp_form = $form->ID;
		break;
		}
	}
	ob_start();
	?>
	<div class="kt-newsletter <?php echo esc_attr( $mailchimp_button_style ); ?> <?php echo esc_attr( $mailchimp_form_style ); ?> <?php echo esc_attr( $mailchimp_form_width_style ); ?>">
		<?php echo do_shortcode('[mc4wp_form id="' . $mailchimp_form . '"]'); ?>
	</div>  
	<?php
	return ob_get_clean();	
}
/*-----------------------------------------------------------------------------------*/
/*  Woocommerce shortcodes
/*-----------------------------------------------------------------------------------*/

	// single product 1
function kite_sc_product( $atts ) {
	$atts = shortcode_atts(
		array(
			'id'                     => '',
			'product_id'             => '',
			'sku'                    => '',
			'style'                  => 'style1',
			'columns'                => '1',
			'border'                 => 'enable',
			'image_size'             => 'shop_catalog',
			'image_size_width'       => '',
			'image_size_height'      => '',
			'image_size_crop'        => '',
			'hover_image'            => 'show',
			'countdown_activation'   => '',
			'progressbar_activation' => '',
			'quickview'              => 'enable',
			'compare'                => 'enable',
			'wishlist'               => 'enable',
			'badges'                 => 'enable',
			'hover_price'            => 'enable',
			'hover_color'            => 'c0392b',
			'custom_hover_color'     => '',
			'animation'              => 'none',
			'delay'                  => '0',
			// reset values that not related to single product shortcode
			'carousel'               => 'disable',
			'layout_mode'            => 'fitRows',
			'list_style'             => 'light',
			'enterance_animation'    => 'default',
			'responsive_animation'   => 'disable',
			'is_autoplay'            => 'off',
			'nav_style'              => 'dark',
			'gutter'                 => '',
			'product_color_scheme'   => 'light',
			'body_class'			 => '',
			'show_card_variations_desktop' 	=> true,
			'show_card_variations_tablet' 	=> true,
			'show_card_variations_mobile' 	=> true,

		),
		$atts
	);

	if ( ! kite_woocommerce_installed() ) {
		return;
	}

	if ( $atts['id'] == '' ) {
		if ( $atts['product_id'] == '' ) {
			return '';
		} else {
			$atts['id'] = $atts['product_id'];
		}
	}

	$query_args = array(
		'post_type'           => 'product',
		'post_status'         => 'publish',
		'ignore_sticky_posts' => 1,
		'posts_per_page'      => 1,
		'no_found_rows'       => 1,
		'meta_query'          => WC()->query->get_meta_query(),
	);

	if ( $atts['sku'] != '' ) {
		$query_args['meta_query'][] = array(
			'key'     => '_sku',
			'value'   => $atts['sku'],
			'compare' => '=',
		);
	}

	$query_args['p'] = $atts['id'];

	if ( $atts['image_size'] == 'custom' && $atts['image_size_width'] != '' && $atts['image_size_height'] != '' ) {
		if ( $atts['image_size_crop'] == 'yes' ) {
			$atts['image_size_crop'] = true;
		} else {
			$atts['image_size_crop'] = false;
		}

		$atts['image_size'] = array( $atts['image_size_width'], $atts['image_size_height'], $atts['image_size_crop'] );
	}

	return kite_product_loop( $query_args, $atts, 'single_product' );
}

function kite_products( $atts ) {
	$atts = shortcode_atts(
		array(
			'columns'                => '1',
			'orderby'                => 'title',
			'order'                  => 'asc',
			'ids'                    => '',
			'skus'                   => '',
			'enterance_animation'    => 'fadein',
			'responsive_animation'   => 'disable',
			'layout_mode'            => 'masonry',
			'list_style'             => 'light',
			'carousel'               => 'disable',
			'countdown_activation'   => '',
			'progressbar_activation' => '',
			'is_autoplay'            => '',
			'nav_style'              => '',
			'gutter'                 => '',
			'style'                  => 'style1',
			'border'                 => 'enable',
			'image_size'             => 'shop_catalog',
			'image_size_width'       => '',
			'image_size_height'      => '',
			'image_size_crop'        => '',
			'hover_image'            => 'show',
			'quickview'              => 'enable',
			'wishlist'               => 'enable',
			'compare'                => 'enable',
			'badges'                 => 'enable',
			'hover_price'            => 'enable',
			'hover_color'            => 'c0392b',
			'custom_hover_color'     => '',
			'animation'              => 'none',
			'delay'                  => '0',
			'product_color_scheme'   => 'light',
			'column_in_mobile'       => '1',
			'tablet_columns'         => '3',
			'body_class'			 => '',
			'show_card_variations_desktop' 	=> true,
			'show_card_variations_tablet' 	=> true,
			'show_card_variations_mobile' 	=> true,
		),
		$atts
	);

	if ( ! kite_woocommerce_installed() ) {
		return;
	}

	$query_args = array(
		'post_type'           => 'product',
		'post_status'         => 'publish',
		'ignore_sticky_posts' => 1,
		'orderby'             => $atts['orderby'],
		'order'               => $atts['order'],
		'posts_per_page'      => -1,
		'meta_query'          => WC()->query->get_meta_query(),
	);

	if ( ! empty( $atts['skus'] ) ) {
		$query_args['meta_query'][] = array(
			'key'     => '_sku',
			'value'   => array_map( 'trim', explode( ',', $atts['skus'] ) ),
			'compare' => 'IN',
		);
	}

	if ( ! empty( $atts['ids'] ) ) {
		$query_args['post__in'] = array_map( 'trim', explode( ',', $atts['ids'] ) );
	}

	if ( $atts['image_size'] == 'custom' && $atts['image_size_width'] != '' && $atts['image_size_height'] != '' ) {
		if ( $atts['image_size_crop'] == 'yes' ) {
			$atts['image_size_crop'] = true;
		} else {
			$atts['image_size_crop'] = false;
		}

		$atts['image_size'] = array( $atts['image_size_width'], $atts['image_size_height'], $atts['image_size_crop'] );
	}

	return kite_product_loop( $query_args, $atts, 'products' );
}
function kite_ajax_products_tab( $atts, $content = null ) {
	$atts = shortcode_atts(
		array(
			'position'           => 'top',
			'alignment'          => 'center',
			'style'              => 'dark',
			'shape'              => 'left',
			'active_tab_color'   => '',
			'deactive_tab_color' => '',
		),
		$atts
	);

	$classes   = array();
	$classes[] = 'vc_tta-style-' . trim( esc_attr( $atts['style'] ) );
	$classes[] = 'vc_tta-tabs-position-' . trim( esc_attr( $atts['position'] ) );
	$classes[] = 'vc_tta-o-shape-group vc_tta-shape-' . trim( esc_attr( $atts['shape'] ) );
	$classes[] = 'vc_tta-controls-align-' . trim( esc_attr( $atts['alignment'] ) );

	$tabs = array();
	preg_match_all( '/' . get_shortcode_regex() . '/', $content, $tabs );

	if ( empty( $tabs ) ) {
		return;
	}

	// Get Tab List Titles and Icons from content
	$tab_titles = array();
	$tab_icons  = array();
	foreach ( $tabs[0] as $key => $tab ) {

		$title      = array();
		$icon       = array();
		$icon_check = array();

		preg_match_all( '/tab_title=".+?(?=")"/', $tab, $title );
		if ( ! empty( $title[0] ) ) {
			$exploded_title     = explode( '"', $title[0][0] );
			$tab_titles[ $key ] = $exploded_title[1];
		} else {
			$tab_titles[ $key ] = esc_html__( 'Tab', 'pinkmart' ) . ' ' . ( $key + 1 );
		}

		preg_match_all( '/tab_icon_check=".+?(?=")"/', $tab, $icon_check );
		preg_match_all( '/tab_icon=".+?(?=")"/', $tab, $icon );
		$tab_icons[ $key ] = '';
		if ( ! empty( $icon_check[0] ) ) {
			$exploded_icon_check = explode( '"', $icon_check[0][0] );
			if ( $exploded_icon_check[1] == 'enable' ) {
				$exploded_icon = explode( '"', $icon[0][0] );
				if ( ! empty( $exploded_icon[1] ) ) {
					$tab_icons[ $key ] = $exploded_icon[1];
				}
			}
		}
	}

	if ( ! function_exists( 'kite_generate_tab_list' ) ) {
		function kite_generate_tab_list( $output, $tabs, $tab_titles, $tab_icons ) {
			$output     .= '<div class="vc_tta-tabs-container">';
				$output .= '<ul class="vc_tta-tabs-list">';
			foreach ( $tab_titles as $key => $title ) {
				$output .= "<li class='vc_tta-tab " . ( ( $key == 0 ) ? 'vc_active' : '' ) . "' data-shortcode-prop='" . kite_extract_woocommerce_shortcode_attributes( $tabs[0][ $key ] ) . "' data-tab-id='" . $key . "'><a>";
				if ( ! empty( $tab_icons[ $key ] ) ) {
						$output .= '<span class="vc_tta-icon icon icon-' . $tab_icons[ $key ] . '"></span>';
				}
						$output .= '<span class="vc_tta-title-text">' . $title . '</span>';
						$output .= '</a></li>';
			}
				$output .= '</ul>';
				$output .= '</div>';
				return $output;
		}
	}

	$first_tab = do_shortcode( $tabs[0][0] );
	$id        = kite_sc_id( 'ajax_products_tab' );
	ob_start();
	if ( ! empty( esc_attr( $atts['active_tab_color'] ) ) || ! empty( esc_attr( $atts['deactive_tab_color'] ) ) ) {
		$kiteInlineStyle = '';
		if ( ! empty( esc_attr( $atts['active_tab_color'] ) ) ) {
			$kiteInlineStyle .= '#' . $id . '.ajax_products_tab ul.vc_tta-tabs-list li.vc_active span {color:' . esc_attr( $atts['active_tab_color'] ) . ' !important;} #' . $id . '.ajax_products_tab ul.vc_tta-tabs-list li.vc_active {border-top-color:' . esc_attr( $atts['active_tab_color'] ) . ' !important;border-bottom-color:' . esc_attr( $atts['active_tab_color'] ) . ' !important;}';
		}
		if ( ! empty( esc_attr( $atts['deactive_tab_color'] ) ) ) {
			$kiteInlineStyle .= '#' . $id . '.ajax_products_tab ul.vc_tta-tabs-list li span {color:' . esc_attr( $atts['deactive_tab_color'] ) . ';}';
		}
		wp_add_inline_style( 'kite-inline-style', $kiteInlineStyle );
	}
	$output      = '<div id=' . $id . ' class="vc_tta-container ajax_products_tab" >';
		$output .= '<div class="vc_general vc_tta vc_tta-tabs ' . implode( ' ', $classes ) . '">';

	if ( esc_attr( $atts['position'] ) == 'top' ) {
		$output = kite_generate_tab_list( $output, $tabs, $tab_titles, $tab_icons );
	}
			$output             .= '<div class="vc_tta-panels-container">';
				$output         .= '<div class="vc_tta-panels" style="">';
					$output     .= '<span class="wc-loading hide"></span>';
					$output     .= '<div class="vc_tta-panel vc_active_show show vc_active" data-tab-id="0">';
						$output .= $first_tab;
					$output     .= '</div>';
				$output         .= '</div>';
			$output             .= '</div>';
	if ( esc_attr( $atts['position'] ) == 'bottom' ) {
		$output = kite_generate_tab_list( $output, $tabs, $tab_titles, $tab_icons );
	}
		$output .= '</div>';
	$output     .= '</div>';

	echo '' . $output;
	return ob_get_clean();
}
function kite_extract_woocommerce_shortcode_attributes( $woocommerce_shortcode ) {
	$defaults                   = array(
		'tab_title'              => '',
		'tab_icon_check'         => '',
		'tab_icon'               => '',
		'product_type'           => 'top_rated',
		'per_page'               => '12',
		'columns'                => '1',
		'orderby'                => 'date',
		'order'                  => 'desc',
		'category'               => '',  // Slugs
		'tags'                   => '',
		'enterance_animation'    => 'fadein',
		'responsive_animation'   => 'disable',
		'layout_mode'            => 'masonry',
		'carousel'               => 'disable',
		'countdown_activation'   => '',
		'progressbar_activation' => '',
		'is_autoplay'            => '',
		'nav_style'              => '',
		'gutter'                 => '',
		'style'                  => 'style1',
		'border'                 => 'enable',
		'image_size'             => 'shop_catalog',
		'image_size_width'       => '',
		'image_size_height'      => '',
		'image_size_crop'        => '',
		'hover_image'            => 'show',
		'quickview'              => 'enable',
		'wishlist'               => 'enable',
		'compare'                => 'enable',
		'badges'                 => 'enable',
		'hover_price'            => 'enable',
		'hover_color'            => 'c0392b',
		'custom_hover_color'     => '',
		'animation'              => 'none',
		'delay'                  => '0',
		'list_style'             => 'light',
		'product_color_scheme'   => 'light',
		'column_in_mobile'       => '1',
		'tablet_columns'         => '3',
		'body_class'			 => '',
		'show_card_variations_desktop' 	=> true,
		'show_card_variations_tablet' 	=> true,
		'show_card_variations_mobile' 	=> true,
	);
	$founded_attributes         = array();
	$woocommerce_shortcode_atts = shortcode_parse_atts( $woocommerce_shortcode );
	foreach ( $defaults as $key => $value ) {
		if ( ! array_key_exists( $key, $woocommerce_shortcode_atts ) ) {
			continue;
		}
		if ( $woocommerce_shortcode_atts[ $key ] != $value ) {
			$founded_attributes[ $key ] = $woocommerce_shortcode_atts[ $key ];
		}
	}

	return json_encode( $founded_attributes );
}
function kite_fetch_woocommerce_shortcode_dom() {
	$atts = $_GET['atts'];
	echo '<div class="vc_tta-panel vc_active_show show vc_active" data-tab-id="' . esc_attr( $_GET['tab_id'] ) . '">' . kite_woocommerce_products( $atts ) . '</div>';
	die();
}

add_action( 'wp_ajax_fetch_woocommerce_shortcode_dom', 'kite_fetch_woocommerce_shortcode_dom' );
add_action( 'wp_ajax_nopriv_fetch_woocommerce_shortcode_dom', 'kite_fetch_woocommerce_shortcode_dom' );

function kite_woocommerce_products( $atts ) {
	$atts = shortcode_atts(
		array(
			'tab_title'              => '',
			'tab_icon_check'         => '',
			'tab_icon'               => '',
			'product_type'           => 'top_rated',
			'per_page'               => '12',
			'columns'                => '1',
			'tablet_columns'         => '3',
			'orderby'                => 'date',
			'order'                  => 'desc',
			'category'               => '',  // Slugs
			'tags'                   => '',
			'enterance_animation'    => 'fadein',
			'responsive_animation'   => 'disable',
			'layout_mode'            => 'masonry',
			'carousel'               => 'disable',
			'countdown_activation'   => '',
			'progressbar_activation' => '',
			'is_autoplay'            => '',
			'nav_style'              => '',
			'gutter'                 => '',
			'style'                  => 'style1',
			'border'                 => 'enable',
			'image_size'             => 'shop_catalog',
			'image_size_width'       => '',
			'image_size_height'      => '',
			'image_size_crop'        => '',
			'hover_image'            => 'show',
			'quickview'              => 'enable',
			'wishlist'               => 'enable',
			'compare'                => 'enable',
			'badges'                 => 'enable',
			'hover_price'            => 'enable',
			'hover_color'            => 'c0392b',
			'custom_hover_color'     => '',
			'animation'              => 'none',
			'delay'                  => '0',
			'list_style'             => 'light',
			'product_color_scheme'   => 'light',
			'column_in_mobile'       => '1',
			'body_class'			 => '',
			'show_card_variations_desktop' 	=> true,
			'show_card_variations_tablet' 	=> true,
			'show_card_variations_mobile' 	=> true,
		),
		$atts
	);

	if ( ! kite_woocommerce_installed() ) {
		return;
	}

	$tax  = '';
	$term = '';
	if ( $atts['tags'] != '' ) {
		$tax  = 'product_tag';
		$term = $atts['tags'];
	}
	if ( $atts['category'] != '' ) {
		$tax  = 'product_cat';
		$term = $atts['category'];
	}

	$query_args = array(
		'post_type'           => 'product',
		'post_status'         => 'publish',
		'ignore_sticky_posts' => 1,
		'posts_per_page'      => $atts['per_page'],
		'orderby'             => $atts['orderby'],
		'order'               => $atts['order'],
	);

	if ( $atts['product_type'] == 'featured' ) {
		$query_args['tax_query'] = array(
			array(
				'taxonomy' => 'product_visibility',
				'field'    => 'name',
				'terms'    => 'featured',
			),
		);
	} elseif ( $atts['product_type'] == 'top_rated' || $atts['product_type'] == 'recent' ) {
		$query_args['meta_query'] = WC()->query->get_meta_query();
	} elseif ( $atts['product_type'] == 'best_selling' ) {
		$query_args['orderby'] = 'meta_value_num';
	} elseif ( $atts['product_type'] == 'sale' ) {
		$query_args['meta_query'] = WC()->query->get_meta_query();
		$query_args['post__in']   = array_merge( array( 0 ), wc_get_product_ids_on_sale() );
	} elseif ( $atts['product_type'] == 'deal' ) {
		$today                    = time();
		$query_args['meta_query'] = array(
			'relation' => 'AND',
			array(
				'key'     => '_sale_price_dates_from',
				'value'   => '',
				'compare' => '!=',
			),
			array(
				'key'     => '_sale_price_dates_from',
				'value'   => $today,
				'compare' => '<=',
			),
			array(
				'key'     => '_sale_price_dates_to',
				'value'   => '',
				'compare' => '!=',
			),
			array(
				'key'     => '_sale_price_dates_to',
				'value'   => $today,
				'compare' => '>=',
			),
		);
	}
	if ( $atts['category'] != '' && $atts['tags'] != '' ) {
		$query_args['tax_query'] = array(
			'relation' => 'AND',
			array(
				'taxonomy' => 'product_cat',
				'field'    => 'slug',
				'terms'    => array_map( 'sanitize_title', explode( ',', $atts['category'] ) ), // display products of the specific categories.
				'operator' => 'IN',
			),
			array(
				'taxonomy' => 'product_tag',
				'field'    => 'slug',
				'terms'    => array_map( 'sanitize_title', explode( ',', $atts['tags'] ) ), // display products of the specific tags.
				'operator' => 'IN',
			),
		);

		if ( $atts['product_type'] == 'featured' ) {
			$query_args['tax_query'] = array(
				'relation' => 'AND',
				array(
					'taxonomy' => 'product_visibility',
					'field'    => 'name',
					'terms'    => 'featured',
				),
				array(
					'taxonomy' => 'product_cat',
					'field'    => 'slug',
					'terms'    => array_map( 'sanitize_title', explode( ',', $atts['category'] ) ), // display products of the specific categories.
					'operator' => 'IN',
				),
				array(
					'taxonomy' => 'product_tag',
					'field'    => 'slug',
					'terms'    => array_map( 'sanitize_title', explode( ',', $atts['tags'] ) ), // display products of the specific tags.
					'operator' => 'IN',
				),
			);
		}
	} elseif ( $tax != '' ) {
		$query_args['tax_query'] = array(
			array(
				'taxonomy' => $tax,
				'field'    => 'slug',
				'terms'    => array_map( 'sanitize_title', explode( ',', $term ) ), // display products of the specific categories or tags.
				'operator' => 'IN',
			),
		);

		if ( $atts['product_type'] == 'featured' ) {
			$query_args['tax_query'] = array(
				'relation' => 'AND',
				array(
					'taxonomy' => 'product_visibility',
					'field'    => 'name',
					'terms'    => 'featured',
				),
				array(
					'taxonomy' => $tax,
					'field'    => 'slug',
					'terms'    => array_map( 'sanitize_title', explode( ',', $term ) ), // display products of the specific categories or tags.
					'operator' => 'IN',
				),
			);
		}
	}

	if ( $atts['image_size'] == 'custom' && $atts['image_size_width'] != '' && $atts['image_size_height'] != '' ) {
		if ( $atts['image_size_crop'] == 'yes' ) {
			$atts['image_size_crop'] = true;
		} else {
			$atts['image_size_crop'] = false;
		}

		$atts['image_size'] = array( $atts['image_size_width'], $atts['image_size_height'], $atts['image_size_crop'] );
	}

	if ( $atts['product_type'] == 'featured' ) {
		return kite_product_loop( $query_args, $atts, 'featured_products' );
	}

	if ( $atts['product_type'] == 'top_rated' ) {
		add_filter( 'posts_clauses', array( 'WC_Shortcodes', 'order_by_rating_post_clauses' ) );
		$return = kite_product_loop( $query_args, $atts, 'top_rated_products' );
		do_action( 'kite_top_rated_product_loop' );
		return $return;
	}

	if ( $atts['product_type'] == 'best_selling' ) {
		return kite_product_loop( $query_args, $atts, 'best_selling_products' );
	}

	if ( $atts['product_type'] == 'sale' ) {
		return kite_product_loop( $query_args, $atts, 'sale_products' );
	}

	if ( $atts['product_type'] == 'recent' ) {
		return kite_product_loop( $query_args, $atts, 'recent_products' );
	}

	if ( $atts['product_type'] == 'deal' ) {
		return kite_product_loop( $query_args, $atts, 'deal_products' );
	}
}

function kite_product_attribute( $atts ) {
	$atts = shortcode_atts(
		array(
			'per_page'               => '12',
			'columns'                => '4',
			'tablet_columns'         => '3',
			'orderby'                => 'date',
			'order'                  => 'desc',
			'attribute'              => '',
			'filter'                 => '',
			'enterance_animation'    => 'fadein',
			'responsive_animation'   => 'disable',
			'layout_mode'            => 'masonry',
			'list_style'             => 'light',
			'carousel'               => 'disable',
			'countdown_activation'   => '',
			'progressbar_activation' => '',
			'is_autoplay'            => '',
			'nav_style'              => '',
			'gutter'                 => '',
			'style'                  => 'style1',
			'border'                 => 'enable',
			'image_size'             => 'shop_catalog',
			'image_size_width'       => '',
			'image_size_height'      => '',
			'image_size_crop'        => '',
			'hover_image'            => 'show',
			'quickview'              => 'enable',
			'wishlist'               => 'enable',
			'compare'                => 'enable',
			'badges'                 => 'enable',
			'hover_price'            => 'enable',
			'hover_color'            => '',
			'custom_hover_color'     => '',
			'animation'              => 'none',
			'delay'                  => '0',
			'body_class'			 => '',
			'show_card_variations_desktop' 	=> true,
			'show_card_variations_tablet' 	=> true,
			'show_card_variations_mobile' 	=> true,
		),
		$atts
	);

	if ( ! kite_woocommerce_installed() ) {
		return;
	}

	$query_args = array(
		'post_type'           => 'product',
		'post_status'         => 'publish',
		'ignore_sticky_posts' => 1,
		'posts_per_page'      => $atts['per_page'],
		'orderby'             => $atts['orderby'],
		'order'               => $atts['order'],
		'meta_query'          => WC()->query->get_meta_query(),
		'tax_query'           => array(
			array(
				'taxonomy' => strstr( $atts['attribute'], 'pa_' ) ? sanitize_title( $atts['attribute'] ) : 'pa_' . sanitize_title( $atts['attribute'] ),
				'terms'    => array_map( 'sanitize_title', explode( ',', $atts['filter'] ) ),
				'field'    => 'slug',
			),
		),
	);

	return kite_product_loop( $query_args, $atts, 'product_attribute' );
}

// utility fucntion to handle woocommerce loops used in woocommerce shortcodes
function kite_product_loop( $query_args, $atts, $loop_name ) {
	global $woocommerce_loop;
	$catalog_mode = kite_opt( 'catalog_mode', false );

	$products                    = new WP_Query( apply_filters( 'woocommerce_shortcode_products_query', $query_args, $atts ) );
	$columns                     = absint( $atts['columns'] );
	$woocommerce_loop['columns'] = $columns;
	$gutter                      = ( $atts['gutter'] == 'no' ? 'no-gutter' : '' );
	$nav_style                   = $atts['nav_style'];
	$carouselClass               = 'no-carousel';
	$carousel                    = 'disable';
	$autoplay                    = $atts['is_autoplay'];
	$style                       = $atts['style'];
	$border                      = $atts['border'];
	$image_size                  = $atts['image_size'];
	$image_size_width            = $atts['image_size_width'];
	$image_size_height           = $atts['image_size_height'];
	$image_size_crop             = $atts['image_size_crop'];
	$hover_image                 = $atts['hover_image'];
	$quickview                   = $atts['quickview'];
	$compare                     = $atts['compare'];
	$hover_price                 = $atts['hover_price'];
	$enterance_animation         = $atts['enterance_animation'];
	$responsive_animation        = $atts['responsive_animation'];
	$layout		                 = $atts['layout_mode'];
	$list_style                  = $atts['list_style'];
	$wishlist                    = $atts['wishlist'];
	$badges                      = $atts['badges'];
	$hover_color                 = $atts['hover_color'];
	$custom_hover_color          = $atts['custom_hover_color'];
	$animation                   = $atts['animation'];
	$delay                       = $atts['delay'];
	$countdown_activation        = $atts['countdown_activation'];
	$progressbar_activation      = $atts['progressbar_activation'];
	$body_class 				 = $atts['body_class'];
	$request_from 				 = 'widget';
	$ajax_add_to_cart 			 = get_option( 'woocommerce_enable_ajax_add_to_cart' );
	$product_rating 			 = kite_opt( 'shop-product-rating' );
	if ( ! kite_woocommerce_installed() ) {
		return;
	}

	if ( $atts['carousel'] == 'enable' && count( $products->posts ) >= $columns ) {
		$carouselClass = 'carousel';
	}
	if ( $atts['carousel'] == 'list' ) {
		$carouselClass = 'list no-carousel';
		if ( $list_style == 'dark' ) {
			$carouselClass = 'list no-carousel dark';
		}
	}

	$hover_layer = '<div class="hover_layer"></div>';
	if ( isset( $atts['hover_color'] ) ) {
		if ( $atts['hover_color'] != 'custom' && $atts['hover_color'] != '' ) {
			$hover_layer = '<div class="hover_layer" style="background-color:#' . esc_attr( $atts['hover_color'] ) . ';"></div>';
		} else {
			if ( isset( $atts['custom_hover_color'] ) && $atts['custom_hover_color'] != '' ) {
				$hover_layer = '<div class="hover_layer" style="background-color:' . esc_attr( $atts['custom_hover_color'] ) . ';"></div>';
			}
		}
	}
	
	if ( $image_size == 'custom' && $image_size_width != '' && $image_size_height != '' ) {
		if ( $image_size_crop == 'yes' ) {
			$image_size_crop = true;
		} else {
			$image_size_crop = false;
		}

		$image_size = array( $image_size_width, $image_size_height, $image_size_crop );
	}

	$product_style = '';
	if ( $atts['carousel'] == 'list' ) {

		$product_style = 'listview';
	} else {
		if ( $style == 'style1' ) {
			$product_style = 'buttonsonhover';
		} elseif ( $style == 'style1-center' ) {
			$product_style = 'buttonsonhover centered';
		} elseif ( $style == 'style2' ) {
			$product_style = 'infoonhover';
		} elseif ( $style == 'style3' ) {
			$product_style = 'infoonclick';
		} elseif ( $style == 'style4' ) {
			$product_style = 'instantshop';
		} elseif ( $style == 'buttonsappearunder' ) {
			$product_style = 'buttonsappearunder';
		}
	}
	
	$products_wrap_classes = array( 
		'kt-widget-product-loop',
		$product_style,
		'shop-' . esc_attr( $columns ) . 'column'
	);
	if ( $border == 'enable' ) {
		$products_wrap_classes[] = 'with-border';
	}
	if ( isset( $atts['column_in_mobile'] ) && $atts['column_in_mobile'] == '2' ) {
		$products_wrap_classes[] = 'column_res';
	}
	if ( ! empty( $atts['tablet_columns'] ) ) {
		$products_wrap_classes[] = 'shop-tablet-' . $atts['tablet_columns'] . 'column column_tablet' ;
	}
	ob_start();

	if ( $products->have_posts() ) :
		?>

		<?php do_action( "woocommerce_shortcode_before_{$loop_name}_loop" ); ?>

		<?php // Use <ul> tag instead of calling woocommerce_product_loop_start(); to detect WC shortcodes ?>
			<div class="products <?php echo implode( ' ', $products_wrap_classes ); ?>">
		<?php if ( $atts['carousel'] == 'enable' && count( $products->posts ) >= $columns ) { ?>

					<div class="swiper-container" data-visibleitems="<?php echo esc_attr( $columns ); ?>">
						<div class="swiper-wrapper">
			<?php
		}

		while ( $products->have_posts() ) :
			$products->the_post();

			global $product,$post;
			$classes = array();
			$devices = array( 'desktop', 'tablet', 'mobile');
			foreach ( $devices as $key => $device ) {
				if ( isset( $atts[ 'show_card_variations_' . $device ] ) && $atts[ 'show_card_variations_' . $device ] != true && $atts[ 'show_card_variations_' . $device ] !== '1' ) {
					$classes[] = 'kt-variations-off-' . $device ;
				}
			}
			if ( $atts['carousel'] == 'list' ) {
				  $classes[] = 'list_view';
			}
			if ( count( $product->get_gallery_image_ids() ) && $hover_image == 'show' ) {
				$classes[] = 'has-gallery';
			}

			if ( $border == 'enable' ) {
				$classes[] = 'with-border';
			}

			if ( $responsive_animation != '' ) {
				$class[] = 'no-responsive-animation';
			}

			if ( $countdown_activation == 'on' ) {
				$count_down = add_deal_count_down_timer( 2 );
				$classes[]    = $count_down;
			}

			if ( $progressbar_activation == 'on' ) {
				$Product_availability = kite_stock_progress_bar( 2 );
				$classes[]              = $Product_availability;
			}

			if ( isset( $atts['product_color_scheme'] ) && $atts['product_color_scheme'] == 'dark' ) {
				$classes[] = 'dark';
			}
			
			$attachment_ids = $product->get_gallery_image_ids();
			if ( ( $style == 'style1' || $style == 'style1-center' ) && $atts['carousel'] != 'list' ) {
				include locate_template( 'templates/woocommerce/product-buttons-on-hover.php', false, false );
			} elseif ( $style == 'style2' && $atts['carousel'] != 'list' ) {
				
				include locate_template( 'templates/woocommerce/product-info-on-hover.php', false, false );
			} elseif ( $style == 'style3' && $atts['carousel'] != 'list' ) {
				
				include locate_template( 'templates/woocommerce/product-info-on-click.php', false, false );

			} elseif ( $style == 'buttonsappearunder' && $atts['carousel'] != 'list' ) {
				
				include locate_template( 'templates/woocommerce/product-buttons-appear-under.php', false, false );

			} elseif ( $atts['carousel'] != 'list' ) {
				
				include locate_template( 'templates/woocommerce/product-instant-shop.php', false, false );

			} else { // If view mode is list view
				
				include locate_template( 'templates/woocommerce/product-list-view.php', false, false );

			}
		endwhile; // end of the loop.
		kite_woocommerce_shop_loop_action();
		?>
						
			<?php if ( $atts['carousel'] == 'enable' && count( $products->posts ) >= $columns ) { ?>
					</div>
				</div>
			
				<div class="arrows-button-next"></div>
				<div class="arrows-button-prev"></div>
			<?php } ?>

			</div>
			<?php // Use </ul> tag instead of calling woocommerce_product_loop_end(); to detect WC shortcodes ?>

			<?php do_action( "woocommerce_shortcode_after_{$loop_name}_loop" ); ?>

		<?php
	endif;

	woocommerce_reset_loop();
	wp_reset_postdata();

	$animation_class = '';
	if ( $animation != 'none' ) {
		$animation_class = ' shortcodeanimation';
	}

	if ( $responsive_animation != '' ) {
		$animation_class .= ' no-responsive-animation';
	}

	return '<div class="woocommerce wc-shortcode ' . $body_class . esc_attr( $gutter ) . ' ' . ( $enterance_animation != 'default' ? esc_attr( $enterance_animation ) : '' ) . ' ' . ( $atts['carousel'] == 'enable' && count( $products->posts ) >= $columns ) . ' ' . esc_attr( $carouselClass . $animation_class . ' ' . $nav_style ) . '"' . ' data-layoutMode="' . esc_attr( $layout ) . '" ' . ( $autoplay == 'on' ? 'data-autoplay="on"' : '' ) . ( strlen( esc_attr( $animation ) ) ? ' data-delay="' . esc_attr( $delay ) . '" data-animation="' . esc_attr( $animation ) : '' ) . '">' . ob_get_clean() . '</div>';
}


	// Product categories
function kite_product_categories( $atts ) {
	global $woocommerce_loop;

	$atts = shortcode_atts(
		array(
			'number'                  => null,
			'orderby'                 => 'name',
			'order'                   => 'ASC',
			'carousel'                => 'disable',
			'columns'                 => '1',
			'nav_style'               => 'light',
			'show_image'              => 1,
			'product-category-styles' => 'style-1',
			'font_type'               => 'default',
			'google_fonts'            => '',
			'font_size'               => '16',
			'carouselClass'           => '',
			'is_autoplay'             => 'off',
			'image_size'              => 'shop_catalog',
			'image_size_width'        => '',
			'image_size_height'       => '',
			'image_size_crop'         => '',
			'hide_empty'              => 1,
			'parent'                  => '',
			'ids'                     => '',
			'border'                  => '',
			'gutter'                  => '',
			'count'                   => '',
			'description'             => 'enable',
			'hover_color'             => 'c0392b',
			'custom_hover_color'      => '',
			'style'                   => '#333',
			'hover_animation'         => 'enable',
			'enterance_animation'     => 'fadein',
			'responsive_animation'    => 'disable',
			'hover_text_color'        => '#333',
			'elementor'               => '',
			'body_class'			 => '',
		),
		$atts
	);

	extract( $atts );
	if ( ! kite_woocommerce_installed() ) {
		return;
	}
	ob_start();
	
	$google_fonts_inline_style = '';

	if ( $font_type != 'default' && $elementor == '' && function_exists( 'kite_get_fonts_data' ) ) {
		$google_fonts_data         = kite_get_fonts_data( $google_fonts );
		$google_fonts_inline_style = kite_google_fonts_styles( $google_fonts_data );
		kite_enqueue_google_fonts( $google_fonts_data );
	}

	$product_category_styles = $atts['product-category-styles'];
	$nav_style               = $atts['nav_style'];
	$carouselClass           = 'no-carousel';
	$carousel                = $atts['carousel'];
	$autoplay                = $atts['is_autoplay'];
	$id                      = kite_sc_id( 'wc_shortcode_category_setting' );

	if ( $carousel == 'enable' ) {
		$carouselClass = 'carousel';
	}
	if ( $carousel == 'list' ) {
		$carouselClass = 'list no-carousel';
	}
	$gutter = ( $gutter == 'no' ? 'no-gutter' : '' );

	if ( isset( $ids ) ) {
		$ids = explode( ',', $ids );
		$ids = array_map( 'trim', $ids );
	} else {
		$ids = array();
	}

	$hide_empty = ( $hide_empty == true || $hide_empty == 1 ) ? 1 : 0;

	// get terms and workaround WP bug with parents/pad counts
	$args = array(
		'orderby'    => $orderby,
		'order'      => $order,
		'hide_empty' => $hide_empty,
		'include'    => $ids,
		'pad_counts' => true,
		'child_of'   => $parent,
	);

	$product_categories = get_terms( 'product_cat', $args );

	if ( is_wp_error( $product_categories ) ) {
		return;
	}

	if ( '' !== $parent ) {
		$product_categories = wp_list_filter( $product_categories, array( 'parent' => $parent ) );
	}

	if ( $hide_empty ) {
		foreach ( $product_categories as $key => $category ) {
			if ( $category->count == 0 ) {
				unset( $product_categories[ $key ] );
			}
		}
	}

	if ( $number ) {
		$product_categories = array_slice( $product_categories, 0, $number );
	}

	$columns                     = absint( $columns );
	$woocommerce_loop['columns'] = $columns;

	$class = array();
	if ( $enterance_animation != 'default' ) {
		$class[] = 'shortcodeanimation ';

		if ( $responsive_animation != '' ) {
			$class[] = 'no-responsive-animation';
		}
	}
	if ( $show_image != 1 && $carousel == 'list' ) {
		$class[] = 'no-image ';
	}

	$color = 'c0392b';
	if ( isset( $hover_color ) ) {
		if ( $hover_color != 'custom' ) {
			$color = '#' . $hover_color;
		} else {
			if ( isset( $custom_hover_color ) ) {
				$color = $custom_hover_color;
			}
		}
	}
	if ( $carousel == 'list' ) {
		$image_size = 'shop_thumbnail';
	}

	if ( $image_size == 'custom' && $image_size_width != '' && $image_size_height != '' ) {
		if ( $image_size_crop == 'yes' ) {
			$image_size_crop = true;
		} else {
			$image_size_crop = false;
		}

		$image_size = array( $image_size_width, $image_size_height, $image_size_crop );
	} else {
		$image_size = esc_attr( $image_size );
	}

	// Reset loop/columns globals when starting a new loop
	$woocommerce_loop['loop'] = $woocommerce_loop['column'] = '';

	$category_style = '';
	if ( $product_categories ) {

		// Use <ul> tag instead of calling woocommerce_product_loop_start(); to detect WC shortcodes
		?>
			<div class="products <?php echo 'shop-' . esc_attr( $columns ) . 'column'; ?>">
			<?php if ( $atts['carousel'] == 'enable' ) { ?>
				<div class="swiper-container" data-visibleitems="<?php echo esc_attr( $columns ); ?>">
					<div class="swiper-wrapper">
						<?php } ?>
		   

			<?php
			$hover_color = $color;
			$font_family = $google_fonts_inline_style;
			foreach ( $product_categories as $category ) {
				
				include locate_template( 'woocommerce/content-product_cat.php', false, false );
				
			}
			if ( $product_category_styles == 'style-2' ) {
				$category_style = 'style2';
			} elseif ( $product_category_styles == 'style-3' ) {
				$category_style = 'style3';
			}
			?>
			<?php if ( $carousel == 'enable' ) { ?>
				</div>
				</div>
				<div class="arrows-button-next"></div>
				<div class="arrows-button-prev"></div>
			<?php } ?>
			</div>
			<?php
			// Use </ul> tag instead of calling woocommerce_product_loop_end(); to detect WC shortcodes
	}

	woocommerce_reset_loop();

	if ( ( $carousel == 'enable' ) || ( $atts['enterance_animation'] != 'default' ) ) {
		$body_class .= ' wc-shortcode';
	}

	return '<div class="woocommerce wc-categories ' . $body_class . ' ' . ( $atts['enterance_animation'] != 'default' ? esc_attr( $enterance_animation ) : '' ) . ' ' . esc_attr( $carouselClass ) . ' ' . esc_attr( $category_style ) . ' ' . esc_attr( $nav_style ) . ' ' . esc_attr( $gutter . ' ' . implode( ' ', $class ) ) . ' ' . ( $hover_animation == 'enable' ? '' : 'nohoveranimation' ) . '"  ' . ( $autoplay == 'on' ? 'data-autoplay="on"' : '' ) . ( strlen( esc_attr( $enterance_animation ) ) ? 'data-animation="' . esc_attr( $enterance_animation ) : '' ) . '">' . ob_get_clean() . '</div>';
}


function kite_product_page( $atts ) {
	if ( ! kite_woocommerce_installed() ) {
		return;
	}

	if ( empty( $atts ) ) {
		return '';
	}
	if ( isset( $atts['product_id'] ) ) {
		$atts['id'] = $atts['product_id'];
	}
	if ( ! isset( $atts['id'] ) && ! isset( $atts['sku'] ) ) {
		return '';
	}

	$args = array(
		'posts_per_page'      => 1,
		'post_type'           => 'product',
		'post_status'         => 'publish',
		'ignore_sticky_posts' => 1,
		'no_found_rows'       => 1,
	);

	if ( isset( $atts['sku'] ) ) {
		$args['meta_query'][] = array(
			'key'     => '_sku',
			'value'   => sanitize_text_field( $atts['sku'] ),
			'compare' => '=',
		);

		$args['post_type'] = array( 'product', 'product_variation' );
	}

	if ( isset( $atts['id'] ) ) {
		$args['p'] = absint( $atts['id'] );
	}

	$single_product = new WP_Query( $args );

	$preselected_id = '0';

	// check if sku is a variation
	if ( isset( $atts['sku'] ) && $single_product->have_posts() && $single_product->post->post_type === 'product_variation' ) {

		$variation  = new WC_Product_Variation( $single_product->post->ID );
		$attributes = $variation->get_variation_attributes();

		// set preselected id to be used by JS to provide context
		$preselected_id = $single_product->post->ID;

		// get the parent product object
		$args = array(
			'posts_per_page'      => 1,
			'post_type'           => 'product',
			'post_status'         => 'publish',
			'ignore_sticky_posts' => 1,
			'no_found_rows'       => 1,
			'p'                   => $single_product->post->post_parent,
		);

		$single_product    = new WP_Query( $args );
		$kiteInlineScript  = 'jQuery( document ).ready( function( $ ) {';
		$kiteInlineScript .= "var variations_form = $( '[data-product-page-preselected-id=" . esc_attr( $preselected_id ) . "]' ).find( 'form.variations_form' );";
		foreach ( $attributes as $attr => $value ) {
			$kiteInlineScript .= "variations_form.find( 'select[name=" . esc_attr( $attr ) . "]' ).val( '" . esc_attr( $value ) . "' );";
		}
		$kiteInlineScript .= '});';
		add_action(
			'wp_enqueue_scripts',
			function() {
				wp_add_inline_script( 'kite-custom', $kiteInlineScript, 'after' );
			},
			100
		);
	}

			// For "is_single" to always make load comments_template() for reviews.
	$single_product->is_single = true;

	ob_start();

	global $wp_query;

	// Backup query object so following loops think this is a product page.
	$previous_wp_query = $wp_query;
	$wp_query          = $single_product;

	wp_enqueue_script( 'wc-single-product' );

	while ( $single_product->have_posts() ) {
		$single_product->the_post()
		?>
			<div class="single-product" data-product-page-preselected-id="<?php echo esc_attr( $preselected_id ); ?>">
			<?php wc_get_template_part( 'content', 'single-product' ); ?>
			</div>
			<?php
	}

	// restore $previous_wp_query and reset post data.
	$wp_query = $previous_wp_query;
	wp_reset_postdata();

	/*--- Added by kite ---*/
	$classes = array();
	// Check wishlist
	if ( class_exists( 'YITH_WCWL' ) ) {
		$classes[] = 'wishlist-enable';
	}

	// Check compare
	if ( class_exists( 'YITH_Woocompare' ) ) {
		$classes[] = 'compare-enable';
	}

	// Product gallery
	if ( function_exists( 'is_woocommerce' ) ) {
		global $product;
		if ( is_product() ) {
			$attachment_ids = $product->get_gallery_image_ids();
			if ( count( $attachment_ids ) > 0 ) {
				$classes[] = 'have_gallery';
			}
		}

		$classes[] = 'shop-' . kite_opt( 'shop-column' ) . 'column';

	}

	return '<div class="woocommerce product-page-shortcode ' . implode( ' ', $classes ) . '">' . ob_get_clean() . '</div>';
}

/*-----------------------------------------------------------------------------------*/
/*  Instagram feed
/*-----------------------------------------------------------------------------------*/

function kite_sc_instgram_feed( $atts ) {
	extract(
		shortcode_atts(
			array(
				'user'                 => 'teta_cosmetic',
				'posts_count'          => '10',
				'column'               => '1',
				'image_resolution'     => 'thumbnail',
				'gutter'               => '',
				'carousel'             => 'disable',
				'naxt_prev_btn'        => 'show',
				'nav_style'            => 'light',
				'hover_color'          => '',
				'custom_hover_color'   => '',
				'like'                 => '',
				'comment'              => '',
				'enterance_animation'  => 'fadein',
				'responsive_animation' => 'disable',
				'delay'                => '0',
				'equal_height_width'   => 'enable',
			),
			$atts
		)
	);

		$id           = kite_sc_id( 'instagram_feed' );
		$ajax_request = false;
		$media_array  = kite_scrape_instagram( $user, $posts_count );

	if ( is_wp_error( $media_array ) ) {
		if ( defined( 'WP_DEBUG' ) && defined( 'WP_DEBUG_LOG' ) ) {
			error_log( print_r( $media_array, true ) );
		}

		$ajax_request = true;
	}

		$gutter = ( $gutter == 'no' ? 'no-gutter' : '' );

	if ( $posts_count < $column ) {
		$post_count = $column;
	}

		$carouselClass     = '';
		$carouselItemClass = '';
	if ( $carousel == 'enable' ) {
		$carouselClass = 'carousel instagram-carousel';

		$carouselItemClass = 'insta-media';
	}

		$color = '#c0392b';
	if ( isset( $hover_color ) ) {
		if ( $hover_color != 'custom' && $hover_color != '' ) {
			$color = '#' . $hover_color;
		} else {
			if ( isset( $custom_hover_color ) && $custom_hover_color != '' ) {
				if ( strpos( $custom_hover_color, '#' ) === false ) {
					$custom_hover_color = '#' . $custom_hover_color;
				}

				$color = $custom_hover_color;
			}
		}
	}
	if ( $ajax_request ) {
		$by_hashtag = ( substr( $user, 0, 1 ) == '#' );
		$hashtag    = $by_hashtag ? 'enable' : '';
		$data_insta = array(
			'username'   => $user,
			'resolution' => $image_resolution,
			'image_num'  => $posts_count,
			'hashtag'    => $hashtag,
			'carousel'   => $carouselItemClass,
			'like'       => $like,
			'comment'    => $comment,
		);
		$data_insta = json_encode( $data_insta );
	}
		$kiteInlineStyle = ".instagram-feed#$id .instagram-img .hover{background-color:$color;}";
		wp_add_inline_style( 'kite-inline-style', $kiteInlineStyle );
		ob_start();
	?>
		<div class="instagram-feed 
		<?php
		echo esc_attr( $enterance_animation );
		if ( $responsive_animation != '' ) {
			echo ' no-responsive-animation'; }
		?>
		 <?php
			if ( $ajax_request ) {
				echo 'insta-ajax';}
			?>
			" id="<?php echo esc_attr( $id ); ?>" data-equal-height-width="
	 <?php
		if ( $equal_height_width == 'enable' ) {
			echo 'true';
		} else {
			echo 'false';
		}
		?>
	" 
	<?php
	if ( $ajax_request ) {
		echo "data-insta='$data_insta'";}
	?>
	>

			<!-- header instagram  -->
			<div class="instagramfeed <?php echo 'column-' . esc_attr( $column ) . ' ' . esc_attr( $gutter ) . ' ' . esc_attr( $carouselClass ) . ' ' . esc_attr( $nav_style ); ?>
												 <?php
													if ( $enterance_animation != 'default' ) {
														?>
				 has-animation <?php } ?>">
				<?php
				if ( $carousel == 'enable' ) {
					?>
						<div class="swiper-container" data-visibleitems="<?php echo esc_attr( $column ); ?>">
							<div class="swiper-wrapper lazy-load-hover-container">
					<?php
				}
				$i = 1;
				if ( ! $ajax_request ) {
					foreach ( $media_array as $item ) {

						if ( $i > $posts_count ) {
							break;
						}
						$i++;

						if ( $image_resolution == 'low_resolution' || $image_resolution == 'low_resolution_crop' || $image_resolution == 'standard_resolution' || $image_resolution == 'standard_resolution_crop' ) {
							$image = $item['large'];
						} else {
							$image = $item[ $image_resolution ];
						}

						$media_tag = "<img src=\"data:image/gif;base64,R0lGODlhAQABAAAAACH5BAEKAAEALAAAAAABAAEAAAICTAEAOw==\" class=\"media\" data-src=\"{$image}\" />";

						$content  = '<div class="instagram-img ' . esc_attr( $carouselItemClass ) . ' " >';
						$content .= '<a  href="' . esc_url( $item['link'] ) . '" target="_blank">';

						$content .= '<img src="' . esc_url( $image ) . '" alt="instagram_feed"/>';

						$content .= '<div class="hover"></div>
                                <div class="content">';

						if ( $like == 'enable' ) {
							$content .= '<span class="like">' . kite_pretty_number( $item['likes'] ) . '</span>';
						}

						if ( $comment == 'enable' ) {
							$content .= '<span class="comment">' . kite_pretty_number( $item['comments'] ) . '</span>';
						}

						$content .= '</div>';

						// output media
						echo '' . $content . '</a></div>';

					}
				}

				if ( $carousel == 'enable' ) {
					?>
							</div>
						</div>
					<?php
				}

				if ( $naxt_prev_btn == 'show' ) {
					?>
					<div class="arrows-button-next"></div>
					<div class="arrows-button-prev"></div>
					<?php
				}

				?>
			</div>
		</div>

		<?php
		return ob_get_clean();
}


/*-----------------------------------------------------------------------------------*/
/*  Masonry Blog - Cart blog
/*-----------------------------------------------------------------------------------*/

function kite_sc_blog_masonry( $atts, $content = null ) {
	extract(
		shortcode_atts(
			array(
				'blog_column'                 => '3',
				'blog_category'               => '',
				'blog_post_number'            => '16',
				'blog_more_button'            => 'disable',
				'blog_foreground_color'       => 'dark',
				'blog_layout_mode'            => 'masonry',
				'blog_background_color'       => '',
				'quote_blog_background_color' => '#073B87',
				'quote_blog_text_color'       => '#fff',
				'blog_category_author'        => 'yes',
				'blog_filter'                 => 'all',
				'blog_style'                  => 'inline_interaction',
				'enterance_animation'         => 'fadein',
				'responsive_animation'        => 'disable',
				'blog_category_visibility'    => 'yes',
				'blog_multimedia_icon_style'  => 'light',
				'load_more_style'             => 'dark',
				'blog_image_size'             => 'large',
			),
			$atts
		)
	);

	$query = $width = $subStr = $col = $id = '';

	$i = 0;

	$id          = kite_sc_id( 'blog-masonry' );
	$postpage    = isset( $_GET['postpage'] ) ? (int) sanitize_text_field( $_GET['postpage'] ) : 1;
	$more_button = '';
	if ( $blog_more_button == 'disable' ) {
		$more_button = 'disablemore ';
	}

	if ( $blog_category == '' ) {
		$category_array = '';
		$arrg           = array(
			'posts_per_page' => $blog_post_number,
			'paged'          => $postpage,
			'post_type'      => 'post',
		);
	} else {
		$category_array = explode( ',', $blog_category );
		$arrg           = array(
			'tax_query'      => array(
				array(
					'taxonomy' => 'category',
					'field'    => 'slug',
					'terms'    => $category_array,
				),
			),
			'posts_per_page' => $blog_post_number,
			'paged'          => $postpage,
			'post_type'      => 'post',
		);
	}

	$query = new WP_Query( $arrg );

	$postCount = $query->found_posts;
	$max       = ceil( $postCount / $blog_post_number );

	if ( $blog_column == '3' ) {
		$width = 100 / 3;
		$col   = 3;
	} else {
		$width = 100 / 4;
		$col   = 4;
	}

	ob_start();
	$kiteInlineStyle = '';
	$color           = '';
	if ( ! empty( $blog_background_color ) ) {
			$color            = $blog_background_color;
			$kiteInlineStyle .= ".$id .blog-masonry-container {background-color: $color;}";
	}

	$kiteInlineStyle .= ".$id .blog-masonry-container.kt_quote {background-color: $quote_blog_background_color;}";

	$kiteInlineStyle .= ".$id .blog-masonry-container .video-img{width:100%;}";

	$kiteInlineStyle .= ".$id .blog-masonry-container .blog-masonry-content .like-count,.$id .blog-masonry-container .blog-masonry-content .post-share:hover .share-hover i{color: $blog_background_color;}";

	$kiteInlineStyle .= ".$id .blog-masonry-container.kt_quote .icon,.$id .blog-masonry-container.kt_quote .blog-masonry-content .blog-excerpt,.$id .blog-masonry-container.kt_quote .blog-masonry-content .quote-author  {color: $quote_blog_text_color;}";
	wp_add_inline_style( 'kite-inline-style', $kiteInlineStyle );
	?>
	<div id="<?php echo esc_attr( $id ); ?>" class="blogloop <?php echo esc_attr( $id ); ?> masonry-blog isotope clearfix 
						<?php
						echo esc_attr( $more_button );
						echo esc_attr( $blog_style );
						?>
	 blogcolumn<?php echo esc_attr( $blog_column ); ?>  <?php
		if ( $enterance_animation != 'default' ) {
			echo 'has-animation';
			if ( $responsive_animation != '' ) {
				echo ' no-responsive-animation';}
		}
		?>
	 <?php echo esc_attr( $enterance_animation ); ?>" data-columnnumber="<?php echo esc_attr( $blog_column ); ?>" data-layoutmode="<?php echo esc_attr( $blog_layout_mode ); ?>" data-id="<?php echo esc_attr( $id ); ?>" data-page="1" data-maxpages="<?php echo esc_attr( $max ); ?>">

		<?php
		while ( $query->have_posts() ) {
			$i++;
			$query->the_post();
			global $post;

			if ( strlen( get_the_excerpt() ) > 100 ) {
				$subStr = '...';
			} else {
				$subStr = '';
			}

			$format = get_post_meta( get_the_ID(), 'media', true );
			if ( $thumb = wp_get_attachment_image_src( get_post_thumbnail_id(), 'Kite_thumbnail-auto-height' ) ) {
				$thumb = $thumb[0];
			} else {
				$thumb = get_the_post_thumbnail_url();
			}
			?>
		<div class="isotope-item">
			<div class="blog_item">
				<div class="blog-masonry-container kt_lightgallery <?php echo esc_attr( $blog_foreground_color ); ?> <?php echo 'kt_' . esc_attr( $format ); ?>" 
																			  <?php
																				if ( $format == 'quote' && ! ( empty( $thumb[0] ) ) ) {
																					?>
					 style="background-image:url(<?php echo esc_attr( $thumb ); ?>);" <?php } ?> >
				
					<?php
					if ( $format == 'audio' ) {

							$audio = get_post_meta( get_the_ID(), 'audio-url', true );
						?>
						 <?php
							if ( $audio != null ) {
								?>

								<?php if ( $blog_style == 'popup_interaction' ) { ?>

									<?php
									if ( $blog_image_size == 'large' ) {
										$thumb = wp_get_attachment_image_src( get_post_thumbnail_id(), 'large' );
									} else {
										$thumb = wp_get_attachment_image_src( get_post_thumbnail_id(), 'Kite_thumbnail-auto-height' );
									}
									if ( $thumb != false ) {
										$image = '<img src="data:image/gif;base64,R0lGODlhAQABAAAAACH5BAEKAAEALAAAAAABAAEAAAICTAEAOw==" width="' . esc_attr( $thumb[1] ) . '" height="' . esc_attr( $thumb[2] ) . '" class="attachment-post-thumbnail size-post-thumbnail wp-post-image" data-src="' . esc_url( $thumb[0] ) . '" alt="' . ( get_the_title( attachment_url_to_postid( $thumb[0] ) ) ? get_the_title( attachment_url_to_postid( $thumb[0] ) ) : '' ) . '" />';
									} else {
										$image = '<div class="cartblogaudioplaceholder"></div>';
									}
									?>

									<?php if ( $thumb != false ) { ?> 

									<div class="soundcloud-format galleryitem" data-iframe="true" data-src="https://w.soundcloud.com/player/?visual=true&url=<?php echo esc_attr( $audio ); ?>">
										<div class="image-container lazy-load lazy-load-on-load" style="padding-top:<?php echo kite_get_height_percentage( $image ); ?>%">
										   <div class="play-button-wrap">
												<a>
													<div class="play-button <?php echo esc_attr( $blog_multimedia_icon_style ); ?>">
														<span class="glyph icon icon-music-note3"></span>
													</div>
												</a>
											</div>
											<?php
											// Sanitization performed in above lines!
											echo '' . $image;
											?>
										</div>
									</div>

							<?php } ?> 

									<?php
								} else {

									echo do_shortcode( '[audio_soundcloud soundcloud_id="' . esc_attr( $audio ) . '"]' );

								}
								?>

						<?php } ?>
					
						<?php
					} elseif ( $format == 'gallery' ) {

						if ( $blog_image_size == 'large' ) {
							$thumb = wp_get_attachment_image_src( get_post_thumbnail_id(), 'large' );
						} else {
							$thumb = wp_get_attachment_image_src( get_post_thumbnail_id(), 'Kite_thumbnail-auto-height' );
						};
						$image = '<img src="data:image/gif;base64,R0lGODlhAQABAAAAACH5BAEKAAEALAAAAAABAAEAAAICTAEAOw==" width="' . esc_attr( $thumb[1] ) . '" height="' . esc_attr( $thumb[2] ) . '" class="attachment-post-thumbnail size-post-thumbnail wp-post-image" data-src="' . esc_url( $thumb[0] ) . '" alt="' . ( get_the_title( attachment_url_to_postid( $thumb[0] ) ) ? get_the_title( attachment_url_to_postid( $thumb[0] ) ) : '' ) . '" />';

						if ( $thumb != false ) {
							?>
							<div class="image-container lazy-load lazy-load-on-load" style="padding-top:<?php echo esc_attr( kite_get_height_percentage( $image ) ); ?>%">
								   <?php

									// Sanitization performed in above lines!
									echo '' . $image;
									?>
							</div>     
							 <?php
						} else {
							?>
							<!-- If we don't have images -->
							   <div class="cartblogplaceholder"></div>
						<?php } ?>
						<?php
					} elseif ( $format == 'video' ) {
						$videoUrl = get_post_meta( get_the_ID(), 'video-id', true );
						$host     = get_post_meta( get_the_ID(), 'video-type', true );

						if ( $blog_style == 'popup_interaction' ) {
							?>

							<?php

							if ( $blog_image_size == 'large' ) {
								$thumb = wp_get_attachment_image_src( get_post_thumbnail_id(), 'large' );
							} else {
								$thumb = wp_get_attachment_image_src( get_post_thumbnail_id(), 'Kite_thumbnail-auto-height' );
							}
							if ( $thumb != false ) {  // if set features image
								$image = '<img src="data:image/gif;base64,R0lGODlhAQABAAAAACH5BAEKAAEALAAAAAABAAEAAAICTAEAOw==" width="' . esc_attr( $thumb[1] ) . '" height="' . esc_attr( $thumb[2] ) . '" class="attachment-post-thumbnail size-post-thumbnail wp-post-image" data-src="' . esc_url( $thumb[0] ) . '" alt="' . ( get_the_title( attachment_url_to_postid( $thumb[0] ) ) ? get_the_title( attachment_url_to_postid( $thumb[0] ) ) : '' ) . '" />';
							}

							?>

							<?php if ( $thumb != false ) { // if set features image ?> 
								<div class="video-format"  data-id="<?php echo esc_attr( $id ); ?>"> 
									<div class="video_buttons_wrap">
										<a class="galleryitem" href="<?php echo esc_url( $videoUrl ); ?>">
											<div class="image-container lazy-load lazy-load-on-load" style="padding-top:<?php echo esc_attr( kite_get_height_percentage( $image ) ); ?>%">
												<?php
												// Sanitization performed in above lines!
												echo '' . $image;
												?>
											</div>
											<div class="play-button <?php echo esc_attr( $blog_multimedia_icon_style ); ?>">
												<span class="glyph icon  icon-play2"></span>
											</div>
										</a>
									</div>
								</div>

						   <?php } ?>

							<?php
						} else {

							  $video_display_type = "embeded_video_$host";
							if ( $video_display_type == 'local_video' ) {

							} elseif ( $video_display_type == 'embeded_video_vimeo' ) {
								?>

							<div data-id="<?php echo esc_attr( $id ); ?>">
								<?php echo do_shortcode( '[embed_video video_display_type="embeded_video_vimeo" video_vimeo_id="' . esc_attr( $videoUrl ) . '"]' ); ?>
							</div>  

								<?php
							} elseif ( $video_display_type == 'embeded_video_youtube' ) {

								// detect youtube id form url
								$video_id = explode( '?v=', $videoUrl ); // For videos like http://www.youtube.com/watch?v=...
								if ( empty( $video_id[1] ) ) {
									$video_id = explode( '/v/', $videoUrl ); // For videos like http://www.youtube.com/watch/v/..
								}
								if ( ! empty( $video_id[1] ) ) {
									 $video_id = explode( '&', $video_id[1] ); // Deleting any other params
									 $video_id = $video_id[0];
								} else {
									$video_id = $videoUrl;
								}

								?>

						 
							<div data-id="<?php echo esc_attr( $id ); ?>">

								<?php
								  $el_aspect = 'vc_video-aspect-ratio-169';
								?>

								  <div class="wpb_video_widget wpb_content_element vc_clearfix <?php echo esc_attr( $el_aspect ); ?>">
									<div class="wpb_wrapper">
										<div class="wpb_video_wrapper"> 
										<?php echo wp_oembed_get( 'https://www.youtube.com/watch?v=' . $video_id ); ?>
										</div>
									</div>
								</div>
							</div>

								<?php
							}
						}
					} elseif ( $format == 'quote' ) {
						?>
							
						<?php
					} else { // format is standard or combined formats like(video/sound)
						if ( has_post_thumbnail() ) {
							if ( $blog_image_size == 'large' ) {
								$thumb = wp_get_attachment_image_src( get_post_thumbnail_id(), 'large' );
							} else {
								$thumb = wp_get_attachment_image_src( get_post_thumbnail_id(), 'Kite_thumbnail-auto-height' );
							};
							 $image = '<img src="data:image/gif;base64,R0lGODlhAQABAAAAACH5BAEKAAEALAAAAAABAAEAAAICTAEAOw==" width="' . esc_attr( $thumb[1] ) . '" height="' . esc_attr( $thumb[2] ) . '" class="attachment-post-thumbnail size-post-thumbnail wp-post-image" data-src="' . esc_url( $thumb[0] ) . '" alt="' . ( get_the_title( attachment_url_to_postid( $thumb[0] ) ) ? get_the_title( attachment_url_to_postid( $thumb[0] ) ) : '' ) . '" />';

							?>
								<div class="image-container lazy-load lazy-load-on-load" style="padding-top:<?php echo esc_attr( kite_get_height_percentage( $image ) ); ?>%">
								   <?php
									// Sanitization performed in above lines!
									echo '' . $image;
									?>
								</div>     
							 <?php
						} else {
							?>
						 <!-- If we don't have images -->
							   <div class="cartblogplaceholder"></div>
							<?php
						}
					}

					if ( $format == 'quote' ) {
						echo '<a class="quote-wrap-link" href="' . esc_url( get_the_permalink() ) . '">';
					}
					?>
					<div class="blog-masonry-content">
					
						<?php if ( $format != 'quote' ) { ?>
							<span class="blog-details">
							<?php
							if ( $blog_category_visibility == 'yes' ) {
								$terms      = get_the_category( $post->ID );
								$catcounter = 0;
								if ( $terms ) {
									foreach ( $terms as $term ) {

										$catcounter++;
										if ( $catcounter < 2 && ( ( $term->cat_name ) != 'Uncategorized' ) ) {
											?>
									<span class="blog-cat">
									   <a href="<?php echo esc_url( get_category_link( get_cat_ID( $term->cat_name ) ) ); ?>" title='<?php echo esc_attr( $term->cat_name ); ?>'>
											<?php echo esc_attr( $term->cat_name ); ?>
									   </a>
									</span>
											<?php
										}
									}
								}
							}
							?>
							</span>
							<?php
						}
						$archive_year  = get_the_time( 'Y' );
						$archive_month = get_the_time( 'm' );
						$archive_day   = get_the_time( 'd' );

						?>
						
						<?php if ( $format != 'quote' ) { ?>
						<a class="link_to_details" href="<?php the_permalink(); ?>">
							<h2 class="blog-title"> <?php the_title(); ?></h2>
							<span class="blog-date">
								<span><?php the_time( get_option( 'date_format' ) ); ?></span>
							</span>
							<p class="blog-excerpt"> <?php echo mb_substr( get_the_excerpt(), 0, 100 ) . $subStr; ?></p>
							</a>
							<?php
						} else {

							$quote_content = get_post_meta( get_the_ID(), 'quote_content', true );
							$quote_author  = get_post_meta( get_the_ID(), 'quote_author', true );
							if ( ! empty( $quote_content ) && ! empty( $quote_author ) ) {
								echo '<div class="icon kt-icon icon-quotes-right"></div>';
							}
							?>
							
							<p class="blog-excerpt"> <?php echo esc_html( $quote_content ); ?></p>
							<p class="quote-author"> <?php echo esc_html( $quote_author ); ?></p>
							<?php
						}
						?>
					</div>
					<?php
					if ( $format == 'quote' ) {
						echo '</a>';
					}

					if ( $format != 'quote' ) {
						?>
						<?php if ( $blog_category_author == 'yes' ) { ?>
							<div class="post-author-meta">

								<span class="kt-icon icon-user"></span>
								<span class="post-author "><?php the_author_posts_link(); ?></span>
								<span class="kt-icon icon-bubble"></span>
								<span class="meta-comment-count"><a href="<?php comments_link(); ?>"> <?php comments_number( esc_html__( '0', 'pinkmart' ), esc_html__( '1', 'pinkmart' ), esc_html__( '%', 'pinkmart' ) ); ?></a></span>

							</div>
						<?php } ?>

					<?php } ?>
					</div>
				</div>
			</div>
			<?php } ?>
		</div>
				<?php if ( $max > 1 ) { ?>
				<!-- Single Page Navigation-->
				<div class="pagenavigation cartblog clearfix <?php echo esc_attr( $load_more_style ); ?>">
					<div class="navNext"><?php next_posts_link( esc_html__( '&larr; Older Entries', 'pinkmart' ) ); ?></div>
					<div class="navPrevious"><?php previous_posts_link( esc_html__( 'Newer Entries &rarr;', 'pinkmart' ) ); ?></div>
				</div>
				<?php } ?>


	<?php
	wp_reset_postdata();

	return ob_get_clean();

}
/*-----------------------------------------------------------------------------------*/
/*  LookBook - Popup Reveal
/*-----------------------------------------------------------------------------------*/
function kite_lookbook_popup_reveal( $atts ) {
	extract(
		shortcode_atts(
			array(
				'title'                    => '',
				'title_font_size'          => '16',
				'title_font_type'          => '',
				'google_fonts'             => '',
				'title_custom_font_size'   => '',
				'title_custom_line_height' => '',
				'title_color'              => '#000',
				'title_hover_color'        => '#000',
				'img_id'                   => '',
				'image_size'               => 'shop_catalog',
				'custom_image_size'        => 'disable',
				'custom_image_width'       => '',
				'custom_image_height'      => '',
				'link_url'                 => '',
				'new_tab'                  => false,
				'alignment'                => 'center',
				'image_animation'          => 2,
			),
			$atts
		)
	);

	$id = kite_sc_id( 'lkbk_popup_reveal' );

	if ( empty( $title ) || ! is_numeric( $img_id ) ) {
		return;
	}
	$img_url = wp_get_attachment_image_src( $img_id, $image_size );
	if ( ! $img_url ) {
		return;
	}
	$style                           = '';
	$title_google_fonts_inline_style = '';
	if ( $title_font_type != 'default' && function_exists( 'kite_get_fonts_data' ) ) {
		$google_fonts_data               = kite_get_fonts_data( $google_fonts );
		$title_google_fonts_inline_style = kite_google_fonts_styles( $google_fonts_data );
		kite_enqueue_google_fonts( $google_fonts_data );
	}
	$style          .= $title_google_fonts_inline_style;
	$kiteInlineStyle = '';
	if ( $title_font_size == 'custom' && ! empty( $title_custom_font_size ) ) {
		$contentSelector  = "#$id.imagepopupreveal a";
		$kiteInlineStyle .= kite_responsive_font_size( $contentSelector, $title_custom_font_size, $title_custom_line_height );
	}

	if ( empty( $link_url ) ) {
		$link_url = '#';
	}

	if ( $new_tab && $link_url != '#' ) {
		$new_tab = "target='_blank'";
	} else {
		$new_tab = '';
	}

	if ( ! empty( $title_color ) ) {
		$kiteInlineStyle .= "#$id.imagepopupreveal > a{color:$title_color;}";
		$kiteInlineStyle .= "#$id.imagepopupreveal > a:after{background-color:$title_color;}";
	}
	if ( ! empty( $title_hover_color ) ) {
		$kiteInlineStyle .= "#$id.imagepopupreveal > a:hover{color:$title_hover_color !important;}";
		$kiteInlineStyle .= "#$id.imagepopupreveal > a:hover:after{background-color:$title_hover_color;}";
	}
	if ( $custom_image_size == 'enable' ) {
		if ( ! empty( $custom_image_width ) && is_numeric( trim( $custom_image_width ) ) ) {
			$kiteInlineStyle .= "#$id.imagepopupreveal .hover-reveal{width:" . trim( $custom_image_width ) . 'px;}';
		}
		if ( ! empty( $custom_image_height ) && is_numeric( trim( $custom_image_height ) ) ) {
			$kiteInlineStyle .= "#$id.imagepopupreveal .hover-reveal{height:" . trim( $custom_image_height ) . 'px;}';
		}
	}
	wp_add_inline_style( 'kite-inline-style', $kiteInlineStyle );
	$GLOBALS['imageReveal'] = true;
	ob_start();
	?>
	<span id="<?php echo esc_attr( $id ); ?>" class='imagepopupreveal <?php echo esc_html( $alignment ); ?>' data-fx='<?php echo esc_attr( $image_animation ); ?>'><a class="<?php echo 'fontsize' . $title_font_size; ?>" href="<?php echo esc_url( $link_url ); ?>" <?php echo '' . $new_tab; ?> data-img="<?php echo esc_attr( $img_url[0] ); ?>" ><?php echo esc_html( $title ); ?></a></span>
	<?php
	wp_enqueue_script( 'gsap' );
	wp_enqueue_script( 'kite-reveal' );
	return ob_get_clean();
}
/*-----------------------------------------------------------------------------------*/
/*  LookBook - FullScreen Reveal
/*-----------------------------------------------------------------------------------*/
function kite_lookbook_fullscreen_reveal( $atts ) {
	extract(
		shortcode_atts(
			array(
				'title'                    => '',
				'title_font_size'          => '16',
				'title_font_type'          => '',
				'google_fonts'             => '',
				'title_custom_font_size'   => '',
				'title_custom_line_height' => '',
				'title_color'              => '#000',
				'title_hover_color'        => '#000',
				'imgs_id'                  => '',
				'link_url'                 => '',
				'new_tab'                  => '',
				'alignment'                => 'center',
			),
			$atts
		)
	);

	$id = kite_sc_id( 'lkbk_fullscreen_reveal' );

	if ( empty( $title ) ) {
		return;
	}

	$imgs_id = explode( ',', $imgs_id );
	foreach ( $imgs_id as $key => $img_id ) {
		$imgs_url[] = wp_get_attachment_image_src( $img_id, 'full' );
	}
	if ( empty( $imgs_url ) || ! $imgs_url ) {
		return;
	}

	$style                           = '';
	$title_google_fonts_inline_style = '';
	if ( $title_font_type != 'default' && function_exists( 'kite_get_fonts_data' ) ) {
		$google_fonts_data               = kite_get_fonts_data( $google_fonts );
		$title_google_fonts_inline_style = kite_google_fonts_styles( $google_fonts_data );
		kite_enqueue_google_fonts( $google_fonts_data );
	}
	$style          .= $title_google_fonts_inline_style;
	$kiteInlineStyle = '';
	if ( $title_font_size == 'custom' && ! empty( $title_custom_font_size ) ) {
		$contentSelector  = "#$id.imagefullscreenreveal a";
		$kiteInlineStyle .= kite_responsive_font_size( $contentSelector, $title_custom_font_size, $title_custom_line_height );
	}

	if ( empty( $link_url ) ) {
		$link_url = '#';
	}

	if ( $new_tab == 'enable' && $link_url != '#' ) {
		$new_tab = "target='_blank'";
	} else {
		$new_tab = '';
	}

	if ( ! empty( $title_color ) ) {
		$style           .= "color:$title_color;";
		$kiteInlineStyle .= "#$id.imagefullscreenreveal:after{background-color:$title_color;}";
	}
	if ( ! empty( $title_hover_color ) ) {
		$kiteInlineStyle .= "#$id.imagefullscreenreveal > span:hover a{color:$title_hover_color !important;}";
	}
	wp_add_inline_style( 'kite-inline-style', $kiteInlineStyle );
	ob_start();
	?>
	<div id="<?php echo esc_attr( $id ); ?>" class='imagefullscreenreveal <?php echo esc_html( $alignment ); ?>'>
		<span data-fx='2'><a class="<?php echo 'fontsize' . $title_font_size; ?>" href="<?php echo esc_url( $link_url ); ?>" <?php echo '' . $new_tab; ?> style="<?php echo '' . $style; ?>"><?php echo esc_html( $title ); ?></a></span>
		<div class="swiper-container">
			<div class="swiper-wrapper">
				<?php
				foreach ( $imgs_url as $key => $img ) {
					?>
					<div class="swiper-slide"><div class="img" style="background-image: url(<?php echo '' . $img[0]; ?>); "></div></div>
					<?php
				}
				?>
			</div>
		</div>
	</div>
	<?php
	return ob_get_clean();
}
/*-----------------------------------------------------------------------------------*/
/*  Blog - HeadLine Blog Feed Style
/*-----------------------------------------------------------------------------------*/
function kite_sc_head_line_blog( $atts ) {
	extract(
		shortcode_atts(
			array(
				'blog_description'         => 'enable',
				'blog_category'            => '',
				'blog_category_visibility' => 'enable',
				'blog_post_number'         => '8',
				'blog_more_button'         => 'disable',
				'image_size'               => 'shop_catalog',
				'custom_image_size'        => 'disable',
				'custom_image_width'       => '',
				'custom_image_height'      => '',
				'image_animation'          => 2,
			),
			$atts
		)
	);
	$kiteInlineStyle = '';
	$query           = $width = $subStr = $col = $id = '';

	$i = 0;

	$id          = kite_sc_id( 'blog-head-line' );
	$postpage    = isset( $_GET['postpage'] ) ? (int) sanitize_text_field( $_GET['postpage'] ) : 1;
	$more_button = '';
	if ( $blog_more_button == 'disable' ) {
		$more_button = 'disablemore ';
	}

	if ( $blog_category == '' ) {
		$category_array = '';
		$arrg           = array(
			'posts_per_page' => $blog_post_number,
			'paged'          => $postpage,
			'post_type'      => 'post',
		);
	} else {
		$category_array = explode( ',', $blog_category );
		$arrg           = array(
			'tax_query'      => array(
				array(
					'taxonomy' => 'category',
					'field'    => 'slug',
					'terms'    => $category_array,
				),
			),
			'posts_per_page' => $blog_post_number,
			'paged'          => $postpage,
			'post_type'      => 'post',
		);
	}

	$query = new WP_Query( $arrg );

	$postCount = $query->found_posts;
	$max       = ceil( $postCount / $blog_post_number );

	if ( $custom_image_size == 'enable' ) {
		if ( ! empty( $custom_image_width ) ) {
			$kiteInlineStyle .= "#$id.blog-head-line-container .hover-reveal{width:" . $custom_image_width . 'px;}';
		}
		if ( ! empty( $custom_image_height ) ) {
			$kiteInlineStyle .= "#$id.blog-head-line-container .hover-reveal{height:" . $custom_image_height . 'px;}';
		}
	}
	wp_add_inline_style( 'kite-inline-style', $kiteInlineStyle );

	ob_start();
	?>
	<div id="<?php echo esc_attr( $id ); ?>" class="blog-head-line-container <?php echo esc_attr( $more_button ); ?>" data-page="1" data-maxpages="<?php echo esc_attr( $max ); ?>" data-id="<?php echo esc_attr( $id ); ?>">          
	<?php
	while ( $query->have_posts() ) {
		$i++;
		$query->the_post();
		global $post;
		if ( has_post_thumbnail() ) {
			$thumb_url = wp_get_attachment_image_src( get_post_thumbnail_id(), $image_size );
		} else {
			$thumb_url = array( 0 => false );
		}
		?>
		<div <?php post_class( array( 'blog-head-line-item' ) ); ?>>
			<h2 class="blog-head-line-title" 
			<?php
			if ( $thumb_url[0] ) {
				echo "data-fx='" . esc_attr( $image_animation ) . "'";}
			?>
			><a href="<?php the_permalink(); ?>" 
								   <?php
									if ( $thumb_url[0] ) {
													echo "data-img='$thumb_url[0]'";}
									?>
><?php the_title(); ?></a></h2>
			<div class="blog-head-line-description">
			<?php
			if ( has_excerpt() && $blog_description != 'disable' ) {
				the_excerpt();
			}
			?>
				<div class="blog-head-line-details">
					<span><a href="<?php the_permalink(); ?>"><?php the_time( get_option( 'date_format' ) ); ?></a></span>
					<span><span class="icon icon-user"></span><?php echo '<a href="' . esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ) . '">' . esc_html( get_the_author_meta( 'display_name' ) ) . '</a>'; ?></span>
					<span><span class="icon icon-comment-o"></span><?php echo get_comments_number(); ?></span>
				</div>
				<?php if ( has_category() && $blog_category_visibility != 'disable' ) { ?>
					<div class="blog-head-line-cats">
						<?php
						$terms = get_the_category( $post->ID );
						foreach ( $terms as $term ) {
							echo "<span><a href='" . get_category_link( $term->term_id ) . "'>$term->name</a></span>";
						}
						?>
					</div>
				<?php } ?>
			</div>
		</div>
		<?php
	}
	?>
	</div>
	<?php if ( $max > 1 ) { ?>
	<!-- Single Page Navigation-->
	<div class="pagenavigation readmore-blog clearfix">
		<div class="navNext"><?php next_posts_link( esc_html__( '&larr; Older Entries', 'pinkmart' ) ); ?></div>
		<div class="navPrevious"><?php previous_posts_link( esc_html__( 'Newer Entries &rarr;', 'pinkmart' ) ); ?></div>
	</div>
	<?php } ?>
	<?php
	wp_reset_query();
	wp_reset_postdata();
	$result = ob_get_clean();
	wp_enqueue_script( 'gsap' );
	wp_enqueue_script( 'kite-reveal' );
	return $result;
}
/*-----------------------------------------------------------------------------------*/
/*  Blog - Toggle Blog
/*-----------------------------------------------------------------------------------*/
function kite_sc_toggle_blog( $atts ) {
	extract(
		shortcode_atts(
			array(
				'blog_description'         => 'enable',
				'blog_category'            => '',
				'blog_category_visibility' => 'enable',
				'blog_post_number'         => '8',
				'blog_more_button'         => 'disable',
				'load_more_style'          => 'dark',
			),
			$atts
		)
	);

	$query = $id = '';

	$i = 0;

	$id       = kite_sc_id( 'blog-toggle' );
	$postpage = isset( $_GET['postpage'] ) ? (int) sanitize_text_field( $_GET['postpage'] ) : 1;

	$class = array();

	if ( $blog_more_button == 'disable' ) {
		$class[] = 'disablemore ';
	}

	if ( $blog_category_visibility == 'disable' ) {
		$class[] = 'disablecat ';
	}

	if ( $blog_description == 'disable' ) {
		$class[] = 'disabledesc ';
	}

	if ( $blog_category == '' ) {
		$category_array = '';
		$arrg           = array(
			'posts_per_page' => $blog_post_number,
			'paged'          => $postpage,
			'post_type'      => 'post',
		);
	} else {
		$category_array = explode( ',', $blog_category );
		$arrg           = array(
			'tax_query'      => array(
				array(
					'taxonomy' => 'category',
					'field'    => 'slug',
					'terms'    => $category_array,
				),
			),
			'posts_per_page' => $blog_post_number,
			'paged'          => $postpage,
			'post_type'      => 'post',
		);
	}
	$query     = new WP_Query( $arrg );
	$postCount = $query->found_posts;
	$max       = ceil( $postCount / $blog_post_number );

	ob_start();
	?>
	<div id="<?php echo esc_attr( $id ); ?>" class="blog-toggle-container <?php echo implode( ' ', $class ); ?>" data-page="1" data-maxpages="<?php echo esc_attr( $max ); ?>" data-id="<?php echo esc_attr( $id ); ?>">          
	<?php
	while ( $query->have_posts() ) {
			$i++;
			$query->the_post();
			global $post;
			get_template_part( 'templates/loop', 'blog' );
	}
	?>
	</div>
	<?php if ( $max > 1 ) { ?>
	<!-- Single Page Navigation-->
		<div class="pagenavigation readmore-blog clearfix <?php echo esc_attr( $load_more_style ); ?>">
			<div class="navNext"><?php next_posts_link( esc_html__( '&larr; Older Entries', 'pinkmart' ) ); ?></div>
			<div class="navPrevious"><?php previous_posts_link( esc_html__( 'Newer Entries &rarr;', 'pinkmart' ) ); ?></div>
		</div>
		<?php
	}
	wp_reset_postdata();

	return ob_get_clean();
}

function kite_sc_text_slider( $atts ) {

	$defaults = array(
		'text_slides' 	=> array(), // [ 0 => [ text => value, icon => value, style => [ prop => value ] ] ]
		'wrap_style'	=> array(), // [ prop => value, prop => value ]
		'next_icon'		=> 'long-arrow-right',
		'prev_icon'		=> 'long-arrow-left',
		'classes'		=> array(),
	);
	extract( wp_parse_args( $atts, $defaults ) );

	if ( empty( $text_slides ) ) {
		return;
	}

	$id = kite_sc_id( 'text_slider' );

	ob_start();
	?>
	<div id="<?php echo esc_attr( $id );?>" class="kt-text-slider-container no-gutter carousel" data-autoplay="on">
		<div class="swiper-container" data-visibleitems="1">
			<div class="swiper-wrapper">
			<?php
			foreach( $text_slides as $slide ) {
				echo '<div class="swiper-slide">';
				if ( ! empty( $slide['icon'] ) ) {
					echo '<span class="icon icon-' . $slide['icon'] . '"></span>';
				}
				echo '<span class="kt-slider-text">' . wp_kses( $slide['text'], $GLOBALS['kite-allowed-tags'] ) . '</span>';
				echo '</div>';
			}
			?>
			</div>
		</div>
		<span class="icon icon-<?php echo esc_attr( $prev_icon ); ?> kt-prev-btn"></span>
    	<span class="icon icon-<?php echo esc_attr( $next_icon ); ?> kt-next-btn"></span>
	</div>
	<?php

	return ob_get_clean();
}
